@@ -587,7 +587,6 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
                 }
             } else if(RFDoptions$type == "RFD_MAX")
             {
-                
                 if (RFDoptions$rfdFunction == "FITTED")
                 {
                     #max is always in the initial point.
@@ -625,10 +624,40 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
                     
                 }
                 
-            }
-            
+            } else if(RFDoptions$type == "BEST_AVG_RFD_IN_X_MS")
+            {
+                window = RFDoptions$start / 1000
+                print("detected BEST_AVG_RFD_IN_X_MS")
+                if (RFDoptions$rfdFunction == "FITTED")
+                {
+                    print("FITTED")
+                    #In the model the max RFD is always the RFD0
+                    time1 = dynamics$time[dynamics$startSample]
+                    # print(paste("In drawDynamics time1:", time1))
+                    time2 = time1 + window
+                    force1 = 0
+                    force2 = dynamics$fmax.fitted*(1 - exp(-dynamics$k.fitted*window))
+                    RFD = force2 / window
+                    legendText = c(legendText, paste("RFD max avg in ", RFDoptions$start, "ms = ", round(RFD, digits = 1), " N/s", sep = ""))
+                    legendColor = c(legendColor, "blue")
+                } else if(RFDoptions$rfdFunction == "RAW")
+                {
+                    maxAvgRFD = getAvgRfdXSeconds(dynamics, window )
+                    force1 = maxAvgRFD$force1
+                    
+                    time1 = maxAvgRFD$time1
+                    time2 = maxAvgRFD$time2
+                    force1 = maxAvgRFD$force1
+                    force2 = maxAvgRFD$force2
+                    RFD = maxAvgRFD$RFD
+                    legendColor = c(legendColor, "black")
+                    legendText = c(legendText, paste("RFD max avg in  ", RFDoptions$start, "ms = ", round(RFD, digits = 1), " N/s", sep = ""))
+                }
+	        }
+
             #The Y coordinate of the line when it crosses the Y axis
             intercept = force1 - RFD * time1
+            print(paste("Intercetp:", intercept))
             
             #The slope of the line seen in the screen(pixels units), NOT in the time-force units
             windowSlope = RFD*(plotHeight/yHeight)/(plotWidth/xWidth)
@@ -651,6 +680,9 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
 
     exportValues = c(exportValues, impulse)
 
+    #adding also model error
+    exportValues = c(exportValues, dynamics$meanError)
+
     if(impulseLegend != ""){
         legendText = c(legendText, impulseLegend)
         legendColor = c(legendColor, impulseColor)
@@ -663,7 +695,15 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
     } else {
         legendColor = c(legendColor, "grey40")
     }
-    
+
+    #experimental avg error on RFD calculation from 0 to 50 ms
+    #window = RFDoptions$start / 1000
+    #force2 = dynamics$fmax.fitted*(1 - exp(-dynamics$k.fitted*window))
+    #modelRFD=force2/0.05
+    #rawRFD = getAvgRfdXSeconds(dynamics, 0.05 )$RFD
+    #legendText = c(legendText, paste("RFD0-50 error = ", round((rawRFD - modelRFD)*100/rawRFD, 2), "%"))
+    #legendColor = c(legendColor, "grey20")
+
     legend(x = xmax, y = dynamics$fmax.fitted/2, legend = legendText, xjust = 1, yjust = 0.1, text.col = legendColor)
 
     if(op$singleOrMultiple == "FALSE")
@@ -672,6 +712,35 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
     }
 }
 
+getAvgRfdXSeconds <-function(dynamics, window)
+{
+    print("In getAvgRfdxSeconds")
+    RFD = 0
+    
+    #if window does not fit in graph, discard it
+    if (dynamics$time[dynamics$startSample] + window > dynamics$time[dynamics$endSample])
+        next
+    #Measure how much samples corresponds to the window
+    time = dynamics$time[dynamics$startSample:dynamics$endSample]
+    windowSamples = which.min(time - (dynamics$time[dynamics$startSample] + window))
+    for (i in dynamics$startSample:(dynamics$endSample - windowSamples))
+    {
+        forceTemp1 = dynamics$f.raw[i]
+        forceTemp2 = interpolateXAtY(dynamics$f.raw, dynamics$time, dynamics$time[i] + window)
+        RFDtemp = (forceTemp2 - forceTemp1) / window
+        
+        if (RFDtemp > RFD)
+        {
+            force1 = forceTemp1
+            force2 = forceTemp2
+            RFD = RFDtemp
+            time1 = dynamics$time[i]
+            time2 = interpolateXAtY(dynamics$time, dynamics$time, dynamics$time[i] + window)
+        }
+    }
+    return(list(RFD = RFD, time1 = time1, force1 = force1, time2 = time2, force2=force2))
+}
+
 #getDynamicsFromLoadCellFolder <- function(folderName, resultFileName, captureOptions)
 #{
 #    originalFiles = list.files(path=folderName, pattern="*")
@@ -681,7 +750,7 @@ drawDynamicsFromLoadCell <- function(title, exercise, datetime,
 #                        "rfd0.fitted", "rfd100.raw", "rfd0_100.raw", "rfd0_100.fitted",
 #                        "rfd200.raw", "rfd0_200.raw", "rfd0_200.fitted",
 #                        "rfd50pfmax.raw", "rfd50pfmax.fitted")
-#    
+
 #    results[,"fileName"] = originalFiles
 #    
 #    for(i in 1:nFiles)
@@ -1048,9 +1117,9 @@ readRFDOptions <- function(optionsStr)
         
         return(list(
             rfdFunction     = options[1],            # raw or fitted
-            type            = options[2],            # instantaeous, average, %fmax, rfdmax
+            type            = options[2],            # instantaneous, average, %fmax, rfdmax, BEST_AVG_RFD_IN_X_MS
             #start and end can be in milliseconds (instant and average RFD), percentage (%fmax) or -1 if not needed
-            start           = as.numeric(options[3]),            # instant at which the analysis starts
+            start           = as.numeric(options[3]),            # instant at which the analysis starts (or time window in BEST_AVG_RFD)
             end             = as.numeric(options[4])             # instant at which the analysis ends
         ))
     } 
@@ -1171,6 +1240,8 @@ start <- function(op)
 		if(impulseOptions$impulseFunction != "-1")
 			exportModelVectorOnFail = c(exportModelVectorOnFail, NA) 		#impulse
 
+		exportModelVectorOnFail = c(exportModelVectorOnFail, NA) 		#model error
+
 		#preparing header row (each set will have this in the result dataframe to be able to combine them)
 		maxAvgWindowSecondsHeader = op$maxAvgWindowSeconds
 		if(op$decimalCharAtExport == ",")
@@ -1189,6 +1260,7 @@ start <- function(op)
 			exportNames = c(exportNames, paste("Impulse", impulseOptions$impulseFunction, impulseOptions$type,
 					impulseOptions$start, impulseOptions$end, sep ="_"))
 
+		exportNames = c(exportNames, "Model mean error (%)")
 		exportNames = c(exportNames, "Comments (set)")
 
 		if(op$includeImagesOnExport)
