@@ -52,9 +52,19 @@ fixDatetime <- function(str)
 }
 
 #Function to get the interpolated x at a given y
-interpolateXAtY <- function(X, Y, desiredY){
-    # print(paste("finding the X at desiredY:", desiredY))
-        if(max(Y) < desiredY){
+interpolateXAtY <- function(X, Y, desiredY, debug = FALSE)
+{
+    if(debug)
+    {
+        print("    In interpolate...")
+        print("    X:")
+        print(X)
+        print("    Y:")
+        print(Y)
+    # 	print(paste("finding the X at desiredY:", desiredY))
+    	#print(paste("max(Y):", max(Y)))
+    }
+	if(max(Y) < desiredY){
                 # print("desiredY is greater than max(Y)")
                 return(max(Y))
         }
@@ -79,63 +89,36 @@ interpolateXAtY <- function(X, Y, desiredY){
 }
 
 
-#Calculate the area under a curve using the cross product of consecutive vectors with the origin in the first point
+#Calculate the area under a curve using the cross product of consecutive vectors with the origin of each vector in the first point
 getAreaUnderCurve <- function(x, y)
 {
-        print("Calculating Area")
-        # print("X:")
-        # print(x)
-        # print("Y:")
-        # print(y)
-        x = c(x, x[length(x)], x[1])
-        y = c(y, 0, 0)
+        #Adding a starting point at (x[1], 0) and last point at (x[last], 0)
+        x = c(x[1], x, x[length(x)])
+        y = c(0,y, 0)
         totalArea = 0
-        # print(paste("V",1," = ", "(",x[1 + 1] - x[1],",", y[1 + 1] - y[1], ")", sep = ""))
-        for(i in 2:(length(x) -1))
-        {
-                parallelogramArea = ((x[i + 1] - x[1])* (y[i] - y[1]) - (x[i] - x[1]) * (y[i+1] - y[1]))
-                
-                # print(paste("V",i," = ", "(",x[i + 1] - x[1],",", y[i + 1] - y[1], ")", sep = ""))
-                # print(parallelogramArea/2)
-                
-                totalArea = totalArea + parallelogramArea
-        }
-        # print(paste("toalArea:", totalArea/2))
-        return(totalArea/2) #The area of the parallelograms are twice the triangles areas
-}
-
-getAreaUnderCurve2 <- function(x, y)
-{
+        
         # print("Calculating Area")
         # print("X:")
         # print(x)
         # print("Y:")
         # print(y)
-
-        totalArea = 0
+        
         # print(paste("V",1," = ", "(",x[1 + 1] - x[1],",", y[1 + 1] - y[1], ")", sep = ""))
-        for(i in 1:length(x))
+        for(i in 2:(length(x) -1))
         {
-                barArea = y[i]*(x[i+1] - x[i])
-                
-                # print(paste("V",i," = ", "(",x[i + 1] - x[1],",", y[i + 1] - y[1], ")", sep = ""))
-                # print(parallelogramArea/2)
-                
-                totalArea = totalArea + barArea
+                parallelogramArea = ((x[i + 1] - x[1])* (y[i] - y[1]) - (x[i] - x[1]) * (y[i+1] - y[1]))
+                #print(paste("V",i," = ", "(",x[i + 1] - x[1],",", y[i + 1] - y[1], ") = " , parallelogramArea / 2, sep = ""))
+
+                totalArea = totalArea + parallelogramArea/2     #The area of the parallelograms are twice the triangles areas
         }
-        # print(paste("toalArea:", totalArea/2))
-        return(totalArea/2) #The area of the parallelograms are twice the triangles areas
+        #print(paste("toalArea:", totalArea))
+        return(totalArea)
 }
 
 #Calculates the mean of a curve interval
-getMeanValue <- function(X, Y, startX, endX)
+getMeanValue <- function(X, Y, startX, endX, debug = FALSE)
 {
-        # print(paste("Calculating mean in the X range of [", startX, ",", endX, "]"))
-        # print("x:")
-        # print(X)
-        # print("y:")
-        # print(Y)
-        
+
         #Calculating the value of Y corresponding at startX
         #print("Calculating the first Y value")
         startY = interpolateXAtY(X = Y, Y = X, desiredY = startX) #The order are changed because we are looking for the Y value instead of X value
@@ -143,17 +126,41 @@ getMeanValue <- function(X, Y, startX, endX)
         #Calculating the last value using the interpolation
         #print("Calculating the last Y value")
         endY = interpolateXAtY(X = Y, Y = X, desiredY = endX) #The order are changed because we are looking for the Y value instead of X value
-
-        X = X[which(X > startX & X < endX)]
+        
+        #trimming X to the values that are between startX and endX
+        selectedRange = which(X > startX & X < endX)
+        X = X[selectedRange]
+        #Adding Xs of the limits
         X = c(startX, X, endX)
         
-        Y = Y[which(X > startX & X < endX)]
+        #trimming Y to the values that are between startY and endY
+        Y = Y[selectedRange]
+        #Adding Ys of the limits
         Y = c(startY, Y, endY)
+        if (debug){
+            print("    In getMeanValue:")
+            print(paste("    startX:", startX))
+            print(paste("    endX:", endX))
+            print(paste("    startY:", startY))
+            print(paste("    endY:", endY))
+            print(paste("Calculating mean in the X range of [", startX, ",", endX, "]"))
+            print("x:")
+            print(X)
+            print("y:")
+            print(Y)
+        }
+        
+        # print("Xs in getMeanValue():")
+        # print(X)
+        # print("Ys in getMeanValue():")
+        # print(Y)
+        
         
         #calculating the area under the curve (integral)
         area = getAreaUnderCurve(X , Y)
 
-        return(area / (X[length(X)] - X[1]))
+        #The mean value is the area under the curve divided by the lenth in the X axis of the curve
+        return(area / (last(X) - X[1]))
 }
 
 prepareGraph <- function(os, pngFile, width, height)
@@ -173,3 +180,7 @@ endGraph <- function()
 {
         dev.off()
 }
+
+last <- function(input) {
+    return( tail(input, n=1) )
+}
\ No newline at end of file
