@@ -61,8 +61,45 @@ public class ChronoJump
 	static extern bool g_setenv (String env, String val, bool overwrite);
 #endif
 
-	public static void Main(string [] args) 
-	{/*
+	public static void Main(string [] args)
+	{
+		//record GetOsEnum on variables to not call it all the time
+		operatingSystem = UtilAll.GetOSEnum();
+		Util.operatingSystem = operatingSystem;
+
+		//show version on console and exit before the starting logs
+		//note version, version2 args are available since: 2.2.0-112-ga4eaadcbc
+		if(args.Length > 0 && (args[0] == "version" || args[0] == "version2"))
+		{
+			if(args[0] == "version")
+			{
+				Console.WriteLine("Chronojump version: " + BuildInfo.chronojumpVersion);
+				if(operatingSystem == UtilAll.OperatingSystems.LINUX)
+					Console.WriteLine("Note in Linux is not reliable if ./autogen.sh was not un before make");
+
+				if(File.Exists(System.IO.Path.Combine(Util.GetDatabaseDir(), "chronojump.db"))) {
+					try {
+						Sqlite.Connect();
+						Console.WriteLine("Chronojump DB version: " +
+								SqlitePreferences.Select("databaseVersion", false));
+						Sqlite.DisConnect();
+					}
+					catch {
+						Console.WriteLine("Cannot check DB version, failed checking");
+						Sqlite.DisConnect();
+					}
+				} else
+					Console.WriteLine("Cannot check DB version, chronojump.db not found on: " + System.IO.Path.Combine(Util.GetDatabaseDir()));
+			}
+			else // (args[0] == "version2")
+			{
+				Console.WriteLine(BuildInfo.chronojumpVersion.ToString());
+			}
+
+			return;
+		}
+
+		/*
 		bool timeLogPassedOk = Log.Start(args);
 		Log.WriteLine(string.Format("Time log passed: {0}", timeLogPassedOk.ToString()));
 		Log.WriteLine(string.Format("Client database option 1 in … " + Util.GetDatabaseDir()));
@@ -79,10 +116,6 @@ public class ChronoJump
 		var envPath = Environment.GetEnvironmentVariable ("PATH");
 		var rBinPath = "";
 
-		//record GetOsEnum on variables to not call it all the time
-		operatingSystem = UtilAll.GetOSEnum();
-		Util.operatingSystem = operatingSystem;
-
 		//we need to set Util.operatingSytem before GetPrefixDir()
 		baseDirectory = Util.GetPrefixDir();
 
@@ -746,7 +779,7 @@ public class ChronoJump
 		int existsTempData = Sqlite.TempDataExists(tableName);
 		if(existsTempData > 0)
 		{
-			JumpRj myJumpRj = SqliteJumpRj.SelectJumpData("tempJumpRj", existsTempData, false);
+			JumpRj myJumpRj = SqliteJumpRj.SelectJumpData("tempJumpRj", existsTempData, false, false);
 			try {
 				myJumpRj.InsertAtDB (true, Constants.JumpRjTable);
 			} catch {} //pitty, cannot insert
@@ -759,7 +792,7 @@ public class ChronoJump
 		existsTempData = Sqlite.TempDataExists(tableName);
 		if(existsTempData > 0)
 		{
-			RunInterval myRun = SqliteRunInterval.SelectRunData("tempRunInterval", existsTempData, false);
+			RunInterval myRun = SqliteRunInterval.SelectRunData("tempRunInterval", existsTempData, false, false);
 			try {
 				myRun.InsertAtDB (true, Constants.RunIntervalTable);
 			} catch {} //pitty, cannot insert
