@@ -67,6 +67,11 @@ class ChronojumpImporter
 			this.output = output;
 			this.error = error;
 		}
+
+		public void AddErrorComment (string s)
+		{
+			this.error += "\n\n" + s;
+		}
 	}
 
 	// ChronojumpImporter class imports a specific session from sourceFile to destinationFile.
@@ -157,17 +162,35 @@ LogB.Information("import D ");
 		Directory.CreateDirectory(Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString()));
 LogB.Information("import E ");
 		Directory.CreateDirectory(Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString()));
-LogB.Information("import F ");
 
+LogB.Information("import F ");
 		string sourceDir = Path.GetDirectoryName(sourceFile);
-		if(Directory.Exists(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())))
-			foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())).GetFiles())
-				file.CopyTo(Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString(), file.Name));
+		try {
+			if(Directory.Exists(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())))
+				foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString())).GetFiles())
+					file.CopyTo(Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString(), file.Name));
+		} catch {
+			LogB.Information ("Catched on copying files, disk full or files not fully downloaded (One drive or other cloud problems)");
+			return new Result (false, "", string.Format(Catalog.GetString ("Cannot copy files from {0} to {1}."),
+				Path.Combine(sourceDir, "..", forceSensorName, sourceSession.ToString()),
+				Path.Combine(tempImportDir, forceSensorName, sourceSession.ToString()) + "\n" +
+				Catalog.GetString ("The disk may be full or the files may be copying from a cloud service but have not been downloaded.")
+				));
+		}
 
 LogB.Information("import G ");
-		if(Directory.Exists(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())))
-			foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())).GetFiles())
-				file.CopyTo(Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString(), file.Name));
+		try {
+			if(Directory.Exists(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())))
+				foreach (FileInfo file in new DirectoryInfo(Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString())).GetFiles())
+					file.CopyTo(Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString(), file.Name));
+		} catch {
+			LogB.Information ("Catched on copying files, disk full or files not fully downloaded (One drive or other cloud problems)");
+			return new Result (false, "", string.Format(Catalog.GetString ("Cannot copy files from {0} to {1}"),
+				Path.Combine(sourceDir, "..", raceAnalyzerName, sourceSession.ToString()),
+				Path.Combine(tempImportDir, raceAnalyzerName, sourceSession.ToString()) + "\n" +
+				Catalog.GetString ("The disk may be full or the files may be copying from a cloud service but have not been downloaded.")
+				));
+		}
 
 LogB.Information("import H ");
 
@@ -184,12 +207,28 @@ LogB.Information("import H ");
 		Result sourceDatabaseVersion = getDatabaseVersionFromFile (temporarySourceFile);
 		Result destinationDatabaseVersion = getDatabaseVersionFromFile (destinationFile);
 
+		/* if it fails here and ends on next return
+		   probably is because on windows it lacks the msvcr100.dll
+		   It is documented on howto_new_version.txt
+		   */
 LogB.Information("import I ");
 		if (! sourceDatabaseVersion.success)
+		{
+			if (UtilAll.IsWindows())
+				sourceDatabaseVersion.AddErrorComment ("This error can be caused by a faulty Windows installation of msvcr100.dll."
+						+ "\n" + "Contact Chronojump to solve it."); //TODO: translate this
+
 			return sourceDatabaseVersion;
+		}
 
 		if (! destinationDatabaseVersion.success)
+		{
+			if (UtilAll.IsWindows())
+				sourceDatabaseVersion.AddErrorComment ("This error can be caused by a faulty Windows installation of msvcr100.dll."
+						+ "\n" + "Contact Chronojump to solve it."); //TODO: translate this
+
 			return destinationDatabaseVersion;
+		}
 
 		float destinationDatabaseVersionNum = float.Parse (destinationDatabaseVersion.output);
 		float sourceDatabaseVersionNum = float.Parse (sourceDatabaseVersion.output);
