@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -29,6 +29,7 @@ public class Config
 	public static bool UseSystemColor; //do nothing at all
 	public static Gdk.Color ColorBackground;
 	public static bool ColorBackgroundIsDark;
+	public static string LastDBFullPathStatic = ""; //works even with spaces in name
 
 	public enum SessionModeEnum { STANDARD, UNIQUE, MONTHLY }
 
@@ -60,6 +61,10 @@ public class Config
 	public bool LowHeight; //devices with less than 500 px vertical, like Odroid Go Super
 	public bool LowCPU; //workaround to not show realtime graph on force sensor capture (until its optimized)
 	public bool GuiTest;
+	public bool CanOpenExternalDB;
+	public string ExternalDBDefaultPath = ""; //on chronojump-networks admin to replace GetLocalDataDir (), think if Import has to be disabled
+	public string LastDBFullPath = ""; //on chronojump-networks admin to replace GetLocalDataDir (), think if Import has to be disabled
+
 	/*
 	 * unused because the default serverURL chronojump.org is ok:
 	 * public string ExhibitionServerURL = "";
@@ -87,7 +92,7 @@ public class Config
 
 	public void Read()
 	{
-		string contents = Util.ReadFile(UtilAll.GetConfigFileName(), false);
+		string contents = Util.ReadFile(Util.GetConfigFileName(), false);
 		if (contents != null && contents != "") 
 		{
 			string line;
@@ -145,6 +150,19 @@ public class Config
 						LowCPU = true;
 					else if(parts[0] == "GuiTest" && Util.StringToBool(parts[1]))
 						GuiTest = true;
+					else if(parts[0] == "CanOpenExternalDB" && Util.StringToBool(parts[1]))
+						CanOpenExternalDB = true;
+					else if(parts[0] == "ExternalDBDefaultPath" && parts[1] != "")
+						ExternalDBDefaultPath = parts[1]; //works even with spaces on name
+					else if(parts[0] == "LastDBFullPath" && parts[1] != "")
+					{
+						LastDBFullPath = parts[1]; //works even with spaces on name
+						/*
+						   DataDirStatic is assigned later to not be active on chronojump.cs,
+						   start when gui is started, to not mess with runningFileName and others
+						LastDBFullPathStatic = parts[1]; //called from Util.GetLocalDataDir
+						 */
+					}
 				} while(true);
 			}
 		}
@@ -165,118 +183,80 @@ public class Config
 		return (Compujump && pID == CompujumpAdminID);
 	}
 
-	/*
-	public void Read()
+	//adapted from: http://stackoverflow.com/a/2401873
+	//useDefaultConfigFile is the default. It ensures no use the config of another database
+	public void UpdateFieldEnsuringDefaultConfigFile (string field, string text)
 	{
-		string contents = Util.ReadFile(UtilAll.GetConfigFileName(), false);
-		if (contents != null && contents != "") 
-		{
-			string line;
-			using (StringReader reader = new StringReader (contents)) {
-				do {
-					line = reader.ReadLine ();
+		string storedLastDBFullPathStatic = Config.LastDBFullPathStatic;
+		Config.LastDBFullPathStatic = "";
 
-					if (line == null)
-						break;
-					if (line == "" || line[0] == '#')
-						continue;
+		UpdateField (field, text);
 
-					string [] parts = line.Split(new char[] {'='});
-					if(parts.Length != 2)
-						continue;
-
-					if(parts[0] == "Maximized" && Util.StringToBool(parts[1]))
-						Maximized = true;
-					else if(parts[0] == "CustomButtons" && Util.StringToBool(parts[1]))
-						CustomButtons = true;
-					else if(parts[0] == "UseVideo" && ! Util.StringToBool(parts[1]))
-						UseVideo = false;
-					else if(parts[0] == "OnlyEncoderGravitatory" && Util.StringToBool(parts[1]))
-						OnlyEncoderGravitatory = true;
-					else if(parts[0] == "OnlyEncoderInertial" && Util.StringToBool(parts[1]))
-						OnlyEncoderInertial = true;
-					else if(parts[0] == "EncoderCaptureShowOnlyBars" && Util.StringToBool(parts[1]))
-						EncoderCaptureShowOnlyBars = true;
-					else if(parts[0] == "EncoderUpdateTreeViewWhileCapturing" && ! Util.StringToBool(parts[1]))
-						EncoderUpdateTreeViewWhileCapturing = false;
-					else if(parts[0] == "PersonWinHide" && Util.StringToBool(parts[1]))
-						PersonWinHide = true;
-					else if(parts[0] == "EncoderAnalyzeHide" && Util.StringToBool(parts[1]))
-						EncoderAnalyzeHide = true;
-					else if(parts[0] == "SessionMode" && Enum.IsDefined(typeof(SessionModeEnum), parts[1]))
-						SessionMode = (SessionModeEnum) 
-							Enum.Parse(typeof(SessionModeEnum), parts[1]);
-					else if(parts[0] == "Compujump" && Util.StringToBool(parts[1]))
-						Compujump = true;
-					else if(parts[0] == "RunScriptOnExit" && parts[1] != "")
-						RunScriptOnExit = parts[1];
-				} while(true);
-			}
-		}
+		Config.LastDBFullPathStatic = storedLastDBFullPathStatic;
 	}
-	*/
-	/*
-	public static void UpdateField(string field, string text)
+	public void UpdateField (string field, string text)
 	{
-		//adapted from
-		//http://stackoverflow.com/a/2401873
-				
-		string tempfile = Path.GetTempFileName();
-
-		LogB.Information("UpdateField, field: " + field + ", text: " + text);
+		string tempfile = Path.GetTempFileName ();
+		string configFile = Util.GetConfigFileName ();
+		LogB.Information( string.Format ("Config.UpdateField tempfile: {0}, configFile: {1}, field: {2}, text: {3}",
+					tempfile, configFile, field, text));
 		
-		if(! File.Exists(UtilAll.GetConfigFileName())) {
+		if(! File.Exists (configFile)) {
 			try {
-				using (var writer = new StreamWriter(tempfile))
+				using (var writer = new StreamWriter (tempfile))
 				{
-					writer.WriteLine(field + "=" + text);
+					writer.WriteLine (field + "=" + text);
 				}
-				File.Copy(tempfile, UtilAll.GetConfigFileName(), true);
+				File.Copy (tempfile, configFile, true);
 			} catch {
-				LogB.Warning("Cannot write at Config.UpdateField");
+				LogB.Warning ("Cannot write at Config.UpdateField");
 			}
 		} else {
 			try {
 				using (var writer = new StreamWriter(tempfile))
-					using (var reader = new StreamReader(UtilAll.GetConfigFileName()))
+					using (var reader = new StreamReader (configFile))
 					{
-						while (! reader.EndOfStream) {
-							string line = reader.ReadLine();
+						bool found = false;
+						while (! reader.EndOfStream)
+						{
+							string line = reader.ReadLine ();
 							if (line != "" && line[0] != '#') 
 							{
-								string [] parts = line.Split(new char[] {'='});
-								if(parts.Length == 2 && parts[0] == field)
+								string [] parts = line.Split (new char[] {'='});
+								if (parts.Length == 2 && parts[0] == field)
+								{
 									line = field + "=" + text;
+									found = true;
+								}
 							}
-
-							writer.WriteLine(line);
+							writer.WriteLine (line);
 						}
+
+						//if not found it adds the command
+						if (! found)
+							writer.WriteLine (field + "=" + text);
 					}
-				File.Copy(tempfile, UtilAll.GetConfigFileName(), true);
+				File.Copy (tempfile, configFile, true);
 			} catch {
-				LogB.Warning("Cannot write at Config.UpdateField");
+				LogB.Warning ("Cannot write at Config.UpdateField");
 			}
 		}
 	}
 
 	public override string ToString() 
 	{
-		return(
-				"Maximized = " + Maximized.ToString() + "\n" +
-				"CustomButtons = " + CustomButtons.ToString() + "\n" +
-				"UseVideo = " + UseVideo.ToString() + "\n" +
-				"OnlyEncoderGravitatory = " + OnlyEncoderGravitatory.ToString() + "\n" +
-				"OnlyEncoderInertial = " + OnlyEncoderInertial.ToString() + "\n" +
-				"EncoderCaptureShowOnlyBars = " + EncoderCaptureShowOnlyBars.ToString() + "\n" +
-				"EncoderUpdateTreeViewWhileCapturing = " + EncoderUpdateTreeViewWhileCapturing.ToString() + "\n" +
-				"PersonWinHide = " + PersonWinHide.ToString() + "\n" +
-				"EncoderAnalyzeHide = " + EncoderAnalyzeHide.ToString() + "\n" +
-				"SessionMode = " + SessionMode.ToString() + "\n" +
-				"Compujump = " + Compujump.ToString() + "\n" +
-				"RunScriptOnExit = " + RunScriptOnExit.ToString() + "\n"
-		      );
+		return (string.Format (
+					"Compujump = {0}, CompujumpDjango = {1}, CompujumpHideTaskDone = {2}, CompujumpServerURL = {3}, " +
+					"CompujumpStationID = {4}, CompujumpAdminID = {5}, compujumpAdminEmail = {6}, CompujumpStationMode = {7}, " +
+					"SessionMode = {8}, PlaySoundsFromFile = {9}, Exhibition = {10}, Raspberry = {11}, " +
+					"LowHeight = {12}, LowCPU = {13}, GuiTest = {14}, CanOpenExternalDB = {15}, " +
+					"ExternalDBDefaultPath = {16}, LastDBFullPath = {17}",
+					Compujump, CompujumpDjango, CompujumpHideTaskDone, CompujumpServerURL,
+					CompujumpStationID, CompujumpAdminID, CompujumpAdminEmail, CompujumpStationMode,
+					SessionMode, PlaySoundsFromFile, Exhibition, Raspberry,
+					LowHeight, LowCPU, GuiTest, CanOpenExternalDB,
+					ExternalDBDefaultPath, LastDBFullPath));
 	}
-	*/
 
 	~Config() {}
 }
