@@ -108,10 +108,10 @@ public class Constants
 	//formulas
 	public static string DjIndexFormula = "Dj Index: (tv-tc)/tc *100)";
 	public static string QIndexFormula = "Q index: (tv/tc)";
-	public static string DjPowerFormula = "Dj Power: mass*g*(fallHeight+1.226*(tv^2)) / (tc+tv)";
+	public static string DjPowerFormula = "Dj Power: mass*g*(fallHeight+1.226*(tv^2)) / tc";
 	public static string DjIndexFormulaOnly = "(tv-tc)*100/(tc*1.0)"; //*1.0 for having double division
 	public static string QIndexFormulaOnly = "tv/(tc*1.0)"; //*1.0 for having double division
-	public static string DjPowerFormulaOnly = PersonSessionTable + ".weight * 9.81 * (fall/100.0 + 1.226 * (tv*tv) ) / ((tc+tv)*1.0)";
+	public static string DjPowerFormulaOnly = PersonSessionTable + ".weight * 9.81 * (fall/100.0 + 1.226 * (tv*tv)) / tc *1.0";
 
 	public static string ChronojumpProfileStr()
 	{
@@ -559,6 +559,14 @@ public class Constants
 		return Catalog.GetString("Races: Intervallic");
 	}
 
+	public static string jumpsTranslatedStr ()
+	{
+		return Catalog.GetString ("jumps");
+	}
+	public static string tracksTranslatedStr ()
+	{
+		return Catalog.GetString ("tracks");
+	}
 
 	//strings
 	public static string AllJumpsNameStr()
@@ -871,7 +879,11 @@ public class Constants
 		"Creating encoder widgets", 	//9
 		"Starting main window", 	//10
 	};
-	
+
+	public static string NotEnoughDataStr ()
+	{
+		return Catalog.GetString ("Not enough data.");
+	}
 	public static string DatabaseNotFoundStr()
 	{
 		return Catalog.GetString("Error. Cannot find database.");
@@ -993,7 +1005,15 @@ public class Constants
 			"A simple method for field measurements of leg stiffness in hopping. " +
 			"Int J Sports Med 25: 170–176";
 	}
-	
+
+	public static string GetRepairWindowMessage ()
+	{
+		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
+		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+		return string.Format(Catalog.GetString("Use this window to repair this test.\nDouble clic any cell to edit it (decimal separator: '{0}')"), localeInfo.NumberDecimalSeparator) +
+			"\n" + Catalog.GetString ("Press enter or tab after editing a cell.");
+	}
+
 	public const string PrefVersionAvailable = "versionAvailable";
 	
 	/*
@@ -1039,7 +1059,7 @@ public class Constants
 	}
 
 	public enum BellModes {
-		JUMPS, RUNS, ENCODERGRAVITATORY, ENCODERINERTIAL, FORCESENSOR
+		JUMPS, RUNS, ENCODERGRAVITATORY, ENCODERINERTIAL, FORCESENSOR, RUNSENCODER
 	}
 
 	public enum Modes {
@@ -1047,7 +1067,57 @@ public class Constants
 		JUMPSSIMPLE, JUMPSREACTIVE,
 		RUNSSIMPLE, RUNSINTERVALLIC, RUNSENCODER,
 		POWERGRAVITATORY, POWERINERTIAL,
-		FORCESENSOR, RT, OTHER } //OTHER can be: Multichronopic, Pulse
+		FORCESENSORISOMETRIC, FORCESENSORELASTIC,
+		RT, OTHER } //OTHER can be: Multichronopic, Pulse
+
+	//to shorten code on the rest of the software
+	public static bool ModeIsENCODER (Modes mode)
+	{
+		return (mode == Modes.POWERGRAVITATORY || mode == Modes.POWERINERTIAL);
+	}
+	public static bool ModeIsFORCESENSOR (Modes mode)
+	{
+		return (mode == Modes.FORCESENSORISOMETRIC || mode == Modes.FORCESENSORELASTIC);
+	}
+
+	public static string ModeFolder (Constants.Modes mode)
+	{
+		if(mode == Constants.Modes.RUNSENCODER)
+			return "raceAnalyzer";
+		else if(mode == Constants.Modes.POWERGRAVITATORY)
+			return "encoder";
+		else if(mode == Constants.Modes.POWERINERTIAL)
+			return "encoder";
+		else if(ModeIsFORCESENSOR (mode))
+			return "forceSensor";
+		else
+			return ""; //should never happen
+	}
+
+	//used on detect device
+	public static string ModeIcon (Constants.Modes mode)
+	{
+		if (mode == Constants.Modes.JUMPSSIMPLE)
+			return "image_jump_simple.png";
+		else if (mode == Constants.Modes.JUMPSREACTIVE)
+			return "image_jump_reactive.png";
+		else if (mode == Constants.Modes.RUNSSIMPLE)
+			return "image_run_simple.png";
+		else if (mode == Constants.Modes.RUNSINTERVALLIC)
+			return "image_run_multiple.png";
+		else if (mode == Constants.Modes.RUNSENCODER)
+			return "race_encoder_icon.png";
+		else if (mode == Constants.Modes.POWERGRAVITATORY)
+			return "image_weight.png";
+		else if (mode == Constants.Modes.POWERINERTIAL)
+			return "image_inertia.png";
+		else if (mode == Constants.Modes.FORCESENSORISOMETRIC)
+			return "isometric.png";
+		else if (mode == Constants.Modes.FORCESENSORELASTIC)
+			return "elastic.png";
+		else
+			return "image_jump_simple"; //to not crash if there is any future mode
+	}
 
 	public static string All = "All";
 	public static string None = "None";
@@ -1114,11 +1184,12 @@ public class Constants
 	{
 		JUMPS_SIMPLE_CAPTURE_SAVE_IMAGE, JUMPS_REACTIVE_CAPTURE_SAVE_IMAGE,
 		JUMPS_PROFILE_SAVE_IMAGE, JUMPS_DJ_OPTIMAL_FALL_SAVE_IMAGE,
+		JUMPS_ASYMMETRY_BILATERAL_SAVE_IMAGE, JUMPS_ASYMMETRY_ASYMMETRY_SAVE_IMAGE,
 		JUMPS_WEIGHT_FV_PROFILE_SAVE_IMAGE, JUMPS_EVOLUTION_SAVE_IMAGE,
 		JUMPS_RJ_FATIGUE_SAVE_IMAGE,
 		RUNS_SIMPLE_CAPTURE_SAVE_IMAGE, RUNS_INTERVALLIC_CAPTURE_SAVE_IMAGE,
 		RUNS_EVOLUTION_SAVE_IMAGE,
-		RUNS_SPRINT_SAVE_IMAGE,
+		RUNS_SPRINT_SAVE_IMAGE, RUNS_SPRINT_SAVE_TABLE,
 		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES,
 		RUNS_SPRINT_EXPORT_INDIVIDUAL_ALL_SESSIONS_NO_IMAGES,
 		RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
@@ -1158,37 +1229,37 @@ public class Constants
 	
 	//encoder configurations
 	//linear
-	public static string FileNameEncoderLinearFreeWeight = "encoder-linear-free-weight.png";
-	public static string FileNameEncoderLinearFreeWeightInv = "encoder-linear-free-weight-inv.png";
-	public static string FileNameEncoderLinearInertial = "encoder-linear-inertial.png";
-	public static string FileNameEncoderWeightedMovPulleyOnPerson1 = "encoder-linear-on-person-weighted-moving-pulley1.png";
-	public static string FileNameEncoderWeightedMovPulleyOnPerson1Inv = "encoder-linear-inv-on-person-weighted-moving-pulley1.png";
-	public static string FileNameEncoderWeightedMovPulleyOnPerson2 = "encoder-linear-on-person-weighted-moving-pulley2.png";
-	public static string FileNameEncoderWeightedMovPulleyOnPerson2Inv = "encoder-linear-inv-on-person-weighted-moving-pulley2.png";
-	public static string FileNameEncoderWeightedMovPulleyOnLinearEncoder = "encoder-linear-on-weighted-moving-pulley.png";
-	public static string FileNameEncoderLinearOnPlane = "encoder-linear-inclined-plane.png";	
-	public static string FileNameEncoderLinearOnPlaneWeightDiffAngle = "encoder-linear-inclined-plane-weight-diff-angle.png";	
-	public static string FileNameEncoderLinearOnPlaneWeightDiffAngleMovPulley = "encoder-linear-inclined-plane-weight-diff-angle-mov-pulley.png";
-	public static string FileNameEncoderLinearPneumatic = "encoder-linear-pneumatic.png";
+	public static string FileNameEncoderLinearFreeWeight = "encoder-l-free-weight.png";
+	public static string FileNameEncoderLinearFreeWeightInv = "encoder-l-free-weight-inv.png";
+	public static string FileNameEncoderLinearInertial = "encoder-l-inertial.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson1 = "encoder-l-on-person-weighted-moving-pulley1.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson1Inv = "encoder-l-inv-on-person-weighted-moving-pulley1.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson2 = "encoder-l-on-person-weighted-moving-pulley2.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson2Inv = "encoder-l-inv-on-person-weighted-moving-pulley2.png";
+	public static string FileNameEncoderWeightedMovPulleyOnLinearEncoder = "encoder-l-on-weighted-moving-pulley.png";
+	public static string FileNameEncoderLinearOnPlane = "encoder-l-inclined-plane.png";
+	public static string FileNameEncoderLinearOnPlaneWeightDiffAngle = "encoder-l-inclined-plane-weight-diff-angle.png";
+	public static string FileNameEncoderLinearOnPlaneWeightDiffAngleMovPulley = "encoder-l-inclined-plane-weight-diff-angle-mov-pulley.png";
+	public static string FileNameEncoderLinearPneumatic = "encoder-l-pneumatic.png";
 
 	//rotary friction
-	public static string FileNameEncoderFrictionSide = "encoder-rotary-friction-pulley.png";
-	public static string FileNameEncoderFrictionAxis = "encoder-rotary-friction-pulley-axis.png";
-	public static string FileNameEncoderFrictionSideInertial = "encoder-rotary-friction-side-inertial.png";
-	public static string FileNameEncoderFrictionAxisInertial = "encoder-rotary-friction-axis-inertial.png";
-	public static string FileNameEncoderFrictionSideInertialLateral = "encoder-rotary-friction-side-inertial-lateral.png";
-	public static string FileNameEncoderFrictionAxisInertialLateral = "encoder-rotary-friction-axis-inertial-lateral.png";
-	public static string FileNameEncoderFrictionSideInertialMovPulley = "encoder-rotary-friction-side-inertial-mov-pulley.png";
-	public static string FileNameEncoderFrictionAxisInertialMovPulley = "encoder-rotary-friction-axis-inertial-mov-pulley.png";
-	public static string FileNameEncoderFrictionWithMovPulley = "encoder-rotary-friction-on-fixed-pulley-with-weighted-moving-pulley.png";
+	public static string FileNameEncoderFrictionSide = "encoder-rf-pulley.png";
+	public static string FileNameEncoderFrictionAxis = "encoder-rf-pulley-axis.png";
+	public static string FileNameEncoderFrictionSideInertial = "encoder-rf-side-inertial.png";
+	public static string FileNameEncoderFrictionAxisInertial = "encoder-rf-axis-inertial.png";
+	public static string FileNameEncoderFrictionSideInertialLateral = "encoder-rf-side-inertial-lateral.png";
+	public static string FileNameEncoderFrictionAxisInertialLateral = "encoder-rf-axis-inertial-lateral.png";
+	public static string FileNameEncoderFrictionSideInertialMovPulley = "encoder-rf-side-inertial-mov-pulley.png";
+	public static string FileNameEncoderFrictionAxisInertialMovPulley = "encoder-rf-axis-inertial-mov-pulley.png";
+	public static string FileNameEncoderFrictionWithMovPulley = "encoder-rf-on-fixed-pulley-with-weighted-moving-pulley.png";
 
 	//rotary axis
-	public static string FileNameEncoderRotaryAxisOnAxis = "encoder-rotary-axis-pulley-axis.png";
-	public static string FileNameEncoderAxisInertial = "encoder-rotary-axis-inertial.png";
-	public static string FileNameEncoderAxisInertialLateral = "encoder-rotary-axis-inertial-lateral.png";
-	public static string FileNameEncoderAxisInertialMovPulley = "encoder-rotary-axis-inertial-mov-pulley.png";
-	public static string FileNameEncoderAxisInertialMovPulleyLateral = "encoder-rotary-axis-inertial-mov-pulley-lateral.png";
-	public static string FileNameEncoderAxisWithMovPulley = "encoder-rotary-axis-on-fixed-pulley-with-weighted-moving-pulley.png";
+	public static string FileNameEncoderRotaryAxisOnAxis = "encoder-ra-pulley-axis.png";
+	public static string FileNameEncoderAxisInertial = "encoder-ra-inertial.png";
+	public static string FileNameEncoderAxisInertialLateral = "encoder-ra-inertial-lateral.png";
+	public static string FileNameEncoderAxisInertialMovPulley = "encoder-ra-inertial-mov-pulley.png";
+	public static string FileNameEncoderAxisInertialMovPulleyLateral = "encoder-ra-inertial-mov-pulley-lateral.png";
+	public static string FileNameEncoderAxisWithMovPulley = "encoder-ra-on-fixed-pulley-with-weighted-moving-pulley.png";
 	
 	public static string FileNameEncoderCalculeIM = "encoder-calcule-im.png";	
 
