@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -530,25 +530,48 @@ public class EncoderSignal
 	
 	//this is an ecc-con curve
 	//start is a counter of phases not of repetitions
-	public int FindPosOfBestEccCon(int start, string variable)
+	public int FindPosOfBestEccCon(int start, string variable, Preferences.EncoderRepetitionCriteria repCriteria)
 	{
 		double eccValue = 0;
 		double conValue = 0;
 
-		double bestValue = 0; //will be ecc-con average
-		int bestValuePos = start; //will be the position of the ecc
+		double bestValue = 0; //will be ecc-con average, ecc or con depending on repCriteria
+		int bestValuePos = start; //will always be the position of the ecc
 		int i = 0;
 		
 		bool ecc = true;
 		foreach(EncoderCurve curve in curves) 
 		{
-			if(ecc) {
-				eccValue = curve.GetParameter(variable);
-			} else {
-				conValue = curve.GetParameter(variable);
-				if( i >= start && ( (eccValue + conValue) / 2 ) > bestValue) {
-					bestValue = (eccValue + conValue) / 2;
-					bestValuePos = i -1;
+			if(repCriteria == Preferences.EncoderRepetitionCriteria.ECC_CON)
+			{
+				if(ecc) {
+					eccValue = curve.GetParameter(variable);
+				} else {
+					conValue = curve.GetParameter(variable);
+					if( i >= start && ( (eccValue + conValue) / 2 ) > bestValue) {
+						bestValue = (eccValue + conValue) / 2;
+						bestValuePos = i -1; //the ecc
+					}
+				}
+			}
+			else if(repCriteria == Preferences.EncoderRepetitionCriteria.ECC)
+			{
+				if(ecc) {
+					eccValue = curve.GetParameter(variable);
+					if(i >= start && eccValue > bestValue) {
+						bestValue = eccValue;
+						bestValuePos = i; //the ecc
+					}
+				}
+			}
+			else// if(repCriteria == Preferences.EncoderRepetitionCriteria.CON)
+			{
+				if(! ecc) {
+					conValue = curve.GetParameter(variable);
+					if(i >= start && conValue > bestValue) {
+						bestValue = conValue;
+						bestValuePos = i-1; //the ecc
+					}
 				}
 			}
 
@@ -559,7 +582,7 @@ public class EncoderSignal
 	}
 
 	public enum Contraction { EC, C };
-	public List<int> FindPosOfBestN(int start, string variable, int n, Contraction eccon)
+	public List<int> FindPosOfBestN(int start, string variable, int n, Contraction eccon, Preferences.EncoderRepetitionCriteria repCriteria)
 	{
 		//1) find how many values to return
 		//size of list will be n or the related curves if it is smaller
@@ -593,7 +616,7 @@ public class EncoderSignal
 			if(eccon == Contraction.C)
 				posOfBest = es.FindPosOfBest(start, variable);
 			else //(eccon == Contraction.EC)
-				posOfBest = es.FindPosOfBestEccCon(start, variable);
+				posOfBest = es.FindPosOfBestEccCon(start, variable, repCriteria);
 
 			listOfPos.Add(posOfBest);
 			count ++;
@@ -629,7 +652,7 @@ public class EncoderSignal
 		}
 		return bestValuePos;
 	}
-	public int FindPosOfBestNConsecutiveEccCon(int start, string variable, int n)
+	public int FindPosOfBestNConsecutiveEccCon(int start, string variable, int n, Preferences.EncoderRepetitionCriteria repCriteria)
 	{
 		//2) find the best values and fill listOfPos
 		double bestValue = 0;
@@ -640,19 +663,34 @@ public class EncoderSignal
 		while(count <= curves.Count - n)
 		{
 			double sum = 0;
+			double eccSum = 0; //used on EncoderRepetitionCriteria.ECC
+			double conSum = 0; //used on EncoderRepetitionCriteria.CON
+
 			for(int i = count; i < count + n; i += 2)
 			{
 				double eccValue = ((EncoderCurve) curves[i]).GetParameter(variable);
 				double conValue = ((EncoderCurve) curves[i+1]).GetParameter(variable);
 				sum += (eccValue + conValue) / 2;
-				LogB.Information(string.Format("eccValue: {0}, conValue: {1}, accumulated sum: {2}", eccValue, conValue, sum));
+				eccSum += eccValue;
+				conSum += conValue;
+				//LogB.Information(string.Format("eccValue: {0}, conValue: {1}, accumulated sum: {2}", eccValue, conValue, sum));
 			}
-			LogB.Information("total sum: " + sum.ToString());
-			if (sum > bestValue)
+			//LogB.Information("total sum: " + sum.ToString());
+			if(repCriteria == Preferences.EncoderRepetitionCriteria.ECC_CON && sum > bestValue)
 			{
 				bestValue = sum;
 				bestValuePos = count;
-				LogB.Information(string.Format("bestValue: {0}, bestValuePos: {1}", bestValue, bestValuePos));
+				//LogB.Information(string.Format("bestValue: {0}, bestValuePos: {1}", bestValue, bestValuePos));
+			}
+			else if (repCriteria == Preferences.EncoderRepetitionCriteria.ECC && eccSum > bestValue)
+			{
+				bestValue = eccSum;
+				bestValuePos = count;
+			}
+			else if (repCriteria == Preferences.EncoderRepetitionCriteria.CON && conSum > bestValue)
+			{
+				bestValue = conSum;
+				bestValuePos = count;
 			}
 
 			count += 2;
@@ -924,6 +962,7 @@ public class EncoderSQL
 	public string future1;
 	public string future2;
 	public string future3;
+	public Preferences.EncoderRepetitionCriteria repCriteria;
 
 	public string exerciseName;
 	
@@ -939,6 +978,7 @@ public class EncoderSQL
 			string description, string status, string videoURL, 
 			EncoderConfiguration encoderConfiguration,
 			string future1, string future2, string future3, 
+			Preferences.EncoderRepetitionCriteria repCriteria,
 			string exerciseName
 			)
 	{
@@ -961,14 +1001,22 @@ public class EncoderSQL
 		this.future1 = future1;	//on curves: meanPower
 		this.future2 = future2; //on curves: meanSpeed
 		this.future3 = future3; //on curves: meanForce
+		this.repCriteria = repCriteria;
 		this.exerciseName = exerciseName;
 
-		if(eccon == "c")
-			ecconLong = Catalog.GetString("Concentric");
-		else if(eccon == "ec" || eccon == "ecS")
-			ecconLong = Catalog.GetString("Eccentric-concentric");
+		ecconLong = EcconLong(eccon);
+	}
+
+	public static string EcconLong (string ecconChars)
+	{
+		if(ecconChars == "c")
+			return Catalog.GetString("Concentric");
+		else if(ecconChars == "ec" || ecconChars == "ecS")
+			return Catalog.GetString("Eccentric-concentric");
+		else if(ecconChars == "ce" || ecconChars == "ceS")
+			return Catalog.GetString("Concentric-eccentric");
 		else
-			ecconLong = Catalog.GetString("Concentric-eccentric");
+			return "";
 	}
 
 	//used on encoder table
@@ -1068,6 +1116,18 @@ public class EncoderSQL
 		return str;
 	}
 
+	public override string ToString () 	 //debug
+	{
+		return string.Format (
+				"uniqueID: {0},  personID: {1},  sessionID: {2},  exerciseID: {3},  eccon: {4}, " +
+				"laterality: {5},  extraWeight: {6},  signalOrCurve: {7},  filename: {8}, " +
+				"url: {9},  time: {10},  minHeight: {11},  description: {12}, " +
+				"status: {13},  videoURL: {14},  encoderConfiguration: {15},  future1: {16}, " +
+				"future2: {17},  future3: {18},   repCriteria: {19},  exerciseName: {20}",
+				uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, signalOrCurve, filename,
+				url, time, minHeight, description, status, videoURL, encoderConfiguration, future1, future2, future3,  repCriteria, exerciseName);
+	}
+
 	//uniqueID:name
 	public EncoderSQL ChangePerson(string newIDAndName) {
 		int newPersonID = Util.FetchID(newIDAndName);
