@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -33,6 +33,7 @@ public class EventExecute
 	protected string personName;
 	protected int sessionID;
 	protected int uniqueID;
+	protected int typeID; //to upload to networks
 	protected string type;
 	protected string description;
 
@@ -65,6 +66,7 @@ public class EventExecute
 	//protected bool needShowSyncMessage;
 	protected string feedbackMessage;
 	protected bool needShowFeedbackMessage;
+	protected bool feedbackMessageOnDialog;
 
 	//instances with the info to create
 	public PrepareEventGraphJumpSimple PrepareEventGraphJumpSimpleObject; 
@@ -83,7 +85,7 @@ public class EventExecute
 	protected bool graphAllTypes;
 	protected bool graphAllPersons;
 	protected double progressbarLimit;
-	protected RepetitiveConditionsWindow repetitiveConditionsWin;
+	protected FeedbackWindow feedbackWin;
 
 	protected ExecutingGraphData egd;
 	protected Gdk.Color colorBackground;
@@ -231,8 +233,13 @@ public class EventExecute
 		if ( ! thread.IsAlive || cancel) {
 			LogB.ThreadEnding();
 
-			//don't show any of the runChangeImage icons
-			runChangeImageForceHide();
+			//don't show any of the change image icons
+			if (this.GetType ().Equals (typeof (JumpExecute)) ||
+					this.GetType ().Equals (typeof (JumpRjExecute)))
+				jumpChangeImageForceHide();
+			else if (this.GetType ().Equals (typeof (RunExecute)) ||
+					this.GetType ().Equals (typeof (RunIntervalExecute)))
+				runChangeImageForceHide();
 
 			fakeButtonThreadDyed.Click();
 
@@ -332,46 +339,63 @@ public class EventExecute
 			needSensitiveButtonFinish = false;
 		}
 
+		// jump specific --------------------------------->
+		if (this.GetType ().Equals (typeof (JumpExecute)) ||
+				this.GetType ().Equals (typeof (JumpRjExecute)))
+			jumpChangeImageIfNeeded ();
+
 		// races specific --------------------------------->
 
-		runChangeImageIfNeeded();
+		//TODO: pass mode and only do what related to mode
 
-		updateRunPhaseInfoManage();
+		if (this.GetType ().Equals (typeof (RunExecute)) ||
+				this.GetType ().Equals (typeof (RunIntervalExecute)))
+		{
+			runChangeImageIfNeeded ();
 
-		//Race track with DoubleContacts mode NONE
-		if(needCallTrackDone)
-		{
-			trackDone();
-			needCallTrackDone = false;
-		}
-		//Race track with DoubleContacts mode != NONE
-		//LogB.Information("needCheckIfTrackEnded: " + needCheckIfTrackEnded.ToString());
-		if(needCheckIfTrackEnded && lastTfCheckTimeEnded())
-		{
-			if(trackDone())
+			updateRunPhaseInfoManage();
+
+			//Race track with DoubleContacts mode NONE
+			if(needCallTrackDone)
 			{
-				//LogB.Information("needCheckIfTrackEnded changing to false");
-				needCheckIfTrackEnded = false;
-			} else {
-				//LogB.Information("needCheckIfTrackEnded continue true, trackDone() will be called again");
-				//this helps to fix when contact time display when it is bigger than double contact time * 1.5
+				trackDone();
+				needCallTrackDone = false;
+			}
+			//Race track with DoubleContacts mode != NONE
+			//LogB.Information("needCheckIfTrackEnded: " + needCheckIfTrackEnded.ToString());
+			if(needCheckIfTrackEnded && lastTfCheckTimeEnded())
+			{
+				if(trackDone())
+				{
+					//LogB.Information("needCheckIfTrackEnded changing to false");
+					needCheckIfTrackEnded = false;
+				} else {
+					//LogB.Information("needCheckIfTrackEnded continue true, trackDone() will be called again");
+					//this helps to fix when contact time display when it is bigger than double contact time * 1.5
+				}
+			}
+
+			//RSA
+			if(needShowCountDown)
+			{
+				feedbackMessage = countDownMessage();
+				UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 			}
 		}
 
-		//RSA
-		if(needShowCountDown) 
-		{
-			feedbackMessage = countDownMessage();
-			UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
-		} 
-		else if(needShowFeedbackMessage) 
+		// <-------------------------- end of races specific
+
+		if(! needShowCountDown && needShowFeedbackMessage)
 		{
+			if (feedbackMessageOnDialog)
+			{
+				new DialogMessage(Constants.MessageTypes.WARNING, feedbackMessage);
+				feedbackMessageOnDialog = false;
+			}
 			UtilGtk.PrintLabelWithTooltip(egd.Label_message, feedbackMessage);
 			needShowFeedbackMessage = false;
 		}
 		
-		// <-------------------------- end of races specific
-
 		//check if it should finish by time
 		if(shouldFinishByTime()) {
 			finish = true;
@@ -394,10 +418,16 @@ public class EventExecute
 		return true;
 	}
 
+	protected virtual void jumpChangeImageIfNeeded()
+	{
+	}
 	protected virtual void runChangeImageIfNeeded()
 	{
 	}
 
+	protected virtual void jumpChangeImageForceHide()
+	{
+	}
 	protected virtual void runChangeImageForceHide()
 	{
 	}
@@ -557,7 +587,7 @@ public class EventExecute
 
 	//from confirm_window cancel button (thread has not started)
 	//this is NOT called when a event has started and user click on "Cancel"
-	protected void cancel_event_before_start(object o, EventArgs args)
+	protected void cancel_event_before_start (object o, EventArgs args)
 	{
 		cancel = true;
 			
@@ -566,11 +596,12 @@ public class EventExecute
 		fakeButtonThreadDyed.Click();
 	}
 
-	protected void chronopicHasBeenDisconnected() {
+	protected void chronopicHasBeenDisconnected ()
+	{
 		chronopicDisconnected = true;
 		ErrorWindow errorWin;		
 		errorWin = ErrorWindow.Show( 
-				Catalog.GetString("Chronopic seems disconnected. Reconnect again on Chronopic Window."));
+				Catalog.GetString("Chronopic seems disconnected."));
 
 		Util.PlaySound(Constants.SoundTypes.BAD, volumeOn, gstreamer);
 		errorWin.Button_accept.Clicked += new EventHandler(cancel_event_before_start);
