@@ -28,6 +28,7 @@ using Mono.Unix;
 
 public class JumpExecute : EventExecute
 {
+	protected double personWeight;
 	protected double tv;
 	protected double tc;
 	protected double fall;
@@ -46,26 +47,41 @@ public class JumpExecute : EventExecute
 		PRE_OR_DOING, PLATFORM_END
 	}
 	protected static jumpPhases jumpPhase;
+	protected static JumpChangeImage jumpChangeImage;
 
 	private int angle = -1;
-	private bool avoidGraph;
-	private bool heightPreferred;
-	
+	//private bool avoidGraph;
+	//private bool heightPreferred;
+	protected bool metersSecondsPreferred;
+	protected Gtk.Image image_jump_execute_air;
+	protected Gtk.Image image_jump_execute_land;
+	protected bool upload;
+	protected int uploadStationId;
+	protected bool django;
+
 	public JumpExecute() {
 	}
 
 	//jump execution
-	public JumpExecute(int personID, string personName, int sessionID, string type, double fall, double weight,  
+	public JumpExecute (
+			int personID, string personName, double personWeight,
+			int sessionID, int typeID, string type, double fall, double weight,
 			Chronopic cp, int pDN,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd, string description,
-			bool avoidGraph, //on configChronojump.Exhibition do not show graph because it gets too slow with big database
-			bool heightPreferred, int graphLimit, bool graphAllTypes, bool graphAllPersons
+			//bool avoidGraph, //on configChronojump.Exhibition do not show graph because it gets too slow with big database
+			//bool heightPreferred,
+			bool metersSecondsPreferred,
+			int graphLimit, bool graphAllTypes, bool graphAllPersons,
+			Gtk.Image image_jump_execute_air, Gtk.Image image_jump_execute_land,
+			bool upload, int uploadStationId, bool django //upload: configChronojump.Compujump && upload (contacts) button active
 			)
 	{
 		this.personID = personID;
 		this.personName = personName;
+		this.personWeight = personWeight; //for Stiffness at upload on compujump
 		this.sessionID = sessionID;
+		this.typeID = typeID;
 		this.type = type;
 		this.fall = fall; //-1 means has to be calculated with a previous jump
 		this.weight = weight;
@@ -78,12 +94,18 @@ public class JumpExecute : EventExecute
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 		this.description = description;
-		this.avoidGraph = avoidGraph;
-		this.heightPreferred = heightPreferred;
+		//this.avoidGraph = avoidGraph;
+		//this.heightPreferred = heightPreferred;
+		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.graphLimit = graphLimit;
 		this.graphAllTypes = graphAllTypes;
 		this.graphAllPersons = graphAllPersons;
-	
+		this.image_jump_execute_air = image_jump_execute_air;
+		this.image_jump_execute_land = image_jump_execute_land;
+		this.upload = upload;
+		this.uploadStationId = uploadStationId;
+		this.django = django;
+
 		if(TypeHasFall) {
 			hasFall = true;
 		} else {
@@ -104,7 +126,7 @@ public class JumpExecute : EventExecute
 	
 	public override void SimulateInitValues(Random randSent)
 	{
-		LogB.Information("From execute/jump.cs");
+		LogB.Information ("From execute/jump.cs");
 
 		rand = randSent; //we send the random, because if we create here, the values will be the same for each nbew instance
 		simulated = true;
@@ -128,8 +150,10 @@ public class JumpExecute : EventExecute
 	
 	public override void Manage()
 	{
+		LogB.Information("Jumps Manage!");
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
+		jumpChangeImage = new JumpChangeImage();
 
 		if (simulated) 
 			platformState = Chronopic.Plataforma.ON;
@@ -137,7 +161,10 @@ public class JumpExecute : EventExecute
 			platformState = chronopicInitialValue(cp);
 		
 		
-		if (platformState==Chronopic.Plataforma.ON) {
+		if (platformState==Chronopic.Plataforma.ON)
+		{
+			jumpChangeImageDo (platformState); //done here before thread starts
+
 			feedbackMessage = Catalog.GetString("You are IN, JUMP when prepared!");
 			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
@@ -161,7 +188,10 @@ public class JumpExecute : EventExecute
 			LogB.ThreadStart(); 
 			thread.Start(); 
 		} 
-		else if (platformState==Chronopic.Plataforma.OFF) {
+		else if (platformState==Chronopic.Plataforma.OFF)
+		{
+			jumpChangeImageDo (platformState);
+
 			ConfirmWindow confirmWin;		
 			confirmWin = ConfirmWindow.Show(Catalog.GetString(
 						"You are OUT, please enter the platform, prepare for jump and press the 'accept' button"),
@@ -176,14 +206,19 @@ public class JumpExecute : EventExecute
 			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
 		}
 		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			jumpChangeImageDo (platformState);
+
 			chronopicHasBeenDisconnected();
 		}
 	}
 
 	public override void ManageFall()
 	{
+		LogB.Information ("Jumps ManageFall!, fall: ", fall.ToString ());
+
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
+		jumpChangeImage = new JumpChangeImage();
 
 		if (simulated) {
 			if(fall != -1)
@@ -200,6 +235,8 @@ public class JumpExecute : EventExecute
 				platformState != Chronopic.Plataforma.ON) 
 		{
 			//UNKNOW (Chronopic disconnected, port changed, ...)
+			jumpChangeImageDo (platformState);
+
 			chronopicHasBeenDisconnected();
 			return;
 		}
@@ -238,7 +275,8 @@ public class JumpExecute : EventExecute
 				else
 					platformState = Chronopic.Plataforma.OFF; //mark now that we have jumped
 			}
-			
+			jumpChangeImageDo (platformState);
+
 			//start thread
 			thread = new Thread(new ThreadStart(waitEvent));
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
@@ -248,6 +286,8 @@ public class JumpExecute : EventExecute
 		} 
 		else  
 		{
+			jumpChangeImageDo (platformState);
+
 			ConfirmWindow confirmWin;
 
 			string message = Catalog.GetString("You are IN, please leave the platform, and press the 'accept' button");
@@ -272,8 +312,46 @@ public class JumpExecute : EventExecute
 	private void callAgainManageFall(object o, EventArgs args) {
 		ManageFall();
 	}
-	
-	
+
+	//before thread start, to set the image
+	protected void jumpChangeImageDo (Chronopic.Plataforma plat)
+	{
+		if (plat == Chronopic.Plataforma.OFF)
+			jumpChangeImage.Current = JumpChangeImage.Types.AIR;
+		else if (plat == Chronopic.Plataforma.ON)
+			jumpChangeImage.Current = JumpChangeImage.Types.LAND;
+		else
+			jumpChangeImage.Current = JumpChangeImage.Types.NONE;
+
+		jumpChangeImageIfNeeded ();
+	}
+
+	protected override void jumpChangeImageIfNeeded ()
+	{
+		if(! jumpChangeImage.ShouldBeChanged())
+			return;
+
+		if (jumpChangeImage.Current == JumpChangeImage.Types.AIR)
+		{
+			image_jump_execute_air.Visible = true;
+			image_jump_execute_land.Visible = false;
+		} else if (jumpChangeImage.Current == JumpChangeImage.Types.LAND)
+		{
+			image_jump_execute_air.Visible = false;
+			image_jump_execute_land.Visible = true;
+		} else
+		{ //UNKNOW (Chronopic disconnected, port changed, ...)
+			image_jump_execute_air.Visible = false;
+			image_jump_execute_land.Visible = false;
+		}
+	}
+
+	protected override void jumpChangeImageForceHide()
+	{
+		image_jump_execute_air.Visible = false;
+		image_jump_execute_land.Visible = false;
+	}
+
 	protected override void waitEvent ()
 	{
 		double timestamp = 0;
@@ -320,6 +398,8 @@ public class JumpExecute : EventExecute
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) 
 				{
 					//has landed
+					jumpChangeImage.Current = JumpChangeImage.Types.LAND;
+
 					if(hasFall && tc == 0) 
 					{
 						//**** graphC **** 
@@ -378,6 +458,7 @@ public class JumpExecute : EventExecute
 				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) 
 				{
 					//it's out, was inside (= has jumped)
+					jumpChangeImage.Current = JumpChangeImage.Types.AIR;
 				
 					//fall != -1 because if it was == -1, it will change once touching floor for the first time	
 					if(hasFall && fall != -1) {
@@ -412,7 +493,7 @@ public class JumpExecute : EventExecute
 								);
 						needUpdateEventProgressBar = true;
 					} else {
-						//**** graphD (if normal jump) **** 
+						//**** graphD (if simple jump) ****
 						//**** graphB (if hasFall and fall == -1) **** 
 
 						initializeTimer();
@@ -467,8 +548,7 @@ public class JumpExecute : EventExecute
 			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
 		else
 			feedbackMessage = "";
-		needShowFeedbackMessage = true; 
-		
+
 		string table = Constants.JumpTable;
 		string datetime = UtilDate.ToFile(DateTime.Now);
 
@@ -481,6 +561,34 @@ public class JumpExecute : EventExecute
 		eventDone = new Jump(uniqueID, personID, sessionID, type, tv, tc, fall, 
 				weight, description, angle, Util.BoolToNegativeInt(simulated), datetime);
 
+		if(upload)
+		{
+			UploadJumpSimpleDataObject uj = new UploadJumpSimpleDataObject (
+					uploadStationId, (Jump) eventDone, typeID, personWeight, metersSecondsPreferred);
+			JsonCompujump js = new JsonCompujump (django);
+			if( ! js.UploadJumpData (uj, Constants.Modes.JUMPSSIMPLE) )
+			{
+				LogB.Error (js.ResultMessage);
+
+				/*
+				   feedbackMessage will be shown on a DialogMessage to not being erased by updateGraphJumpsSimple -> event_execute_initializeVariables
+				   the dialog cannot be called here to avoid gtk crash
+				   */
+				feedbackMessageOnDialog = true;
+				feedbackMessage = js.ResultMessage;
+
+				//since 2.1.3 do not store in Temp, if there are network errors, it is not going to be uploaded later, because wristbands can be re-assigned
+				//SqliteJson.InsertTempSprint(false, usdo); //insert only if couldn't be uploaded
+			}
+		}
+		needShowFeedbackMessage = true;
+
+		/* 2.2.2 do not do the graph here because PrepareEventGraphJumpSimple has an SQL call with a reader
+		   and updateGraph can be also called by gtk thread and also call PrepareEventGraphJumpSimple,
+		   so SQL can be tried to open again, but the problem is in reader that if both run at same time it will crash (seen a log on 2.2.1)
+		   Note on_jump_finished (main thread) also calls updateGraphJumpsSimple(); so graph will be updated at end
+		   Note also the PrepareEventGraphJumpReactiveRealtimeCaptureObject has no SQL calls, and the PrepareEventGraphJumpReactive is not called while capture
+
 		if(! avoidGraph)
 		{
 			if(graphAllTypes)
@@ -494,6 +602,7 @@ public class JumpExecute : EventExecute
 			needUpdateGraphType = eventType.JUMP;
 			needUpdateGraph = true;
 		}
+		*/
 		
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
@@ -560,19 +669,23 @@ public class JumpRjExecute : JumpExecute
 	}
 
 	//jump execution
-	public JumpRjExecute(int personID, string personName, 
-			int sessionID, string type, double fall, double weight, 
+	public JumpRjExecute(int personID, string personName, double personWeight,
+			int sessionID, int typeID, string type, double fall, double weight,
 			double limitAsDouble, bool jumpsLimited, 
 			Chronopic cp, int pDN, bool allowFinishAfterTime,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			RepetitiveConditionsWindow repetitiveConditionsWin,
-			double progressbarLimit, ExecutingGraphData egd
+			bool metersSecondsPreferred, FeedbackWindow feedbackWin,
+			double progressbarLimit, ExecutingGraphData egd,
+			Gtk.Image image_jump_execute_air, Gtk.Image image_jump_execute_land,
+			bool upload, int uploadStationId, bool django //upload: configChronojump.Compujump && upload (contacts) button active
 			)
 	{
 		this.personID = personID;
 		this.personName = personName;
+		this.personWeight = personWeight; //for Stiffness at upload on compujump
 		this.sessionID = sessionID;
 		this.type = type;
+		this.typeID = typeID;
 		this.fall = fall;
 		this.weight = weight;
 		this.limitAsDouble = limitAsDouble;
@@ -593,12 +706,19 @@ public class JumpRjExecute : JumpExecute
 		this.allowFinishAfterTime = allowFinishAfterTime;
 		this.volumeOn = volumeOn;
 		this.gstreamer = gstreamer;
-		this.repetitiveConditionsWin = repetitiveConditionsWin;
+		this.metersSecondsPreferred = metersSecondsPreferred;
+		this.feedbackWin = feedbackWin;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 	
 		if(TypeHasFall) { hasFall = true; } 
 		else { hasFall = false; }
+
+		this.image_jump_execute_air = image_jump_execute_air;
+		this.image_jump_execute_land = image_jump_execute_land;
+		this.upload = upload;
+		this.uploadStationId = uploadStationId;
+		this.django = django;
 		
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
@@ -618,6 +738,7 @@ public class JumpRjExecute : JumpExecute
 	{
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
+		jumpChangeImage = new JumpChangeImage();
 
 		if (simulated)
 			if(hasFall) 
@@ -636,7 +757,8 @@ public class JumpRjExecute : JumpExecute
 			return;
 		}
 
-		
+		jumpChangeImageDo (platformState);
+
 		bool success = false;
 
 		if (platformState==Chronopic.Plataforma.OFF && hasFall ) {
@@ -726,6 +848,10 @@ public class JumpRjExecute : JumpExecute
 			else
 				ok = cp.Read_event(out timestamp, out platformState);
 			
+			if (platformState == Chronopic.Plataforma.OFF)
+				jumpChangeImage.Current = JumpChangeImage.Types.AIR;
+			else if (platformState == Chronopic.Plataforma.ON)
+				jumpChangeImage.Current = JumpChangeImage.Types.LAND;
 			
 			//if chronopic signal is Ok and state has changed
 			if (ok && (
@@ -1063,6 +1189,11 @@ public class JumpRjExecute : JumpExecute
 					jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated),
 					datetime);
 		else {
+			if(simulated)
+				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
+			else
+				feedbackMessage = "";
+
 			uniqueID = SqliteJumpRj.Insert(false, Constants.JumpRjTable, "NULL", personID, sessionID, 
 					type, Util.GetMax(tvString), Util.GetMax(tcString), 
 					fall, weight, description,
@@ -1074,22 +1205,31 @@ public class JumpRjExecute : JumpExecute
 			//define the created object
 			eventDone = new JumpRj(uniqueID, personID, sessionID, type, tvString, tcString, fall, weight, description, jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated), datetime);
 
+			if(upload)
+			{
+				/* debug
+				LogB.Information ("upload will start");
+				LogB.Information (string.Format (
+							"uploadStationId: {0}, (JumpRj) eventDone {1}, typeID {2}, personWeight {3}, metersSecondsPreferred {4}",
+							uploadStationId, (JumpRj) eventDone, typeID, personWeight, metersSecondsPreferred));
+				 */
+
+				UploadJumpReactiveDataObject uj = new UploadJumpReactiveDataObject (
+						uploadStationId, (JumpRj) eventDone, typeID, personWeight, metersSecondsPreferred);
+				LogB.Information ("uj: " + uj.ToString ());
+
+				JsonCompujump js = new JsonCompujump (django);
+				if( ! js.UploadJumpData (uj, Constants.Modes.JUMPSREACTIVE) )
+				{
+					LogB.Error (js.ResultMessage);
+
+					feedbackMessageOnDialog = true;
+					feedbackMessage = js.ResultMessage;
+				}
+			}
 
-			//event will be raised, and managed in chronojump.cs
-			/*
-			string myStringPush =   
-				//Catalog.GetString("Last jump: ") + 
-				personName + " " + 
-				type + " (" + limitString + ") " +
-				" " + Catalog.GetString("AVG TF") + ": " + Util.TrimDecimals( Util.GetAverage (tvString).ToString(), pDN ) +
-				" " + Catalog.GetString("AVG TC") + ": " + Util.TrimDecimals( Util.GetAverage (tcString).ToString(), pDN ) ;
-			*/
-			if(simulated)
-				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
-			else
-				feedbackMessage = "";
 			needShowFeedbackMessage = true; 
-		
+
 			needEndEvent = true; //used for hiding some buttons on eventWindow, and also for updateTimeProgressBar here
 		}
 	}
