@@ -72,9 +72,11 @@ public class RunExecute : EventExecute
 	protected static RunChangeImage runChangeImage;
 	protected static bool success;
 	protected RunExecuteInspector.Types runEIType;
+	protected static List<int> photocell_l; //for Wichro
 
 	protected Gtk.Image image_run_execute_running;
-	protected Gtk.Image image_run_execute_photocell;
+	protected Gtk.Image image_run_execute_photocell_icon;
+	protected Gtk.Label label_run_execute_photocell_code;
 
 	protected PhotocellWirelessCapture photocellWirelessCapture;
 
@@ -93,7 +95,9 @@ public class RunExecute : EventExecute
 			double progressbarLimit, ExecutingGraphData egd,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
 			bool speedStartArrival, bool measureReactionTime,
-			Gtk.Image image_run_execute_running, Gtk.Image image_run_execute_photocell,
+			Gtk.Image image_run_execute_running,
+			Gtk.Image image_run_execute_photocell_icon,
+			Gtk.Label label_run_execute_photocell_code,
 			int graphLimit, bool graphAllTypes, bool graphAllPersons
 			)
 	{
@@ -120,7 +124,8 @@ public class RunExecute : EventExecute
 		this.speedStartArrival = speedStartArrival;	
 		this.measureReactionTime = measureReactionTime;
 		this.image_run_execute_running = image_run_execute_running;
-		this.image_run_execute_photocell = image_run_execute_photocell;
+		this.image_run_execute_photocell_icon = image_run_execute_photocell_icon;
+		this.label_run_execute_photocell_code = label_run_execute_photocell_code;
 		this.graphLimit = graphLimit;
 		this.graphAllTypes = graphAllTypes;
 		this.graphAllPersons = graphAllPersons;
@@ -137,6 +142,7 @@ public class RunExecute : EventExecute
 		needCallTrackDone = false;
 		needCheckIfTrackEnded = false;
 		runEIType = RunExecuteInspector.Types.RUN_SIMPLE;
+		photocell_l = new List<int>();
 		
 		//initialize eventDone as a Run	
 		eventDone = new Run();
@@ -325,7 +331,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 			needShowFeedbackMessage = true;
 			runPhase = runPhases.START_WIRELESS_UNKNOWN;
 			//photocellWirelessCapture = new PhotocellWirelessCapture(wirelessPort);
-			photocellWirelessCapture.Reset(wirelessPort);
+			photocellWirelessCapture.Reset ();
 			photocellWirelessCapture.CaptureStart ();
 
 			manageIniWireless();
@@ -345,7 +351,15 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 					LogB.Information("waitEvent 3");
 					PhotocellWirelessEvent pwe = photocellWirelessCapture.PhotocellWirelessCaptureReadNext();
 					LogB.Information("wait_event pwe: " + pwe.ToString());
+
 					photocell = pwe.photocell;
+
+					/*
+					//to debug photocell assignement on Wichro.
+					Random randDelete = new Random();
+					photocell = randDelete.Next(0,10);
+					*/
+
 					timestamp = pwe.timeMs - timestampAccumulated; //photocell does not send splittime, sends absolute time
 					timestampAccumulated += timestamp;
 
@@ -371,14 +385,14 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 					firstFromChronopicReceived = true;
 				}
 
-				onlyInterval_CalculateDistanceIntervalFixed();
-
 				//LogB.Information("timestamp:" + timestamp);
 				if (has_arrived()) // timestamp is tf
 				{
 					LogB.Information("has arrived");
 					loggedState = States.ON;
 					runChangeImage.Current = RunChangeImage.Types.PHOTOCELL;
+					if(wireless)
+						runChangeImage.Photocell = photocell;
 
 					onlyInterval_NeedShowCountDownFalse();
 
@@ -421,7 +435,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						//prevent double contact stuff
 						if(runDC.UseDoubleContacts())
 						{
-							runDC.DoneTF (timestamp);
+							runDC.DoneTF (timestamp, photocell);
 							timerLastTf = DateTime.Now;
 							needCheckIfTrackEnded = true;
 						} else
@@ -469,7 +483,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						 * other double contacts that will come just after
 						 * depending on biggest tc
 						 */
-						runDC.DoneTC(timestamp, false);
+						runDC.DoneTC(timestamp, false, photocell);
 						runPTL.AddTC(photocell, timestamp);
 
 						feedbackMessage = "";
@@ -485,7 +499,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 							lastTc = timestamp / 1000.0;
 							runEI.ChangePhase(photocell, RunExecuteInspector.Phases.OUT,
 								string.Format("SpeedStartArrival, tc = {0}", Math.Round(lastTc, 3)));
-							runDC.DoneTC(timestamp, true);
+							runDC.DoneTC(timestamp, true, photocell);
 							runPTL.AddTC(photocell, timestamp);
 						}
 
@@ -496,7 +510,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 								string.Format("SpeedStartArrival, timestamp = {0}", timestamp));
 
 						if(runDC.UseDoubleContacts())
-							runDC.DoneTC(timestamp, true);
+							runDC.DoneTC(timestamp, true, photocell);
 						else
 							lastTc = timestamp / 1000.0;
 
@@ -539,9 +553,6 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 	
 	/* only run interval functions */
 
-	protected virtual void onlyInterval_CalculateDistanceIntervalFixed()
-	{
-	}
 	protected virtual void onlyInterval_NeedShowCountDownFalse()
 	{
 	}
@@ -559,13 +570,23 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 		if(runDC.UseDoubleContacts())
 		{
 			LogB.Information(string.Format("success: {0}, cancel: {1}, finish: {2}", success, cancel, finish));
-			while(needCheckIfTrackEnded)
+
+			//to avoid get hung waiting needCheckIfTrackEnded
+			DateTime started = DateTime.Now;
+			TimeSpan span = DateTime.Now - started;
+
+			while(needCheckIfTrackEnded && span.TotalMilliseconds < checkDoubleContactTime * 1.5)
 			{
 				LogB.Information("WAITING 100 MS TO EXIT BUCLE");
 				//TODO: checks what happens with cancel... in the pulse thread, will change this boolean? needCheckIfTrackEnded
 				//TODO: also think on what happens if needCheckIfTrackEnded never gets negative
 				Thread.Sleep(100);
+				span = DateTime.Now - started;
 			}
+			if(! needCheckIfTrackEnded)
+				LogB.Information("Exited 100 MS BUCLE because needCheckIfTrackEnded is false");
+			else
+				LogB.Information("Exited 100 MS BUCLE because time exceded");
 
 			return true;
 		}
@@ -581,23 +602,31 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 		if(runChangeImage.Current == RunChangeImage.Types.RUNNING)
 		{
 			image_run_execute_running.Visible = true;
-			image_run_execute_photocell.Visible = false;
+			image_run_execute_photocell_icon.Visible = false;
+			label_run_execute_photocell_code.Visible = false;
 		}
 		else if(runChangeImage.Current == RunChangeImage.Types.PHOTOCELL)
 		{
 			image_run_execute_running.Visible = false;
-			image_run_execute_photocell.Visible = true;
+			image_run_execute_photocell_icon.Visible = true;
+			if(runChangeImage.Photocell >= 0)
+			{
+				label_run_execute_photocell_code.Text = runChangeImage.Photocell.ToString();
+				label_run_execute_photocell_code.Visible = true;
+			}
 		} else
 		{
 			image_run_execute_running.Visible = false;
-			image_run_execute_photocell.Visible = false;
+			image_run_execute_photocell_icon.Visible = false;
+			label_run_execute_photocell_code.Visible = false;
 		}
 	}
 
 	protected override void runChangeImageForceHide()
 	{
 		image_run_execute_running.Visible = false;
-		image_run_execute_photocell.Visible = false;
+		image_run_execute_photocell_icon.Visible = false;
+		label_run_execute_photocell_code.Visible = false;
 	}
 
 	protected override void updateRunPhaseInfoManage()
@@ -673,10 +702,25 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						runDC.UpdateStartPos(1);
 					}
 				}
-
 			}
 
+			//store because runDC.GetTrackTimeInSecondsAndUpdateStartPos() will change it
+			int photocellAtStartPos = runDC.GetPhotocellAtStartPos();
+
 			trackTime = runDC.GetTrackTimeInSecondsAndUpdateStartPos(); //will come in seconds
+
+			//add photocell to photocell_l
+			if(trackTime != 0)
+			{
+				if(photocell_l.Count == 0)
+				{
+					photocell_l.Add(photocellAtStartPos);
+					LogB.Information("photocell_l.Add at start photocell_l: " + photocellAtStartPos.ToString());
+				}
+				photocell_l.Add(runDC.GetPhotocellAtStartPos());
+				LogB.Information("photocell_l.Add photocell_l: " + runDC.GetPhotocellAtStartPos().ToString());
+			}
+
 			runDC.FirstTrackDone = true;
 		}
 		else {
@@ -828,7 +872,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 				!startIn,	//initialSpeed true if not startIn
 				datetime
 				); 
-		
+
 		//define the created object
 		eventDone = new Run(uniqueID, personID, sessionID, type, distance, trackTime, description,
 				Util.BoolToNegativeInt(simulated), !startIn, datetime);
@@ -836,6 +880,12 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 		if(graphAllTypes)
 			type = "";
 
+		/* 2.2.2 do not do the graph here because PrepareEventGraphRunSimple has an SQL call with a reader
+		   and updateGraph can be also called by gtk thread and also call PrepareEventGraphRunSimple,
+		   so SQL can be tried to open again, but the problem is in reader that if both run at same time it will crash (seen a log on 2.2.1)
+		   Note on_run_finished (main thread) also calls updateGraphRunsSimple(); so graph will be updated at end
+		   Note also the PrepareEventGraphRunIntervalRealtimeCaptureObject has no SQL calls, and the PrepareEventGraphRunInterval is not called while capture
+
 		//app1.PrepareRunSimpleGraph(time, distance/time);
 		PrepareEventGraphRunSimpleObject = new PrepareEventGraphRunSimple(
 				trackTime, distance/trackTime, sessionID,
@@ -844,6 +894,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 
 		needUpdateGraphType = eventType.RUN;
 		needUpdateGraph = true;
+		*/
 		
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
@@ -891,7 +942,6 @@ public class RunIntervalExecute : RunExecute
 	bool tracksLimited;
 
 	string distancesString; //if distances are variable (distanceInterval == -1), this is used
-	double distanceIntervalFixed; //if distanceInterval == -1, then Fixed is the corresponding base on distancesString
 
 	//static because they are used on both threads at the same time
 	static double tracks; //double because if we limit by time (runType tracksLimited false), we do n.nn tracks
@@ -913,11 +963,13 @@ public class RunIntervalExecute : RunExecute
 			string wirelessPort, int wirelessBauds,
 			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			RepetitiveConditionsWindow repetitiveConditionsWin,
+			FeedbackWindow feedbackWin,
 			double progressbarLimit, ExecutingGraphData egd ,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
 			bool speedStartArrival, bool measureReactionTime,
-			Gtk.Image image_run_execute_running, Gtk.Image image_run_execute_photocell
+			Gtk.Image image_run_execute_running,
+			Gtk.Image image_run_execute_photocell_icon,
+			Gtk.Label label_run_execute_photocell_code
 			)
 	{
 		this.personID = personID;
@@ -956,7 +1008,7 @@ public class RunIntervalExecute : RunExecute
 		this.pDN = pDN;
 		this.volumeOn = volumeOn;
 		this.gstreamer = gstreamer;
-		this.repetitiveConditionsWin = repetitiveConditionsWin;
+		this.feedbackWin = feedbackWin;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 		this.checkDoubleContactMode = checkDoubleContactMode;
@@ -964,7 +1016,8 @@ public class RunIntervalExecute : RunExecute
 		this.speedStartArrival = speedStartArrival;	
 		this.measureReactionTime = measureReactionTime;
 		this.image_run_execute_running = image_run_execute_running;
-		this.image_run_execute_photocell = image_run_execute_photocell;
+		this.image_run_execute_photocell_icon = image_run_execute_photocell_icon;
+		this.label_run_execute_photocell_code = label_run_execute_photocell_code;
 
 		reactionTimeMS = 0;
 		reactionTimeIncludedStr = Catalog.GetString("Included on race time of first track");
@@ -986,11 +1039,12 @@ public class RunIntervalExecute : RunExecute
 		//initialize variables
 		equal = "";
 		intervalTimesString = "";
-		distanceIntervalFixed = distanceInterval;
 		tracks = 0;
 		//countForSavingTempTable = 0;
 		finishByTimeReturnedTrueAtThisCapture = false;
 
+		photocell_l = new List<int>();
+
 		//initialize eventDone as a RunInterval
 		eventDone = new RunInterval();
 	}
@@ -998,12 +1052,6 @@ public class RunIntervalExecute : RunExecute
 
 	/* only run interval functions */
 
-	protected override void onlyInterval_CalculateDistanceIntervalFixed()
-	{
-		if(distanceInterval == -1)
-			distanceIntervalFixed = Util.GetRunIVariableDistancesStringRow(distancesString, (int) tracks);
-	}
-					
 	protected override void onlyInterval_NeedShowCountDownFalse()
 	{
 		//show RSA count down only on air
@@ -1114,8 +1162,8 @@ public class RunIntervalExecute : RunExecute
 
 		//update graph
 		PrepareEventGraphRunIntervalRealtimeCaptureObject = new PrepareEventGraphRunIntervalRealtimeCapture (
-				type, distanceIntervalFixed, trackTime, intervalTimesString,
-				distanceTotal, distancesString, startIn, success);
+				type, intervalTimesString, distanceInterval, distancesString,
+				photocell_l, startIn, success);
 
 		needUpdateGraphType = eventType.RUNINTERVAL;
 		needUpdateGraph = true;
@@ -1318,7 +1366,8 @@ public class RunIntervalExecute : RunExecute
 					limitString,
 					Util.BoolToNegativeInt(simulated),
 					!startIn,	//initialSpeed true if not startIn
-					datetime
+					datetime,
+					photocell_l
 					);
 		else {
 			uniqueID = SqliteRunInterval.Insert(false, Constants.RunIntervalTable, "NULL", personID, sessionID, type, 
@@ -1328,28 +1377,14 @@ public class RunIntervalExecute : RunExecute
 					limitString,
 					Util.BoolToNegativeInt(simulated),
 					!startIn,
-					datetime
+					datetime,
+					photocell_l
 					);
 
 			//define the created object
 			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString,
-					tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn, datetime); 
+					tracksHere, description, limitString, Util.BoolToNegativeInt(simulated), !startIn, datetime, photocell_l);
 
-			/*
-			string tempValuesString;
-			if(tracksLimited) 
-				tempValuesString = " (" + distanceIntervalFixed + "x" + tracksHere + "R), " + Catalog.GetString("Time") + ": " + Util.TrimDecimals( timeTotal.ToString(), pDN);
-			else
-				tempValuesString = " (" + distanceIntervalFixed + "x" + Util.TrimDecimals( timeTotal.ToString(), pDN) + "T), " + Catalog.GetString("Tracks") + ": " + tracksHere;
-
-
-			string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + ", " + 
-				type + tempValuesString + ", " +
-				Catalog.GetString("AVG Speed") + ": " + Util.TrimDecimals( 
-						Util.GetSpeed(distanceTotal.ToString(),
-							timeTotal.ToString(), metersSecondsPreferred )
-						, pDN ) ;
-			*/
 			if(simulated)
 				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
 			else
@@ -1357,8 +1392,8 @@ public class RunIntervalExecute : RunExecute
 			needShowFeedbackMessage = true; 
 
 			PrepareEventGraphRunIntervalRealtimeCaptureObject = new PrepareEventGraphRunIntervalRealtimeCapture (
-					type, distanceIntervalFixed, trackTime, intervalTimesString,
-					distanceTotal, distancesString, startIn, true);
+					type, intervalTimesString, distanceInterval, distancesString,
+					photocell_l, startIn, success);
 
 			needUpdateGraphType = eventType.RUNINTERVAL;
 			needUpdateGraph = true;
