@@ -155,15 +155,21 @@ public class ForceSensor
 	}
 
 	//for load window
-	public string [] ToStringArray (int count)
+	public string [] ToStringArray (int count, Constants.Modes mode)
 	{
-		int all = 11;
+		int all = 10;
+		if (mode == Constants.Modes.FORCESENSORELASTIC)
+			all = 11; 	//only show stiffness on elastic
+
 		string [] str = new String [all];
 		int i=0;
 		str[i++] = uniqueID.ToString();
 		str[i++] = count.ToString();
 		str[i++] = exerciseName;
-		str[i++] = exerciseElasticStiffnessString();
+
+		if (mode == Constants.Modes.FORCESENSORELASTIC)
+			str[i++] = exerciseElasticStiffnessString();
+
 		str[i++] = Catalog.GetString(GetCaptureOptionsString(captureOption));
 		str[i++] = Catalog.GetString(laterality);
 		if(maxForceRaw == -1)
@@ -353,6 +359,17 @@ public class ForceSensor
 		}
 	}
 
+	//used to do selects on the software
+	public static int GetElasticIntFromMode (Constants.Modes mode)
+	{
+		int elastic = -1;
+		if (mode == Constants.Modes.FORCESENSORISOMETRIC)
+			elastic = 0;
+		else if (mode == Constants.Modes.FORCESENSORELASTIC)
+			elastic = 1;
+
+		return elastic;
+	}
 
 
 	public string Filename
@@ -429,7 +446,10 @@ public class ForceSensorExercise
 	private string description;
 	private bool tareBeforeCapture;
 	private bool forceResultant;
-	private bool elastic;
+
+	public enum Types { ISOMETRIC, ELASTIC, BOTH };
+	private Types type;
+
 	//private bool eccReps;
 	public enum RepetitionsShowTypes { CONCENTRIC, BOTHTOGETHER, BOTHSEPARATED };
 	private RepetitionsShowTypes repetitionsShow;
@@ -447,7 +467,7 @@ public class ForceSensorExercise
 	{
 		//default values
 		this.forceResultant = false;
-		this.elastic = false;
+		this.type = Types.ISOMETRIC;
 	}
 
 	public ForceSensorExercise(string name)
@@ -456,12 +476,12 @@ public class ForceSensorExercise
 
 		//default values
 		this.forceResultant = false;
-		this.elastic = false;
+		this.type = Types.ISOMETRIC;
 	}
 
 	public ForceSensorExercise(int uniqueID, string name, int percentBodyWeight, string resistance, int angleDefault,
-			string description, bool tareBeforeCapture, bool forceResultant, bool elastic,
-			RepetitionsShowTypes repetitionsShow, double eccMin, double conMin)
+			string description, bool tareBeforeCapture, bool forceResultant,
+			Types type, RepetitionsShowTypes repetitionsShow, double eccMin, double conMin)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -471,7 +491,7 @@ public class ForceSensorExercise
 		this.description = description;
 		this.tareBeforeCapture = tareBeforeCapture;
 		this.forceResultant = forceResultant;
-		this.elastic = elastic;
+		this.type = type;
 		this.repetitionsShow = repetitionsShow;
 		this.eccMin = eccMin;
 		this.conMin = conMin;
@@ -479,7 +499,7 @@ public class ForceSensorExercise
 
 	//constructor at DB: 1.86
 	public ForceSensorExercise(int uniqueID, string name, int percentBodyWeight, string resistance, int angleDefault,
-			string description, bool tareBeforeCapture, bool forceResultant, bool elastic)
+			string description, bool tareBeforeCapture, bool forceResultant, Types type)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -489,14 +509,15 @@ public class ForceSensorExercise
 		this.description = description;
 		this.tareBeforeCapture = tareBeforeCapture;
 		this.forceResultant = forceResultant;
-		this.elastic = elastic;
+		this.type = type;
 	}
 
 	public override string ToString()
 	{
 		return uniqueID.ToString() + ":" + name + ":" + percentBodyWeight.ToString() + ":" +
 			resistance + ":" + angleDefault.ToString() + ":" + description + ":" +
-			tareBeforeCapture.ToString() + ":" + forceResultant.ToString() + ":" + elastic.ToString() + ":" +
+			tareBeforeCapture.ToString() + ":" + forceResultant.ToString() + ":" +
+			type.ToString() + ":" +
 			repetitionsShow.ToString() + ":" + eccMin.ToString() + ":" + conMin.ToString();
 	}
 
@@ -532,6 +553,25 @@ public class ForceSensorExercise
 		return RepetitionsShowTypes.CONCENTRIC;
 	}
 
+	public int TypeToInt ()
+	{
+		if (type == Types.ISOMETRIC)
+			return 0;
+		else if (type == Types.ELASTIC)
+			return 1;
+		else //if (type == Types.BOTH)
+			return -1; //-1 as is the same than a select inespecific
+	}
+	public static Types IntToType (int i)
+	{
+		if (i == 0)
+			return Types.ISOMETRIC;
+		else if (i == 1)
+			return Types.ELASTIC;
+		else //if (type == -1)
+			return Types.BOTH; //-1 as is the same than a select inespecific
+	}
+
 	public string ToSQLInsertString()
 	{
 		string uniqueIDStr = "NULL";
@@ -543,7 +583,7 @@ public class ForceSensorExercise
 			resistance + "\", " + angleDefault + ", \"" + description + "\", " +
 			Util.BoolToInt(tareBeforeCapture).ToString() + ", " +
 			Util.BoolToInt(forceResultant).ToString() + ", " +
-			Util.BoolToInt(elastic).ToString() + ", " +
+			TypeToInt ().ToString() + ", " +
 			RepetitionsShowToCode().ToString() + ", " +
 			Util.ConvertToPoint(eccMin) + ", " + Util.ConvertToPoint(conMin);
 	}
@@ -561,7 +601,7 @@ public class ForceSensorExercise
 			Util.BoolToInt(tareBeforeCapture).ToString();
 	}
 
-	public bool Changed(ForceSensorExercise newEx)
+	public bool Changed (ForceSensorExercise newEx)
 	{
 		if(
 				name == newEx.Name &&
@@ -569,9 +609,9 @@ public class ForceSensorExercise
 				resistance == newEx.Resistance &&
 				angleDefault == newEx.AngleDefault &&
 				description == newEx.Description &&
-				tareBeforeCapture == newEx.TareBeforeCapture &&
+				tareBeforeCapture == newEx.TareBeforeCaptureOnExerciseEdit &&
 				forceResultant == newEx.ForceResultant &&
-				elastic == newEx.Elastic &&
+				type == newEx.Type &&
 				repetitionsShow == newEx.RepetitionsShow &&
 				eccMin == newEx.EccMin &&
 				conMin == newEx.ConMin)
@@ -606,7 +646,22 @@ public class ForceSensorExercise
 		get { return description; }
 		set { description = value; }
 	}
-	public bool TareBeforeCapture
+
+	/*
+	   at exercise edit with forceResultant, user can select tareBeforeCapture
+	   if edit again and select forceRaw, tareBeforeCapture bool is still ok on sqlite,
+	   just to be shown again if user want to go to forceResultant again.
+	   So this applies to TareBeforeCaptureOnExerciseEdit
+
+	   But, on capture, only apply tareBeforeCapture if forceResultant is true,
+	   so useTareBeforeCaptureAndForceResultant
+	   */
+
+	public bool TareBeforeCaptureAndForceResultant
+	{
+		get { return (tareBeforeCapture && forceResultant); }
+	}
+	public bool TareBeforeCaptureOnExerciseEdit
 	{
 		get { return tareBeforeCapture; }
 	}
@@ -614,13 +669,14 @@ public class ForceSensorExercise
 	{
 		get { return forceResultant; }
 	}
-	public bool Elastic //TODO: take care because ComputeAsElastic is much better criteria
+
+	public Types Type
 	{
-		get { return elastic; }
+		get { return type; }
 	}
 	public bool ComputeAsElastic //use this
 	{
-		get { return forceResultant && elastic; }
+		get { return forceResultant && type != Types.ISOMETRIC; }
 	}
 	public RepetitionsShowTypes RepetitionsShow
 	{
@@ -869,8 +925,8 @@ public class ForceSensorCapturePoints
 
 	public int RealWidthG; //width of graph in microseconds (will be upgraded if needed, but not while capturing on scroll)
 
-	public const int DefaultRealHeightG = 2;
-	public const int DefaultRealHeightGNeg = 2; //absolute values
+	public const int DefaultRealHeightG = 50;
+	public const int DefaultRealHeightGNeg = 50; //absolute values
 	public int RealHeightG; //Newtons (will be upgraded if needed)
 	public int RealHeightGNeg; //Newtons (negative) (will be upgraded if needed) //absolute values
 
@@ -1171,9 +1227,9 @@ public class ForceSensorCapturePoints
 		return sum * UtilAll.DivideSafe(elapsedSeconds, samples);
 	}
 	
-	public void GetVariabilityAndAccuracy(int countA, int countB, int feedbackF,
+	public void GetVariabilityAndAccuracy (int countA, int countB, int feedbackF,
 			out double variability, out double feedbackDifference,
-			Preferences.VariabilityMethodEnum variabilityMethod)
+			Preferences.VariabilityMethodEnum variabilityMethod, int lag)
 	{
 		if(countA == countB)
 		{
@@ -1190,7 +1246,7 @@ public class ForceSensorCapturePoints
 		if(variabilityMethod == Preferences.VariabilityMethodEnum.CHRONOJUMP_OLD)
 			variability = getVariabilityOldMethod (countA, countB, numSamples);
 		else
-			variability = getVariabilityRMSSDCVRMSSD (variabilityMethod, countA, countB, numSamples);
+			variability = getVariabilityRMSSDCVRMSSD (variabilityMethod, lag, countA, countB, numSamples);
 
 		// 3) Calculate difference.
 		// Average of the differences between force and average
@@ -1203,7 +1259,7 @@ public class ForceSensorCapturePoints
 
 		feedbackDifference = UtilAll.DivideSafe(sum, numSamples);
 	}
-	private double getVariabilityRMSSDCVRMSSD (Preferences.VariabilityMethodEnum method, int countA, int countB, int numSamples)
+	private double getVariabilityRMSSDCVRMSSD (Preferences.VariabilityMethodEnum method, int lag, int countA, int countB, int numSamples)
 	{
 		//see a test of this method below:
 		//public static void TestVariabilityCVRMSSD()
@@ -1211,13 +1267,13 @@ public class ForceSensorCapturePoints
 		//sqrt(Σ( x_i - x_{i+1})^2 /(n-1)) )   //note pow should be inside the summation
 		double sum = 0;
 		double sumForMean = 0;
-		for(int i = countA; i < countB; i ++)
+		for(int i = countA; i+lag <= countB; i ++)
 		{
-			sum += Math.Pow(forces[i] - forces[i+1], 2);
+			sum += Math.Pow(forces[i] - forces[i+lag], 2);
 			sumForMean += forces[i];
 		}
 
-		double rmssd = Math.Sqrt(UtilAll.DivideSafe(sum, numSamples -1));
+		double rmssd = Math.Sqrt(UtilAll.DivideSafe(sum, numSamples -lag));
 		LogB.Information("RMSSD: " + rmssd.ToString());
 
 		if(method == Preferences.VariabilityMethodEnum.RMSSD)
@@ -1245,25 +1301,25 @@ public class ForceSensorCapturePoints
 		return UtilAll.DivideSafe(sum, numSamples);
 	}
 
-	public static void TestVariabilityCVRMSSD()
+	public static void TestVariabilityCVRMSSD (int lag)
 	{
 		/*
 		   R psych test:
 		   library("psych")
-		   > x=c(21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8)
+		   > x=c(21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8, -15.9, -11.5, -2, 5.3)
 		   > rmssd(x,group=NULL, lag=1, na.rm=TRUE)
 		   [1] 234.2467
 		*/
 
 		ForceSensorCapturePoints fscp = new ForceSensorCapturePoints(
 				ForceSensorCapturePoints.GraphTypes.FORCESIGNAL, 300, 300, 10);
-		List <double> nums = new List<double> {21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8};
+		List <double> nums = new List<double> {21, 45, 75, 54, 5.5, 545.5, 44, 17, 8, -15, -12.8, -15.9, -11.5, -2, 5.3};
 		for (int i = 0; i < nums.Count; i ++)
 			fscp.Add(i+1, nums[i]);
 
 		double variability = 0;
 		double feedbackDiff = 0;
-		fscp.GetVariabilityAndAccuracy(0, nums.Count -1, 20, out variability, out feedbackDiff, Preferences.VariabilityMethodEnum.CVRMSSD);
+		fscp.GetVariabilityAndAccuracy (0, nums.Count -1, 20, out variability, out feedbackDiff, Preferences.VariabilityMethodEnum.CVRMSSD, lag);
 		LogB.Information("cvRMSSD: " + variability);
 	}
 
@@ -1543,11 +1599,12 @@ public class ForceSensorRFD
 	protected static string function_FITTED_name = "Fitted";
 
 	//if these names change, change TypePrint() below
-	public enum Types { INSTANTANEOUS, AVERAGE, PERCENT_F_MAX, RFD_MAX, IMP_UNTIL_PERCENT_F_MAX, IMP_RANGE } //on SQL is inserted like this
+	public enum Types { INSTANTANEOUS, AVERAGE, PERCENT_F_MAX, RFD_MAX, BEST_AVG_RFD_IN_X_MS, IMP_UNTIL_PERCENT_F_MAX, IMP_RANGE } //on SQL is inserted like this
 	private static string type_INSTANTANEOUS_name = "Instantaneous";
 	private static string type_AVERAGE_name = "Average";
 	private static string type_PERCENT_F_MAX_name = "% Force max";
 	private static string type_RFD_MAX_name = "RFD max";
+	private static string type_BEST_AVG_RFD_IN_X_MS_name = "Best average RFD";
 
 	public string code; //RFD1...4 //I: on impulse
 	public bool active;
@@ -1594,11 +1651,14 @@ public class ForceSensorRFD
 		if(translated)
 			return new string [] {
 				Catalog.GetString(type_INSTANTANEOUS_name), Catalog.GetString(type_AVERAGE_name),
-				Catalog.GetString(type_PERCENT_F_MAX_name), Catalog.GetString(type_RFD_MAX_name)
+					Catalog.GetString(type_PERCENT_F_MAX_name), Catalog.GetString(type_RFD_MAX_name),
+					Catalog.GetString(type_BEST_AVG_RFD_IN_X_MS_name)
 			};
 		else
 			return new string [] {
-				type_INSTANTANEOUS_name, type_AVERAGE_name, type_PERCENT_F_MAX_name, type_RFD_MAX_name
+				type_INSTANTANEOUS_name, type_AVERAGE_name,
+					type_PERCENT_F_MAX_name, type_RFD_MAX_name,
+					type_BEST_AVG_RFD_IN_X_MS_name
 			};
 	}
 
@@ -1619,30 +1679,36 @@ public class ForceSensorRFD
 
 	public virtual string TypePrint(bool translated)
 	{
-		if(type == Types.INSTANTANEOUS) {
-			if(translated)
-				return Catalog.GetString(type_INSTANTANEOUS_name);
+		if (type == Types.INSTANTANEOUS) {
+			if (translated)
+				return Catalog.GetString (type_INSTANTANEOUS_name);
 			else
 				return type_INSTANTANEOUS_name;
 		}
-		else if(type == Types.AVERAGE) {
-			if(translated)
-				return Catalog.GetString(type_AVERAGE_name);
+		else if (type == Types.AVERAGE) {
+			if (translated)
+				return Catalog.GetString (type_AVERAGE_name);
 			else
 				return type_AVERAGE_name;
 		}
-		else if(type == Types.PERCENT_F_MAX) {
-			if(translated)
-				return Catalog.GetString(type_PERCENT_F_MAX_name);
+		else if (type == Types.PERCENT_F_MAX) {
+			if (translated)
+				return Catalog.GetString (type_PERCENT_F_MAX_name);
 			else
 				return type_PERCENT_F_MAX_name;
 		}
-		else { //if(type == Types.RFD_MAX)
-			if(translated)
-				return Catalog.GetString(type_RFD_MAX_name);
+		else if (type == Types.RFD_MAX) {
+			if (translated)
+				return Catalog.GetString (type_RFD_MAX_name);
 			else
 				return type_RFD_MAX_name;
 		}
+		else { //if (type == Types.BEST_AVG_RFD_IN_X_MS)
+			if (translated)
+				return Catalog.GetString (type_BEST_AVG_RFD_IN_X_MS_name);
+			else
+				return type_BEST_AVG_RFD_IN_X_MS_name;
+		}
 	}
 
 	public string ToSQLInsertString()
@@ -1699,6 +1765,10 @@ public class ForceSensorRFD
 	{
 		get { return type_RFD_MAX_name; }
 	}
+	public static string Type_BEST_AVG_RFD_IN_X_MS_name
+	{
+		get { return type_BEST_AVG_RFD_IN_X_MS_name; }
+	}
 }
 
 public class ForceSensorImpulse : ForceSensorRFD
@@ -2509,9 +2579,9 @@ public class ForceSensorAnalyzeInstant
 
 	public void CalculateVariabilityAndAccuracy(int countA, int countB,
 			int feedbackF, out double variability, out double feedbackDifference,
-			Preferences.VariabilityMethodEnum variabilityMethod)
+			Preferences.VariabilityMethodEnum variabilityMethod, int lag)
 	{
-		fscAIPoints.GetVariabilityAndAccuracy(countA, countB, feedbackF, out variability, out feedbackDifference, variabilityMethod);
+		fscAIPoints.GetVariabilityAndAccuracy (countA, countB, feedbackF, out variability, out feedbackDifference, variabilityMethod, lag);
 	}
 	/*
 	 * Calculates RFD in a point using previous and next point
