@@ -32,9 +32,9 @@ using Mono.Unix;
 public partial class ChronoJumpWindow
 {
 	[Widget] Gtk.Alignment alignment_session_persons;
-	[Widget] Gtk.VBox vbox_manage_persons;
-	[Widget] Gtk.Arrow arrow_manage_persons_up;
-	[Widget] Gtk.Arrow arrow_manage_persons_down;
+	[Widget] Gtk.EventBox eventbox_button_person_close;
+	[Widget] Gtk.Image image_person_manage_blue;
+	[Widget] Gtk.Image image_person_manage_yellow;
 
 	private void showPersonsOnTop (bool onTop)
 	{
@@ -69,15 +69,12 @@ public partial class ChronoJumpWindow
 		{
 			Pixbuf pixbuf = new Pixbuf (filenameMini);
 			image_current_person.Pixbuf = pixbuf;
-			button_image_current_person_zoom_h.Sensitive = true;
 		} else {
 			//image_current_person.Pixbuf = null;
 			Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
 			if(Config.ColorBackgroundIsDark)
 				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo_yellow.png");
 			image_current_person.Pixbuf = pixbuf;
-
-			button_image_current_person_zoom_h.Sensitive = false;
 		}
 	}
 
@@ -256,13 +253,13 @@ public partial class ChronoJumpWindow
 	private void person_add_multiple ()
 	{
 		personAddMultipleWin = PersonAddMultipleWindow.Show(app1, currentSession, preferences.CSVColumnDelimiter);
-		personAddMultipleWin.Button_accept.Clicked -= new EventHandler(on_person_add_multiple_accepted);
-		personAddMultipleWin.Button_accept.Clicked += new EventHandler(on_person_add_multiple_accepted);
+		personAddMultipleWin.FakeButtonDone.Clicked -= new EventHandler(on_person_add_multiple_accepted);
+		personAddMultipleWin.FakeButtonDone.Clicked += new EventHandler(on_person_add_multiple_accepted);
 	}
 	
 	private void on_person_add_multiple_accepted (object o, EventArgs args)
 	{
-		personAddMultipleWin.Button_accept.Clicked -= new EventHandler(on_person_add_multiple_accepted);
+		personAddMultipleWin.FakeButtonDone.Clicked -= new EventHandler(on_person_add_multiple_accepted);
 		if (personAddMultipleWin.CurrentPerson != null)
 		{
 			currentPerson = personAddMultipleWin.CurrentPerson;
@@ -352,8 +349,12 @@ public partial class ChronoJumpWindow
 
 	private void on_show_all_person_events_activate (object o, EventArgs args)
 	{
+		Person p = new Person (); //uniqueID = -1
+		if (currentPerson != null)
+			p = currentPerson;
+
 		personShowAllEventsWin = PersonShowAllEventsWindow.Show(app1,
-				currentSession.UniqueID, currentPerson, true, preferences.colorBackground);
+				currentSession.UniqueID, p, true, preferences.colorBackground);
 	}
 	
 	
@@ -398,6 +399,10 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
+		//personSelectWindow is not modal to allow other windows to show on top
+		//but not allow to change session while personSelectWindow is active
+		vbox_menu_tiny.Sensitive = false;
+
 		//if not compujump show person change window
 		ArrayList myPersons = SqlitePersonSession.SelectCurrentSessionPersons(
 				currentSession.UniqueID, 
@@ -489,6 +494,8 @@ public partial class ChronoJumpWindow
 
 	private void on_button_top_person_change_done(object o, EventArgs args)
 	{
+		vbox_menu_tiny.Sensitive = true;
+
 		if(personSelectWin.SelectedPerson == null)
 			return;
 
