@@ -38,10 +38,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_db_backup;
 	[Widget] Gtk.Image image_db_view;
 	[Widget] Gtk.Image image_mode_encoder_capture;
-	[Widget] Gtk.Image image_current_person_zoom_h;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person1;
-	[Widget] Gtk.Image image_person2;
 	[Widget] Gtk.Image image_edit_current_person_h;
 	//[Widget] Gtk.Image image_persons_up;
 	//[Widget] Gtk.Image image_persons_down;
@@ -53,10 +51,18 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_contacts_recalculate;
 	[Widget] Gtk.Image image_all_persons_events_h;
 	[Widget] Gtk.Image image_person_delete_h;
+	[Widget] Gtk.Image image_merge_persons;
 	[Widget] Gtk.Image image_chronopic_connect_contacts;
+	[Widget] Gtk.Image image_chronopic_connect_contacts1;
+	[Widget] Gtk.Image image_chronopic_connect_contacts2;
+	[Widget] Gtk.Image image_chronopic_connect_contacts3;
+	[Widget] Gtk.Image image_chronopic_connect_contacts4;
 	[Widget] Gtk.Image image_chronopic_connect_encoder;
 	[Widget] Gtk.Image image_chronopic_connect_encoder1;
 	[Widget] Gtk.Image image_chronopic_connect_encoder2;
+	[Widget] Gtk.Image image_micro_discover_device;
+	[Widget] Gtk.Image image_button_contacts_detect;
+	[Widget] Gtk.Image image_button_encoder_detect;
 	[Widget] Gtk.Image image_button_execute;
 	[Widget] Gtk.Image image_contacts_bell;
 	[Widget] Gtk.Image image_contacts_close_and_capture;
@@ -88,29 +94,20 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_logo_encoder;
 	[Widget] Gtk.Image image_logo_encoder_transp;
 
-	[Widget] Gtk.Image image_selector_start_jumps;
-	[Widget] Gtk.Image image_selector_start_runs;
-	[Widget] Gtk.Image image_selector_start_encoder;
-	[Widget] Gtk.Image image_selector_start_rt;
-	[Widget] Gtk.Image image_selector_start_other;
-	[Widget] Gtk.Image image_selector_start_back;
+	[Widget] Gtk.Image image_selector_start_jumps1;
+	[Widget] Gtk.Image image_selector_start_runs1;
+	[Widget] Gtk.Image image_selector_start_isometric;
+	[Widget] Gtk.Image image_selector_start_elastic;
+	[Widget] Gtk.Image image_selector_start_displ_weights;
+	[Widget] Gtk.Image image_selector_start_inertial;
 
-	[Widget] Gtk.Image image_mode_jumps_small;
-	[Widget] Gtk.Image image_mode_jumps_reactive_small;
-	[Widget] Gtk.Image image_mode_runs_small;
-	[Widget] Gtk.Image image_mode_runs_small1;
-	[Widget] Gtk.Image image_mode_runs_intervallic_small;
-	[Widget] Gtk.Image image_mode_runs_intervallic_small1;
-	[Widget] Gtk.Image image_mode_race_encoder_small;
-	[Widget] Gtk.Image image_mode_pulses_small;
-	[Widget] Gtk.Image image_mode_multi_chronopic_small;
-	[Widget] Gtk.Image image_mode_encoder_gravitatory;
-	[Widget] Gtk.Image image_mode_encoder_inertial;
-
-	[Widget] Gtk.Label label_start_selector_jumps;
-	[Widget] Gtk.Label label_start_selector_races1;
-	[Widget] Gtk.Label label_start_selector_races;
-	[Widget] Gtk.Label label_start_selector_encoder;
+	//[Widget] Gtk.Image image_down_menu_2_2_2;
+	[Widget] Gtk.Image image_start;
+	[Widget] Gtk.Image image_mode_jumps_small1;
+	[Widget] Gtk.Image image_mode_jumps_reactive_small1;
+	[Widget] Gtk.Image image_mode_runs_small2;
+	[Widget] Gtk.Image image_mode_runs_intervallic_small2;
+	[Widget] Gtk.Image image_mode_race_encoder_small1;
 
 	[Widget] Gtk.Image image_button_help_close;
 
@@ -125,10 +122,15 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_button_contacts_capture_save_image_chart;
 	[Widget] Gtk.Image image_button_contacts_capture_save_image_disk;
 
+	//jump
+	[Widget] Gtk.Image image_jump_execute_air;
+	[Widget] Gtk.Image image_jump_execute_land;
+
 	//run
 	[Widget] Gtk.Image image_run_simple_show_time;
 	[Widget] Gtk.Image image_run_execute_running;
-	[Widget] Gtk.Image image_run_execute_photocell;
+	[Widget] Gtk.Image image_run_execute_photocell_icon;
+	[Widget] Gtk.Label label_run_execute_photocell_code;
 	[Widget] Gtk.Image image_sprint_analyze_save;
 	[Widget] Gtk.Image image_sprint_analyze_table_save;
 	[Widget] Gtk.Image image_sprint_analyze_table_save_1;
@@ -182,12 +184,13 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_encoder_capture_inertial_con;
 
 	//force sensor
-	[Widget] Gtk.Image image_selector_start_force_sensor;
+	//[Widget] Gtk.Image image_selector_start_force_sensor;
 	[Widget] Gtk.Image image_force_sensor_adjust_help;
 	[Widget] Gtk.Image image_force_sensor_analyze_load;
 	[Widget] Gtk.Image image_force_sensor_tare;
 	[Widget] Gtk.Image image_force_sensor_calibrate;
 	[Widget] Gtk.Image image_force_sensor_capture_adjust;
+	[Widget] Gtk.Image image_force_sensor_capture_adjust1;
 	[Widget] Gtk.Image image_force_sensor_capture_adjust_close;
 	[Widget] Gtk.Image image_force_sensor_analyze_options;
 	[Widget] Gtk.Image image_force_sensor_analyze_options1;
@@ -234,6 +237,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_run_encoder_analyze_image_save_disk;
 	[Widget] Gtk.Image image_run_encoder_export_cancel;
 	[Widget] Gtk.Image image_run_encoder_exercise_is_sprint_help;
+	[Widget] Gtk.Image image_run_encoder_exercise_angle_default_help;
 
 	//video play icons
 	[Widget] Gtk.Image image_video_play_this_test_contacts;
@@ -263,12 +267,15 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save5;
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save6;
 	[Widget] Gtk.Image image_forcesensor_analyze_image_save7;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save8;
 	[Widget] Gtk.Image image_force_sensor_analyze_table_save;
 	[Widget] Gtk.Image image_force_sensor_analyze_table_save_1;
 	[Widget] Gtk.Image image_run_encoder_analyze_table_save;
 	[Widget] Gtk.Image image_run_encoder_analyze_table_save_1;
 	[Widget] Gtk.Image image_sprint_analyze_image_save;
 	[Widget] Gtk.Image image_raceAnalyzer_table_save_grid;
+	[Widget] Gtk.Image image_sprint_table_save_disk;
+	[Widget] Gtk.Image image_sprint_table_save_grid;
 	[Widget] Gtk.Image image_raceAnalyzer_table_save_disk;
 	[Widget] Gtk.Image image_message_permissions_at_boot;
 	[Widget] Gtk.Image image_camera_at_boot;
@@ -298,8 +305,8 @@ public partial class ChronoJumpWindow
 		image_contacts_exercise_settings.Pixbuf = pixbuf;
 		image_encoder_exercise_settings.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "persons_manage.png");
-		image_persons_manage.Pixbuf = pixbuf;
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "persons_manage.png");
+		//image_persons_manage.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_store_blue.png");
 		image_menu_news.Pixbuf = pixbuf;
@@ -319,13 +326,14 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders.png");
 		if(Config.ColorBackgroundIsDark)
 			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders_yellow.png");
-		image_menu_folders.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folders_manage_blue.png");
-		image_menu_folders2.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders.png");
 		image_menu_folders1.Pixbuf = pixbuf;
 		image_session_export1.Pixbuf = pixbuf;
+		image_menu_folders2.Pixbuf = pixbuf;
+		image_session_more_window_blue.Pixbuf = pixbuf;
+		image_session_more_window_yellow.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders_yellow.png");
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_db_backup.png");
 		image_db_backup.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_more_horiz.png");
@@ -380,20 +388,15 @@ public partial class ChronoJumpWindow
 		image_encoder_inertial_weights.Pixbuf = pixbuf;
 		image_force_sensor_calibrate.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "portrait_zoom.png");
-		image_current_person_zoom_h.Pixbuf = pixbuf;
-
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
 		if(Config.ColorBackgroundIsDark)
 			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo_yellow.png");
 		image_current_person.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
-		image_mode_encoder_gravitatory.Pixbuf = pixbuf;
 		image_change_modes_encoder_gravitatory.Pixbuf = pixbuf;
 		app1s_image_show_data_encoder_grav.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_inertia.png");
-		image_mode_encoder_inertial.Pixbuf = pixbuf;
 		image_change_modes_encoder_inertial.Pixbuf = pixbuf;
 		app1s_image_show_data_encoder_inertial.Pixbuf = pixbuf;
 
@@ -402,9 +405,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run.png");
 		app1s_image_show_data_runs.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "race_encoder_icon.png");
-		app1s_image_show_data_run_encoder.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "force_sensor_icon.png");
-		app1s_image_show_data_force_sensor.Pixbuf = pixbuf;
+		app1s_image_show_data_isometric.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "isometric.png");
+		app1s_image_show_data_elastic.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "elastic.png");
 
 		image_run_simple_show_time.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_time.png");
 
@@ -418,20 +420,23 @@ public partial class ChronoJumpWindow
 		image_tests_sprint.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "arrow_back.png");
-		image_selector_start_back.Pixbuf = pixbuf;
 		image_button_force_sensor_analyze_back_to_signal.Pixbuf = pixbuf;
 		image_app1s_button_back.Pixbuf = pixbuf;
 
 		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
 		if(Config.ColorBackgroundIsDark)
 			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_yellow.png");
-		image_person2.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
 		image_person.Pixbuf = pixbuf;
 		image_person1.Pixbuf = pixbuf;
 		app1s_image_show_data_persons.Pixbuf = pixbuf;
+		image_persons_manage.Pixbuf = pixbuf;
+
+		image_person_manage_blue.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
+		image_person_manage_yellow.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_yellow.png");
+
+		image_merge_persons.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "merge.png");
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
 		image_info1.Pixbuf = pixbuf;
@@ -441,6 +446,7 @@ public partial class ChronoJumpWindow
 		image_run_simple_with_reaction_time_help.Pixbuf = pixbuf;
 		image_run_interval_with_reaction_time_help.Pixbuf = pixbuf;
 		image_run_encoder_exercise_is_sprint_help.Pixbuf = pixbuf;
+		image_run_encoder_exercise_angle_default_help.Pixbuf = pixbuf;
 		image_info_sessions_info.Pixbuf = pixbuf;
 		image_encoder_1RM_info.Pixbuf = pixbuf;
 		image_force_sensor_adjust_help.Pixbuf = pixbuf;
@@ -461,10 +467,17 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_chronopic_connect.png");
 		image_chronopic_connect_contacts.Pixbuf = pixbuf;
+		image_chronopic_connect_contacts1.Pixbuf = pixbuf;
+		image_chronopic_connect_contacts2.Pixbuf = pixbuf;
+		image_chronopic_connect_contacts3.Pixbuf = pixbuf;
+		image_chronopic_connect_contacts4.Pixbuf = pixbuf;
 		image_chronopic_connect_encoder.Pixbuf = pixbuf;
 		image_chronopic_connect_encoder1.Pixbuf = pixbuf;
 		image_chronopic_connect_encoder2.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_chronopic_connect_yellow.png");
+		image_micro_discover_device.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_recalculate.png");
 		image_recalculate.Pixbuf = pixbuf;
 		image_contacts_recalculate.Pixbuf = pixbuf;
@@ -476,6 +489,7 @@ public partial class ChronoJumpWindow
 		image_multi_chronopic_repair.Pixbuf = pixbuf;
 		image_encoder_configuration.Pixbuf = pixbuf;
 		image_force_sensor_capture_adjust.Pixbuf = pixbuf;
+		image_force_sensor_capture_adjust1.Pixbuf = pixbuf;
 		image_force_sensor_analyze_options.Pixbuf = pixbuf;
 		image_force_sensor_analyze_options1.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build_16.png");
@@ -483,9 +497,6 @@ public partial class ChronoJumpWindow
 
 		//assign here to have gui ok and not having chronojump logo at top right outside the screen
 		//all these will change when mode is selected
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_modes.png");
-		image_button_show_modes_contacts_grid.Pixbuf = pixbuf;
-		image_button_show_modes_encoder_grid.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
 		image_encoder_exercise.Pixbuf = pixbuf;
 
@@ -520,6 +531,10 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "zero.png");
 		image_force_sensor_tare.Pixbuf = pixbuf;
 		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_2x.png");
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_capture.png");
+		image_button_contacts_detect.Pixbuf = pixbuf;
+		image_button_encoder_detect.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_capture_big.png");
 		image_encoder_capture_execute.Pixbuf = pixbuf;
 		image_button_execute.Pixbuf = pixbuf;
@@ -549,6 +564,7 @@ public partial class ChronoJumpWindow
 		image_force_sensor_capture_adjust_close.Pixbuf = pixbuf;
 		app1s_image_button_close.Pixbuf = pixbuf;
 		image_news_close.Pixbuf = pixbuf;
+		image_button_person_close.Pixbuf = pixbuf;
 
 
 		/*
@@ -557,6 +573,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_down.png");
 		image_persons_down.Pixbuf = pixbuf;
 		*/
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_down.png");
+		//image_down_menu_2_2_2.Pixbuf = pixbuf;
 		
 		//persons buttons
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_add.png");
@@ -628,62 +646,52 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameIconTransp);
 		image_logo_icon_transp.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-jumps.png");
-		image_selector_start_jumps.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-runs.png");
-		image_selector_start_runs.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-encoder.png");
-		image_selector_start_encoder.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-force.png");
-		image_selector_start_force_sensor.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-rt.png");
-		image_selector_start_rt.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-multichronopic.png");
-		image_selector_start_other.Pixbuf = pixbuf;
-
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_2x.png");
+		image_selector_start_jumps1.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_mov_2x.png");
+		image_selector_start_runs1.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "isometric_2x.png");
+		image_selector_start_isometric.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "elastic_2x.png");
+		image_selector_start_elastic.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight_mov_2x.png");
+		image_selector_start_displ_weights.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_inertia_2x_2col.png");
+		image_selector_start_inertial.Pixbuf = pixbuf;
 		/*
 		 * gui for small screens
 		 */
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "start.png");
+		image_start.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_simple.png");
-		image_mode_jumps_small.Pixbuf = pixbuf;
+		image_mode_jumps_small1.Pixbuf = pixbuf;
 		image_change_modes_contacts_jumps_simple.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_reactive.png");
-		image_mode_jumps_reactive_small.Pixbuf = pixbuf;
+		image_mode_jumps_reactive_small1.Pixbuf = pixbuf;
 		image_change_modes_contacts_jumps_reactive.Pixbuf = pixbuf;
 		image_tests_analyze_jump_rj.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
-		image_mode_runs_small.Pixbuf = pixbuf;
-		image_mode_runs_small1.Pixbuf = pixbuf;
+		image_mode_runs_small2.Pixbuf = pixbuf;
 		image_change_modes_contacts_runs_simple.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_multiple.png");
-		image_mode_runs_intervallic_small.Pixbuf = pixbuf;
-		image_mode_runs_intervallic_small1.Pixbuf = pixbuf;
+		image_mode_runs_intervallic_small2.Pixbuf = pixbuf;
 		image_change_modes_contacts_runs_intervallic.Pixbuf = pixbuf;
-		image_change_modes_contacts_force_sensor.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "force_sensor_icon.png");
+		image_change_modes_contacts_force_sensor.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "isometric.png");
+		image_change_modes_contacts_force_sensor1.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "elastic.png");
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "race_encoder_icon.png");
-		image_mode_race_encoder_small.Pixbuf = pixbuf;
+		image_mode_race_encoder_small1.Pixbuf = pixbuf;
 		image_change_modes_contacts_runs_encoder.Pixbuf = pixbuf;
 
+		image_jump_execute_air.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_air.png");
+		image_jump_execute_land.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_land.png");
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_2x.png");
 		image_run_execute_running.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "run_photocell.png");
-		image_run_execute_photocell.Pixbuf = pixbuf;
+		image_run_execute_photocell_icon.Pixbuf = pixbuf;
 		
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNamePulse);
-		image_mode_pulses_small.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameMultiChronopic);
-		image_mode_multi_chronopic_small.Pixbuf = pixbuf;
-		
-		label_start_selector_jumps.Text = "<b>" + label_start_selector_jumps.Text + "</b>";
-		label_start_selector_races1.Text = "<b>" + label_start_selector_races1.Text + "</b>";
-		label_start_selector_races.Text = "<b>" + label_start_selector_races.Text + "</b>";
-		label_start_selector_encoder.Text = "<b>" + label_start_selector_encoder.Text + "</b>";
-		label_start_selector_jumps.UseMarkup = true;
-		label_start_selector_races1.UseMarkup = true;
-		label_start_selector_races.UseMarkup = true;
-		label_start_selector_encoder.UseMarkup = true;
-
 		image_check_runI_realtime_rel_abs.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "bar_relative.png");
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameJumpsFallCalculate);
@@ -692,7 +700,13 @@ public partial class ChronoJumpWindow
 		extra_windows_jumps_image_dj_fall_predefined.Pixbuf = pixbuf;
 		image_tab_jumps_dj_optimal_fall.Pixbuf = pixbuf;
 
+		extra_window_jumps_image_fall.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_fall.png");
+		extra_window_jumps_rj_image_fall.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_fall.png");
+		extra_window_jumps_image_weight.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "extra-mass.png");
+		extra_window_jumps_rj_image_weight.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "extra-mass.png");
+
 		image_tab_jumps_weight_fv_profile.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "jumps-fv.png");
+		image_tab_jumps_asymmetry.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-both.png");
 
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "line_session_avg.png");
@@ -787,8 +801,10 @@ public partial class ChronoJumpWindow
 		image_app1s_button_export_cancel.Pixbuf = pixbuf;
 		image_app1s_button_export_close.Pixbuf = pixbuf;
 		image_app1s_button_backup_cancel_close.Pixbuf = pixbuf;
+		image_app1s_button_view_data_folder_close.Pixbuf = pixbuf;
 		image_app1s_button_cancel1.Pixbuf = pixbuf;
 		image_button_help_close.Pixbuf = pixbuf;
+		image_button_micro_discover_cancel_close.Pixbuf = pixbuf;
 
 		//accept
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_done_blue.png");
@@ -821,6 +837,7 @@ public partial class ChronoJumpWindow
 		image_encoder_analyze_table_save.Pixbuf = pixbuf;
 		image_force_sensor_analyze_table_save.Pixbuf = pixbuf;
 		image_run_encoder_analyze_table_save.Pixbuf = pixbuf;
+		image_sprint_table_save_grid.Pixbuf = pixbuf;
 		image_raceAnalyzer_table_save_grid.Pixbuf = pixbuf;
 		image_session_export_csv1.Pixbuf = pixbuf;
 
@@ -855,6 +872,7 @@ public partial class ChronoJumpWindow
 		image_jumps_profile_save.Pixbuf = pixbuf;
 		image_jumps_dj_optimal_fall_save.Pixbuf = pixbuf;
 		image_jumps_weight_fv_profile_save.Pixbuf = pixbuf;
+		image_jumps_asymmetry_save.Pixbuf = pixbuf;
 		image_jumps_evolution_save.Pixbuf = pixbuf;
 		image_runs_evolution_save.Pixbuf = pixbuf;
 		image_jumps_rj_fatigue_save.Pixbuf = pixbuf;
@@ -885,12 +903,14 @@ public partial class ChronoJumpWindow
 		image_forcesensor_analyze_image_save5.Pixbuf = pixbuf;
 		image_forcesensor_analyze_image_save6.Pixbuf = pixbuf;
 		image_forcesensor_analyze_image_save7.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save8.Pixbuf = pixbuf;
 		image_runs_evolution_analyze_image_save.Pixbuf = pixbuf;
 		image_force_sensor_analyze_table_save_1.Pixbuf = pixbuf;
 		image_button_contacts_run_encoder_capture_save_image_disk.Pixbuf = pixbuf;
 		image_run_encoder_analyze_table_save_1.Pixbuf = pixbuf;
 		image_sprint_analyze_image_save.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_disk.Pixbuf = pixbuf;
+		image_sprint_table_save_disk.Pixbuf = pixbuf;
 		image_raceAnalyzer_table_save_disk.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_email.png");
