@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -42,8 +42,10 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_fall_calculate;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_start_inside;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_start_outside;
+	[Widget] Gtk.Image extra_window_jumps_image_fall;
+	[Widget] Gtk.Image extra_window_jumps_image_weight;
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_fall;
-	[Widget] Gtk.HBox hbox_extra_window_jumps_weight;
+	[Widget] Gtk.Table table_extra_window_jumps_weight;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
 	//[Widget] Gtk.Label extra_window_jumps_label_weight;
@@ -75,10 +77,10 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.SpinButton extra_window_jumps_rj_spinbutton_fall;
 	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_weight;
-	[Widget] Gtk.HBox hbox_extra_window_jumps_rj_weight;
-	//[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
-	[Widget] Gtk.Label extra_window_jumps_rj_label_fall;
-	[Widget] Gtk.Label extra_window_jumps_rj_label_cm;
+	[Widget] Gtk.Table table_extra_window_jumps_rj_weight;
+	[Widget] Gtk.HBox hbox_extra_window_jumps_rj_hbox_fall;
+	[Widget] Gtk.Image extra_window_jumps_rj_image_fall;
+	[Widget] Gtk.Image extra_window_jumps_rj_image_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_rj_start_inside;
 	[Widget] Gtk.Label extra_window_jumps_label_rj_start_outside;
 	[Widget] Gtk.CheckButton checkbutton_allow_finish_rj_after_time;
@@ -106,11 +108,14 @@ public partial class ChronoJumpWindow
 	
 	
 	//creates and if is not predefined, checks database to gather all the data
-	//simple == true  for normal jumps, and false for reactive
-	private JumpType createJumpType(string name, bool simple) {
+	//simple == true  for simple jumps, and false for reactive
+	private JumpType createJumpType(string name, bool simple)
+	{
 		JumpType t = new JumpType(name);
-		
-		if(! t.IsPredefined) {
+
+		//on networks need the uniquedID, so we need to do the SQL selection
+		if(! t.IsPredefined || configChronojump.Compujump)
+		{
 			if(simple) {
 				t = SqliteJumpType.SelectAndReturnJumpType(name, false);
 				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.JumpTable, name);
@@ -119,6 +124,7 @@ public partial class ChronoJumpWindow
 				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.JumpRjTable, name);
 			}
 		}
+
 		return t;
 	}
 
@@ -231,7 +237,7 @@ public partial class ChronoJumpWindow
 		setLabelContactsExerciseSelected(Constants.Modes.JUMPSSIMPLE);
 
 		LastJumpSimpleTypeParams ljstp = new LastJumpSimpleTypeParams(myJumpType.Name);
-		if(myJumpType.HasWeight || myJumpType.HasFall)
+		if(myJumpType.HasWeight || myJumpType.HasFall (configChronojump.Compujump))
 			ljstp = SqliteJumpType.LastJumpSimpleTypeParamsSelect(myJumpType.Name); //search it on DB
 
 		if(myJumpType.HasWeight)
@@ -239,7 +245,7 @@ public partial class ChronoJumpWindow
 		else
 			extra_window_showWeightData(myJumpType, false);	
 
-		if(myJumpType.HasFall) {
+		if(myJumpType.HasFall (configChronojump.Compujump)) {
 			extra_window_showFallData(myJumpType, true);
 			if(ljstp.uniqueID != -1)
 				extra_window_jumps_check_dj_fall_calculate.Active = (ljstp.fallmm == -1);
@@ -272,7 +278,7 @@ public partial class ChronoJumpWindow
 
 		button_jump_type_delete_simple.Sensitive = ! myJumpType.IsPredefined;
 
-		if( (myJumpType.HasWeight || myJumpType.HasFall) && ljstp.uniqueID != -1) {
+		if( (myJumpType.HasWeight || myJumpType.HasFall (configChronojump.Compujump)) && ljstp.uniqueID != -1) {
 			extra_window_jumps_spinbutton_weight.Value = ljstp.weightValue;
 			extra_window_jumps_spinbutton_fall.Value = ljstp.fallmm/10.0;
 		} else {
@@ -307,7 +313,7 @@ public partial class ChronoJumpWindow
 	private void updateGraphJumpsSimple () 
 	{
 		LogB.Information("Called updateGraphJumpsSimple");
-		if(currentPerson == null || currentSession == null)
+		if(currentPerson == null || currentSession == null || currentJumpType == null) //currentJumpType needed if there are no jumpTypes
 			return;
 
 		double tc = 0.0;
@@ -435,14 +441,14 @@ public partial class ChronoJumpWindow
 		} else 
 			extra_window_showWeightData(myJumpType, false);	
 
-		if(myJumpType.HasFall || myJumpType.Name == Constants.RunAnalysisName) {
+		if(myJumpType.HasFall (configChronojump.Compujump) || myJumpType.Name == Constants.RunAnalysisName) {
 			extra_window_showFallData(myJumpType, true);	
 		} else
 			extra_window_showFallData(myJumpType, false);
 
 		button_jump_type_delete_reactive.Sensitive = ! myJumpType.IsPredefined;
 
-		if( (myJumpType.HasWeight || myJumpType.HasFall) && ljrtp.uniqueID != -1) {
+		if( (myJumpType.HasWeight || myJumpType.HasFall (configChronojump.Compujump)) && ljrtp.uniqueID != -1) {
 			extra_window_jumps_rj_spinbutton_weight.Value = ljrtp.weightValue;
 			extra_window_jumps_rj_spinbutton_fall.Value = ljrtp.fallmm/10.0;
 		} else {
@@ -544,10 +550,10 @@ public partial class ChronoJumpWindow
 	
 	private void extra_window_showWeightData (JumpType myJumpType, bool show) {
 		if(myJumpType.IsRepetitive) {
-			hbox_extra_window_jumps_rj_weight.Visible = show;
+			table_extra_window_jumps_rj_weight.Visible = show;
 			update_label_extra_window_jumps_rj_radiobutton_weight_percent_as_kg(show);
 		} else {
-			hbox_extra_window_jumps_weight.Visible = show;
+			table_extra_window_jumps_weight.Visible = show;
 			update_label_extra_window_jumps_radiobutton_weight_percent_as_kg(show);
 		}
 	}
@@ -561,10 +567,7 @@ public partial class ChronoJumpWindow
 	{
 		if(myJumpType.IsRepetitive)
 		{
-			extra_window_jumps_rj_label_fall.Visible = show;
-			extra_window_jumps_rj_spinbutton_fall.Visible = show;
-			extra_window_jumps_rj_label_cm.Visible = show;
-
+			hbox_extra_window_jumps_rj_hbox_fall.Visible = show;
 			extra_window_jumps_label_rj_start_inside.Visible = ! show;
 			extra_window_jumps_label_rj_start_outside.Visible = show;
 		
@@ -618,6 +621,93 @@ public partial class ChronoJumpWindow
 		label_extra_window_jumps_rj_radiobutton_weight_percent_as_kg.Visible = true;
 	}
 
+	[Widget] Gtk.Button button_jumps_extra_weight_minus_10;
+	[Widget] Gtk.Button button_jumps_extra_weight_minus_1;
+	[Widget] Gtk.Button button_jumps_extra_weight_plus_1;
+	[Widget] Gtk.Button button_jumps_extra_weight_plus_10;
+	[Widget] Gtk.Button button_jumps_rj_extra_weight_minus_10;
+	[Widget] Gtk.Button button_jumps_rj_extra_weight_minus_1;
+	[Widget] Gtk.Button button_jumps_rj_extra_weight_plus_1;
+	[Widget] Gtk.Button button_jumps_rj_extra_weight_plus_10;
+	[Widget] Gtk.Button button_jumps_extra_fall_minus_10;
+	[Widget] Gtk.Button button_jumps_extra_fall_minus_1;
+	[Widget] Gtk.Button button_jumps_extra_fall_plus_1;
+	[Widget] Gtk.Button button_jumps_extra_fall_plus_10;
+	[Widget] Gtk.Button button_jumps_rj_extra_fall_minus_10;
+	[Widget] Gtk.Button button_jumps_rj_extra_fall_minus_1;
+	[Widget] Gtk.Button button_jumps_rj_extra_fall_plus_1;
+	[Widget] Gtk.Button button_jumps_rj_extra_fall_plus_10;
+
+	private void on_button_jumps_params_accelerators_clicked (object o, EventArgs args)
+	{
+		//jumps simple, weight
+		if (o == (object) button_jumps_extra_weight_minus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_weight, -10);
+		else if (o == (object) button_jumps_extra_weight_minus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_weight, -1);
+		else if (o == (object) button_jumps_extra_weight_plus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_weight, 1);
+		else if (o == (object) button_jumps_extra_weight_plus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_weight, 10);
+		//jumps rj weight
+		else if (o == (object) button_jumps_rj_extra_weight_minus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_weight, -10);
+		else if (o == (object) button_jumps_rj_extra_weight_minus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_weight, -1);
+		else if (o == (object) button_jumps_rj_extra_weight_plus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_weight, 1);
+		else if (o == (object) button_jumps_rj_extra_weight_plus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_weight, 10);
+		//jumps simple fall
+		else if (o == (object) button_jumps_extra_fall_minus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_fall, -10);
+		else if (o == (object) button_jumps_extra_fall_minus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_fall, -1);
+		else if (o == (object) button_jumps_extra_fall_plus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_fall, 1);
+		else if (o == (object) button_jumps_extra_fall_plus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_spinbutton_fall, 10);
+		//jumps rj fall
+		else if (o == (object) button_jumps_rj_extra_fall_minus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_fall, -10);
+		else if (o == (object) button_jumps_rj_extra_fall_minus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_fall, -1);
+		else if (o == (object) button_jumps_rj_extra_fall_plus_1)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_fall, 1);
+		else if (o == (object) button_jumps_rj_extra_fall_plus_10)
+			button_jumps_params_accelerators_do
+				(extra_window_jumps_rj_spinbutton_fall, 10);
+	}
+
+	private void button_jumps_params_accelerators_do (Gtk.SpinButton spin, int change)
+	{
+		double newValue = spin.Value + change;
+
+		double min, max;
+		spin.GetRange (out min, out max);
+		if(newValue < min)
+			spin.Value = min;
+		else if(newValue > max)
+			spin.Value = max;
+		else
+			spin.Value = newValue;
+	}
+
 	private void on_extra_window_jumps_spinbutton_weight_value_changed (object o, EventArgs args)
 	{
 		update_label_extra_window_jumps_radiobutton_weight_percent_as_kg(true);
