@@ -121,6 +121,7 @@ public partial class ChronoJumpWindow
 			//regular constructor
 			jumpsEvolutionGraph = new JumpsEvolutionGraph(
 					jumpsEvolution.Point_l,
+					jumpsEvolution.Dates_l,
 					jumpsEvolution.Slope,
 					jumpsEvolution.Intercept,
 					drawingarea_jumps_evolution,
@@ -132,10 +133,6 @@ public partial class ChronoJumpWindow
 	}
 	private void on_drawingarea_jumps_evolution_expose_event (object o, ExposeEventArgs args) 
 	{
-		//needed to have mouse clicks at: on_drawingarea_jumps_evolution_button_press_event ()
-//		drawingarea_jumps_evolution.AddEvents((int) (Gdk.EventMask.ButtonPressMask | Gdk.EventMask.ButtonReleaseMask));
-		drawingarea_jumps_evolution.AddEvents((int) Gdk.EventMask.ButtonPressMask);
-
 		jumpsEvolutionDo(false); //do not calculate data
 		//data is calculated on switch page (at notebook_capture_analyze) or on change person
 	}
@@ -143,15 +140,15 @@ public partial class ChronoJumpWindow
 	private void on_drawingarea_jumps_evolution_button_press_event (object o, ButtonPressEventArgs args)
 	{
 		//if there is no data and nothing to show, nothing to press, and also this is null
-		if(jumpsEvolutionGraph == null)
+		// without jumpsEvolution.Point_l.Count == 0 condition, it will show graph/data on mouse (with data of previous person/graph)
+		if(jumpsEvolutionGraph == null || jumpsEvolution.Point_l.Count == 0)
 			return;
 
 		LogB.Information("Button press done!");
 
 		//redo the graph to delete previous rectangles of previous mouse clicks
-		jumpsEvolutionGraph.Do(preferences.fontType.ToString());
-		LogB.Information(string.Format("Mouse X: {0}; Mouse Y: {1}", args.Event.X, args.Event.Y));
-		jumpsEvolutionGraph.CalculateAndWriteRealXY(args.Event.X, args.Event.Y);
+		jumpsEvolutionGraph.PassMouseXY (args.Event.X, args.Event.Y);
+		jumpsEvolutionGraph.Do (preferences.fontType.ToString());
 	}
 
 	private void on_button_jumps_evolution_save_image_clicked (object o, EventArgs args)
@@ -338,6 +335,7 @@ public partial class ChronoJumpWindow
 			//regular constructor
 			runsEvolutionGraph = new RunsEvolutionGraph(
 					runsEvolution.Point_l,
+					runsEvolution.Dates_l,
 					runsEvolution.Slope,
 					runsEvolution.Intercept,
 					drawingarea_runs_evolution,
@@ -352,10 +350,6 @@ public partial class ChronoJumpWindow
 	}
 	private void on_drawingarea_runs_evolution_expose_event (object o, ExposeEventArgs args)
 	{
-		//needed to have mouse clicks at: on_drawingarea_runs_evolution_button_press_event ()
-//		drawingarea_runs_evolution.AddEvents((int) (Gdk.EventMask.ButtonPressMask | Gdk.EventMask.ButtonReleaseMask));
-		drawingarea_runs_evolution.AddEvents((int) Gdk.EventMask.ButtonPressMask);
-
 		runsEvolutionDo(false, false); //do not calculate data
 		//data is calculated on switch page (at notebook_capture_analyze) or on change person
 	}
@@ -363,15 +357,15 @@ public partial class ChronoJumpWindow
 	private void on_drawingarea_runs_evolution_button_press_event (object o, ButtonPressEventArgs args)
 	{
 		//if there is no data and nothing to show, nothing to press, and also this is null
-		if(runsEvolutionGraph == null)
+		// without runsEvolution.Point_l.Count == 0 condition, it will show graph/data on mouse (with data of previous person/graph)
+		if(runsEvolutionGraph == null | runsEvolution.Point_l.Count == 0)
 			return;
 
 		LogB.Information("Button press done!");
 
 		//redo the graph to delete previous rectangles of previous mouse clicks
-		runsEvolutionGraph.Do(preferences.fontType.ToString());
-		LogB.Information(string.Format("Mouse X: {0}; Mouse Y: {1}", args.Event.X, args.Event.Y));
-		runsEvolutionGraph.CalculateAndWriteRealXY(args.Event.X, args.Event.Y);
+		runsEvolutionGraph.PassMouseXY (args.Event.X, args.Event.Y);
+		runsEvolutionGraph.Do (preferences.fontType.ToString());
 	}
 
 	private void on_button_runs_evolution_save_image_clicked (object o, EventArgs args)
