@@ -43,20 +43,21 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.EventBox eventbox_button_menu_help;
 	[Widget] Gtk.EventBox eventbox_button_menu_news;
 	[Widget] Gtk.EventBox eventbox_button_menu_exit;
+	[Widget] Gtk.VBox vbox_person;
+	[Widget] Gtk.Arrow arrow_manage_persons_left;
+	[Widget] Gtk.Arrow arrow_manage_persons_right;
+	[Widget] Gtk.Image image_button_person_close;
 	[Widget] Gtk.EventBox eventbox_check_manage_persons;
 	[Widget] Gtk.EventBox eventbox_persons_up;
 	[Widget] Gtk.EventBox eventbox_persons_down;
-	[Widget] Gtk.EventBox eventbox_person_add_single;
-	[Widget] Gtk.EventBox eventbox_person_add_multiple;
-	[Widget] Gtk.EventBox eventbox_recuperate_person;
-	[Widget] Gtk.EventBox eventbox_recuperate_persons_from_other_session;
-	[Widget] Gtk.EventBox eventbox_current_person_zoom_h;
-	[Widget] Gtk.EventBox eventbox_edit_current_person_h;
-	[Widget] Gtk.EventBox eventbox_show_all_person_events_h;
-	[Widget] Gtk.EventBox eventbox_delete_current_person_h;
+	[Widget] Gtk.Label label_current_database;
 	[Widget] Gtk.Label label_current_session;
 	[Widget] Gtk.Label label_current_person;
 
+	[Widget] Gtk.Frame frame_database;
+	[Widget] Gtk.Label label_database_at_frame_database;
+	[Widget] Gtk.Button button_menu_database;
+
 	[Widget] Gtk.CheckButton check_menu_session;
 	[Widget] Gtk.CheckButton check_manage_persons;
 	[Widget] Gtk.Button button_menu_help;
@@ -75,11 +76,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_menu_help_shortcuts;
 	[Widget] Gtk.Button button_menu_help_about;
 	[Widget] Gtk.Button button_menu_guiTest;
+	[Widget] Gtk.HBox hbox_prefs_help_news_exit;
 
 	//just to manage width
-	[Widget] Gtk.VBox vbox_person_manage_create;
-	[Widget] Gtk.VBox vbox_person_manage_load;
-
 	[Widget] Gtk.Image image_session_import;
 	[Widget] Gtk.Image image_session_export;
 	[Widget] Gtk.Image image_session_export1;
@@ -87,7 +86,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_session_export_csv1;
 
 	//menu icons
-	[Widget] Gtk.Image image_menu_folders;
+	//[Widget] Gtk.Image image_menu_folders;
 	[Widget] Gtk.Image image_menu_folders2;
 	[Widget] Gtk.Image image_session_new3;
 	[Widget] Gtk.Image image_session_load2;
@@ -174,9 +173,6 @@ public partial class ChronoJumpWindow
 		l.Add(button_menu_help_shortcuts.SizeRequest().Width + 16);
 		l.Add(button_menu_help_about.SizeRequest().Width + 16);
 
-		l.Add(vbox_person_manage_create.SizeRequest().Width);
-		l.Add(vbox_person_manage_load.SizeRequest().Width);
-
 		//int maxWidth = getMenuButtonsMaxWidth(l) + 4 + 6; //4, 6 are alignments spaces.
 
 		/*
@@ -186,7 +182,6 @@ public partial class ChronoJumpWindow
 		LogB.Information(string.Format("frame_persons_top: {0}", frame_persons_top.SizeRequest().Width));
 		LogB.Information(string.Format("treeview_persons: {0}", treeview_persons.SizeRequest().Width));
 		LogB.Information(string.Format("vbox_persons_bottom: {0}", vbox_persons_bottom.SizeRequest().Width));
-		LogB.Information(string.Format("hbox_persons_bottom_no_photo: {0}", hbox_persons_bottom_no_photo.SizeRequest().Width));
 		LogB.Information(string.Format("hbox_persons_bottom_photo: {0}", hbox_persons_bottom_photo.SizeRequest().Width));
 		LogB.Information(string.Format("image_current_person: {0}", image_current_person.SizeRequest().Width));
 		LogB.Information(string.Format("hbox_rest_time: {0}", hbox_rest_time.SizeRequest().Width));
@@ -268,14 +263,6 @@ public partial class ChronoJumpWindow
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_check_manage_persons, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_persons_up, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 		UtilGtk.EventBoxColorBackgroundActive (eventbox_persons_down, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_person_add_single, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_person_add_multiple, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_recuperate_person, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_recuperate_persons_from_other_session, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_current_person_zoom_h, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_edit_current_person_h, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_show_all_person_events_h, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
-		UtilGtk.EventBoxColorBackgroundActive (eventbox_delete_current_person_h, UtilGtk.YELLOW, UtilGtk.YELLOW_LIGHT);
 	}
 
 	private void menuShowVerticalArrow (bool selected, Gtk.Arrow a_up, Gtk.Arrow a_down)
@@ -284,43 +271,42 @@ public partial class ChronoJumpWindow
 		a_down.Visible = ! selected;
 	}
 
-	private void on_check_menu_session_or_persons_clicked (object o, EventArgs args)
+	private void on_check_manage_persons_clicked (object o, EventArgs args)
 	{
-		/*
-		   if one checkbutton unfolds, the other should get folded.
-		   do not need to care for circular calls, because it sets the other as false
-		   */
-
-		if(o == (object) check_menu_session)
+		if (check_manage_persons.Active)
 		{
-			menuShowVerticalArrow (check_menu_session.Active, arrow_menu_show_session_up, arrow_menu_show_session_down);
-			if(check_menu_session.Active)
-			{
-				vbuttonbox_menu_session.Visible = true;
+			app1s_notebook_sup_entered_from = notebook_sup.CurrentPage;
+			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.PERSON);
 
-				if(check_manage_persons.Active)
-					check_manage_persons.Active = false; //changing the other checkbutton
-			}
-			else
-				vbuttonbox_menu_session.Visible = false;
-		}
-		else if(o == (object) check_manage_persons)
-		{
-			menuShowVerticalArrow (check_manage_persons.Active, arrow_manage_persons_up, arrow_manage_persons_down);
-			if(check_manage_persons.Active)
-			{
-				vbox_manage_persons.Visible = true;
+			//do not allow to use session buttons to not confuse the button_close actions
+			vbuttonbox_menu_session.Sensitive = false;
+			hbox_prefs_help_news_exit.Sensitive = false;
 
-				if(check_menu_session.Active)
-					check_menu_session.Active = false; //changing the other checkbutton
-			} else
-				vbox_manage_persons.Visible = false;
+			arrow_manage_persons_left.Visible = true;
+			arrow_manage_persons_right.Visible = false;
+		} else {
+			notebook_sup.CurrentPage = app1s_notebook_sup_entered_from;
+
+			vbuttonbox_menu_session.Sensitive = true;
+			hbox_prefs_help_news_exit.Sensitive = true;
+
+			arrow_manage_persons_left.Visible = false;
+			arrow_manage_persons_right.Visible = true;;
 		}
+	}
+	private void on_button_person_close_clicked (object o, EventArgs args)
+	{
+		check_manage_persons.Click ();
+	}
+
+	private void on_check_menu_session_clicked (object o, EventArgs args)
+	{
+		menuShowVerticalArrow (check_menu_session.Active, arrow_menu_show_session_up, arrow_menu_show_session_down);
+		vbuttonbox_menu_session.Visible = check_menu_session.Active;
 
 		//hide the person photo if anything is unfolded
 		if(preferences.personPhoto)
-			vbox_persons_bottom.Visible =
-				(! check_menu_session.Active && ! check_manage_persons.Active);
+			vbox_persons_bottom.Visible = ! check_menu_session.Active;
 
 		//scroll it, but wait a bit before to be all the things at place
 		if(myTreeViewPersons != null)
