@@ -44,6 +44,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_combo_run_encoder_exercise;
 	[Widget] Gtk.ComboBox combo_run_encoder_exercise;
 	[Widget] Gtk.SpinButton race_analyzer_spinbutton_distance;
+	[Widget] Gtk.SpinButton race_analyzer_spinbutton_angle;
 	[Widget] Gtk.SpinButton race_analyzer_spinbutton_temperature;
 	[Widget] Gtk.ComboBox combo_race_analyzer_device;
 	[Widget] Gtk.Image image_run_encoder_graph;
@@ -62,11 +63,15 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_speed_time;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_accel_time;
 	[Widget] Gtk.VBox vbox_race_analyzer_capture_graphs;
+	[Widget] Gtk.CheckButton check_race_analyzer_capture_smooth_graphs;
+	[Widget] Gtk.HScale hscale_race_analyzer_capture_smooth_graphs;
+	[Widget] Gtk.Label label_race_analyzer_capture_smooth_graphs;
 
 	[Widget] Gtk.Frame frame_run_encoder_exercise;
 	[Widget] Gtk.Entry entry_run_encoder_exercise_name;
 	[Widget] Gtk.Entry entry_run_encoder_exercise_description;
 	[Widget] Gtk.CheckButton check_run_encoder_exercise_is_sprint;
+	[Widget] Gtk.SpinButton spin_run_encoder_exercise_angle_default;
 	[Widget] Gtk.CheckButton check_run_encoder_exercise_fixed_size;
 	[Widget] Gtk.HBox hbox_run_encoder_exercise_fixed_segments_size;
 	[Widget] Gtk.HBox hbox_run_encoder_exercise_notfixed_segment_num;
@@ -115,6 +120,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_39;
 
 	int race_analyzer_distance;
+	//int race_analyzer_angle;
 	int race_analyzer_temperature;
 	RunEncoder.Devices race_analyzer_device;
 
@@ -146,7 +152,6 @@ public partial class ChronoJumpWindow
 
 	*/
 	static string captureEndedMessage;
-	string runEncoderPortName;
 	SerialPort portRE; //Attention!! Don't reopen port because arduino makes reset
 	bool portREOpened;
 
@@ -167,6 +172,10 @@ public partial class ChronoJumpWindow
 
 		manageRunEncoderCaptureViews();
 
+		check_race_analyzer_capture_smooth_graphs.Active = false;
+		hscale_race_analyzer_capture_smooth_graphs.Visible = false;
+		label_race_analyzer_capture_smooth_graphs.Text = "";
+
 		createRunEncoderExerciseCombo();
 		createRunEncoderAnalyzeCombos();
 		setRunEncoderAnalyzeWidgets();
@@ -210,24 +219,16 @@ public partial class ChronoJumpWindow
 	private bool runEncoderConnect()
 	{
 		LogB.Information(" RE connect 0 ");
-		if(chronopicRegister.ConnectedOfType(ChronopicRegisterPort.Types.ARDUINO_RUN_ENCODER) == null)
+		if (chronopicRegister.GetSelectedForMode (current_mode).Port == "")
 		{
 			runEncoderPulseMessage = runEncoderNotConnectedString;
 			return false;
 		}
 
 		LogB.Information(" RE connect 1 ");
-		runEncoderPortName = chronopicRegister.ConnectedOfType(ChronopicRegisterPort.Types.ARDUINO_RUN_ENCODER).Port;
-		LogB.Information(" RE connect 2 ");
-		if(runEncoderPortName == null || runEncoderPortName == "")
-		{
-			runEncoderPulseMessage = "Please, select port!";
-			return false;
-		}
-		LogB.Information(" RE connect 3 ");
 		runEncoderPulseMessage = "Connecting ...";
 
-		portRE = new SerialPort(runEncoderPortName, 115200); //runEncoder
+		portRE = new SerialPort (chronopicRegister.GetSelectedForMode (current_mode).Port, 115200);
 		LogB.Information(" RE connect 4: opening port...");
 
 		try {
@@ -276,7 +277,7 @@ public partial class ChronoJumpWindow
 				LogB.Information("catched! checking version");
 				return "";
 			}
-			LogB.Information("init string: " + str);
+			LogB.Information(string.Format("init string: |{0}|", str));
 		}
 		while(! str.Contains("Race_Analyzer-"));
 
@@ -290,8 +291,8 @@ public partial class ChronoJumpWindow
 		 * init string: ^@;Race_analyzer-0.3
 		 */
 		Match match = Regex.Match(str, @"Race_Analyzer-(\d+\.\d+)");
-		if(match.Groups.Count == 1)
-			return str = match.Value;
+		if(match.Groups.Count == 2)
+			return str = match.Groups[1].ToString();
 		else
 			return "0.3"; //if there is a problem default to 0.3. 0.2 was the first that will be distributed and will be on binary. 0.3 has the byte of encoderOrRCA
 	}
@@ -381,7 +382,9 @@ public partial class ChronoJumpWindow
 		//to not show old vertical segments info on a capture that maybe cannot be done by lack of device
 		if(currentRunEncoderExercise != null)
 			reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
-					currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
+					currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm,
+					currentPersonSession.Weight, //but note if person changes (but graph will be hopefully erased), this will change also take care on exports
+					Convert.ToInt32(race_analyzer_spinbutton_angle.Value));
 
 		updateRaceAnalyzerCapturePositionTime(true);
 		updateRaceAnalyzerCaptureSpeedTime(true);
@@ -389,8 +392,7 @@ public partial class ChronoJumpWindow
 		//if graphs are not updated with the line, use this that will fire ExposeEvent:
 		//drawingarea_race_analyzer_capture_position_time.QueueDraw(); and the others
 
-
-		if(chronopicRegister.NumConnectedOfType(ChronopicRegisterPort.Types.ARDUINO_RUN_ENCODER) == 0)
+		if (chronopicRegister.GetSelectedForMode (current_mode).Port == "")
 		{
 			event_execute_label_message.Text = runEncoderNotConnectedString;
 			runEncoderButtonsSensitive(true);
@@ -479,6 +481,7 @@ public partial class ChronoJumpWindow
 	private void raceEncoderReadWidgets()
 	{
 		race_analyzer_distance = Convert.ToInt32(race_analyzer_spinbutton_distance.Value);
+		//race_analyzer_angle = Convert.ToInt32(race_analyzer_spinbutton_angle.Value);
 		race_analyzer_temperature = Convert.ToInt32(race_analyzer_spinbutton_temperature.Value);
 
 		if(UtilGtk.ComboGetActive(combo_race_analyzer_device) == RunEncoder.DevicesStringMANUAL)
@@ -518,9 +521,10 @@ public partial class ChronoJumpWindow
 		image_test.Pixbuf = pixbuf;
 	}
 
-	private void raceEncoderSetDistanceAndTemp(int distance, int temp)
+	private void raceEncoderSetDistanceAngleAndTemp (int distance, int angle, int temp)
 	{
 		race_analyzer_spinbutton_distance.Value = distance;
+		race_analyzer_spinbutton_angle.Value = angle;
 		race_analyzer_spinbutton_temperature.Value = temp;
 	}
 
@@ -580,7 +584,9 @@ public partial class ChronoJumpWindow
 
 		//RunEncoderCaptureGetSpeedAndDisplacement reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
 		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
-				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
+				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm,
+				currentPersonSession.Weight, //but note if person changes (but graph will be hopefully erased), this will change also take care on exports
+				Convert.ToInt32(race_analyzer_spinbutton_angle.Value));
 		runEncoderShouldShowCaptureGraphsWithData = true;
 
 		runEncoderCaptureThread = new Thread(new ThreadStart(runEncoderCaptureDo));
@@ -609,7 +615,10 @@ public partial class ChronoJumpWindow
 
 		if(! portREOpened)
 			if(! runEncoderConnect()) //GTK
+			{
+				runEncoderProcessError = true;
 				return;
+			}
 
 		lastChangedTime = 0;
 
@@ -617,11 +626,17 @@ public partial class ChronoJumpWindow
 		if(versionDouble >= Convert.ToDouble(Util.ChangeDecimalSeparator("0.3")))
 		{
 			if(! runEncoderSendCommand(string.Format("set_pps:{0};", preferences.runEncoderPPS), "Sending pps", "Catched at set_pps"))
+			{
+				runEncoderProcessError = true;
 				return;
+			}
 
 			//read confirmation data
 			if(runEncoderReceiveFeedback("pps set to") == "")
+			{
+				runEncoderProcessError = true;
 				return;
+			}
 		}
 
 		string command = "start_capture:";
@@ -688,6 +703,7 @@ public partial class ChronoJumpWindow
 		double timePre2 = -1;
 		double speedPre = -1;
 		double timePre = -1;
+		bool enoughAccelFound = false; //accel has been > preferences.runEncoderMinAccel (default 10ms^2)
 
 		int rowsCount = 0;
 		while(! runEncoderProcessFinish && ! runEncoderProcessCancel && ! runEncoderProcessError)
@@ -739,15 +755,22 @@ public partial class ChronoJumpWindow
 
 				if(timePre2 > 0)
 				{
-					LogB.Information(string.Format("accel at capture is: {0} m/s",
-								UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
-									UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+					double accel = UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2);
+
+					if (accel >= preferences.runEncoderMinAccel && ! enoughAccelFound)
+					{
+						enoughAccelFound = true;
+
+						//at load to shift times to the left
+						//at capture to draw a vertical line
+						reCGSD.SetTimeAtEnoughAccelMark (binaryReaded);
+					}
 
 					//accel/time
 					cairoGraphRaceAnalyzerPoints_at_l.Add(new PointF(
 								UtilAll.DivideSafe(reCGSD.Time, 1000000),
-								UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
-									UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+								accel));
 				}
 
 				sw.Restart();
@@ -974,7 +997,8 @@ public partial class ChronoJumpWindow
 		genericWin.ShowEditRow(false);
 
 		//select row corresponding to current signal
-		genericWin.SelectRowWithID(0, currentRunEncoder.UniqueID); //colNum, id
+		if(currentRunEncoder != null)
+			genericWin.SelectRowWithID(0, currentRunEncoder.UniqueID); //colNum, id
 
 		genericWin.VideoColumn = 6;
 		genericWin.CommentColumn = 7;
@@ -1039,7 +1063,7 @@ public partial class ChronoJumpWindow
 		assignCurrentRunEncoderExercise();
 
 		raceEncoderSetDevice(re.Device);
-		raceEncoderSetDistanceAndTemp(re.Distance, re.Temperature);
+		raceEncoderSetDistanceAngleAndTemp(re.Distance, re.Angle, re.Temperature);
 ///		textview_race_analyzer_comment.Buffer.Text = re.Comments;
 		textview_contacts_signal_comment.Buffer.Text = re.Comments;
 
@@ -1057,7 +1081,9 @@ public partial class ChronoJumpWindow
 
 		int count = 0;
 		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
-				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
+				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm,
+				currentPersonSession.Weight, //but note if person changes (but graph will be hopefully erased), this will change also take care on exports
+				currentRunEncoder.Angle);
 		runEncoderShouldShowCaptureGraphsWithData = true;
 
 		cairoGraphRaceAnalyzer_dt = null;
@@ -1073,11 +1099,15 @@ public partial class ChronoJumpWindow
 		double timePre2 = -1;
 		double speedPre = -1;
 		double timePre = -1;
+		double accel = -1;
+		bool enoughAccelFound = false; //accel has been > preferences.runEncoderMinAccel (default 10ms^2)
+		bool signalShifted = false; //shifted on trigger0 or accel >= minAccel, whatever is first
+		string rowPre = "";
 
+		//store data on cairoGraphRaceAnalyzerPoints_dt_l, ...st_l, ...at_l
 		foreach(string row in contents)
 		{
-			LogB.Information("row: " + row);
-			if(count < 3)
+			if(count < 3) //is this useful at all? because the timePre will be also -1 on the 4th row
 			{
 				count ++;
 				continue;
@@ -1086,34 +1116,110 @@ public partial class ChronoJumpWindow
 			if(reCGSD.PassLoadedRow (row))
 				reCGSD.Calcule();
 
-			//distance/time
-			cairoGraphRaceAnalyzerPoints_dt_l.Add(new PointF(
-						UtilAll.DivideSafe(reCGSD.Time, 1000000),
-						reCGSD.RunEncoderCaptureDistance));
-			//speed/time
-			cairoGraphRaceAnalyzerPoints_st_l.Add(new PointF(
-						UtilAll.DivideSafe(reCGSD.Time, 1000000),
-						reCGSD.RunEncoderCaptureSpeed));
-
 			speedPre2 = speedPre;
 			timePre2 = timePre;
 			speedPre = reCGSD.RunEncoderCaptureSpeed;
 			timePre = UtilAll.DivideSafe(reCGSD.Time, 1000000);
 
-			if(timePre2 > 0)
-			{
-				LogB.Information(string.Format("accel at load is: {0} m/s",
-							UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
-								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+			/*
+			LogB.Information ( string.Format ("reCGSD.RunEncoderCaptureSpeed: {0}, speedPre2: {1}," +
+						"UtilAll.DivideSafe(reCGSD.Time, 1000000): {2}, timePre2: {3}",
+						reCGSD.RunEncoderCaptureSpeed, speedPre2,
+						UtilAll.DivideSafe(reCGSD.Time, 1000000), timePre2));
+						*/
 
-				//accel/time
-				cairoGraphRaceAnalyzerPoints_at_l.Add(new PointF(
-							UtilAll.DivideSafe(reCGSD.Time, 1000000),
-							UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
-								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2)));
+			if(speedPre2 > 0)
+			{
+				accel = UtilAll.DivideSafe(reCGSD.RunEncoderCaptureSpeed - speedPre2,
+								UtilAll.DivideSafe(reCGSD.Time, 1000000) - timePre2);
+
+				//LogB.Information (string.Format ("accel: {0} (count {1})", accel, count));
+
+				int timeNow = 0;
+				string [] cells = row.Split(new char[] {';'});
+				timeNow = Convert.ToInt32(cells[1]);
+
+				if (! signalShifted)
+				{
+					/*
+					   pass when the first trigger is done,
+					   because first time will be on first trigger or when accel >= minAccel
+					   whatever is first.
+					   We need timeAtTrigger0 and timeAtEnoughAccel,
+					   because if timeAtTrigger0 is first, display also timeAtEnougAccel
+					 */
+					bool shiftNow = false;
+					int shiftTo = 0;
+
+					if (triggerListRunEncoder != null && triggerListRunEncoder.Count() > 0 &&
+							triggerListRunEncoder.GetList()[0].Us < timeNow)
+					{
+						//reCGSD.SetTimeAtTrigger0 (triggerListRunEncoder.GetList()[0].Us);
+						shiftTo = triggerListRunEncoder.GetList()[0].Us;
+						shiftNow = true;
+					}
+
+					if (accel >= preferences.runEncoderMinAccel && ! enoughAccelFound)
+					{
+						if (cells.Length == 3 && Util.IsNumber(cells[0], false) && Util.IsNumber(cells[1], false))
+						{
+							shiftTo = timeNow;
+							shiftNow = true;
+							enoughAccelFound = true;
+						}
+					}
+
+					if (shiftNow)
+					{
+						//recreate rcCGSD object since now
+						reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
+								currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm,
+								currentPersonSession.Weight, //but note if person changes (but graph will be hopefully erased), this will change also take care on exports
+								currentRunEncoder.Angle);
+
+						reCGSD.SetTimeAtEnoughAccelOrTrigger0 (shiftTo);
+
+						if (reCGSD.PassLoadedRow (row))
+							reCGSD.CalculeSpeedAt0Shifted (rowPre, row);
+						//LogB.Information(string.Format("after row runEncoderCaptureSpeed: {0}", reCGSD.RunEncoderCaptureSpeed));
+
+						signalShifted = true;
+					}
+				} else {
+					/*
+					   if first was trigger then accel >= minAccel,
+					   we need to use the reCGSD.SetTimeAtEnoughAccelMark () to show a line
+					   */
+					if (accel >= preferences.runEncoderMinAccel && ! enoughAccelFound)
+					{
+						reCGSD.SetTimeAtEnoughAccelMark (timeNow);
+						enoughAccelFound = true;
+					}
+				}
 			}
 
+			if(signalShifted)
+			{
+				cairoGraphRaceAnalyzerPoints_dt_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							reCGSD.RunEncoderCaptureDistance));
+
+				cairoGraphRaceAnalyzerPoints_st_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							reCGSD.RunEncoderCaptureSpeed));
+
+				cairoGraphRaceAnalyzerPoints_at_l.Add(new PointF(
+							UtilAll.DivideSafe(reCGSD.Time, 1000000),
+							accel));
+			}
+
+			rowPre = row;
 		}
+
+		if (getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs () > 0)
+			reCGSD.SegmentsRedoWithSmoothing (
+					getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ());
+
 		if(reCGSD.RunEncoderCaptureSpeedMax > 0)
 		{
 			if(cairoRadial == null)
@@ -1131,6 +1237,19 @@ public partial class ChronoJumpWindow
 			updateRaceAnalyzerCaptureAccelTime(true);
 		}
 
+		//debug reCGSD.SegmentCalcs
+		if (reCGSD != null && reCGSD.SegmentCalcs != null)
+		{
+			LogB.Information ("segmentCalcs:");
+			LogB.Information ("- TimeStart_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.TimeStart_l, 3, ";"));
+			LogB.Information ("- TimeEnd_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.TimeEnd_l, 3, ";"));
+			LogB.Information ("- Dist_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.Dist_l, 3, ";"));
+			LogB.Information ("- SpeedCont_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.SpeedCont_l, 3, ";"));
+			LogB.Information ("- Accel_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.Accel_l, 3, ";"));
+			LogB.Information ("- Force_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.Force_l, 3, ";"));
+			LogB.Information ("- Power_l: " + Util.ListDoubleToString (reCGSD.SegmentCalcs.Power_l, 3, ";"));
+		}
+
 		// <---- capture tab graphs end ----
 
 		//on load do the R graph, but not on capture, to show on capture the label related to lack of person height
@@ -1304,6 +1423,7 @@ public partial class ChronoJumpWindow
 		currentRunEncoder.ExerciseName = currentRunEncoderExercise.Name; //just in case
 		currentRunEncoder.Device = raceEncoderGetDevice();
 		currentRunEncoder.Distance = Convert.ToInt32(race_analyzer_spinbutton_distance.Value);
+		currentRunEncoder.Angle = Convert.ToInt32(race_analyzer_spinbutton_angle.Value);
 		currentRunEncoder.Temperature = Convert.ToInt32(race_analyzer_spinbutton_temperature.Value);
 		//currentRunEncoder.Comments = UtilGtk.TextViewGetCommentValidSQL(textview_race_analyzer_comment);
 		currentRunEncoder.Comments = UtilGtk.TextViewGetCommentValidSQL(textview_contacts_signal_comment);
@@ -1338,10 +1458,12 @@ public partial class ChronoJumpWindow
 
 		string contents = Util.ReadFile(RunEncoder.GetCSVResultsURL(), false);
 
-		//maybe captured data was too low or two different than an sprint.
-		//then we have image but maybe we have no sprintResults.csv
-
-		if(contents == null || contents == "")
+		/*
+		   maybe captured data was too low or two different than an sprint.
+		   Then we have image but maybe we have no sprintResults.csv
+		   Length < 10 is written because on a model too short R can just return ""
+		   */
+		if(contents == null || contents == "" || contents.Length < 10)
 			return;
 		else {
 			createTreeViewRaceEncoder(contents);
@@ -1363,6 +1485,7 @@ public partial class ChronoJumpWindow
 		//create graph
 		RunEncoderGraph reg = new RunEncoderGraph(
 				race_analyzer_distance,
+				//race_analyzer_angle, 		//TODO: unused
 				currentPersonSession.Weight,  	//TODO: can be more if extra weight
 				currentPersonSession.Height,
 				race_analyzer_temperature,
@@ -1410,32 +1533,57 @@ public partial class ChronoJumpWindow
 
 	private void createTreeViewRaceEncoder (string contents)
 	{
-		string [] columnsString = getTreeviewRaceAnalyzerHeaders();
+		// 1) read the contents of the CSV
+		RunEncoderCSV recsv = readRunEncoderCSVContents (contents);
+
+		// 2) Add the columns to the treeview
+		string [] columnsString = getTreeviewRaceAnalyzerHeaders(contents);
 		int count = 0;
 		foreach(string column in columnsString)
 			treeview_raceAnalyzer.AppendColumn (column, new CellRendererText(), "text", count++);
 
-		TreeStore store = new TreeStore(
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string), typeof (string), typeof (string),
-				typeof (string)
-				);
+		// 3) Add the TreeStore
+		Type [] types = new Type [columnsString.Length];
+		for (int i=0; i < columnsString.Length; i++) {
+			types[i] = typeof (string);
+		}
+		TreeStore store = new TreeStore(types);
 
-		RunEncoderCSV recsv = readRunEncoderCSVContents (contents);
 		store.AppendValues (recsv.ToTreeView());
 
+		// 4) Assing model to store and other tweaks
 		treeview_raceAnalyzer.Model = store;
 		treeview_raceAnalyzer.Selection.Mode = SelectionMode.None;
                 treeview_raceAnalyzer.HeadersVisible=true;
 	}
 
-	private string [] getTreeviewRaceAnalyzerHeaders ()
+	private string [] getTreeviewRaceAnalyzerHeaders (string contents)
         {
+		// 1) check how many dist columns we should add
+		List<string> dist_l = new List<string> ();
+		using (StringReader reader = new StringReader (contents))
+		{
+			string line = reader.ReadLine ();      //headers
+			LogB.Information(line);
+			if (line != null)
+			{
+				string [] cells = line.Split(new char[] {';'});
+				dist_l = new List<string> ();
+				for (int i = 26; i < cells.Length; i ++) //Attention!: take care with this 26 if in the future add more columns before dist/times
+				{
+					//each string comes as "X0Y25.5m_Speed" convert to 0-25.5 m\nSpeed or 0-25,5 m/nSpeed
+					string temp = Util.RemoveChar (cells[i], '"', false);
+					temp = Util.RemoveChar (temp, 'X', false);
+					temp = Util.ChangeChars (temp, "Y", "-");
+					temp = Util.ChangeDecimalSeparator (temp);
+					temp = Util.ChangeChars (temp, "_", "\n");
+
+					dist_l.Add (temp);
+				}
+			}
+		}
+
+		// 2) prepare the headers
                 string [] headers = {
 			"Mass\n\n(Kg)", "Height\n\n(m)", "Temperature\n\n(ºC)",
 			"V (wind)\n\n(m/s)", "Ka\n\n", "K\nfitted\n(s^-1)",
@@ -1444,8 +1592,13 @@ public partial class ChronoJumpWindow
 			"Sfv\nlm\n", "Sfv\nrel lm\n", "Pmax\nfitted\n(W)",
 			"Pmax\nrel fitted\n(W/Kg)", "Time to pmax\nfitted\n(s)", "F0\n\n(N)",
 			"F0\nrel\n(N/Kg)", "V0\n\n(m/s)", "Pmax\nlm\n(W)",
-			"Pmax\nrel lm\n(W/Kg)"
+			"Pmax\nrel lm\n(W/Kg)",
+			"Vmax\nraw\n(m/s)", "Amax\nraw\n(m/s^2)", "Fmax\nraw\n(N)", "Pmax\nraw\n(W)"
 		};
+
+		// 3) add the dists to the headers
+		headers = Util.AddToArrayString (headers, dist_l);
+
 		return headers;
 	}
 
@@ -1457,7 +1610,6 @@ public partial class ChronoJumpWindow
 		using (StringReader reader = new StringReader (contents))
 		{
 			line = reader.ReadLine ();      //headers
-			//LogB.Information(line);
 			do {
 				line = reader.ReadLine ();
 				LogB.Information(line);
@@ -1466,7 +1618,12 @@ public partial class ChronoJumpWindow
 
 				string [] cells = line.Split(new char[] {';'});
 
-				recsv = new RunEncoderCSV(
+				// get the times (total columns can be different each time)
+				List<double> time_l = new List<double> ();
+				for (int i = 26; i < cells.Length; i ++) //Attention! take care with this 26 if in the future add more columns before dist/times
+					time_l.Add (Convert.ToDouble (cells[i]));
+
+				recsv = new RunEncoderCSV (
 						Convert.ToDouble(cells[0]), Convert.ToDouble(cells[1]), Convert.ToInt32(cells[2]),
 						Convert.ToDouble(cells[3]), Convert.ToDouble(cells[4]), Convert.ToDouble(cells[5]),
 						Convert.ToDouble(cells[6]), Convert.ToDouble(cells[7]), Convert.ToDouble(cells[8]),
@@ -1474,7 +1631,10 @@ public partial class ChronoJumpWindow
 						Convert.ToDouble(cells[12]), Convert.ToDouble(cells[13]), Convert.ToDouble(cells[14]),
 						Convert.ToDouble(cells[15]), Convert.ToDouble(cells[16]), Convert.ToDouble(cells[17]),
 						Convert.ToDouble(cells[18]), Convert.ToDouble(cells[19]), Convert.ToDouble(cells[20]),
-						Convert.ToDouble(cells[21])
+						Convert.ToDouble(cells[21]),
+						Convert.ToDouble(cells[22]), Convert.ToDouble(cells[23]), //vmax raw, amax raw
+						Convert.ToDouble(cells[24]), Convert.ToDouble(cells[25]), //fmax raw, pmax raw
+						time_l
 						);
 			} while(true);
 		}
@@ -1562,6 +1722,7 @@ public partial class ChronoJumpWindow
 							UtilDate.ToFile(runEncoderTimeStartCapture),
 							"", //on capture cannot store comment (comment has to be written after),
 							"", //videoURL
+							Convert.ToInt32(race_analyzer_spinbutton_angle.Value),
 							currentRunEncoderExercise.Name);
 
 					currentRunEncoder.UniqueID = currentRunEncoder.InsertSQL(false);
@@ -1628,8 +1789,11 @@ public partial class ChronoJumpWindow
 
 				if(runEncoderProcessCancel)
 					event_execute_label_message.Text = "Cancelled.";
-				else
+				else {
 					event_execute_label_message.Text = runEncoderNotConnectedString;
+					button_detect_show_hide (true); // show the detect big button
+				}
+
 				LogB.Information(" re C cancel 2");
 			}
 			else
@@ -1854,6 +2018,10 @@ public partial class ChronoJumpWindow
 
 		setLabelContactsExerciseSelected(Constants.Modes.RUNSENCODER);
 
+		RunEncoderExercise exTemp = SqliteRunEncoderExercise.Select (
+                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false))[0];
+		race_analyzer_spinbutton_angle.Value = exTemp.AngleDefault;
+
 		//sensitivity of left/right buttons
 		button_combo_run_encoder_exercise_capture_left.Sensitive = (combo_run_encoder_exercise.Active > 0);
 		button_combo_run_encoder_exercise_capture_right.Sensitive = ! UtilGtk.ComboSelectedIsLast(combo_run_encoder_exercise);
@@ -1916,6 +2084,7 @@ public partial class ChronoJumpWindow
 		entry_run_encoder_exercise_name.Text = ex.Name;
 		entry_run_encoder_exercise_description.Text = ex.Description;
 		check_run_encoder_exercise_is_sprint.Active = ex.IsSprint;
+		spin_run_encoder_exercise_angle_default.Value = ex.AngleDefault;
 
 		if(v_segments_size_cm_l == null)
 			spin_race_encoder_exercise_v_segment_size_cm_create_list ();
@@ -1946,6 +2115,7 @@ public partial class ChronoJumpWindow
 		entry_run_encoder_exercise_name.Text = "";
 		entry_run_encoder_exercise_description.Text = "";
 		check_run_encoder_exercise_is_sprint.Active = true;
+		spin_run_encoder_exercise_angle_default.Value = 0;
 		spin_race_encoder_exercise_f_segment_size_cm.Value = RunEncoderExercise.SegmentCmDefault;
 		spin_race_encoder_exercise_v_segments_num.Value = 2;
 
@@ -1966,6 +2136,15 @@ public partial class ChronoJumpWindow
 		return;
 	}
 
+	private void on_button_run_encoder_exercise_angle_default_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.INFO,
+				Catalog.GetString("Default angle of this exercise.") + "\n" +
+				Catalog.GetString("90 means go vertically up.") + "\n" +
+				Catalog.GetString("-90 means go vertically down.") + "\n" +
+				string.Format(Catalog.GetString("Possible range goes from {0} to {1}."), -90, 90));
+		return;
+	}
 	private void on_check_run_encoder_exercise_fixed_size_toggled (object o, EventArgs args)
 	{
 		if(check_run_encoder_exercise_fixed_size.Active)
@@ -2106,14 +2285,16 @@ public partial class ChronoJumpWindow
 		{
 			RunEncoderExercise ex = new RunEncoderExercise (
 					-1, name, entry_run_encoder_exercise_description.Text,
-					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active);
+					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active,
+					Convert.ToInt32(spin_run_encoder_exercise_angle_default.Value));
 			ex.InsertSQL (false);
 			currentRunEncoderExercise = ex;
 		} else {
 			RunEncoderExercise ex = new RunEncoderExercise(
 					getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false),
 					name, entry_run_encoder_exercise_description.Text,
-					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active);
+					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active,
+					Convert.ToInt32(spin_run_encoder_exercise_angle_default.Value));
 
 			SqliteRunEncoderExercise.Update(false, ex);
 			currentRunEncoderExercise = ex;
@@ -2245,21 +2426,36 @@ public partial class ChronoJumpWindow
 		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
 			isSprint = true;
 
-		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		RunEncoderSegmentCalcs segmentCalcs = new RunEncoderSegmentCalcs ();
 		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
-				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
-			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+				reCGSD != null && reCGSD.SegmentCalcs != null)
+			segmentCalcs = reCGSD.SegmentCalcs;
 
-		if(cairoGraphRaceAnalyzer_dt == null)
+		int timeAtEnoughAccel = 0;
+		int timeAtEnoughAccelMark = 0;
+		if (reCGSD != null)
+		{
+			timeAtEnoughAccel = reCGSD.TimeAtEnoughAccelOrTrigger0; //to shift time at load, sent here to sync/delete triggers
+			timeAtEnoughAccelMark = reCGSD.TimeAtEnoughAccelMark; //to show mark at capture
+		}
+
+		if(cairoGraphRaceAnalyzer_dt == null || forceRedraw)
 			cairoGraphRaceAnalyzer_dt = new CairoGraphRaceAnalyzer(
+					(currentRunEncoder != null && currentRunEncoder.UniqueID >= 0),
 					drawingarea_race_analyzer_capture_position_time, "title",
 					Catalog.GetString("Distance"), "m",
 					isSprint, false,
-					verticalLinesUs_2l, true);
+					segmentCalcs,
+					false, feedbackWin.GetRunsEncoderMainVariable (),
+					true);
 
+		int smoothGui = getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ();
 		cairoGraphRaceAnalyzer_dt.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_dt_l, triggerListRunEncoder,
-				forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_dt_l,
+				forceRedraw, CairoXY.PlotTypes.LINES, smoothGui == 0,
+				smoothGui,
+				triggerListRunEncoder, timeAtEnoughAccel,
+				timeAtEnoughAccelMark, preferences.runEncoderMinAccel);
 	}
 	private void updateRaceAnalyzerCaptureSpeedTime(bool forceRedraw)
 	{
@@ -2267,21 +2463,36 @@ public partial class ChronoJumpWindow
 		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
 			isSprint = true;
 
-		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		RunEncoderSegmentCalcs segmentCalcs = new RunEncoderSegmentCalcs ();
 		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
-				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
-			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+				reCGSD != null && reCGSD.SegmentCalcs != null)
+			segmentCalcs = reCGSD.SegmentCalcs;
 
-		if(cairoGraphRaceAnalyzer_st == null)
+		int timeAtEnoughAccel = 0;
+		int timeAtEnoughAccelMark = 0;
+		if (reCGSD != null)
+		{
+			timeAtEnoughAccel = reCGSD.TimeAtEnoughAccelOrTrigger0; //to shift time at load, sent here to sync/delete triggers
+			timeAtEnoughAccelMark = reCGSD.TimeAtEnoughAccelMark; //to show mark at capture
+		}
+
+		if(cairoGraphRaceAnalyzer_st == null || forceRedraw)
 			cairoGraphRaceAnalyzer_st = new CairoGraphRaceAnalyzer(
+					(currentRunEncoder != null && currentRunEncoder.UniqueID >= 0),
 					drawingarea_race_analyzer_capture_speed_time, "title",
 					Catalog.GetString("Speed"), "m/s",
 					isSprint, true,
-					verticalLinesUs_2l, false);
+					segmentCalcs,
+					true, feedbackWin.GetRunsEncoderMainVariable (),
+					false);
 
+		int smoothGui = getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ();
 		cairoGraphRaceAnalyzer_st.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_st_l, triggerListRunEncoder,
-				forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_st_l,
+				forceRedraw, CairoXY.PlotTypes.LINES, smoothGui == 0,
+				smoothGui,
+				triggerListRunEncoder, timeAtEnoughAccel,
+				timeAtEnoughAccelMark, preferences.runEncoderMinAccel);
 	}
 	private void updateRaceAnalyzerCaptureAccelTime(bool forceRedraw)
 	{
@@ -2292,21 +2503,84 @@ public partial class ChronoJumpWindow
 		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
 			isSprint = true;
 
-		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		RunEncoderSegmentCalcs segmentCalcs = new RunEncoderSegmentCalcs ();
 		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
-				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
-			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+				reCGSD != null && reCGSD.SegmentCalcs != null)
+			segmentCalcs = reCGSD.SegmentCalcs;
 
-		if(cairoGraphRaceAnalyzer_at == null)
+		int timeAtEnoughAccel = 0;
+		int timeAtEnoughAccelMark = 0;
+		if (reCGSD != null)
+		{
+			timeAtEnoughAccel = reCGSD.TimeAtEnoughAccelOrTrigger0; //to shift time at load, sent here to sync/delete triggers
+			timeAtEnoughAccelMark = reCGSD.TimeAtEnoughAccelMark; //to show mark at capture
+		}
+
+		if(cairoGraphRaceAnalyzer_at == null || forceRedraw)
 			cairoGraphRaceAnalyzer_at = new CairoGraphRaceAnalyzer(
+					(currentRunEncoder != null && currentRunEncoder.UniqueID >= 0),
 					drawingarea_race_analyzer_capture_accel_time, "title",
 					Catalog.GetString("Accel"), "m/s^2",
 					isSprint, false,
-					verticalLinesUs_2l, false);
+					segmentCalcs,
+					false, feedbackWin.GetRunsEncoderMainVariable (),
+					false);
 
 		cairoGraphRaceAnalyzer_at.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_at_l, triggerListRunEncoder,
-				forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_at_l,
+				forceRedraw, CairoXY.PlotTypes.LINES, false,
+				getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs (),
+				triggerListRunEncoder, timeAtEnoughAccel,
+				timeAtEnoughAccelMark, preferences.runEncoderMinAccel);
+	}
+
+	private void on_check_race_analyzer_capture_smooth_graphs_clicked (object o, EventArgs args)
+	{
+		int smooth = getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ();
+		if(check_race_analyzer_capture_smooth_graphs.Active)
+		{
+			hscale_race_analyzer_capture_smooth_graphs.Visible = true;
+			label_race_analyzer_capture_smooth_graphs.Visible = true;
+
+			if(smooth == 0)
+				label_race_analyzer_capture_smooth_graphs.Text = "";
+			else
+				label_race_analyzer_capture_smooth_graphs.Text = smooth.ToString();
+		} else {
+			hscale_race_analyzer_capture_smooth_graphs.Visible = false;
+			label_race_analyzer_capture_smooth_graphs.Visible = false;
+		}
+
+		if (reCGSD != null)
+			reCGSD.SegmentsRedoWithSmoothing (smooth);
+
+		updateRaceAnalyzerCapturePositionTime(true);
+		updateRaceAnalyzerCaptureSpeedTime(true);
+		updateRaceAnalyzerCaptureAccelTime(true);
+	}
+
+	private int getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ()
+	{
+		if(! check_race_analyzer_capture_smooth_graphs.Active)
+			return 0;
+
+		//if 1,2,3,4,5,6,7  return 3,5,7,9,11,13,15
+		return Convert.ToInt32(hscale_race_analyzer_capture_smooth_graphs.Value)*2 +1;
+	}
+	private void on_hscale_race_analyzer_capture_smooth_graphs_value_changed (object o, EventArgs args)
+	{
+		int smooth = getSmoothFrom_gui_at_race_analyzer_capture_smooth_graphs ();
+		if(smooth == 0)
+			label_race_analyzer_capture_smooth_graphs.Text = "";
+		else
+			label_race_analyzer_capture_smooth_graphs.Text = smooth.ToString();
+
+		if (reCGSD != null)
+			reCGSD.SegmentsRedoWithSmoothing (smooth);
+
+		updateRaceAnalyzerCapturePositionTime(true);
+		updateRaceAnalyzerCaptureSpeedTime(true);
+		updateRaceAnalyzerCaptureAccelTime(true);
 	}
 
 	private void on_button_race_analyzer_capture_save_image_clicked (object o, EventArgs args)
