@@ -209,10 +209,10 @@ public partial class ChronoJumpWindow
 			showMacRInstallMessage ();
 			return;
 		}
-
-		if(! currentRunEncoderExercise.IsSprint)
+		else if (operatingSystem == UtilAll.OperatingSystems.LINUX &&
+				! ExecuteProcess.InstalledOnLinux ("R"))
 		{
-			new DialogMessage(Constants.MessageTypes.WARNING, "Currently you can only analyze sprint exercises.");
+			showLinuxRInstallMessage ();
 			return;
 		}
 
@@ -267,11 +267,12 @@ public partial class ChronoJumpWindow
 			else
 				sep = ",";
 
+			string contents = Util.ReadFile(RunEncoder.GetCSVResultsURL(), false);
+
 			//write header
 			writer.WriteLine(Util.RemoveNewLine(Util.StringArrayToString(
-							getTreeviewRaceAnalyzerHeaders(), sep), false));
+							getTreeviewRaceAnalyzerHeaders(contents), sep), true));
 
-			string contents = Util.ReadFile(RunEncoder.GetCSVResultsURL(), false);
 			RunEncoderCSV recsv = readRunEncoderCSVContents(contents);
 
 			writer.WriteLine(recsv.ToCSV(preferences.CSVExportDecimalSeparator));
