@@ -64,6 +64,8 @@ public partial class ChronoJumpWindow
 		app1s_button_backup_start.Sensitive = false;
 		app1s_button_delete_old_incomplete.Visible = false;
 		app1s_button_backup_cancel_close.Sensitive = true;
+		image_app1s_button_backup_cancel_close.Pixbuf =
+				new Gdk.Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
 		app1s_label_backup_cancel_close.Text = Catalog.GetString("Cancel");
 
 		app1s_notebook.CurrentPage = app1s_PAGE_BACKUP;
@@ -165,6 +167,8 @@ public partial class ChronoJumpWindow
 		app1s_label_remind_feedback.Text = message;
 
 		backup_cancel_close_show_more_notebook = false; //clicking on close should not show session more
+		image_app1s_button_backup_cancel_close.Pixbuf =
+				new Gdk.Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		app1s_label_backup_cancel_close.Text = Catalog.GetString("Close");
 		app1s_button_backup_cancel_close.Visible = true;
 	}
@@ -359,6 +363,8 @@ public partial class ChronoJumpWindow
 			app1s_button_backup_cancel_close.Sensitive = false; //or make cancel sensitive while process?
 		} else {
 			app1s_button_backup_cancel_close.Sensitive = true;
+			image_app1s_button_backup_cancel_close.Pixbuf =
+				new Gdk.Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 			app1s_label_backup_cancel_close.Text = Catalog.GetString("Close");
 		}
 	}
@@ -394,6 +400,8 @@ public partial class ChronoJumpWindow
 	private void on_app1s_button_delete_old_incomplete_clicked (object o, EventArgs args)
 	{
 		label_backup_why.Visible = false; //do not show again label_backup_why
+		image_app1s_button_backup_cancel_close.Pixbuf =
+				new Gdk.Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
 		app1s_label_backup_cancel_close.Text = Catalog.GetString("Cancel");
 
 		notebook_session_backup.Page = Convert.ToInt32(notebook_session_backup_pages.DELETE_OLD);
@@ -404,6 +412,8 @@ public partial class ChronoJumpWindow
 
 		app1s_button_old_backups_delete_do.Sensitive = false;
 		app1s_label_old_backups_delete_done.Visible = true;
+		image_app1s_button_backup_cancel_close.Pixbuf =
+				new Gdk.Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		app1s_label_backup_cancel_close.Text = Catalog.GetString("Close");
 	}
 
@@ -420,7 +430,7 @@ public partial class ChronoJumpWindow
 		sw.Start();
 
 		app1s_copyRecursiveSuccess = app1s_uc.CopyFilesRecursively(
-				new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(app1s_fileCopy), 0);
+				new DirectoryInfo(Util.GetLocalDataDir(false)), new DirectoryInfo(app1s_fileCopy), 0);
 		sw.Stop();
 
 		app1s_copyRecursiveElapsedMs = sw.ElapsedMilliseconds;
@@ -444,7 +454,7 @@ public partial class ChronoJumpWindow
 						//	tarArchive.WriteEntry (tarEntry, true);
 						//}
 						//AddDirectoryFilesToTar (tarArchive, Path.Combine (Config.DBDir, storageName + " attachments"), true);
-						AddDirectoryFilesToTar (tarArchive, Util.GetParentDir(false), true);
+						AddDirectoryFilesToTar (tarArchive, Util.GetLocalDataDir(false), true);
 					}
 				}
 			}
@@ -484,6 +494,8 @@ public partial class ChronoJumpWindow
 		else {
 			menus_sensitive_import_not_danger(true);
 			notebook_supSetOldPage();
+			if (notebook_sup.CurrentPage == Convert.ToInt32(notebook_sup_pages.START))
+				new ChronojumpLogo (notebook_chronojump_logo, drawingarea_chronojump_logo, preferences.logoAnimatedShow);
 		}
 	}
 }
