@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -32,6 +32,13 @@ public partial class ChronoJumpWindow
 	private Thread app1s_threadExport;
 	private static bool cancelExport;
 
+	/*
+	   on Windows when exporting and compressing, the chronojump.db is still used
+	   so better export on app1s_fileCopyPre, then copy dir to app1s_fileCopy and then compress
+	   this will be on a temp file because it also cannot be deleted on export end
+	   */
+	string app1s_fileCopyPre;
+
 	private void on_button_session_export_pre_clicked (object o, EventArgs args)
 	{
 		if(! app1s_getDatabaseFile())
@@ -40,6 +47,12 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
+		if (operatingSystem == UtilAll.OperatingSystems.LINUX && ! ExecuteProcess.InstalledOnLinux ("7z"))
+		{
+			showLinux7zInstallMessage ();
+			return;
+		}
+
 		app1s_label_export_destination.Text = "";
 		app1s_label_export_progress.Text = "";
 		app1s_exportText = "";
@@ -68,8 +81,11 @@ public partial class ChronoJumpWindow
 		if (app1s_fc.Run() == (int)ResponseType.Accept)
 		{
 			app1s_fileCopy = app1s_fc.Filename + Path.DirectorySeparatorChar + "chronojump_" + currentSession.Name + "_" + UtilDate.ToFile();
+			app1s_fileCopyPre = Path.Combine (Path.GetTempPath (), "chronojumpCopyPre_" + currentSession.Name + "_" + UtilDate.ToFile()); //on temp because on Windows cannot be deleted
 
 			app1s_label_export_destination.Text = app1s_fileCopy;
+			if (exportImportCompressed)
+				app1s_label_export_destination.Text += ".7z";
 
 			app1s_button_export_start.Sensitive = true;
 		}
@@ -90,6 +106,7 @@ public partial class ChronoJumpWindow
 							app1s_fileCopy, Directory.GetCreationTime(app1s_fileCopy)));
 				exists = true;
 			}
+			//if exists app1s_fileCopyPre overwrite it without asking
 
 			if(exists) {
 				LogB.Information("Overwrite...");
@@ -102,6 +119,7 @@ public partial class ChronoJumpWindow
 				app1s_uc = new UtilCopy(currentSession.UniqueID, false);
 
 				cancelExport = false;
+				needToCloseSessionToCompress = false;
 				app1s_threadExport = new Thread(new ThreadStart(app1s_export));
 				GLib.Idle.Add (new GLib.IdleHandler (app1s_ExportPulseGTK));
 
@@ -119,14 +137,28 @@ public partial class ChronoJumpWindow
 
 	private bool app1s_ExportPulseGTK ()
 	{
+		if (exportImportCompressed && needToCloseSessionToCompress)
+		{
+			LogB.Information("calling reloadSession on compress");
+			reloadSession ();
+			LogB.Information("called reloadSession on compress");
+
+			needToCloseSessionToCompress = false;
+		}
+
 		if ( ! app1s_threadExport.IsAlive )
 		{
 			LogB.ThreadEnding();
 			app1s_ExportPulseEnd();
 
-			LogB.Information("calling reloadSession");
-			reloadSession(); //to use default db again
-			LogB.Information("called reloadSession");
+			/* This is commented to avoid the unreachable code warning. If ever change the exportImportCompressed, uncomment
+			if (! exportImportCompressed)
+			{
+				LogB.Information("calling reloadSession on thread end");
+				reloadSession(); //to use default db again
+				LogB.Information("called reloadSession on thread end");
+			}
+			*/
 
 			//but unsensitivize left menu
 			vbox_menu_tiny_menu.Sensitive = false;
@@ -153,8 +185,8 @@ public partial class ChronoJumpWindow
 				Catalog.GetString("Cancelled.");
 		else
 			app1s_label_export_progress.Text =
-				string.Format(Catalog.GetString("Exported in {0} ms"),
-						app1s_exportElapsedMs);
+				string.Format(Catalog.GetString("Exported in {0} s"),
+						Math.Round(UtilAll.DivideSafe(app1s_exportElapsedMs, 1000.0), 1));
 
 		app1s_export_doing_sensitive_start_end(false);
 	}
@@ -182,12 +214,15 @@ public partial class ChronoJumpWindow
 	{
 		try {
 			Directory.Delete(app1s_fileCopy, true);
+			if(Directory.Exists(app1s_fileCopyPre))
+				Directory.Delete(app1s_fileCopyPre, true);
 
 			//note this is the same than: on_app1s_button_export_start_clicked
 			app1s_pulsebarExportActivity.Visible = true;
 			app1s_uc = new UtilCopy(currentSession.UniqueID, false);
 
 			cancelExport = false;
+			needToCloseSessionToCompress = false;
 			app1s_threadExport = new Thread(new ThreadStart(app1s_export));
 			GLib.Idle.Add (new GLib.IdleHandler (app1s_ExportPulseGTK));
 
@@ -201,6 +236,8 @@ public partial class ChronoJumpWindow
 		}
 	}
 
+	private const bool exportImportCompressed = true;
+	private static bool needToCloseSessionToCompress;
 	static string app1s_exportText;
 	static long app1s_exportElapsedMs;
 	//No GTK here!
@@ -212,11 +249,15 @@ public partial class ChronoJumpWindow
 
 		app1s_exportText = Catalog.GetString("Copying files");
 
+		string exportDir = app1s_fileCopy;
+		if (exportImportCompressed)
+			exportDir = app1s_fileCopyPre;
+
 		//TODO: copy only needed multimedia (photos), videos are discarded by sessions
-		app1s_uc.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(app1s_fileCopy), 0);
+		app1s_uc.CopyFilesRecursively (new DirectoryInfo(Util.GetLocalDataDir (false)), new DirectoryInfo (exportDir), 0);
 
 		//TODO: check that db exists and manage sessionSwitcher to go back
-		string exportedDB = app1s_fileCopy + System.IO.Path.DirectorySeparatorChar  +
+		string exportedDB = exportDir + System.IO.Path.DirectorySeparatorChar  +
 			 "database" + System.IO.Path.DirectorySeparatorChar + "chronojump.db";
 		LogB.Information("exporting to:" + exportedDB);
 		if(! File.Exists(exportedDB))
@@ -228,36 +269,59 @@ public partial class ChronoJumpWindow
 		SqliteSessionSwitcher sessionSwitcher = new SqliteSessionSwitcher
 			(SqliteSessionSwitcher.DatabaseType.EXPORT, exportedDB);
 
-		/*
-		 * TODO (optional): use this to have objects intead of strings []
-		List<Session> session_l = SqliteSession.SelectAll();
-		foreach(Session session in session_l)
-			if(session.UniqueID != currentSession.UniqueID)
-				SqliteSession.DeleteAllStuff(session.UniqueID.ToString());
-				*/
-
-		string [] mySessions = sessionSwitcher.SelectAllSessions(""); //returns a string of values separated by ':'
+		List<SessionTestsCount> stc_l = sessionSwitcher.SelectAllSessionsTestsCount (""); //returns a string of values separated by ':'
 
 		int count = 1;
-		foreach (string session in mySessions)
+		foreach (SessionTestsCount stc in stc_l)
 		{
 			//cancelExport breaks here instead doing it on pulse to avoid leaving some Sqlite DataReader opened
 			if(cancelExport)
 				break;
 
-			app1s_exportText = string.Format("Adjusting new database {0}/{1}", count, mySessions.Length);
-			LogB.Information(string.Format("session: {0}", session));
-			string [] myStringFull = session.Split(new char[] {':'});
-			string sessionID = myStringFull[0];
-			if(sessionID != currentSession.UniqueID.ToString())
+			app1s_exportText = string.Format("Adjusting new database {0}/{1}", count, stc_l.Count);
+			if(stc.sessionParams.ID != currentSession.UniqueID)
 			{
-				LogB.Information(string.Format("session: {0}, will be deleted", sessionID));
-				sessionSwitcher.DeleteAllStuff(sessionID);
+				LogB.Information(string.Format("session: {0}, will be deleted", stc.sessionParams.ID));
+				sessionSwitcher.DeleteAllStuff(stc.sessionParams.ID.ToString ());
 			}
-			LogB.Information(string.Format("export session {0}/{1} done!", count, mySessions.Length ));
+			LogB.Information(string.Format("export session {0}/{1} done!", count, stc_l.Count ));
 			count ++;
 		}
 
+		if (exportImportCompressed)
+		{
+			needToCloseSessionToCompress = true;
+			while (needToCloseSessionToCompress)
+				;
+			//sessionSwitcher.Dispose ();
+			sessionSwitcher = null;
+
+			//need to copy the dir from app1s_fileCopyPre to app1s_fileCopy, because the exported chronojump.db is still used (not succeeded on closing it on Windows)
+			Util.CopyFilesRecursively(app1s_fileCopyPre, app1s_fileCopy);
+
+			//compressing with 7z
+			app1s_exportText = string.Format("Compressing …");
+			List<string> parameters = new List<string>();
+			parameters.Add ("a");
+
+			parameters.Add (app1s_fileCopy + ".7z");
+
+			// option 1 add the folder with the files (better to have a dir that can be uncompressed in order to be opened from importer)
+			parameters.Add (app1s_fileCopy);
+			// option 2 without the parent folder (cleaner, but do not found how to import)
+			//parameters.Add (app1s_fileCopy + Path.DirectorySeparatorChar + "*");
+
+			string executable = ExecuteProcess.Get7zExecutable (operatingSystem);
+			ExecuteProcess.Result execute_result = ExecuteProcess.run (executable, parameters, false, false);
+			// delete exported folder
+			if (execute_result.success)
+			{
+				Util.DirectoryDelete (app1s_fileCopy);
+				Util.DirectoryDelete (app1s_fileCopyPre);
+			}
+		}
+
+		//finishing
 		sw.Stop();
 		app1s_exportElapsedMs = sw.ElapsedMilliseconds;
 		LogB.Information("ended app1s_export()");
