@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
+using System.IO;
 using Gtk;
 using Glade;
 using GLib; //for Value
@@ -129,40 +130,47 @@ public partial class ChronoJumpWindow
 		app1s_checkbutton_show_data_runs.Active = (current_mode == Constants.Modes.RUNSSIMPLE ||
 				current_mode == Constants.Modes.RUNSINTERVALLIC ||
 				current_mode == Constants.Modes.RUNSENCODER);
-		app1s_checkbutton_show_data_force_sensor.Active = (current_mode == Constants.Modes.FORCESENSOR);
-		app1s_checkbutton_show_data_encoder.Active = (current_mode == Constants.Modes.POWERGRAVITATORY ||
-				current_mode == Constants.Modes.POWERINERTIAL);
+		app1s_checkbutton_show_data_isometric.Active = (current_mode == Constants.Modes.FORCESENSORISOMETRIC);
+		app1s_checkbutton_show_data_elastic.Active = (current_mode == Constants.Modes.FORCESENSORELASTIC);
+		app1s_checkbutton_show_data_weights.Active = (current_mode == Constants.Modes.POWERGRAVITATORY);
+		app1s_checkbutton_show_data_inertial.Active = (current_mode == Constants.Modes.POWERINERTIAL);
 
 		sessionLoadWinSignals = true;
 
-		app1s_createTreeView(app1s_treeview_session_load, app1s_type == app1s_windowType.LOAD_SESSION,
+		app1s_createTreeView (app1s_treeview_session_load, app1s_type == app1s_windowType.LOAD_SESSION,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
 
-		app1s_store = app1s_getStore(true,
+		app1s_store = app1s_getStore (true,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
 
 		app1s_treeview_session_load.Model = app1s_store;
 
-		app1s_fillTreeView(app1s_treeview_session_load, app1s_store,
+		app1s_fillTreeView (app1s_treeview_session_load, app1s_store,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
@@ -192,8 +200,9 @@ public partial class ChronoJumpWindow
 		*/
 	}
 
-	private TreeStore app1s_getStore(bool loadOrImport, bool showPersons,
-			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
+	private TreeStore app1s_getStore (bool loadOrImport, bool showPersons,
+			bool showJumps, bool showRuns, bool showIsometric, bool showElastic,
+			bool showWeights, bool showInertial)//, bool showRT, bool showOther)
 	{
 		int columns = 6;
 		if(loadOrImport)
@@ -205,10 +214,14 @@ public partial class ChronoJumpWindow
 			columns += 2;
 		if(showRuns)
 			columns += 3; //includes race analyzer
-		if(showForceSensor)
+		if(showIsometric)
+			columns ++;
+		if(showElastic)
+			columns ++;
+		if(showWeights)
+			columns ++;
+		if(showInertial)
 			columns ++;
-		if(showEncoder)
-			columns += 2;
 		/*
 		if(showRT)
 			columns ++;
@@ -255,7 +268,8 @@ public partial class ChronoJumpWindow
 	}
 
 	private void app1s_createTreeView (Gtk.TreeView tv, bool loadOrImport, bool showPersons,
-			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
+			bool showJumps, bool showRuns, bool showIsometric, bool showElastic,
+			bool showWeights, bool showInertial)//, bool showRT, bool showOther)
 	{
 		tv.HeadersVisible=true;
 		int count = 0;
@@ -285,33 +299,34 @@ public partial class ChronoJumpWindow
 			tv.AppendColumn (colTags);
 		}
 
-		tv.AppendColumn ( Catalog.GetString ("Place"), new CellRendererText(), "text", count++);
-		tv.AppendColumn ( Catalog.GetString ("Persons"), new CellRendererText(), "text", count++);
-		if(showPersons) {
-			tv.AppendColumn ( Catalog.GetString ("Sport"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Specialty"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Level"), new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString ("Place"), new CellRendererText(), "text", count++);
+		tv.AppendColumn (Catalog.GetString ("Persons"), new CellRendererText(), "text", count++);
+		if (showPersons) {
+			tv.AppendColumn (Catalog.GetString ("Sport"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Specialty"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Level"), new CellRendererText(), "text", count++);
 		}
-		if(showJumps) {
-			tv.AppendColumn ( Catalog.GetString ("Jumps simple"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Jumps reactive"), new CellRendererText(), "text", count++);
+		if (showJumps) {
+			tv.AppendColumn (Catalog.GetString ("Jumps simple"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Jumps reactive"), new CellRendererText(), "text", count++);
 		}
-		if(showRuns) {
-			tv.AppendColumn ( Catalog.GetString ("Races simple"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Races interval"), new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Race analyzer"), new CellRendererText(), "text", count++);
+		if (showRuns) {
+			tv.AppendColumn (Catalog.GetString ("Races simple"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Races interval"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Race analyzer"), new CellRendererText(), "text", count++);
 		}
-		if(showForceSensor) {
-			tv.AppendColumn ( Catalog.GetString ("Force sensor"), new CellRendererText(), "text", count++);
-		}
-		if(showEncoder) {
-			tv.AppendColumn ( Catalog.GetString ("Gravitatory encoder") + "\n" +
+		if (showIsometric)
+			tv.AppendColumn (Catalog.GetString ("Isometric"), new CellRendererText(), "text", count++);
+		if (showElastic)
+			tv.AppendColumn (Catalog.GetString ("Elastic"), new CellRendererText(), "text", count++);
+		if (showWeights)
+			tv.AppendColumn (Catalog.GetString ("Weights") + "\n" +
 					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
 					new CellRendererText(), "text", count++);
-			tv.AppendColumn ( Catalog.GetString ("Inertial encoder") + "\n" +
+		if (showInertial)
+			tv.AppendColumn (Catalog.GetString ("Inertial") + "\n" +
 					Catalog.GetString("Sets") + " ; " + Catalog.GetString("Repetitions"),
 					new CellRendererText(), "text", count++);
-		}
 		/*
 		if(showRT) {
 			tv.AppendColumn ( Catalog.GetString ("Reaction time"), new CellRendererText(), "text", count++);
@@ -358,12 +373,46 @@ public partial class ChronoJumpWindow
 		                                                               "Open",ResponseType.Accept);
 
 		FileFilter file_filter = new FileFilter();
-		file_filter.AddPattern ("*.db");
-		file_filter.Name = "Chronojump database (chronojump.db)";
+
+		if (exportImportCompressed)
+		{
+			file_filter.AddPattern ("*.7z");
+			file_filter.Name = "Chronojump data (.7z)";
+		}
+		/* This is commented to avoid the unreachable code warning. If ever change the exportImportCompressed, uncomment
+		else {
+			file_filter.AddPattern ("*.db");
+			file_filter.Name = "Chronojump database (chronojump.db)";
+		}
+		*/
 		filechooser.AddFilter (file_filter);
 
-		if (filechooser.Run () == (int)ResponseType.Accept) {
+		if (filechooser.Run () == (int)ResponseType.Accept)
+		{
+			if (exportImportCompressed)
+			{
+				List<string> parameters = new List<string>();
+				//parameters.Add ("e");
+				parameters.Add ("x"); //we need the parent folder
+				parameters.Add ("-aoa"); //Overwrite All existing files without prompt.
+				parameters.Add ("-o" + UtilAll.GetTempDir ());
+				parameters.Add (filechooser.Filename);
+
+				string executable = ExecuteProcess.Get7zExecutable (operatingSystem);
+				ExecuteProcess.run (executable, parameters, false, false);
+			}
+
 			app1s_import_file_path = filechooser.Filename;
+			if (exportImportCompressed)
+			{
+				app1s_import_file_path = Path.Combine (
+						UtilAll.GetTempDir (),
+						Util.RemoveExtension (Util.GetLastPartOfPath (filechooser.Filename)),
+						"database",
+						"chronojump.db");
+				LogB.Information ("import from: " + app1s_import_file_path);
+			}
+
 			//file_path_import.Text = System.IO.Path.GetFileName (import_file_path);
 			app1s_file_path_import.Text = app1s_import_file_path;
 			app1s_file_path_import.TooltipText = app1s_import_file_path;
@@ -408,33 +457,39 @@ public partial class ChronoJumpWindow
 
 		UtilGtk.RemoveColumns(app1s_treeview_session_load);
 		
-		app1s_createTreeView(app1s_treeview_session_load,
+		app1s_createTreeView (app1s_treeview_session_load,
 				app1s_type == app1s_windowType.LOAD_SESSION,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
-		app1s_store = app1s_getStore(
+		app1s_store = app1s_getStore (
 				true,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
 		app1s_treeview_session_load.Model = app1s_store;
-		app1s_fillTreeView(app1s_treeview_session_load, app1s_store,
+		app1s_fillTreeView (app1s_treeview_session_load, app1s_store,
 				app1s_checkbutton_show_data_persons.Active,
 				app1s_checkbutton_show_data_jumps.Active,
 				app1s_checkbutton_show_data_runs.Active,
-				app1s_checkbutton_show_data_force_sensor.Active,
-				app1s_checkbutton_show_data_encoder.Active);/*,
+				app1s_checkbutton_show_data_isometric.Active,
+				app1s_checkbutton_show_data_elastic.Active,
+				app1s_checkbutton_show_data_weights.Active,
+				app1s_checkbutton_show_data_inertial.Active);/*,
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
@@ -457,7 +512,8 @@ public partial class ChronoJumpWindow
 	}
 
 	private void app1s_fillTreeView (Gtk.TreeView tv, TreeStore store, bool showPersons,
-			bool showJumps, bool showRuns, bool showForceSensor, bool showEncoder)//, bool showRT, bool showOther)
+			bool showJumps, bool showRuns, bool showIsometric, bool showElastic,
+			bool showWeights, bool showInertial)//, bool showRT, bool showOther)
 	{
 		string filterName = "";
 		if(app1s_entry_search_filter.Text.ToString().Length > 0)
@@ -471,7 +527,7 @@ public partial class ChronoJumpWindow
 		}
 		SqliteSessionSwitcher sessionSwitcher = new SqliteSessionSwitcher (databaseType, app1s_import_file_path);
 		
-		string [] mySessions = sessionSwitcher.SelectAllSessions(filterName); //returns a string of values separated by ':'
+		List<SessionTestsCount> stc_l = sessionSwitcher.SelectAllSessionsTestsCount (filterName); //returns a string of values separated by ':'
 
 		//new 2.0 code
 		int columns = 6;
@@ -481,10 +537,14 @@ public partial class ChronoJumpWindow
 			columns += 2;
 		if(showRuns)
 			columns += 3; //includes race analyzer
-		if(showForceSensor)
+		if(showIsometric)
+			columns ++;
+		if(showElastic)
+			columns ++;
+		if(showWeights)
+			columns ++;
+		if(showInertial)
 			columns ++;
-		if(showEncoder)
-			columns += 2;
 		/*
 		if(showRT)
 			columns ++;
@@ -500,38 +560,35 @@ public partial class ChronoJumpWindow
 			columns ++;
 		}
 
-		foreach (string session in mySessions)
+		foreach (SessionTestsCount stc in stc_l)
 		{
-			string [] myStringFull = session.Split(new char[] {':'});
-		
 			//don't show any text at sport, speciallity and level if it's undefined	
 			string mySport = "";
-			if (myStringFull[4] != Catalog.GetString(Constants.SportUndefined)) 
-				mySport = Catalog.GetString(myStringFull[4]);
+			if (stc.sessionParams.SportName != Catalog.GetString(Constants.SportUndefined))
+				mySport = stc.sessionParams.SportName;
 
 			string mySpeciallity = ""; //done also because Undefined has "" as name and crashes with gettext
-			if (myStringFull[5] != "") 
-				mySpeciallity = Catalog.GetString(myStringFull[5]);
+			if (stc.sessionParams.SpeciallityName != "")
+				mySpeciallity = stc.sessionParams.SpeciallityName;
 			
 			string myLevel = "";
-			if (myStringFull[6] != Catalog.GetString(Constants.LevelUndefined)) 
-				myLevel = Catalog.GetString(myStringFull[6]);
+			if (stc.sessionParams.LevelName != Catalog.GetString(Constants.LevelUndefined))
+				myLevel = stc.sessionParams.LevelName;
 
 			string [] strings = new string [columns];
 			//for (int i=0; i < columns; i++) {
 			//	types[i] = typeof (string);
 			//}
 			int i = 0;
-			strings[i ++] = myStringFull[0]; 	//session num
-			strings[i ++] = myStringFull[3];	//session date
-			strings[i ++] = myStringFull[1]; 	//session name
+			strings[i ++] = stc.sessionParams.ID.ToString();
+			strings[i ++] = stc.sessionParams.Date;
+			strings[i ++] = stc.sessionParams.Name;
 
 			//to show tag column
 			if (app1s_type == app1s_windowType.LOAD_SESSION)
 			{
 				List<TagSession> tagSession_list = SessionTagSession.FindTagSessionsOfSession(
-						Convert.ToInt32(myStringFull[0]),
-						tagsOfAllSessions);
+						stc.sessionParams.ID, tagsOfAllSessions);
 				strings[i ++] = SessionTagSession.PrintTagNamesOfSession(tagSession_list);
 
 				//do not show this session depending on tags
@@ -547,8 +604,8 @@ public partial class ChronoJumpWindow
 				}
 			}
 
-			strings[i ++] = myStringFull[2]; 	//session place
-			strings[i ++] = myStringFull[8];	//number of jumpers x session
+			strings[i ++] = stc.sessionParams.Place;
+			strings[i ++] = stc.Persons.ToString (); // persons x session
 
 			if(showPersons) {
 				strings[i ++] = mySport;		//personsSport
@@ -556,21 +613,24 @@ public partial class ChronoJumpWindow
 				strings[i ++] = myLevel;		//personsLevel
 			}
 			if(showJumps) {
-				strings[i ++] = myStringFull[9];	//number of jumps x session
-				strings[i ++] = myStringFull[10];	//number of jumpsRj x session
+				strings[i ++] = stc.JumpsSimple.ToString ();
+				strings[i ++] = stc.JumpsReactive.ToString ();
 			}
 			if(showRuns) {
-				strings[i ++] = myStringFull[11]; 	//number of runs x session
-				strings[i ++] = myStringFull[12]; 	//number of runsInterval x session
-				strings[i ++] = myStringFull[19]; 	//number of runEncoder
-			}
-			if(showForceSensor) {
-				strings[i ++] = myStringFull[18]; 	//number of forceSensor
-			}
-			if(showEncoder) {
-				strings[i ++] = myStringFull[16]; 	//number of encoder signal x session
-				strings[i ++] = myStringFull[17]; 	//number of encoder curve x session
+				strings[i ++] = stc.RunsSimple.ToString ();
+				strings[i ++] = stc.RunsInterval.ToString ();
+				strings[i ++] = stc.RunsEncoder.ToString ();
 			}
+			if (showIsometric)
+				strings[i ++] = stc.Isometric.ToString ();
+			if (showElastic)
+				strings[i ++] = stc.Elastic.ToString ();
+			if (showWeights)
+				strings[i ++] = string.Format ("{0} ; {1}",
+						stc.WeightsSets, stc.WeightsReps); //number of encoder grav signal,reps x session
+			if (showInertial)
+				strings[i ++] = string.Format ("{0} ; {1}",
+						stc.InertialSets, stc.InertialReps); //number of encoder inertial signal,reps x session
 			/*
 			if(showRT) {
 				strings[i ++] = myStringFull[13]; 	//number of reaction times x session
@@ -580,7 +640,7 @@ public partial class ChronoJumpWindow
 				strings[i ++] = myStringFull[15]; 	//number of multiChronopics x session
 			}
 			*/
-			strings[i ++] = myStringFull[7];		//description of session (comments)
+			strings[i ++] = stc.sessionParams.Description;
 
 			app1s_store.AppendValues (strings);
 		}	
