@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -42,8 +42,12 @@ public abstract class EvolutionGraph : CairoXY
 		plotRealPoints(PlotTypes.POINTS);
 
 		writeTitle();
+		addClickableMark(g);
 
-		endGraphDisposing(g);
+		if(mouseX >= 0 && mouseY >= 0)
+			calculateAndWriteRealXY ();
+
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	//here X is year, add/subtract third of a year
@@ -134,15 +138,17 @@ public class JumpsEvolutionGraph : EvolutionGraph
 		printText(area.Allocation.Width /2, area.Allocation.Height /2, 24, textHeight,
 				errorMessage, g, alignTypes.CENTER);
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	//regular constructor
 	public JumpsEvolutionGraph (
-			List<PointF> point_l, double slope, double intercept,
+			List<PointF> point_l, List<DateTime> dates_l,
+			double slope, double intercept,
 			DrawingArea area, string title, string jumpType, string date)
 	{
 		this.point_l = point_l;
+		this.dates_l = dates_l;
 		this.slope = slope;
 		this.intercept = intercept;
 		this.area = area;
@@ -155,6 +161,10 @@ public class JumpsEvolutionGraph : EvolutionGraph
 		yVariable = heightStr;
 		xUnits = "";
 		yUnits = "cm";
+
+		area.AddEvents((int) Gdk.EventMask.ButtonPressMask); //to have mouse clicks
+		mouseX = -1;
+		mouseY = -1;
 	}
 
 	protected override void writeTitle()
@@ -180,16 +190,18 @@ public class RunsEvolutionGraph : EvolutionGraph
 		printText(area.Allocation.Width /2, area.Allocation.Height /2, 24, textHeight,
 				needToExecuteRunsStr + " " + runType + ".", g, alignTypes.CENTER);
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	//regular constructor
 	public RunsEvolutionGraph (
-			List<PointF> point_l, double slope, double intercept,
+			List<PointF> point_l, List<DateTime> dates_l,
+			double slope, double intercept,
 			DrawingArea area, string title, string runType, string date,
 			bool showTime, bool metersSecondsPreferred)
 	{
 		this.point_l = point_l;
+		this.dates_l = dates_l;
 		this.slope = slope;
 		this.intercept = intercept;
 		this.area = area;
@@ -213,6 +225,10 @@ public class RunsEvolutionGraph : EvolutionGraph
 			else
 				yUnits = "km/h";
 		}
+
+		area.AddEvents((int) Gdk.EventMask.ButtonPressMask); //to have mouse clicks
+		mouseX = -1;
+		mouseY = -1;
 	}
 
 	protected override void writeTitle()
@@ -223,4 +239,90 @@ public class RunsEvolutionGraph : EvolutionGraph
 		writeTextAtRight(ypos++, runTypeStr + " " + runType, false);
 		writeTextAtRight(ypos++, date, false);
 	}
+
+}
+
+public class JumpsAsymmetryGraph : EvolutionGraph //to inherit paintGridDatetime()
+{
+	public enum Error { NEEDJUMP, REPEATEDJUMPS }
+
+	private string personName;
+	private string index;
+	private string formula;
+
+	//constructor when there are no points
+	public JumpsAsymmetryGraph (DrawingArea area, Error error, string title, string font)
+	{
+		this.area = area;
+		this.title = "";
+		this.formula = "";
+
+		initGraph(font, .8);
+
+		g.SetFontSize(16);
+
+		if (error == Error.REPEATEDJUMPS)
+			printText(area.Allocation.Width /2, area.Allocation.Height /2, 24, textHeight,
+					repeatedJumpsStr, g, alignTypes.CENTER);
+		else
+			printText(area.Allocation.Width /2, area.Allocation.Height /2, 24, textHeight,
+					Constants.NotEnoughDataStr (), g, alignTypes.CENTER);
+
+		endGraphDisposing(g, surface, area.GdkWindow);
+	}
+
+	//regular constructor
+	public JumpsAsymmetryGraph (
+			List<PointF> point_l, List<DateTime> dates_l,
+			double slope, double intercept,
+			DrawingArea area,
+			string personName, string index, string formula,
+			string date, bool showTime, bool metersSecondsPreferred)
+	{
+		this.point_l = point_l;
+		this.dates_l = dates_l;
+		this.slope = slope;
+		this.intercept = intercept;
+		this.area = area;
+		this.personName = personName;
+		this.index = index;
+		this.formula = formula;
+		this.date = date;
+		this.colorBackground = colorFromGdk(Config.ColorBackground); //but note if we are using system colors, this will not match
+
+		xVariable = dateStr;
+		yVariable = "Index";
+
+		xUnits = "";
+		yUnits = "";
+
+		area.AddEvents((int) Gdk.EventMask.ButtonPressMask); //to have mouse clicks
+		mouseX = -1;
+		mouseY = -1;
+	}
+
+	//on jumpsAsymmetry is overrided and only prints time
+	protected override string printXDateTime (DateTime dt)
+	{
+		return (dt.ToShortDateString ());
+	}
+
+	protected override void writeTitle()
+	{
+		int ypos = -7;
+
+		writeTextAtRight(ypos++, personName, true);
+		writeTextAtRight(ypos++, index, false);
+		if (formula.Contains ("\n"))
+		{
+			string [] strFull = formula.Split(new char[] {'\n'});
+			foreach (string str in strFull)
+				writeTextAtRight(ypos++, str, false);
+		} else
+			writeTextAtRight(ypos++, formula, false);
+
+		//better do not write the date as this graph is longitudinal
+		//writeTextAtRight(ypos++, date, false);
+	}
+
 }
