@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  *  Copyright (C) 2004-2020   Jordi Rodeiro <jordirodeiro@gmail.com> 
  */
 
@@ -48,7 +48,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 
 		plotError();
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	//regular constructor
@@ -106,6 +106,10 @@ public class JumpsWeightFVProfileGraph : CairoXY
 		LogB.Information(string.Format("sfvOpt: {0}", jwp.SfvOpt));
 		LogB.Information(string.Format("f0Opt: {0}, v0Opt: {1}", f0Opt, v0Opt));
 		LogB.Information(string.Format("Imbalance: {0}", imbalance));
+
+		area.AddEvents((int) Gdk.EventMask.ButtonPressMask); //to have mouse clicks
+		mouseX = -1;
+		mouseY = -1;
 	}
 
 	private void plotError()
@@ -168,11 +172,15 @@ public class JumpsWeightFVProfileGraph : CairoXY
 		plotRealPoints(PlotTypes.POINTS);
 
 		writeTitle();
+		addClickableMark(g);
+
+		if(mouseX >= 0 && mouseY >= 0)
+			calculateAndWriteRealXY ();
 
 		if(errorMessage != ErrorAtStart.ALLOK)
 			plotError();
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	protected override void writeTitle()
@@ -210,7 +218,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 					), false);
 	}
 
-	protected override void writeSelectedValues(int line, PointF pClosest)
+	protected override void writeSelectedValues (int line, PointF pClosest, int closestPos)
 	{
 		g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 		g.SetFontSize(textHeight);
