@@ -31,6 +31,7 @@ public class CairoRadial : CairoGeneric
 	private int margin = 6;
 	private int offsetV = 6; //to move the graph vertically
 	private Gtk.DrawingArea area;
+	protected ImageSurface surface;
 	private double minSide;
 	private Cairo.Color black;
 	private Cairo.Color colorArrow;
@@ -45,13 +46,14 @@ public class CairoRadial : CairoGeneric
 	public void GraphBlank()
 	{
 		initGraph();
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	private void initGraph()
 	{
-		//1 create context
-		g = Gdk.CairoHelper.Create (area.GdkWindow);
+		//1 create context from area->surface (see xy.cs)
+                surface = new ImageSurface(Format.RGB24, area.Allocation.Width, area.Allocation.Height);
+                g = new Context (surface);
 		
 		//2 clear DrawingArea (white)
 		g.SetSourceRGB(1,1,1);
@@ -83,7 +85,7 @@ public class CairoRadial : CairoGeneric
 			minSide = graphHeight;
 
 		double tickLength = .1;
-		for(int i = 0; i <= 20; i ++)
+		for(int i = 0; i <= maxPossibleValue; i ++)
 		{
 			double iArc = (2*Math.PI / (maxPossibleValue +7)) * (i+17); //+7 for have the maxvalue at bottom right, +17 to have 0 on the bottom left
 
@@ -142,19 +144,19 @@ public class CairoRadial : CairoGeneric
 				Convert.ToInt32(margin + graphWidth/2),
 				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)),
 				0, textHeight,
-				"Speed: " + Util.TrimDecimals(speed, 1) + " m/s",
+				Catalog.GetString("Speed") + ": " + Util.TrimDecimals(speed, 1) + " m/s",
 				g, alignTypes.CENTER);
 		printText(
 				Convert.ToInt32(margin + graphWidth/2),
-				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)) + 20,
+				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)) + maxPossibleValue,
 				0, textHeight,
-				"Distance: " + Util.TrimDecimals(distance, 3) + " m",
+				Catalog.GetString("Distance") + ": " + Util.TrimDecimals(distance, 3) + " m",
 				g, alignTypes.CENTER);
 
 		if(speedMax > speed)
 			graphLineFromCenter(speedMax, gray);
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	//used at end or capture or at load
@@ -169,18 +171,18 @@ public class CairoRadial : CairoGeneric
 				Convert.ToInt32(margin + graphWidth/2),
 				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)),
 				0, textHeight,
-				"Max Speed: " + Util.TrimDecimals(speedMax, 1) + " m/s",
+				Catalog.GetString("Max Speed") + ": " + Util.TrimDecimals(speedMax, 1) + " m/s",
 				g, alignTypes.CENTER);
 		printText(
 				Convert.ToInt32(margin + graphWidth/2),
-				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)) + 20,
+				Convert.ToInt32(offsetV + margin + (.66 * graphHeight)) + maxPossibleValue,
 				0, textHeight,
-				"Distance: " + Util.TrimDecimals(distance, 3) + " m",
+				Catalog.GetString("Distance") + ": " + Util.TrimDecimals(distance, 3) + " m",
 				g, alignTypes.CENTER);
 
 		graphLineFromCenter(speedMax, gray);
 
-		endGraphDisposing(g);
+		endGraphDisposing(g, surface, area.GdkWindow);
 	}
 
 	private void graphLineFromCenter(double toValue, Cairo.Color color)
