@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -29,6 +29,7 @@ public abstract class CairoXY : CairoGeneric
 {
 	//used on construction
 	protected List<PointF> point_l;
+	protected List<DateTime> dates_l; //used on button press to know day date instead of date as double
 	protected bool predictedPointDone;
 
 	//regression line straight
@@ -48,6 +49,7 @@ public abstract class CairoXY : CairoGeneric
 	protected double pointsMaxValue;
 
 	protected DrawingArea area;
+	protected ImageSurface surface;
 	protected string title;
 	protected string jumpType;
 	protected string runType;
@@ -66,9 +68,12 @@ public abstract class CairoXY : CairoGeneric
 	protected double minY = 1000000;
 	protected double maxY = 0;
 	protected double xAtMaxY = 0; //raw, used on raceAnalyzer
+	protected double yAtMaxY = 0; //raw, used on raceAnalyzer (needed because maxY can increase if == to minY, and this yAtMaxY refers to the best point
 	double yAtMMaxY;
 	protected double absoluteMaxX;
 	protected double absoluteMaxY;
+	protected double mouseX;
+	protected double mouseY;
 
 	protected Cairo.Color black;
 	protected Cairo.Color gray99;
@@ -82,15 +87,18 @@ public abstract class CairoXY : CairoGeneric
 
 	//translated strings
 	//done to use Catalog just only on gui/cairo/xy.cs
-	//but jumpsWeightFVProfile has many messages, so done also there
+	//but jumpsWeightFVProfile has many messages, so done also there, and also on radial
 	protected string needToExecuteJumpsStr = Catalog.GetString("Need to execute jumps:");
 	protected string needToExecuteRunsStr = Catalog.GetString("Need to execute races:");
+	protected string repeatedJumpsStr = Catalog.GetString("Jumps cannot be the same.");
 	protected string optimalFallHeightStr = Catalog.GetString("Optimal fall height");
 	protected string heightStr = Catalog.GetString("Height");
 	protected string extraWeightStr = Catalog.GetString("Extra weight");
 	protected string fallStr = Catalog.GetString("Fall");
 	protected string speedStr = Catalog.GetString("Speed");
+	protected string accelStr = Catalog.GetString("Acceleration");
 	protected string forceStr = Catalog.GetString("Force");
+	protected string powerStr = Catalog.GetString("Power");
 	protected string dateStr = Catalog.GetString("Date");
 	protected string timeStr = Catalog.GetString("Time");
 	protected string distanceStr = Catalog.GetString("Distance");
@@ -106,13 +114,28 @@ public abstract class CairoXY : CairoGeneric
 		return false;
 	}
 
-	public virtual void Do(string font)
+	public void PassMouseXY (double mouseX, double mouseY)
+	{
+		this.mouseX = mouseX;
+		this.mouseY = mouseY;
+	}
+
+	public virtual void Do (string font)
 	{
 	}
-	public virtual void DoSendingList(string font, List<PointF> points_list, TriggerList triggerList, bool forceRedraw, PlotTypes plotType)
+
+	//encoderSignal (with inertial stuff & ! triggers at the moment)
+	public virtual void DoSendingList (string font, bool isInertial,
+			List<PointF> points_list, List<PointF> points_list_inertial,
+			bool forceRedraw, PlotTypes plotType)
 	{
 	}
 
+	//raceAnalyzer XY graphs (triggers)
+//	public virtual void DoSendingList(string font, List<PointF> points_list, TriggerList triggerList, bool forceRedraw, PlotTypes plotType)
+//	{
+//	}
+
 	protected void initGraph(string font, double widthPercent1)
 	{
 		initGraph(font, widthPercent1, true);
@@ -127,12 +150,20 @@ public abstract class CairoXY : CairoGeneric
 
 		totalMargins = outerMargin + innerMargin;
 
-		//1 create context
-		g = Gdk.CairoHelper.Create (area.GdkWindow);
+		// 1 create context
+		/* using drawingarea (slow)
+		   g = Gdk.CairoHelper.Create (area.GdkWindow);
+
+		   //from area->surface (see xy.cs)
+		   //draw on surface: create surface, context related to this surface, draw on this contex
+		   //copy later to drawingarea before disposing, this is much faster
+		 */
+		surface = new ImageSurface(Format.RGB24, area.Allocation.Width, area.Allocation.Height);
+		g = new Context (surface);
 
 		if(clearDrawingArea)
 		{
-			//2 clear DrawingArea (white)
+			//2 clear DrawingArea (context) (paint in white)
 			g.SetSourceRGB(1,1,1);
 			g.Paint();
 		}
@@ -170,14 +201,10 @@ public abstract class CairoXY : CairoGeneric
 	//true if changed
 	protected bool findPointMaximums(bool showFullGraph, List<PointF> points_list)
 	{
-		//foreach(PointF p in points_list)
-		/*
-		int start = lastPointPainted;
-		if(lastPointPainted < 0)
-			start = 0;
-
-		//for(int i = start; i < points_list.Count; i ++)
-		*/
+		minX = 1000000;
+		minY = 1000000;
+		maxX = 0;
+		maxY = 0;
 		for(int i = 0; i < points_list.Count; i ++)
 		{
 			PointF p = points_list[i];
@@ -192,6 +219,7 @@ public abstract class CairoXY : CairoGeneric
 			{
 				maxY = p.Y;
 				xAtMaxY = p.X; //used on raceAnalyzer
+				yAtMaxY = p.Y; //used on raceAnalyzer (needed because maxY can increase if == to minY), and this yAtMaxY refers to the best point
 			}
 		}
 
@@ -405,22 +433,40 @@ public abstract class CairoXY : CairoGeneric
 	//called from almost all methods
 	protected void plotRealPoints (PlotTypes plotType)
 	{
-		plotRealPoints (plotType, point_l, 0);
+		plotRealPoints (plotType, point_l, 0, false);
 	}
 
-	//called from raceAnalyzer (sending it own list of points)
-	protected void plotRealPoints (PlotTypes plotType, List<PointF> points_list, int startAt)
+	//called from raceAnalyzer and encoder (sending it own list of points)
+	//fast: calculated first calculatePaintX/Y for most of the formula. foreach value does short operation.
+	protected void plotRealPoints (PlotTypes plotType, List<PointF> points_list, int startAt, bool fast)
 	{
 		if(plotType == PlotTypes.LINES || plotType == PlotTypes.POINTSLINES) //draw line first to not overlap the points
 		{
 			bool firstDone = false;
-			//foreach(PointF p in points_list)
+			double xgraph;
+			double ygraph;
+			double paintXfastA = 0;
+			double paintXfastB = 0;
+			double paintYfastA = 0;
+			double paintYfastB = 0;
+
+			if(fast)
+			{
+				calculatePaintXFastPre (out paintXfastA, out paintXfastB);
+				calculatePaintYFastPre (out paintYfastA, out paintYfastB);
+			}
 			for(int i = startAt; i < points_list.Count; i ++)
 			{
 				PointF p = points_list[i];
 
-				double xgraph = calculatePaintX(p.X);
-				double ygraph = calculatePaintY(p.Y);
+				if(fast)
+				{
+					xgraph = calculatePaintXFastDo (p.X, paintXfastA, paintXfastB);
+					ygraph = calculatePaintYFastDo (p.Y, paintYfastA, paintYfastB);
+				} else {
+					xgraph = calculatePaintX(p.X);
+					ygraph = calculatePaintY(p.Y);
+				}
 
 				if(! firstDone)
 				{
@@ -528,27 +574,12 @@ public abstract class CairoXY : CairoGeneric
 			g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 	}
 
-	protected void writeCoordinatesOfMouseClick(double graphX, double graphY, double realX, double realY)
+	protected PointF pClosest;
+	protected void writeCoordinatesOfMouseClick (double graphX, double graphY, double realX, double realY)
 	{
-		// 1) need to do this because context has been disposed
-		LogB.Information(string.Format("g == null: {0}", (g = null)));
-		if(g == null)
-			g = Gdk.CairoHelper.Create (area.GdkWindow);
-
-
 		int line = 4;
-		/*
-		 * This is not needed because graph is re-done at each mouse click
-		 *
-		//rectangle to erase previous values
-		g.SetSourceColor(white);
-		g.Rectangle(graphWidth + 1, Convert.ToInt32(graphHeight/2) + textHeight*2*line - textHeight,
-				area.Allocation.Width -1, textHeight*8);
-		g.Fill();
-		g.SetSourceColor(black);
-		*/
 
-		// 2) exit if out of graph area
+		// 1) exit if out of graph area
 		LogB.Information(string.Format("graphX: {0}; graphY: {1}", graphX, graphY));
 		if(
 				graphX < outerMargin || graphX > graphWidth - outerMargin ||
@@ -562,36 +593,34 @@ public abstract class CairoXY : CairoGeneric
 		*/
 
 		LogB.Information("calling findClosestGraphPoint ...");
-		// 3) find closest point (including predicted point if any)
-		PointF pClosest = findClosestGraphPoint(graphX, graphY);
+		// 2) find closest point (including predicted point if any)
+		int closestPos = findClosestGraphPointPos (graphX, graphY);
 
 		LogB.Information("writeSelectedValues ...");
-		// 4) write text at right
-		writeSelectedValues(line, pClosest);
+		// 3) write text at right
+		writeSelectedValues (line, pClosest, closestPos);
 
 		LogB.Information("painting rectangle ...");
-		// 4) write text at right
-		// 5) paint rectangle around that point
+		// 4) paint rectangle around that point
 		g.SetSourceColor(bluePlots);
 		g.Rectangle(calculatePaintX(pClosest.X) - 2*pointsRadius, calculatePaintY(pClosest.Y) -2*pointsRadius,
 				4*pointsRadius, 4*pointsRadius);
 		g.Stroke();
 		g.SetSourceColor(black);
-		LogB.Information("writeCoordinatesOfMouseClick done! disposing");
-
-		endGraphDisposing(g);
-
-		LogB.Information("writeCoordinatesOfMouseClick disposed!");
 	}
 
 	/*
 	 * using graphPoints and not real points because X and Y scale can be very different
 	 * and this would be stranger for user to have a point selected far away to the "graph" closest point
 	 */
-	private PointF findClosestGraphPoint(double graphX, double graphY)
+	//return the position in point_l, -1 if predicted is used
+	//the position is useful for jumpsRunsEvolution and asymmetry to know the real date on date_l
+	private int findClosestGraphPointPos (double graphX, double graphY)
 	{
 		double distMin = 10000000;
-		PointF pClosest = point_l[0];
+		pClosest = point_l[0];
+		int count = 0;
+		int found = 0;
 		foreach(PointF p in point_l)
 		{
 			double dist = Math.Sqrt(Math.Pow(graphX - calculatePaintX(p.X), 2) + Math.Pow(graphY - calculatePaintY(p.Y), 2));
@@ -599,17 +628,22 @@ public abstract class CairoXY : CairoGeneric
 			{
 				distMin = dist;
 				pClosest = p;
+				found = count;
 			}
+			count ++;
 		}
 
 		//also check predicted point if exists
 		if(predictedPointDone && Math.Sqrt(Math.Pow(graphX - calculatePaintX(xAtMMaxY), 2) + Math.Pow(graphY - calculatePaintY(yAtMMaxY), 2)) < distMin)
+		{
 			pClosest = new PointF(xAtMMaxY, yAtMMaxY);
+			return -1;
+		}
 
-		return pClosest;
+		return found;
 	}
 
-	protected virtual void writeSelectedValues(int line, PointF pClosest)
+	protected virtual void writeSelectedValues(int line, PointF pClosest, int closestPos)
 	{
 		g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 		g.SetFontSize(textHeight);
@@ -618,22 +652,104 @@ public abstract class CairoXY : CairoGeneric
 		writeTextAtRight(line, Catalog.GetString("Selected") + ":", false);
 		g.SetSourceRGB(0, 0, 0);
 
-		writeTextAtRight(line +1, string.Format("- {0}: {1} {2}", xVariable, Util.TrimDecimals(pClosest.X, 2), xUnits), false);
+		if (closestPos >= 0 && dates_l != null && dates_l.Count > 0 && closestPos < dates_l.Count)
+			writeTextAtRight(line +1, string.Format("- {0}: {1} {2}", xVariable, printXDateTime (dates_l[closestPos]), xUnits), false);
+		else
+			writeTextAtRight(line +1, string.Format("- {0}: {1} {2}", xVariable, Util.TrimDecimals(pClosest.X, 2), xUnits), false);
+
 		writeTextAtRight(line +2, string.Format("- {0}: {1} {2}", yVariable, Util.TrimDecimals(pClosest.Y, 2), yUnits), false);
 	}
 
+	//on jumpsAsymmetry is overrided and only prints time
+	protected virtual string printXDateTime (DateTime dt)
+	{
+		return (dt.ToString ());
+	}
 
-	//TODO: check if for one value this is /0
 	protected override double calculatePaintX (double realX)
 	{
-                return totalMargins + (realX - minX) * (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
+                //return totalMargins + (realX - minX) * (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
+                return totalMargins + (realX - minX) * UtilAll.DivideSafe(
+				graphWidth - totalMargins - totalMargins,
+				absoluteMaxX - minX);
         }
-	//TODO: check if for one value this is /0
 	protected override double calculatePaintY (double realY)
 	{
-                return graphHeight - totalMargins - ((realY - minY) * (graphHeight - totalMargins - totalMargins) / (absoluteMaxY - minY));
+                //return graphHeight - totalMargins - ((realY - minY) * (graphHeight - totalMargins - totalMargins) / (absoluteMaxY - minY));
+		//to avoid /0 problems (eg raceAnalyzer change person: absoluteMaxY-minY = 0
+
+		/* debug:
+		LogB.Information(string.Format("graphHeight: {0}, totalMargins: {1}, restOfFormula: {2}",
+					graphHeight, totalMargins,
+					(realY - minY) * UtilAll.DivideSafe (
+				graphHeight - totalMargins - totalMargins,
+				absoluteMaxY - minY) ));
+		*/
+
+                return graphHeight - totalMargins - ((realY - minY) * UtilAll.DivideSafe (
+				graphHeight - totalMargins - totalMargins,
+				absoluteMaxY - minY));
         }
 
+	//when you want to plot another value, so minY, maxY is different
+	protected double calculatePaintYProportion (double YProp) //from 0 to 1
+	{
+                return graphHeight - totalMargins - (YProp * (graphHeight - 2*totalMargins));
+	}
+
+	// Fast calculatePaintX/Y, sadly for 10000 points the difference between fast and slow is very low
+
+	/*
+	   paintX = totalMargins + (realX - minX) * (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
+	   take out realX:
+	     paintX = A + realX * B
+	     A = totalMargins - minX  *  (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX)
+	     B = (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX)
+	   */
+	protected void calculatePaintXFastPre (out double A, out double B)
+	{
+		//A = totalMargins - minX  *  (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
+		A = totalMargins - minX  *  UtilAll.DivideSafe (
+				graphWidth - totalMargins - totalMargins,
+				absoluteMaxX - minX);
+
+		//B = (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
+		B = UtilAll.DivideSafe(graphWidth - totalMargins - totalMargins, absoluteMaxX - minX);
+
+		return;
+	}
+	protected double calculatePaintXFastDo (double realX, double A, double B)
+	{
+                return A + realX * B;
+        }
+
+	/*
+	   paintY = graphHeight - totalMargins - ((realY - minY) * (graphHeight - totalMargins - totalMargins) / (absoluteMaxY - minY))
+                //x = g - t - ((r - m) * (g - 2*t) / (a - m));
+
+	   take out realY:
+	     paintY = A + realY * B
+	     By = - (graphHeight - 2*totalMargins) / (absoluteMaxY - minY))
+	     Ay = graphHeight - totalMargins - minY * B
+	   */
+	protected void calculatePaintYFastPre (out double A, out double B)
+	{
+		B = UtilAll.DivideSafe(
+				- (graphHeight - 2*totalMargins),
+				absoluteMaxY - minY);
+
+		A = graphHeight - totalMargins - minY * B;
+
+		return;
+	}
+	protected double calculatePaintYFastDo (double realY, double A, double B)
+	{
+                return A + realY * B;
+        }
+
+
+	//calculate real (from graph coordinates)
+
 	private double calculateRealX (double graphX)
 	{
                 return minX + ( (graphX - totalMargins) * (absoluteMaxX - minX) / (graphWidth - totalMargins - totalMargins) );
@@ -642,11 +758,17 @@ public abstract class CairoXY : CairoGeneric
 	{
 		return minY - (graphY - graphHeight + totalMargins) * (absoluteMaxY - minY) / (graphHeight - totalMargins - totalMargins);
         }
+
+	//TODO: delete this method (see gui/cairo/jumpsDjOptimalFall.cs), use only the protected below
 	public void CalculateAndWriteRealXY (double graphX, double graphY)
 	{
 		writeCoordinatesOfMouseClick(graphX, graphY, calculateRealX(graphX), calculateRealY(graphY));
 	}
-
+	protected void calculateAndWriteRealXY ()
+	{
+		writeCoordinatesOfMouseClick (mouseX, mouseY,
+				calculateRealX(mouseX), calculateRealY(mouseY));
+	}
 	/*
 	private void getMinMaxXDrawable(int ancho, double maxValue, double minValue, int rightMargin, int leftMargin)
 	{
@@ -657,4 +779,12 @@ public abstract class CairoXY : CairoGeneric
 	}
 	*/
 
+	protected void drawCircle (double x, double y, double radio, Cairo.Color color)
+	{
+		g.MoveTo(x +radio, y);
+		g.Arc(x, y, radio, 0.0, 2.0 * Math.PI); //full circle
+		g.SetSourceColor(color);
+		g.Stroke();
+	}
+
 }
