@@ -47,6 +47,13 @@ public class ConfirmWindowJumpRun
 		confirm_window.Title = "Chronojump - " + Catalog.GetString("Confirm");
 		//put an icon to window
 		UtilGtk.IconWindow(confirm_window);
+
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.WindowColor(confirm_window, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel(UtilGtk.ColorIsDark(Config.ColorBackground), label1);
+			UtilGtk.ContrastLabelsLabel(UtilGtk.ColorIsDark(Config.ColorBackground), label_question);
+		}
 		
 		label1.Text = text1;
 		if(question == "")
@@ -112,8 +119,17 @@ public class ConfirmWindow
 		gladeXML.Autoconnect(this);
 		
 		confirm_window.Title = "Chronojump - " + Catalog.GetString("Confirm");
+
 		//put an icon to window
 		UtilGtk.IconWindow(confirm_window);
+
+		if(! Config.UseSystemColor)
+		{
+			UtilGtk.WindowColor(confirm_window, Config.ColorBackground);
+			UtilGtk.ContrastLabelsLabel(UtilGtk.ColorIsDark(Config.ColorBackground), label1);
+			UtilGtk.ContrastLabelsLabel(UtilGtk.ColorIsDark(Config.ColorBackground), label_link);
+			UtilGtk.ContrastLabelsLabel(UtilGtk.ColorIsDark(Config.ColorBackground), label_question);
+		}
 		
 		label1.Text = text1;
 		label1.UseMarkup = true;
