@@ -26,6 +26,7 @@ using Glade;
 public class DialogShortcuts
 {
 	[Widget] Gtk.Dialog dialog_shortcuts;
+	/*
 	[Widget] Gtk.Label label_ctrl;
 	[Widget] Gtk.Label label_ctrl1;
 	[Widget] Gtk.Label label_ctrl2;
@@ -33,6 +34,8 @@ public class DialogShortcuts
 	[Widget] Gtk.Label label_ctrl4;
 	[Widget] Gtk.Label label_ctrl5;
 	[Widget] Gtk.Label label_enter;
+	*/
+	[Widget] Gtk.Image image_button_close;
 
 	//images on capture tab
 	[Widget] Gtk.Image image_enc_grav_1;
@@ -99,6 +102,9 @@ public class DialogShortcuts
 	{
 		Pixbuf pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
+		image_button_close.Pixbuf = pixbuf;
+
 		//capture tab
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png"); //encoder gravitatory
 		image_enc_grav_1.Pixbuf = pixbuf;
