@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2019-2020   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2019-2022   Xavier de Blas <xaviblas@gmail.com>
  * Copyright (C) 2019  	Xavier Padullés <x.padulles@gmail.com>
  */
 
@@ -52,6 +52,11 @@ public class ForceSensorExerciseWindow
 	[Widget] Gtk.Image image_next;
 	[Widget] Gtk.Image image_cancel;
 
+	//type tab
+	[Widget] Gtk.RadioButton radio_type_both;
+	[Widget] Gtk.RadioButton radio_type_isometric;
+	[Widget] Gtk.RadioButton radio_type_elastic;
+
 	//force tab
 	[Widget] Gtk.Label label_force;
 	[Widget] Gtk.TextView textview_force_explanation;
@@ -63,8 +68,9 @@ public class ForceSensorExerciseWindow
 	//fixation tab
 	[Widget] Gtk.Label label_fixation;
 	[Widget] Gtk.TextView textview_fixation_explanation;
-	[Widget] Gtk.RadioButton radio_fixation_elastic;
-	[Widget] Gtk.RadioButton radio_fixation_not_elastic;
+	// disabled, using the "type" variable
+	//[Widget] Gtk.RadioButton radio_fixation_elastic;
+	//[Widget] Gtk.RadioButton radio_fixation_not_elastic;
 
 	//mass tab
 	[Widget] Gtk.Label label_mass;
@@ -109,6 +115,9 @@ public class ForceSensorExerciseWindow
 	[Widget] Gtk.Button fakeButtonReadValues;
 
 	public bool Success;
+	private bool adding;
+	private Constants.Modes chronojumpMode;
+	private ForceSensorExercise.Types type;
 	private ForceSensorExercise exercise;
 
 	//values on preferences, useful to show them unsensitive if the radio_detect_repetitions_from_prefs.Active
@@ -120,7 +129,7 @@ public class ForceSensorExerciseWindow
 
 	private enum modesEnum { EDIT, ADD }
 	private modesEnum modeEnum;
-	private enum Pages { FORCE, FIXATION, MASS, REPSDETECT, REPSSHOW, OTHER }
+	private enum Pages { TYPE, FORCE, FIXATION, MASS, REPSDETECT, REPSSHOW, OTHER }
 	private enum Options { FORCE_SENSOR, FORCE_RESULTANT, FIXATION_ELASTIC, FIXATION_NOT_ELASTIC,
 		MASS_ADD, MASS_SUBTRACT, MASS_NOTHING,
 		REPETITIONS_PREFS, REPETITIONS_NO_PREFS, REPETITIONS_SHOW, OTHER }
@@ -163,9 +172,10 @@ public class ForceSensorExerciseWindow
 		//DestroyOnAccept = false;
 	}
 
-	static public ForceSensorExerciseWindow ShowEdit (string title, string textHeader, ForceSensorExercise exercise,
-				double prefsForceSensorElasticEccMinDispl, double prefsForceSensorElasticConMinDispl,
-				int prefsForceSensorNotElasticEccMinForce, int prefsForceSensorNotElasticConMinForce)
+	static public ForceSensorExerciseWindow ShowEdit (Constants.Modes chronojumpMode,
+			string title, string textHeader, ForceSensorExercise exercise,
+			double prefsForceSensorElasticEccMinDispl, double prefsForceSensorElasticConMinDispl,
+			int prefsForceSensorNotElasticEccMinForce, int prefsForceSensorNotElasticConMinForce)
 	{
 		if (ForceSensorExerciseWindowBox == null) {
 			ForceSensorExerciseWindowBox = new ForceSensorExerciseWindow(title, textHeader);
@@ -174,6 +184,9 @@ public class ForceSensorExerciseWindow
 			ForceSensorExerciseWindowBox.label_header.Text = textHeader;
 		}
 
+		ForceSensorExerciseWindowBox.adding = false;
+		ForceSensorExerciseWindowBox.chronojumpMode = chronojumpMode;
+		ForceSensorExerciseWindowBox.type = exercise.Type; //do not change the type here, if it's both will continue being both
 		ForceSensorExerciseWindowBox.Success = false;
 		ForceSensorExerciseWindowBox.modeEnum = modesEnum.EDIT;
 		ForceSensorExerciseWindowBox.exercise = exercise;
@@ -186,7 +199,7 @@ public class ForceSensorExerciseWindow
 
 		//on edit, if elastic, pass elastic params from exercise, and not elastic from preferences. Opposite on not elastic
 		bool repsFromPrefs = false;
-		if(exercise.Elastic)
+		if(exercise.ComputeAsElastic)
 		{
 			//to avoid put -1 (in fact is 1, minimum value) on spinbuttons
 			double em = exercise.EccMin;
@@ -225,15 +238,16 @@ public class ForceSensorExerciseWindow
 					Convert.ToInt32(em), Convert.ToInt32(cm));
 		}
 
-		ForceSensorExerciseWindowBox.initializeGuiAtShow(false);
+		ForceSensorExerciseWindowBox.initializeGuiAtShow ();
 		ForceSensorExerciseWindowBox.force_sensor_exercise.Show ();
 
 		return ForceSensorExerciseWindowBox;
 	}
 
-	static public ForceSensorExerciseWindow ShowAdd (string title, string textHeader,
-				double prefsForceSensorElasticEccMinDispl, double prefsForceSensorElasticConMinDispl,
-				int prefsForceSensorNotElasticEccMinForce, int prefsForceSensorNotElasticConMinForce)
+	static public ForceSensorExerciseWindow ShowAdd (Constants.Modes chronojumpMode,
+			string title, string textHeader,
+			double prefsForceSensorElasticEccMinDispl, double prefsForceSensorElasticConMinDispl,
+			int prefsForceSensorNotElasticEccMinForce, int prefsForceSensorNotElasticConMinForce)
 	{
 		if (ForceSensorExerciseWindowBox == null) {
 			ForceSensorExerciseWindowBox = new ForceSensorExerciseWindow(title, textHeader);
@@ -242,6 +256,13 @@ public class ForceSensorExerciseWindow
 			ForceSensorExerciseWindowBox.label_header.Text = textHeader;
 		}
 
+		ForceSensorExerciseWindowBox.adding = true;
+		ForceSensorExerciseWindowBox.chronojumpMode = chronojumpMode;
+		if(chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC)
+			ForceSensorExerciseWindowBox.type = ForceSensorExercise.Types.ISOMETRIC;
+		else //if(chronojumpMode == Constants.Modes.FORCESENSORELASTIC)
+			ForceSensorExerciseWindowBox.type = ForceSensorExercise.Types.ELASTIC;
+
 		ForceSensorExerciseWindowBox.Success = false;
 		ForceSensorExerciseWindowBox.modeEnum = modesEnum.ADD;
 		ForceSensorExerciseWindowBox.exercise = null;
@@ -256,7 +277,7 @@ public class ForceSensorExerciseWindow
 				prefsForceSensorElasticEccMinDispl, prefsForceSensorElasticConMinDispl,
 				prefsForceSensorNotElasticEccMinForce, prefsForceSensorNotElasticConMinForce);
 
-		ForceSensorExerciseWindowBox.initializeGuiAtShow(true);
+		ForceSensorExerciseWindowBox.initializeGuiAtShow ();
 		ForceSensorExerciseWindowBox.force_sensor_exercise.Show ();
 
 		return ForceSensorExerciseWindowBox;
@@ -296,10 +317,17 @@ public class ForceSensorExerciseWindow
 		image_force_exerted_help.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
 	}
 
-	private void initializeGuiAtShow (bool adding)
+	private void initializeGuiAtShow ()
 	{
-		managePage(Pages.FORCE);
-		ForceSensorExerciseWindowBox.notebook_main.CurrentPage = Convert.ToInt32(Pages.FORCE);
+		Pages p = Pages.FORCE;
+		if (! adding && exercise.Type == ForceSensorExercise.Types.BOTH)
+		{
+			p = Pages.TYPE;
+			radio_type_both.Active = true;
+		}
+
+		managePage (p);
+		ForceSensorExerciseWindowBox.notebook_main.CurrentPage = Convert.ToInt32 (p);
 
 		//on edit spin_body_mass_add.Value is set at exerciseToGUI(), but on adding, set at 100
 		if(adding)
@@ -319,15 +347,10 @@ public class ForceSensorExerciseWindow
 			button_force_exerted_help.Sensitive = false;
 		}
 
-		if(exercise.Elastic)
-			radio_fixation_elastic.Active = true;
-		else
-			radio_fixation_not_elastic.Active = true;
-
-		if(exercise.PercentBodyWeight > 0 && ! exercise.TareBeforeCapture)
+		if(exercise.PercentBodyWeight > 0 && ! exercise.TareBeforeCaptureOnExerciseEdit)
 			radio_mass_add.Active = true;
 
-		else if(exercise.PercentBodyWeight == 0 && exercise.TareBeforeCapture)
+		else if(exercise.PercentBodyWeight == 0 && exercise.TareBeforeCaptureOnExerciseEdit)
 			radio_mass_subtract.Active = true;
 		else
 			radio_mass_nothing.Active = true;
@@ -420,7 +443,7 @@ public class ForceSensorExerciseWindow
 		else if(o == Options.REPETITIONS_NO_PREFS)
 			str = Catalog.GetString("These values will be used to detect repetitions.");
 		else if(o == Options.REPETITIONS_SHOW)
-			str = Catalog.GetString("Detected repetitions will show only concentric phase or both.");
+			str = Catalog.GetString("Detected repetitions will show only the phase in which the force increases or also where decreases.");
 		else //if(o == Options.OTHER)
 			str = Catalog.GetString("0 means horizontally") + "\n" +
 				Catalog.GetString("90 means vertically with the person above the sensor") + "\n" +
@@ -433,10 +456,13 @@ public class ForceSensorExerciseWindow
 	{
 		string str;
 		if(o == Options.FORCE_SENSOR)
-			str = "1.- " + Catalog.GetString("Isometric Leg Extension.") +
-				"\n2.- " + Catalog.GetString("Upper limb movements against a rubber if the displaced mass is considered insignificant.");
-		else if(o == Options.FORCE_RESULTANT)
-			str = "1.- " + Catalog.GetString("Vertical:") + " " + Catalog.GetString("Isometric squat with the force sensor fixed between the floor and the body.") +
+		{
+			if (chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC)
+				str = "- " + Catalog.GetString("Isometric Leg Extension.");
+			else //if (chronojumpMode == Constants.Modes.FORCESENSORELASTIC)
+				str = "- " + Catalog.GetString("Upper limb movements against a rubber if the displaced mass is considered insignificant.");
+		} else if(o == Options.FORCE_RESULTANT)
+			str = "1.- " + Catalog.GetString("Vertical:") + " " + Catalog.GetString("Squat with the force sensor fixed between the floor and the body.") +
 				"\n2.- " + Catalog.GetString("Horizontal:") + " " + Catalog.GetString("Movements where a significant mass is accelerated.") +
 				"\n3.- " + Catalog.GetString("Diagonal movement:") + " " + Catalog.GetString("Lateral squat.");
 		else if(o == Options.FIXATION_ELASTIC)
@@ -509,9 +535,16 @@ public class ForceSensorExerciseWindow
 		radio_desc_examples_examples.Show();
 		notebook_desc_examples.GetNthPage(1).Show();
 
-		if(p == Pages.FORCE)
+		if(p == Pages.TYPE)
 		{
+			desc = "";
+			ex = "";
 			button_back.Sensitive = false;
+		}
+		else if(p == Pages.FORCE)
+		{
+			if (adding || exercise.Type != ForceSensorExercise.Types.BOTH)
+				button_back.Sensitive = false;
 
 			if(radio_force_sensor_raw.Active) {
 				desc = getDescription(Options.FORCE_SENSOR);
@@ -527,15 +560,8 @@ public class ForceSensorExerciseWindow
 		}
 		else if(p == Pages.FIXATION)
 		{
-			if(radio_fixation_elastic.Active) {
-				desc = getDescription(Options.FIXATION_ELASTIC);
-				ex = getExample(Options.FIXATION_ELASTIC);
-				set_notebook_desc_example_labels(Options.FIXATION_ELASTIC);
-			} else {
-				desc = getDescription(Options.FIXATION_NOT_ELASTIC);
-				ex = getExample(Options.FIXATION_NOT_ELASTIC);
-				set_notebook_desc_example_labels(Options.FIXATION_NOT_ELASTIC);
-			}
+			desc = "";
+			ex = "";
 		}
 		else if(p == Pages.MASS)
 		{
@@ -556,7 +582,7 @@ public class ForceSensorExerciseWindow
 		}
 		else if(p == Pages.REPSDETECT)
 		{
-			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active)
+			if(radio_force_sensor_raw.Active || chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC)
 			{
 				label_repetitions_prefs_ecc_value.Text = prefsForceSensorNotElasticEccMinForce.ToString();
 				label_repetitions_prefs_con_value.Text = prefsForceSensorNotElasticConMinForce.ToString();
@@ -571,7 +597,7 @@ public class ForceSensorExerciseWindow
 
 
 			//visibilities
-			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active)
+			if(radio_force_sensor_raw.Active || chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC)
 			{
 				hbox_detect_repetitions_not_elastic.Visible = true;
 				hbox_detect_repetitions_elastic.Visible = false;
@@ -651,9 +677,14 @@ public class ForceSensorExerciseWindow
 
 	private void on_button_next_clicked (object o, EventArgs args)
 	{
-		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.FORCE) && radio_force_sensor_raw.Active)
-			notebook_main.CurrentPage = Convert.ToInt32(Pages.REPSDETECT);
-		else if(notebook_main.CurrentPage < Convert.ToInt32(Pages.OTHER))
+		// do not ask about elastic. Since 2.2.2 depends on mode
+		if (notebook_main.CurrentPage == Convert.ToInt32 (Pages.FORCE))
+		{
+			if (radio_force_sensor_raw.Active)
+				notebook_main.CurrentPage = Convert.ToInt32 (Pages.REPSDETECT);
+			else //if (radio_force_resultant.Active)
+				notebook_main.CurrentPage = Convert.ToInt32 (Pages.MASS);
+		} else if (notebook_main.CurrentPage < Convert.ToInt32 (Pages.OTHER))
 			notebook_main.CurrentPage ++;
 		else
 			return;
@@ -662,9 +693,19 @@ public class ForceSensorExerciseWindow
 	}
 	private void on_button_back_clicked (object o, EventArgs args)
 	{
-		if(notebook_main.CurrentPage == Convert.ToInt32(Pages.REPSDETECT) && radio_force_sensor_raw.Active)
-			notebook_main.CurrentPage = Convert.ToInt32(Pages.FORCE);
-		else if(notebook_main.CurrentPage > Convert.ToInt32(Pages.FORCE))
+		// do not ask about elastic. Since 2.2.2 depends on mode
+		if (notebook_main.CurrentPage == Convert.ToInt32 (Pages.REPSDETECT))
+		{
+			if (radio_force_sensor_raw.Active)
+				notebook_main.CurrentPage = Convert.ToInt32 (Pages.FORCE);
+			else //if (radio_force_resultant.Active)
+				notebook_main.CurrentPage = Convert.ToInt32 (Pages.MASS);
+		} else if (notebook_main.CurrentPage == Convert.ToInt32 (Pages.MASS))
+			notebook_main.CurrentPage = Convert.ToInt32 (Pages.FORCE);
+		else if (notebook_main.CurrentPage > Convert.ToInt32 (Pages.FORCE))
+			notebook_main.CurrentPage --;
+		else if (notebook_main.CurrentPage == Convert.ToInt32 (Pages.FORCE) &&
+				! adding && exercise.Type == ForceSensorExercise.Types.BOTH)
 			notebook_main.CurrentPage --;
 		else
 			return;
@@ -765,7 +806,7 @@ public class ForceSensorExerciseWindow
 		double conMin = -1;
 		if(! radio_detect_repetitions_from_prefs.Active)
 		{
-			if(radio_force_sensor_raw.Active || ! radio_fixation_elastic.Active) {
+			if (radio_force_sensor_raw.Active || chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC) {
 				eccMin = spin_force_sensor_not_elastic_ecc_min_force.Value;
 				conMin = spin_force_sensor_not_elastic_con_min_force.Value;
 			} else {
@@ -793,6 +834,15 @@ public class ForceSensorExerciseWindow
 		else //if(radio_reps_show_both.Active && radio_reps_show_both_separated.Active)
 			repetitionsShow = ForceSensorExercise.RepetitionsShowTypes.BOTHSEPARATED;
 
+		ForceSensorExercise.Types typeNew = type;
+		if (! adding && exercise.Type == ForceSensorExercise.Types.BOTH)
+		{
+			if (radio_type_isometric.Active)
+				typeNew = ForceSensorExercise.Types.ISOMETRIC;
+			else if (radio_type_elastic.Active)
+				typeNew = ForceSensorExercise.Types.ELASTIC;
+		}
+
 		ForceSensorExercise exerciseTemp = new ForceSensorExercise(
 				myID, entry_name.Text,
 				percentBodyWeight,
@@ -801,7 +851,7 @@ public class ForceSensorExerciseWindow
 				entry_description.Text,
 				radio_mass_subtract.Active, 	//tareBeforeCapture
 				radio_force_resultant.Active,
-				radio_fixation_elastic.Active,
+				typeNew,
 				repetitionsShow, eccMin, conMin);
 
 		if(modeEnum == modesEnum.ADD)
