@@ -170,9 +170,9 @@ public class EditJumpWindow : EditEventWindow
 		Jump myJump = (Jump) myEvent;
 		if(myJump.TypeHasWeight) {
 			if(weightPercentPreferred)
-				entryWeight = myJump.Weight.ToString();
+				entryWeight = myJump.WeightPercent.ToString ();
 			else
-				entryWeight = Util.WeightFromPercentToKg(myJump.Weight, personWeight).ToString();
+				entryWeight = Util.WeightFromPercentToKg (myJump.WeightPercent, personWeight).ToString ();
 
 			entry_weight_value.Text = entryWeight;
 			entry_weight_value.Sensitive = true;
@@ -518,9 +518,9 @@ public class EditJumpRjWindow : EditJumpWindow
 		JumpRj myJump = (JumpRj) myEvent;
 		if(myJump.TypeHasWeight) {
 			if(weightPercentPreferred)
-				entryWeight = myJump.Weight.ToString();
+				entryWeight = myJump.WeightPercent.ToString ();
 			else
-				entryWeight = Util.WeightFromPercentToKg(myJump.Weight, personWeight).ToString();
+				entryWeight = Util.WeightFromPercentToKg (myJump.WeightPercent, personWeight).ToString ();
 
 			entry_weight_value.Text = entryWeight;
 			entry_weight_value.Sensitive = true;
@@ -604,14 +604,10 @@ public class RepairJumpRjWindow
 		this.jumpRj = myJump;
 
 		//this.pDN = pDN;
-	
+
 		repair_sub_event.Title = Catalog.GetString("Repair reactive jump");
-		
-		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
-		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
-		label_header.Text = string.Format(Catalog.GetString("Use this window to repair this test.\nDouble clic any cell to edit it (decimal separator: '{0}')"), localeInfo.NumberDecimalSeparator);
-	
-		
+		label_header.Text = Constants.GetRepairWindowMessage ();
+
 		jumpType = SqliteJumpType.SelectAndReturnJumpRjType(myJump.Type, false);
 		
 		TextBuffer tb = new TextBuffer (new TextTagTable());
@@ -672,7 +668,7 @@ public class RepairJumpRjWindow
 							"This jump type is fixed to one jump.",
 							"This jump type is fixed to {0} jumps.",
 							Convert.ToInt32(myJumpType.FixedValue)),
-						myJumpType.FixedValue) +
+						myJumpType.FixedValue) + " " +
 					Catalog.GetString("You cannot add more.");
 			} else {
 				//if it's a jump type timeLimited with a fixed value, then complain when the total time is higher
@@ -681,7 +677,7 @@ public class RepairJumpRjWindow
 							"This jump type is fixed to one second.",
 							"This jump type is fixed to {0} seconds.",
 							Convert.ToInt32(myJumpType.FixedValue)),
-						myJumpType.FixedValue) +
+						myJumpType.FixedValue) + " " +
 					Catalog.GetString("You cannot add more.");
 			}
 		}
