@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -39,7 +39,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.VBox vbox_start_window_sub;
 	[Widget] Gtk.Alignment alignment_start_window;
 	[Widget] Gtk.Alignment alignment_encoder_capture_options;
-	[Widget] Gtk.Button button_activate_chronopics_networks_problems;
+	[Widget] Gtk.Button button_contacts_devices_networks_problems;
 
 	//RFID
 	[Widget] Gtk.Label label_rfid_wait;
@@ -60,10 +60,11 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_top_person_encoder;
 	[Widget] Gtk.Label label_top_person_name;
 	[Widget] Gtk.Label label_top_encoder_person_name;
-	[Widget] Gtk.Button button_image_current_person_zoom_h;
 	[Widget] Gtk.Image image_current_person;
 	[Widget] Gtk.Button button_contacts_person_change;
 	[Widget] Gtk.Button button_encoder_person_change;
+	[Widget] Gtk.Button button_networks_contacts_guest;
+	[Widget] Gtk.Button button_networks_encoder_guest;
 
 	//encoder exercise stuff
 	[Widget] Gtk.Label label_encoder_exercise_encoder;
@@ -74,7 +75,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_encoder_exercise_delete;
 
 	//encoder ...
-	[Widget] Gtk.Alignment alignment_check_encoder_networks_upload;
 	[Widget] Gtk.CheckButton check_encoder_networks_upload;
 	[Widget] Gtk.Button button_encoder_monthly_change_current_session;
 	[Widget] Gtk.Button button_encoder_analyze_image_compujump_send_email;
@@ -88,6 +88,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_RFID_disconnected;
 	[Widget] Gtk.Label label_encoder_checked_error;
 
+	//contacts
+	[Widget] Gtk.CheckButton check_contacts_networks_upload;
+
 	//runsInterval
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_5m;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_10m;
@@ -108,7 +111,7 @@ public partial class ChronoJumpWindow
 	private static string capturedRFID; //current RFID in use
 	private static bool shouldUpdateRFIDGui;
 	private static bool shouldShowRFIDDisconnected;
-	private static bool updatingRFIDGuiStuff;
+	private static bool sendingJsonRFID; //if connection is very slow, this helps to show a Readed (RFID) message fast and then the connection will be done
 	private static bool networksRunIntervalCanChangePersonSQLReady;
 	private static DateTime startedRFIDWait; //just to display a message at the moment of try to wristband change while capturing
 	private bool rfidProcessCancel;
@@ -127,7 +130,8 @@ public partial class ChronoJumpWindow
 
 	private void configInitRead()
 	{
-		configChronojump.Read();
+		configChronojump.Read ();
+		LogB.Information("readed config: " + configChronojump.ToString ());
 
 		if(configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED)
 		{
@@ -189,13 +193,15 @@ public partial class ChronoJumpWindow
 
 			//on networks do not allow to change devices until preferences option is checked
 			viewport_chronopics.Sensitive = false;
-			button_activate_chronopics_encoder.Sensitive = false;
+			button_encoder_devices_networks.Sensitive = false;
 
 			//do not allow camera controls
 			showWebcamCaptureContactsControls (false); //contacts
+			notebook_video_contacts.Visible = false;
 			hbox_video_encoder.Visible = false;
 
-			alignment_check_encoder_networks_upload.Visible = true;
+			check_contacts_networks_upload.Visible = true;
+			check_encoder_networks_upload.Visible = true;
 
 			//networks always without lateral person win
 			//also this is important for seing label_rfid_encoder_wait
@@ -204,6 +210,11 @@ public partial class ChronoJumpWindow
 			configChronojump.PersonWinHide = true;
 			showPersonsOnTop(true);
 
+			button_networks_contacts_guest.Visible = true;
+			button_networks_encoder_guest.Visible = true;
+			button_contacts_person_change.Visible = false;
+			button_encoder_person_change.Visible = false;
+
 			if(configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED)
 			{
 				//changeModeCheckRadios (configChronojump.CompujumpStationMode);
@@ -226,7 +237,6 @@ public partial class ChronoJumpWindow
 			Json.ChangeServerUrl(configChronojump.CompujumpServerURL);
 
 			capturedRFID = "";
-			updatingRFIDGuiStuff = false;
 			shouldUpdateRFIDGui = false;
 			rfidProcessCancel = false;
 			networksRunIntervalCanChangePersonSQLReady = true;
@@ -241,6 +251,7 @@ public partial class ChronoJumpWindow
 				rfid.FakeButtonDisconnected.Clicked += new EventHandler(rfidDisconnected);
 				rfid.FakeButtonAdminDetected.Clicked += new EventHandler(rfidAdminDetectedSendMail);
 
+				sendingJsonRFID = false;
 				threadRFID = new Thread (new ThreadStart (RFIDStart));
 				GLib.Idle.Add (new GLib.IdleHandler (pulseRFID));
 
@@ -253,6 +264,22 @@ public partial class ChronoJumpWindow
 				button_encoder_analyze_image_compujump_send_email.Visible = true;
 		}
 
+		if (configChronojump.Compujump) {
+			button_contacts_devices_networks.Visible = true;
+			button_encoder_devices_networks.Visible = true;
+			button_contacts_detect_small.Visible = false;
+			button_threshold.Visible = false;
+			//button_force_sensor_adjust.Visible = false;
+			button_encoder_detect_small.Visible = false;
+		} else {
+			button_contacts_devices_networks.Visible = false;
+			button_encoder_devices_networks.Visible = false;
+			button_contacts_detect_small.Visible = true;
+			button_threshold.Visible = true;
+			//button_force_sensor_adjust.Visible = true;
+			button_encoder_detect_small.Visible = true;
+		}
+
 		if(configChronojump.Raspberry)
 		{
 			//make easiers to use some treeviews
@@ -264,22 +291,7 @@ public partial class ChronoJumpWindow
 
 		if(configChronojump.LowHeight)
 		{
-			Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-jumps-small.png");
-			image_selector_start_jumps.Pixbuf = pixbuf;
-			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-runs-small.png");
-			image_selector_start_runs.Pixbuf = pixbuf;
-			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-encoder-small.png");
-			image_selector_start_encoder.Pixbuf = pixbuf;
-			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-force-small.png");
-			image_selector_start_force_sensor.Pixbuf = pixbuf;
-			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-rt-small.png");
-			image_selector_start_rt.Pixbuf = pixbuf;
-			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "selector-multichronopic-small.png");
-			image_selector_start_other.Pixbuf = pixbuf;
-
-
 			vbox_menu_tiny_menu.Spacing = 14; //spacing 10 or 14 is the same. 20 makes window higher
-
 			image_encoder_inertial_instructions.Visible = false;
 		}
 
@@ -295,6 +307,15 @@ public partial class ChronoJumpWindow
 			SqliteJson.UploadExhibitionTestsPending();
 		}
 
+		if (configChronojump.CanOpenExternalDB)
+		{
+			frame_database.Visible = true;
+			button_menu_database.Visible = true;
+
+			if (configChronojump.LastDBFullPath != "")
+				databaseChange ();
+		}
+
 		configDo();
 	}
 	private void RFIDStart()
@@ -362,6 +383,169 @@ public partial class ChronoJumpWindow
 		rfidProcessCancel = true;
 	}
 
+	// updateConfigFile only if selected a new db by user: on_button_database_change_clicked ()
+	private void databaseChange ()
+	{
+		closeSession ();
+
+		Sqlite.DisConnect ();
+
+		//called from Util.GetLocalDataDir
+		Config.LastDBFullPathStatic = configChronojump.LastDBFullPath;
+		Sqlite.SetHome ();
+
+		Sqlite.Connect ();
+
+		//this updated if needed:
+		Sqlite.ConvertToLastChronojumpDBVersion ();
+
+		label_current_database.Text = "<b>" + Util.GetLastPartOfPath (
+				configChronojump.LastDBFullPath) + "</b>";
+
+		label_current_database.UseMarkup = true;
+		label_current_database.TooltipText = configChronojump.LastDBFullPath;
+	}
+
+	Gtk.FileChooserDialog database_fc;
+	private void on_button_database_change_clicked (object o, EventArgs args)
+	{
+		database_fc = new Gtk.FileChooserDialog("Select folder:",
+				app1,
+				FileChooserAction.SelectFolder,
+				Catalog.GetString("Cancel"),ResponseType.Cancel,
+				Catalog.GetString("Select"),ResponseType.Accept
+				);
+
+		if (configChronojump.ExternalDBDefaultPath != "")
+			database_fc.SetCurrentFolder (configChronojump.ExternalDBDefaultPath);
+
+		if (database_fc.Run() == (int)ResponseType.Accept)
+		{
+			// 1) check that there is a database/chronojump.db inside
+			if ( ! File.Exists( System.IO.Path.Combine (database_fc.Filename, "database", "chronojump.db")) )
+			{
+				new DialogMessage (Constants.MessageTypes.WARNING,
+						"Error: Need to select a folder that has a \"database\" folder inside an a \"chronojump.db\" file inside.");
+			} else {
+				// 2) reassing configChronojump.LastDBFullPath
+				configChronojump.LastDBFullPath = database_fc.Filename;
+
+				// 3) update config file (taking care of being default config file)
+				configChronojump.UpdateFieldEnsuringDefaultConfigFile ("LastDBFullPath", database_fc.Filename);
+
+				// 4) change database
+				databaseChange ();
+			}
+		}
+
+		database_fc.Hide ();
+
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		database_fc.Destroy();
+	}
+
+	private void on_button_networks_guest_clicked (object sender, EventArgs e)
+	{
+		// 1) do not allow to click again the button
+		button_networks_contacts_guest.Visible = false;
+		button_networks_encoder_guest.Visible = false;
+
+		// 2) reset logout counter
+		compujumpAutologout = new CompujumpAutologout();
+
+		// 3) create/load person. guest is id: -2, check if it exists. If it exists will return -2, if not: -1
+		currentPerson = SqlitePerson.Select(false, -2);
+		if(currentPerson.UniqueID == -1) //do not exists, create it
+			currentPerson = new Person (true, -2, Catalog.GetString("Guest"), "-1", ""); //this true means insertPerson
+
+		// 4) personSession insert if needed and assign
+		currentPersonSession = SqlitePersonSession.Select(false, currentPerson.UniqueID, currentSession.UniqueID);
+		if(currentPersonSession.UniqueID == -1)
+			currentPersonSession = new PersonSession (
+					currentPerson.UniqueID, currentSession.UniqueID,
+					0, 0, //width, height
+					Constants.SportUndefinedID,
+					Constants.SpeciallityUndefinedID,
+					Constants.LevelUndefinedID,
+					"", 	//comments
+					Constants.TrochanterToeUndefinedID,
+					Constants.TrochanterFloorOnFlexionUndefinedID,
+					false); //dbconOpened
+
+		// 5) person active gui changes
+		sensitiveGuiYesPerson();
+		personChanged(); //GTK
+		label_person_change();
+
+		// 6) specific guest setup
+		if (Constants.ModeIsENCODER (current_mode))
+			configNetworksEncoderAsGuest (true);
+		else
+			configNetworksContactsAsGuest (true);
+	}
+	private void configNetworksContactsAsGuest (bool guest)
+	{
+		//on guest widgets are invisible, cleaner and easier than unsensitive because during capture/curves sensitivity changes on some buttons
+		check_contacts_networks_upload.Active = ! guest;
+		check_contacts_networks_upload.Visible = ! guest;
+
+		//radio_mode_contacts_analyze_small.Visible = ! guest;
+		button_menu_preferences1.Visible = ! guest;
+		button_contacts_capture_load.Visible = ! guest;
+		button_contacts_capture_session_overview.Visible = ! guest;
+		button_delete_last_test.Visible = ! guest;
+
+		button_contacts_bells.Visible = ! guest;
+
+		//simple jumps
+		button_edit_selected_jump.Visible = ! guest;
+		button_video_play_selected_jump.Visible = ! guest;
+		button_delete_selected_jump.Visible = ! guest;
+
+		//multiple jumps
+		button_edit_selected_jump_rj.Visible = ! guest;
+		button_repair_selected_jump_rj.Visible = ! guest;
+		button_video_play_selected_jump_rj.Visible = ! guest;
+		button_delete_selected_jump_rj.Visible = ! guest;
+
+		//simple races
+		button_edit_selected_run.Visible = ! guest;
+		button_video_play_selected_run.Visible = ! guest;
+		button_delete_selected_run.Visible = ! guest;
+
+		//intervallic races
+		button_edit_selected_run_interval.Visible = ! guest;
+		button_repair_selected_run_interval.Visible = ! guest;
+		button_video_play_selected_run_interval.Visible = ! guest;
+		button_delete_selected_run_interval.Visible = ! guest;
+	}
+	private void configNetworksEncoderAsGuest(bool guest)
+	{
+		//on guest widgets are invisible, cleaner and easier than unsensitive because during capture/curves sensitivity changes on some buttons
+		check_encoder_networks_upload.Active = ! guest;
+		check_encoder_networks_upload.Visible = ! guest;
+
+		radio_mode_encoder_analyze_small.Visible = ! guest;
+		button_menu_preferences1.Visible = ! guest;
+		button_encoder_load_signal.Visible = ! guest;
+		button_encoder_capture_session_overview.Visible = ! guest;
+		button_encoder_delete_signal.Visible = ! guest;
+
+		button_encoder_bells.Visible = ! guest;
+		if(guest)
+		{
+			preferences.encoderCaptureMainVariable = Constants.EncoderVariablesCapture.MeanSpeed;
+			preferences.encoderCaptureSecondaryVariable = Constants.EncoderVariablesCapture.RangeAbsolute;
+		} else {
+			preferences.encoderCaptureMainVariable = (Constants.EncoderVariablesCapture)
+				Enum.Parse(typeof(Constants.EncoderVariablesCapture),
+						SqlitePreferences.Select("encoderCaptureMainVariable", false));
+			preferences.encoderCaptureSecondaryVariable = (Constants.EncoderVariablesCapture)
+				Enum.Parse(typeof(Constants.EncoderVariablesCapture),
+						SqlitePreferences.Select("encoderCaptureSecondaryVariable", false));
+		}
+	}
+
 	private void configInitFromPreferences()
 	{
 		if(configChronojump == null)
@@ -428,11 +612,6 @@ public partial class ChronoJumpWindow
 			hbox_encoder_analyze_signal_or_curves.HeightRequest = 40;
 			button_encoder_analyze.SetSizeRequest(120,40);
 		}
-		/*
-		if(! configChronojump.UseVideo) {
-			alignment_video_encoder.Visible = false;
-		}
-		*/
 		//restriction for configured Compujump clients
 		//if(configChronojump.Compujump)
 		//	hbox_encoder_im_weights_n.Sensitive = false;
@@ -543,7 +722,7 @@ public partial class ChronoJumpWindow
 			Session s = SqliteSession.SelectByName(yearLastMonthStr);
 
 			//import all persons from last session
-			List<PersonSession> personSessions = SqlitePersonSession.SelectPersonSessionList(s.UniqueID);
+			List<PersonSession> personSessions = SqlitePersonSession.SelectPersonSessionList(-1, s.UniqueID);
 
 			//convert all personSessions to currentSession
 			//and nullify UniqueID in order to be inserted incrementally by SQL
@@ -644,31 +823,49 @@ public partial class ChronoJumpWindow
 		}
 
 
-		//don't allow this method to be called again until ended
-		//Note RFID detection can send many cards (the same) per second
-		if(updatingRFIDGuiStuff) {
-			Thread.Sleep (100);
-			return true;
-		}
-
 		if(! shouldUpdateRFIDGui) {
 			Thread.Sleep (100);
 			return true;
 		}
 
 		//show a Read message nice if the network is slow or there is any problem with the web services
-		label_rfid_wait.Text = Catalog.GetString("Read");
-		label_rfid_encoder_wait.Text = Catalog.GetString("Read");
+		string str = Catalog.GetString ("The wristband has been read.") + "\n" +
+			Catalog.GetString ("Connecting to server …");
+		label_rfid_wait.Text = str;
+		label_rfid_encoder_wait.Text = str;
 		label_rfid_wait.Visible = true;
 		label_rfid_encoder_wait.Visible = true;
 
 		shouldUpdateRFIDGui = false;
-		updatingRFIDGuiStuff = true;
 
 		//is we are on analyze, switch to capture
 		if(! radio_mode_encoder_capture_small.Active)
 			radio_mode_encoder_capture_small.Active = true;
 
+		/*
+		   don't allow sendJsonRFID to be called again until ended
+		   Note RFID detection can send many cards (the same) per second
+		   having that call on a timeout is to ensure the label_rfid_wait will be shown
+		   */
+		if (sendingJsonRFID)
+		{
+			Thread.Sleep (100);
+			LogB.Information(" threadRFID:" + threadRFID.ThreadState.ToString());
+
+			return false;
+		} else {
+			//don't allow to press guest button while connection is being done
+			button_networks_contacts_guest.Visible = false;
+			button_networks_encoder_guest.Visible = false;
+
+			sendingJsonRFID = true;
+			GLib.Timeout.Add (50, new GLib.TimeoutHandler (sendJsonRFID));
+		}
+
+		return true;
+	}
+	private bool sendJsonRFID ()
+	{
 		/*
 		 * This method is shown on diagrams/processes/rfid-local-read.dia
 		 */
@@ -850,10 +1047,21 @@ public partial class ChronoJumpWindow
 		if(currentPerson != null && currentPersonWasNull)
 			sensitiveGuiYesPerson();
 
+		//it is not a guest remove guest changes
+		if (Constants.ModeIsENCODER (current_mode))
+			configNetworksEncoderAsGuest (false);
+		else
+			configNetworksContactsAsGuest (false);
+
 		if(pChangedShowTasks)
 		{
 			compujumpAutologout = new CompujumpAutologout();
 
+			button_networks_contacts_guest.Visible = false;
+			button_networks_encoder_guest.Visible = false;
+			button_contacts_person_change.Visible = true;
+			button_encoder_person_change.Visible = true;
+
 			/*TODO:
 			int rowToSelect = myTreeViewPersons.FindRow(currentPerson.UniqueID);
 			if(rowToSelect != -1)
@@ -866,18 +1074,14 @@ public partial class ChronoJumpWindow
 
 			//not allow to change devices if person changed. If you want to change again, go to preferences/advanced networksAllowChangeDevices
 			preferences.networksAllowChangeDevices = false;
-			button_activate_chronopics_encoder.Sensitive = false;
+			button_encoder_devices_networks.Sensitive = false;
 		}
 
 		//Wakeup screen if it's off
 		Networks.WakeUpRaspberryIfNeeded();
 
-		updatingRFIDGuiStuff = false;
-
-		Thread.Sleep (100);
-		//LogB.Information(" threadRFID:" + threadRFID.ThreadState.ToString());
-
-		return true;
+		sendingJsonRFID = false;
+		return false;
 	}
 
 	private void compujumpDownloadImage (JsonCompujump json, string url, int personID)
@@ -974,7 +1178,21 @@ public partial class ChronoJumpWindow
 	private void getTasksExercisesAndPopup()
 	{
 		//1) get tasks
-		JsonCompujump json = new JsonCompujump(configChronojump.CompujumpDjango);
+		JsonCompujump json;
+
+		if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
+				configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
+		{
+			json = new JsonCompujumpEncoder (configChronojump.CompujumpDjango);
+		}
+		else if(configChronojump.CompujumpStationMode == Constants.Modes.JUMPSSIMPLE ||
+				configChronojump.CompujumpStationMode == Constants.Modes.JUMPSREACTIVE)
+		{
+			json = new JsonCompujumpJumps (configChronojump.CompujumpDjango);
+		}
+		else
+			return;
+
 		string tasksStr = json.GetTasksResponse (currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
 		List<Task> tasks = new List<Task>();
@@ -987,8 +1205,70 @@ public partial class ChronoJumpWindow
 				tasks = new TaskDeserialize().DeserializeTaskEncoder(tasksStr);
 		}
 
-		//3) get exercises and insert if needed (only on encoder)
-		if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
+		// 1) get tasks
+		// 3) get exercises and insert if needed (at the moment only for jumps and encoder)
+		// 3a) jumps
+		if(configChronojump.CompujumpStationMode == Constants.Modes.JUMPSSIMPLE ||
+				configChronojump.CompujumpStationMode == Constants.Modes.JUMPSREACTIVE)
+		{
+			List<object> jumpsSimpleExercisesOnLocal = SqliteJumpType.SelectJumpTypesNew (false, "", "", false);
+			List<object> jumpsRjExercisesOnLocal = SqliteJumpType.SelectJumpRjTypesNew ("", false);
+
+			//List<SelectJumpTypes> exRemote_l = json.GetJumpStationExercises (configChronojump.CompujumpStationID);
+			json.GetJumpStationExercises (configChronojump.CompujumpStationID);
+
+			// 3a1) Jumps simple
+			bool insertedJumps = false;
+			foreach(SelectJumpTypes exRemote in json.JumpSimpleExercises_l)
+			{
+				bool found = false;
+				foreach(SelectJumpTypes jLocal in jumpsSimpleExercisesOnLocal)
+					if(jLocal.Id == exRemote.Id)
+					{
+						found = true;
+						break;
+					}
+
+				if(! found)
+				{
+					SqliteJumpType.JumpTypeInsert (exRemote.Id, exRemote.ToSQLString (), false);
+					insertedJumps = true;
+				}
+			}
+			if (insertedJumps)
+			{
+				createComboSelectJumps (false);
+				if (current_mode == Constants.Modes.JUMPSSIMPLE)
+					createComboSelectContactsTop ();
+			}
+
+			// 3a2) Jumps Reactive
+			insertedJumps = false;
+			foreach(SelectJumpRjTypes exRemote in json.JumpRjExercises_l)
+			{
+				bool found = false;
+				foreach(SelectJumpRjTypes jLocal in jumpsRjExercisesOnLocal)
+					if(jLocal.Id == exRemote.Id)
+					{
+						found = true;
+						break;
+					}
+
+				if(! found)
+				{
+					SqliteJumpType.JumpRjTypeInsert (exRemote.Id, exRemote.ToSQLString (), false);
+					insertedJumps = true;
+				}
+			}
+			if (insertedJumps)
+			{
+				createComboSelectJumpsRj (false);
+				if (current_mode == Constants.Modes.JUMPSSIMPLE)
+					createComboSelectContactsTop ();
+			}
+		}
+		// 3b) encoder
+		else if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
 				configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
 		{
 			Constants.EncoderGI type = Constants.EncoderGI.GRAVITATORY;
@@ -996,7 +1276,7 @@ public partial class ChronoJumpWindow
 				type = Constants.EncoderGI.INERTIAL;
 
 			ArrayList encoderExercisesOnLocal = SqliteEncoder.SelectEncoderExercises(false, -1, false, type);
-			List<EncoderExercise> exRemote_list = json.GetStationExercises(configChronojump.CompujumpStationID, type);
+			List<EncoderExercise> exRemote_list = json.GetEncoderStationExercises (configChronojump.CompujumpStationID, type);
 
 			foreach(EncoderExercise exRemote in exRemote_list)
 			{
@@ -1134,17 +1414,17 @@ public partial class ChronoJumpWindow
 			spin_encoder_extra_weight.Value = Convert.ToDouble(task.Load);
 
 		if(task.Speed > 0) {
-			repetitiveConditionsWin.EncoderMeanSpeedHigherValue = task.Speed;
-			repetitiveConditionsWin.EncoderMeanSpeedHigher = true;
-			repetitiveConditionsWin.EncoderMeanSpeedLowerValue = task.Speed / 2;
-			repetitiveConditionsWin.EncoderMeanSpeedHigher = true;
-			repetitiveConditionsWin.Encoder_show_manual_feedback = true;
-			repetitiveConditionsWin.Notebook_encoder_conditions_page = 1; //speed
+			feedbackWin.EncoderMeanSpeedHigherValue = task.Speed;
+			feedbackWin.EncoderMeanSpeedHigher = true;
+			feedbackWin.EncoderMeanSpeedLowerValue = task.Speed / 2;
+			feedbackWin.EncoderMeanSpeedHigher = true;
+			feedbackWin.Encoder_show_manual_feedback = true;
+			feedbackWin.Notebook_encoder_conditions_page = 1; //speed
 			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_active.png");
 		} else {
-			repetitiveConditionsWin.EncoderMeanSpeedHigher = false;
-			repetitiveConditionsWin.EncoderMeanSpeedLower = false;
-			repetitiveConditionsWin.Encoder_show_manual_feedback = false;
+			feedbackWin.EncoderMeanSpeedHigher = false;
+			feedbackWin.EncoderMeanSpeedLower = false;
+			feedbackWin.Encoder_show_manual_feedback = false;
 			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_none.png");
 		}
 		image_encoder_bell.Pixbuf = pixbuf;
@@ -1178,10 +1458,14 @@ public partial class ChronoJumpWindow
 		currentPerson = null;
 		currentPersonSession = null;
 		sensitiveGuiNoPerson ();
+		button_networks_contacts_guest.Visible = true;
+		button_networks_encoder_guest.Visible = true;
+		button_contacts_person_change.Visible = false;
+		button_encoder_person_change.Visible = false;
 
 		//not allow to change devices if person changed. If you want to change again, go to preferences/advanced networksAllowChangeDevices
 		preferences.networksAllowChangeDevices = false;
-		button_activate_chronopics_encoder.Sensitive = false;
+		button_encoder_devices_networks.Sensitive = false;
 	}
 
 	private void compujumpPersonAutoLogoutChanged(object o, EventArgs args)
@@ -1239,7 +1523,7 @@ public partial class ChronoJumpWindow
 			hbox_RFID_disconnected.Visible = false;
 			hbox_encoder_disconnected.Visible = true;
 			label_encoder_checked_error.Visible = false;
-			button_activate_chronopics_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
+			button_contacts_devices_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
 		}
 		else {
 			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.ENCODER);
@@ -1260,7 +1544,7 @@ public partial class ChronoJumpWindow
 			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.NETWORKSPROBLEMS);
 			hbox_RFID_disconnected.Visible = true;
 
-			button_activate_chronopics_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
+			button_contacts_devices_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
 			hbox_encoder_disconnected.Visible = false;
 		}
 		else {
