@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2016-2020   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2016-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -257,9 +257,9 @@ public class EncoderOverviewWindow : OverviewWindow
 	protected override ArrayList selectData(treeviewType type)
 	{
 		if(type == treeviewType.SETS)
-			return SqliteEncoder.SelectSessionOverviewSets(false, encoderGI, sessionID);
+			return SqliteEncoder.SelectSessionOverviewSets (false, encoderGI, sessionID);
 		else
-			return SqliteEncoder.SelectSessionOverviewReps(false, encoderGI, sessionID);
+			return SqliteEncoder.SelectSessionOverviewReps (false, encoderGI, sessionID);
 	}
 
 	protected override void createTreeView(Gtk.TreeView tv, treeviewType type)
@@ -290,7 +290,11 @@ public class EncoderOverviewWindow : OverviewWindow
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
 				tv.AppendColumn (Catalog.GetString ("Extra mass"), new CellRendererText(), "text", count++);
 
+			tv.AppendColumn (Catalog.GetString ("Contraction"), new CellRendererText(), "text", count++);
 			tv.AppendColumn (Catalog.GetString ("Power"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Speed"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Force"), new CellRendererText(), "text", count++);
+			tv.AppendColumn (Catalog.GetString ("Save criteria on eccentric-concentric"), new CellRendererText(), "text", count++);
 		}
 	}
 
@@ -300,14 +304,18 @@ public class EncoderOverviewWindow : OverviewWindow
 		if(type == treeviewType.SETS)
 		{
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
-				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof(string)); //personID (hidden), person name, sex, encoderConfiguration, exercise, displaced mass, sets
+				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string));
+				//personID (hidden), person name, sex, encoderConfiguration, exercise, displaced mass, sets
 			else
-				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string)); //personID (hidden), person name, sex, encoderConfiguration, exercise, sets
+				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string));
+				//personID (hidden), person name, sex, encoderConfiguration, exercise, sets
 		} else {
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
-				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof(string)); //personID (hidden), person name, sex, encoderConfiguration, exercise, extra mass, power
+				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string));
+				//personID (hidden), person name, sex, encoderConfiguration, exercise, extra mass, contraction, power, speed, force, repCriteria
 			else
-				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string)); //personID (hidden), person name, sex, encoderConfiguration, exercise, power
+				s = new TreeStore(typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string), typeof (string));
+				//personID (hidden), person name, sex, encoderConfiguration, exercise, contraction, power, speed, force, repCriteria
 		}
 
 		return s;
@@ -329,6 +337,7 @@ public class EncoderOverviewWindow : OverviewWindow
 public class ForceSensorOverviewWindow : OverviewWindow
 {
 	static ForceSensorOverviewWindow ForceSensorOverviewWindowBox;
+	private Constants.Modes chronojumpMode;
 
 	public ForceSensorOverviewWindow(Gtk.Window parent)
 	{
@@ -347,13 +356,14 @@ public class ForceSensorOverviewWindow : OverviewWindow
 	}
 
 	//if personIDAtStart == -1, there is not currentPerson
-	static public ForceSensorOverviewWindow Show (Gtk.Window parent, int sessionID, int personIDAtStart)
+	static public ForceSensorOverviewWindow Show (Gtk.Window parent, int sessionID, int personIDAtStart, Constants.Modes chronojumpMode)
 	{
 		if (ForceSensorOverviewWindowBox == null)
 			ForceSensorOverviewWindowBox = new ForceSensorOverviewWindow (parent);
 
 		ForceSensorOverviewWindowBox.sessionID = sessionID;
 		ForceSensorOverviewWindowBox.personIDAtStart = personIDAtStart;
+		ForceSensorOverviewWindowBox.chronojumpMode = chronojumpMode;
 
 		ForceSensorOverviewWindowBox.initialize();
 
@@ -375,7 +385,7 @@ public class ForceSensorOverviewWindow : OverviewWindow
 
 	protected override ArrayList selectData(treeviewType type)
 	{
-		return SqliteForceSensor.SelectSessionOverviewSets(false, sessionID);
+		return SqliteForceSensor.SelectSessionOverviewSets(false, sessionID, chronojumpMode);
 	}
 
 	protected override void on_button_close_clicked (object o, EventArgs args)
