@@ -154,6 +154,14 @@ public class PersonAddModifyWindow
 	//PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showCapturePhoto)
 	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson)
 	{
+		//this strings will be used on merge persons code. Now are here just to be translated in the meantime.
+		LogB.Information (Catalog.GetString ("Merge with another person"));
+		LogB.Information (string.Format (Catalog.GetString ("Merge persons '{0}' with '{1}' in all sessions."), "xavi", "jordi") + "\n" +
+			string.Format (Catalog.GetString ("All tests of person '{0}' will be assigned to person '{1}'."),
+				"jordi", "xavi")); //Are you sure?
+		LogB.Information (Catalog.GetString ("Please, choose person's parameters."));
+		LogB.Information (string.Format (Catalog.GetString ("Please, choose person's parameters at session {0}."), "session"));
+
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_win.glade", "person_win", null);
 		gladeXML.Autoconnect(this);
@@ -1075,20 +1083,20 @@ public class PersonAddModifyWindow
 						(! radio_metric.Active && Util.ConvertPoundsToKg(spinbutton_weight_imperial.Value) != weightIniMetric)
 				      ) ) {
 				//see if this person has done jumps with weight
-				string [] myJumpsNormal = SqliteJump.SelectJumpsSA (false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "",
+				string [] myJumpsSimple = SqliteJump.SelectJumpsSA (false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "",
 						Sqlite.Orders_by.DEFAULT, -1);
 				string [] myJumpsReactive = SqliteJumpRj.SelectJumpsSA (false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
 
-				if(myJumpsNormal.Length > 0 || myJumpsReactive.Length > 0) {
+				if(myJumpsSimple.Length > 0 || myJumpsReactive.Length > 0) {
 					//create the convertWeight Window
 					if(radio_metric.Active)
 						convertWeightWin = ConvertWeightWindow.Show(
 								weightIniMetric, (double) spinbutton_weight_metric.Value,
-								myJumpsNormal, myJumpsReactive);
+								myJumpsSimple, myJumpsReactive);
 					else
 						convertWeightWin = ConvertWeightWindow.Show(
 								weightIniMetric, Util.ConvertPoundsToKg(spinbutton_weight_imperial.Value),
-								myJumpsNormal, myJumpsReactive);
+								myJumpsSimple, myJumpsReactive);
 					convertWeightWin.Button_accept.Clicked += new EventHandler(on_convertWeightWin_accepted);
 					convertWeightWin.Button_cancel.Clicked += new EventHandler(on_convertWeightWin_cancelled);
 				} else 
@@ -1189,7 +1197,7 @@ public class PersonAddModifyWindow
 			Run mRun = SqliteRun.SelectRunData(Convert.ToInt32(margaria[1]), false);
 			double distanceMeters = mRun.Distance / 1000;
 			mRun.Description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / mRun.Time).ToString(), pDN) + " (Watts)";
-			SqliteRun.Update(mRun.UniqueID, mRun.Type, mRun.Distance.ToString(), mRun.Time.ToString(), mRun.PersonID, mRun.Description);
+			SqliteRun.Update(mRun.UniqueID, mRun.Type, mRun.Distance, mRun.Time.ToString(), mRun.PersonID, mRun.Description);
 		}
 
 		string personName = Util.MakeValidSQLAndFileName(entry1.Text);
@@ -1263,7 +1271,7 @@ public class PersonAddModifyWindow
 					trochanterFloorOnFlexion);
 
 			//3.- update in database
-			SqlitePersonSession.Update (currentPersonSession); 
+			SqlitePersonSession.Update (false, currentPersonSession);
 		}
 
 		if(webcam != null && webcam.Running)
