@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -23,7 +23,7 @@ using Gtk;
 using Glade;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
-
+using System.Collections.Generic; //List<T>
 using System.Threading;
 using Mono.Unix;
 
@@ -182,8 +182,11 @@ public class EditRunWindow : EditEventWindow
 	}
 		
 
-	protected override void updateEvent(int eventID, int personID, string description) {
-		SqliteRun.Update(eventID, UtilGtk.ComboGetActive(combo_eventType), entryDistance, entryTime, personID, description);
+	protected override void updateEvent(int eventID, int personID, string description)
+	{
+		SqliteRun.Update (eventID, UtilGtk.ComboGetActive(combo_eventType),
+				Convert.ToDouble (entry_distance_value.Text),
+				entryTime, personID, description);
 	}
 
 	protected override void on_button_cancel_clicked (object o, EventArgs args)
@@ -250,6 +253,9 @@ public class EditRunIntervalWindow : EditRunWindow
 
 	static EditRunIntervalWindow EditRunIntervalWindowBox;
 
+	private double tracks = -1;
+	private string distancesString; //to manage agility/non agility tests in order to know totalDistance, this will not change
+
 	EditRunIntervalWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
@@ -499,11 +505,45 @@ public class EditRunIntervalWindow : EditRunWindow
 	}
 	
 	
-	protected override void fillDistance(Event myEvent) {
+	protected override void fillDistance(Event myEvent)
+	{
 		RunInterval myRun = (RunInterval) myEvent;
-		entry_distance_value.Text = myRun.DistanceInterval.ToString() +
-			"x" + myRun.Limited;
+
+		//distanceAtInit = 0;
+		tracks = myRun.Tracks;
+
+		//string distancesString = "";
+		distancesString = "";
+		List<object> selectRunITypes_l = SqliteRunIntervalType.SelectRunIntervalTypesNew ("", false);
 		entry_distance_value.Sensitive = false;
+
+		//1 on agility test show the distances string in meters
+		if (myRun.DistanceInterval < 0)
+		{
+			if (selectRunITypes_l != null && selectRunITypes_l.Count > 0)
+				distancesString = SelectRunITypes.RunIntervalTypeDistancesString (myRun.Type, selectRunITypes_l);
+		}
+
+		if (distancesString != "")
+		{
+			entry_distance_value.Text = RunType.DistancesStringAsMeters (distancesString);
+			label_distance_units.Hide ();
+		} else {
+			//2 on the rest of tests show interval x times
+			entry_distance_value.Text = myRun.DistanceInterval.ToString();
+			label_distance_units.Show ();
+
+			if (selectRunITypes_l != null && selectRunITypes_l.Count > 0)
+				foreach (SelectRunITypes srit in selectRunITypes_l)
+				{
+					if (srit.NameEnglish == myRun.Type && srit.Distance == 0)
+					{
+						entry_distance_value.Sensitive = true;
+						//distanceAtInit = myRun.DistanceInterval;
+						break;
+					}
+				}
+		}
 	}
 
 	protected override void fillTime(Event myEvent) {
@@ -518,7 +558,24 @@ public class EditRunIntervalWindow : EditRunWindow
 		//don't allow to change totaltime in rjedit
 		entry_time_value.Sensitive = false; 
 	}
-	
+
+	protected override void on_entry_distance_changed (object o, EventArgs args)
+	{
+		if (Util.IsNumber(entry_distance_value.Text.ToString(), distanceCanBeDecimal))
+		{
+			label_speed_value.Text = Util.TrimDecimals(
+					Util.GetSpeed (
+						Util.GetRunITotalDistance (Convert.ToDouble(entry_distance_value.Text), distancesString, tracks), //TODO: check this ToDouble works on RSA
+						Convert.ToDouble (entryTime), //totalTime
+						metersSecondsPreferred) , pDN);
+			button_accept.Sensitive = true;
+		} else {
+			button_accept.Sensitive = false;
+			//entry_distance_value.Text = "";
+			//entry_distance_value.Text = entryDistance;
+		}
+	}
+
 	protected override void fillSpeed(Event myEvent) {
 		RunInterval myRun = (RunInterval) myEvent;
 		label_speed_value.Text = Util.TrimDecimals( 
@@ -534,8 +591,19 @@ public class EditRunIntervalWindow : EditRunWindow
 	}
 
 
-	protected override void updateEvent(int eventID, int personID, string description) {
-		SqliteRunInterval.Update(eventID, personID, description);
+	protected override void updateEvent (int eventID, int personID, string description)
+	{
+		LogB.Information (string.Format (
+			"updateEvent eventID: {0}, entry_distance_value.Text: {1}, tracks: {2}, personID: {3}, description: {4}",
+			eventID, entry_distance_value.Text, tracks, personID, description));
+
+		double distanceInterval = 0;
+		if (Util.IsNumber (entry_distance_value.Text, true))
+			distanceInterval = Convert.ToDouble (entry_distance_value.Text);
+		else
+			distanceInterval = -1;
+
+		SqliteRunInterval.Update (eventID, distanceInterval, tracks, distancesString, personID, description);
 	}
 
 	protected override void on_button_cancel_clicked (object o, EventArgs args)
@@ -593,10 +661,7 @@ public class RepairRunIntervalWindow
 		this.runInterval = myRun;
 	
 		repair_sub_event.Title = Catalog.GetString("Repair intervallic race");
-		
-		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
-		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
-		label_header.Text = string.Format(Catalog.GetString("Use this window to repair this test.\nDouble clic any cell to edit it (decimal separator: '{0}')"), localeInfo.NumberDecimalSeparator);
+		label_header.Text = Constants.GetRepairWindowMessage ();
 	
 		
 		type = SqliteRunIntervalType.SelectAndReturnRunIntervalType(myRun.Type, false);
@@ -653,7 +718,7 @@ public class RepairRunIntervalWindow
 							"This race type is fixed to one lap.",
 							"This race type is fixed to {0} laps.",
 							myRunType.FixedValue), 
-						myRunType.FixedValue) +
+						myRunType.FixedValue) + " " +
 					Catalog.GetString("You cannot add more.");
 			} else {
 				//if it's a run type timeLimited with a fixed value, then complain when the total time is higher
@@ -662,7 +727,7 @@ public class RepairRunIntervalWindow
 							"This race type is fixed to one second.",
 							"This race type is fixed to {0} seconds.",
 							myRunType.FixedValue),
-						myRunType.FixedValue) +
+						myRunType.FixedValue) + " " +
 					Catalog.GetString("Totaltime cannot be greater.");
 			}
 		}
