@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -94,7 +94,7 @@ public class PrepareEventGraphJumpSimple
 			personIDTemp = -1;
 
 		jumpsAtSQL = SqliteJump.SelectJumps (sessionID, personIDTemp, type,
-				Sqlite.Orders_by.ID_DESC, limit,
+				Sqlite.Orders_by.ID_ASC, limit,
 				allPersons, 	//show names on comments only if "all persons"
 				false); 	//! onlyBestInSession
 
@@ -181,7 +181,7 @@ public class PrepareEventGraphJumpReactive
 			personIDTemp = -1;
 
 		jumpsAtSQL = SqliteJumpRj.SelectJumps (true, sessionID, personIDTemp, type,
-				Sqlite.Orders_by.ID_DESC, limit, allPersons); 	//show names on comments only if "all persons"
+				Sqlite.Orders_by.ID_ASC, limit, allPersons); 	//show names on comments only if "all persons"
 
 		// sum of each subjump
 		//string sqlSelect = "tvAvg*jumps";
@@ -263,7 +263,7 @@ public class PrepareEventGraphRunSimple {
 
 		//obtain data
 		runsAtSQL = SqliteRun.SelectRuns (true, sessionID, personIDTemp, type,
-				Sqlite.Orders_by.ID_DESC, limit,
+				Sqlite.Orders_by.ID_ASC, limit,
 				allPersons, false); //show names on comments only if "all persons"
 
 		
@@ -332,7 +332,7 @@ public class PrepareEventGraphRunInterval
 			personIDTemp = -1;
 
 		runsAtSQL = SqliteRunInterval.SelectRuns (true, sessionID, personIDTemp, type,
-				Sqlite.Orders_by.ID_DESC, limit, allPersons); 	//show names on comments only if "all persons"
+				Sqlite.Orders_by.ID_ASC, limit, allPersons); 	//show names on comments only if "all persons"
 
 		string sqlSelect = "distanceTotal/timeTotal";
 		string table = Constants.RunIntervalTable;
@@ -358,26 +358,27 @@ public class PrepareEventGraphRunInterval
 public class PrepareEventGraphRunIntervalRealtimeCapture
 {
 	public string type;
-	public double distance;
-	public double lastTime;
 	public string timesString;
-	public double distanceTotal; //we pass this because it's dificult to calculate in runs with variable distances
+	public double distanceInterval; //we pass this because it's dificult to calculate in runs with variable distances
 	public string distancesString; //we pass this because it's dificult to calculate in runs with variable distances
+	public List<int> photocell_l; //for Wichro
 	public bool startIn;
 	public bool finished;
 
 	public PrepareEventGraphRunIntervalRealtimeCapture() {
 	}
 
-	public PrepareEventGraphRunIntervalRealtimeCapture (string type, double distance, double lastTime, string timesString,
-			double distanceTotal, string distancesString, bool startIn, bool finished)
+	public PrepareEventGraphRunIntervalRealtimeCapture (string type,
+			string timesString,
+			double distanceInterval, string distancesString,
+			List<int> photocell_l,
+			bool startIn, bool finished)
 	{
 		this.type = type;
-		this.distance = distance;
-		this.lastTime = lastTime;
 		this.timesString = timesString;
-		this.distanceTotal = distanceTotal;
+		this.distanceInterval = distanceInterval;
 		this.distancesString = distancesString;
+		this.photocell_l = photocell_l;
 		this.startIn = startIn;
 		this.finished = finished;
 	}
@@ -385,6 +386,68 @@ public class PrepareEventGraphRunIntervalRealtimeCapture
 	~PrepareEventGraphRunIntervalRealtimeCapture() {}
 }
 
+public class PrepareEventGraphBarplotEncoder
+{
+	public string mainVariable;
+	public double mainVariableHigher;
+	public double mainVariableLower;
+	public string secondaryVariable;
+	public bool showLoss;
+	public bool capturing;
+	public string eccon;
+	public FeedbackEncoder feedback;
+	public bool hasInertia;
+	public bool playSoundsFromFile;
+	public ArrayList data9Variables;
+	public Gtk.ListStore encoderCaptureListStore;
+	public bool relativeToSet;
+	public double maxPowerSpeedForceIntersession; //it will be one of these 3
+	public string maxPowerSpeedForceIntersessionDate;
+	public int discardFirstN;
+	public int showNRepetitions;
+	public bool volumeOn;
+	public Preferences.GstreamerTypes gstreamer;
+
+	public PrepareEventGraphBarplotEncoder () {
+	}
+
+	public PrepareEventGraphBarplotEncoder (
+			string mainVariable, double mainVariableHigher, double mainVariableLower,
+			string secondaryVariable, bool showLoss,
+			bool capturing, string eccon,
+			FeedbackEncoder feedback,
+			bool hasInertia, bool playSoundsFromFile,
+			ArrayList data9Variables, Gtk.ListStore encoderCaptureListStore,
+			bool relativeToSet,
+			double maxPowerSpeedForceIntersession, string maxPowerSpeedForceIntersessionDate,
+			int discardFirstN, int showNRepetitions, bool volumeOn, Preferences.GstreamerTypes gstreamer)
+
+	{
+		this.mainVariable = mainVariable;
+		this.mainVariableHigher = mainVariableHigher;
+		this.mainVariableLower = mainVariableLower;
+		this.secondaryVariable = secondaryVariable;
+		this.showLoss = showLoss;
+		this.capturing = capturing;
+		this.eccon = eccon;
+		this.feedback = feedback;
+		this.hasInertia = hasInertia;
+		this.playSoundsFromFile = playSoundsFromFile;
+		this.data9Variables = data9Variables;
+		this.encoderCaptureListStore = encoderCaptureListStore;
+		this.relativeToSet = relativeToSet;
+		this.maxPowerSpeedForceIntersession = maxPowerSpeedForceIntersession;
+		this.maxPowerSpeedForceIntersessionDate = maxPowerSpeedForceIntersessionDate;
+		this.discardFirstN = discardFirstN;
+		this.showNRepetitions = showNRepetitions;
+		this.volumeOn = volumeOn;
+		this.gstreamer = gstreamer;
+	}
+
+	~PrepareEventGraphBarplotEncoder () {}
+}
+
+
 public class PrepareEventGraphPulse {
 	public double lastTime;
 	public string timesString;
@@ -648,7 +711,15 @@ public class RepetitionMouseLimits
 	{
 		PointStartEnd p = new PointStartEnd(current ++, start, end);
 		list.Add(p);
-		LogB.Information("Added: " + p.ToString());
+		LogB.Information("Mouse added: " + p.ToString());
+	}
+
+	//used on CairoBars because bars go from right to left, so we force the pos here
+	public void AddInPos (int pos, double start, double end)
+	{
+		PointStartEnd p = new PointStartEnd(pos, start, end);
+		list.Add(p);
+		LogB.Information("Mouse added: " + p.ToString());
 	}
 
 	public int FindBarInPixel (double pixel)
@@ -668,4 +739,10 @@ public class RepetitionMouseLimits
 	{
 		return ((PointStartEnd) list[rep]).End;
 	}
+
+	//to debug
+	public int Count ()
+	{
+		return list.Count;
+	}
 }
