@@ -205,7 +205,7 @@ public partial class ChronoJumpWindow
 				notebook_video_contacts.CurrentPage = 1;
 			}
 
-			if(current_mode == Constants.Modes.FORCESENSOR)
+			if(Constants.ModeIsFORCESENSOR (current_mode))
 				forceSensorCapturePre3_GTK_cameraCalled();
 			else if(current_mode == Constants.Modes.RUNSENCODER)
 				runEncoderCapturePre3_GTK_cameraCalled();
@@ -506,33 +506,6 @@ public partial class ChronoJumpWindow
 				checkbutton_video_contacts.Active = false;
 			}
 
-			if(notebook_sup.CurrentPage == Convert.ToInt32(notebook_sup_pages.CONTACTS)) {
-				/*
-				 * TODO:
-				//remove video capture from encoder tab
-				viewport_video_capture_encoder.Remove(capturer);
-				//add in contacts tab
-				hbox_video_capture.PackStart(capturer, true, true, 0);
-				*/
-			} else {
-				/*
-				 * TODO:
-				//remove video capture from contacts tab
-				hbox_video_capture.Remove(capturer);
-				//add in encoder tab
-
-				//switch to capture tab
-				radiobutton_video_encoder_capture.Active = true;
-
-				//sometimes it seems is not removed and then cannot be added again
-				//just add if not exists
-				//maybe this error was because before we were not doing the:
-				//radiobutton_video_encoder_capture.Active = true;
-				if(viewport_video_capture_encoder.Child == null)
-					viewport_video_capture_encoder.Add(capturer);
-					*/
-			}
-
 			if(wasActive)
 				checkbutton_video_contacts.Active = true;
 
@@ -774,7 +747,7 @@ public partial class ChronoJumpWindow
 
 	private void on_button_video_play_this_test_contacts_clicked (object o, EventArgs args)
 	{
-		if(current_mode == Constants.Modes.FORCESENSOR)
+		if(Constants.ModeIsFORCESENSOR (current_mode))
 		{
 			if(currentForceSensor == null || currentForceSensor.UniqueID == -1)
 				new DialogMessage(Constants.MessageTypes.WARNING, "Sorry, file not found");
