@@ -16,7 +16,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2016-2017 Carles Pina
- * Copyright (C) 2016-2021 Xavier de Blas
+ * Copyright (C) 2016-2022 Xavier de Blas
  */
 
 using System;
@@ -32,7 +32,13 @@ using Mono.Unix;
 
 public class JsonCompujump : Json
 {
-	private bool django;
+	protected bool django;
+	protected string exercisesFailedStr = Catalog.GetString("Could not get station exercises.");
+
+	//for inheritance
+	public JsonCompujump ()
+	{
+	}
 
 	public JsonCompujump(bool django)
 	{
@@ -310,89 +316,17 @@ public class JsonCompujump : Json
 		return stations;
 	}
 
-	//stationType can be GRAVITATORY or INERTIAL
-	public List<EncoderExercise> GetStationExercises(int stationId, Constants.EncoderGI stationType)
+	public List<SelectJumpTypes> JumpSimpleExercises_l;
+	public List<SelectJumpRjTypes> JumpRjExercises_l;
+
+	public virtual void GetJumpStationExercises (int stationId)
 	{
-		List<EncoderExercise> ex_list = new List<EncoderExercise>();
-
-		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getStationExercises"))
-			return ex_list;
-
-		// Set the Method property of the request to GET.
-		request.Method = "GET";
-
-		HttpWebResponse response;
-		if(! getHttpWebResponse (request, out response, Catalog.GetString("Could not get station exercises.")))
-			return ex_list;
-
-		string responseFromServer;
-		using (var sr = new StreamReader(response.GetResponseStream()))
-		{
-			responseFromServer = sr.ReadToEnd();
-		}
-
-		LogB.Information("GetStationExercises: " + responseFromServer);
-
-		if(responseFromServer == "")
-			LogB.Information(" Empty "); //never happens
-		else if(responseFromServer == "[]")
-			LogB.Information(" Empty2 "); //when rfid is not on server
-		else {
-			ex_list = stationExercisesDeserialize(responseFromServer, stationId, stationType);
-		}
-
-		return ex_list;
 	}
-	private List<EncoderExercise> stationExercisesDeserialize(string str, int stationId, Constants.EncoderGI stationType)
+	public virtual List<EncoderExercise> GetEncoderStationExercises (int stationId, Constants.EncoderGI stationType)
 	{
-		List<EncoderExercise> ex_list = new List<EncoderExercise>();
-		JsonValue jsonStationExercises = JsonValue.Parse (str);
-
-		foreach (JsonValue jsonSE in jsonStationExercises)
-		{
-			// 1) discard exercise if is not for this station
-			JsonValue jsonSEStations = JsonValue.Parse (jsonSE["stations"].ToString());
-			bool exerciseForThisStation = false;
-			foreach (JsonValue jsonSEStation in jsonSEStations)
-			{
-				Int32 stations_id = jsonSEStation ["id"];
-				if(stations_id == stationId)
-					exerciseForThisStation = true;
-			}
-
-			if(! exerciseForThisStation)
-				continue;
-
-			// 2) discard if is not for this station type
-			string type = jsonSE ["measurable"];
-			Constants.EncoderGI newExEncoderGi = Constants.EncoderGI.GRAVITATORY;
-			if(type == "I")
-				newExEncoderGi = Constants.EncoderGI.INERTIAL;
-
-			if(stationType != newExEncoderGi)
-				continue;
-
-			// 3) add exercise to the list
-			Int32 newExId = jsonSE ["id"];
-			string newExName = jsonSE ["name"];
-
-			int newExPercentBodyMassDisplaced = 0;
-			if(jsonSE ["measurable_info"]["percent_body_mass_displaced"] != null)
-				newExPercentBodyMassDisplaced = jsonSE ["measurable_info"]["percent_body_mass_displaced"];
-
-			double newExSpeedAt1RM = 0;
-			if(jsonSE ["measurable_info"]["speed_at_one_rm"] != null)
-				newExSpeedAt1RM = Convert.ToDouble(Util.ChangeDecimalSeparator(
-							jsonSE ["measurable_info"]["speed_at_one_rm"].ToString() )); //ToString is mandatory
-
-			ex_list.Add(new EncoderExercise(newExId, newExName, newExPercentBodyMassDisplaced,
-						"", "", newExSpeedAt1RM, newExEncoderGi));
-		}
-		return ex_list;
+		return new List<EncoderExercise> ();
 	}
 
-
 	/*
 	 * Unused, now using the above methods
 	 *
@@ -473,6 +407,71 @@ public class JsonCompujump : Json
 	}
 	*/
 
+	public bool UploadJumpData (UploadJumpDataObject o, Constants.Modes m)
+	{
+		LogB.Information("calling jump upload, mode = " + m.ToString());
+		// Create a request using a URL that can receive a post.
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadJump"))
+			return false;
+
+		// Set the Method property of the request to POST.
+		request.Method = "POST";
+
+		// Creates the json object
+		// debug reading on server /var/log/chronojump/debug.log
+
+		JsonObject json = new JsonObject();
+		json.Add("station_id", o.stationId);
+		json.Add("exercise_id", o.ExerciseIdStr);
+		json.Add("comment", "");
+		json.Add("extra_weight", o.WeightInKg);
+		if (m == Constants.Modes.JUMPSSIMPLE)
+		{
+			json.Add("player_id", o.jump.PersonID);
+			json.Add("multiple", 0);
+			json.Add("contact_time", Util.ConvertToPoint (o.jump.Tc));
+			json.Add("flight_time", Util.ConvertToPoint (o.jump.Tv));
+			json.Add("fall", Util.ConvertToPoint (o.jump.Fall));
+		} else // if (m == Constants.Modes.JUMPSREACTIVE)
+		{
+			json.Add("player_id", o.jumpRj.PersonID);
+			json.Add("multiple", 1);
+			json.Add("contact_time", Util.ConvertToPoint (o.jumpRj.TcAvg));
+			json.Add("flight_time", Util.ConvertToPoint (o.jumpRj.TvAvg));
+			json.Add("fall", Util.ConvertToPoint (o.jumpRj.Fall));
+		}
+		json.Add("power", o.PowerStr);
+		json.Add("stiffness", o.StiffnessStr);
+		json.Add("initial_speed", o.InitialSpeedStr);
+
+		// Converts it to a String
+		String js = json.ToString();
+		LogB.Information("json UploadJumpData: ", js);
+
+		// Writes the json object into the request dataStream
+		Stream dataStream;
+		if(! getWebRequestStream (request, out dataStream, "Could not upload jump data."))
+			return false;
+
+		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
+		dataStream.Close ();
+
+		// Get the response.
+		WebResponse response;
+		if(! getWebResponse (request, out response, "Could not upload jump data."))
+			return false;
+
+		// Display the status (will be 202, CREATED)
+		Console.WriteLine (((HttpWebResponse)response).StatusDescription);
+
+		// Clean up the streams.
+		dataStream.Close ();
+		response.Close ();
+
+		this.ResultMessage = "Jump data sent.";
+		return true;
+	}
+
 	public bool UploadSprintData (UploadSprintDataObject o)
 	{
 		LogB.Information("calling upload sprint");
