@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -30,7 +30,7 @@ public class Jump : Event
 	protected double tc;
 	protected double fall;	//-1 if start inside to detect the fall. This is a special case where there are two flight times, but 1st is only used to detect fall-
 				//when jump finishes, fall is calculated and 2nd flight time is stored. It becomes a jump with one TC and one TF
-	protected double weight; //always write in % (not kg or %) then sqlite can do avgs
+	protected double weightPercent; //always write in % (not kg or %) then sqlite can do avgs
 
 	//for not checking always in database
 	protected bool hasFall;
@@ -41,7 +41,7 @@ public class Jump : Event
 	}
 	
 	//after inserting database (SQL)
-	public Jump(int uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated, string datetime)
+	public Jump(int uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weightPercent, string description, double angle, int simulated, string datetime)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -50,7 +50,7 @@ public class Jump : Event
 		this.tv = tv;
 		this.tc = tc;
 		this.fall = fall;
-		this.weight = weight;
+		this.weightPercent = weightPercent;
 		this.description = description;
 		this.angle = angle;
 		this.simulated = simulated;
@@ -67,7 +67,7 @@ public class Jump : Event
 		this.tv = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[4]));
 		this.tc = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[5]));
 		this.fall = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[6]));
-		this.weight = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[7]));
+		this.weightPercent = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[7]));
 		this.description = eventString[8].ToString();
 		this.angle = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[9]));
 		this.simulated = Convert.ToInt32(eventString[10]);
@@ -88,15 +88,75 @@ public class Jump : Event
 				uniqueID.ToString(), 
 				personID, sessionID, 
 				type, tv, tc, fall, 
-				weight, description, 
+				weightPercent, description, 
 				angle, simulated, datetime);
 	}
-	
+
+	public static double GetDjPower (double tc, double tf, double mass, double fallHeight)
+	{
+		/*
+		 * old method
+		//relative potency in Watts/Kg
+		//Bosco. Pendent to find if published
+
+		//P = 24.6 * (TotalTime + FlightTime) / ContactTime
+
+		double tt = tc + tf; //totalTime
+
+		return 24.6 * ( tt + tf ) / (Double)tc;
+		*/
+
+		//new method (proposal by Xavier Padullés)
+		//Calcule the potential energies before (mass * g * fallHeight) and after the jump (mass * g * tv^2 * 1.226)
+		//and divide by the time during force is applied
+		double g = 9.81;
+		fallHeight = fallHeight / 100.0; //cm -> m
+
+		return mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tc;
+	}
+
+	//only Lewis now
+	public static double GetPower (double tf, double bodyWeight, double extraWeightKg)
+	{
+		//LogB.Information ("tf: " + tf + ", bodyWeight: " + bodyWeight + ", extra: " + extraWeightKg);
+		double pw = System.Math.Sqrt ( 4.9 ) * 9.8 * (bodyWeight + extraWeightKg) *
+			System.Math.Sqrt(
+				       Convert.ToDouble ( Util.GetHeightInCentimeters(tf.ToString()))/100);
+		//LogB.Information ("pw: " + pw);
+		return pw;
+
+	}
+
 	public virtual double Stiffness(double personMassInKg, double extraMass) 
 	{
 		return Util.GetStiffness(personMassInKg, extraMass, tv, tc);
 	}	
-	
+
+	//in JumpRj do not use this because we don't know on which subjumps use it
+	public double GetInitialSpeedJumpSimple (bool metersSecondsPreferred)
+	{
+		return (GetInitialSpeed (tv, metersSecondsPreferred));
+	}
+
+	//old code sends and returns strings
+	public static string GetInitialSpeed (string time, bool metersSecondsPreferred)
+	{
+		return GetInitialSpeed (Convert.ToDouble (time), metersSecondsPreferred).ToString();
+	}
+	//new code (2019 ...) sends and returns doubles
+	public static double GetInitialSpeed (double time, bool metersSecondsPreferred)
+	{
+		double height = Util.GetHeightInCentimeters (time);
+		height = height / 100; //in meters
+
+		// Vo = sqrt(2gh)
+		double initialSpeed = System.Math.Sqrt ( 2 * 9.81 * height );
+
+		if(! metersSecondsPreferred)
+			initialSpeed *= 3.6;
+
+		return initialSpeed;
+	}
 
 	public override string ToString() {
 		return uniqueID + ":" + personID + ":" + sessionID + ":" + type + ":" + tv + ":" + tc + ":" + datetime + ":" + description;
@@ -125,9 +185,13 @@ public class Jump : Event
 		set { fall = value; }
 	}
 	
-	public double Weight {
-		get { return weight; }
-		set { weight = value; }
+	public double WeightPercent {
+		get { return weightPercent; }
+		set { weightPercent = value; }
+	}
+	public double WeightInKg (double personMassInKg)
+	{
+		return Util.WeightFromPercentToKg (weightPercent, personMassInKg);
 	}
 
 	public double RSI {
@@ -175,7 +239,7 @@ public class JumpRj : Jump
 
 	public JumpRj(int uniqueID, int personID, int sessionID, string type,
 			double tvMax, double tcMax,
-			double fall, double weight, string description,
+			double fall, double weightPercent, string description,
 			double tvAvg, double tcAvg,
 			string tvString, string tcString,
 			int jumps, double time, string limited,
@@ -188,7 +252,7 @@ public class JumpRj : Jump
 		this.tvMax = tvMax;
 		this.tcMax = tcMax;
 		this.fall = fall;
-		this.weight = weight;
+		this.weightPercent = weightPercent;
 		this.description = description;
 		this.tvAvg = tvAvg;
 		this.tcAvg = tcAvg;
@@ -206,7 +270,7 @@ public class JumpRj : Jump
 	
 	//after inserting database (SQL)
 	public JumpRj(int uniqueID, int personID, int sessionID, string type, 
-			string tvString, string tcString, double fall, double weight, 
+			string tvString, string tcString, double fall, double weightPercent, 
 			string description, int jumps, double time, string limited, string angleString, int simulated, string datetime)
 	{
 		this.uniqueID = uniqueID;
@@ -216,7 +280,7 @@ public class JumpRj : Jump
 		this.tvString = tvString;
 		this.tcString = tcString;
 		this.fall = fall;
-		this.weight = weight;
+		this.weightPercent = weightPercent;
 		this.description = description;
 		this.jumps = jumps;
 		this.time = time;
@@ -241,7 +305,7 @@ public class JumpRj : Jump
 		this.tvString = Util.ChangeDecimalSeparator(eventString[11].ToString());
 		this.tcString = Util.ChangeDecimalSeparator(eventString[12].ToString());
 		this.fall = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[6]));
-		this.weight = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[7]));
+		this.weightPercent = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[7]));
 		this.description = eventString[8].ToString();
 		this.jumps = Convert.ToInt32(eventString[13]);
 		this.time = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[14]));
@@ -266,12 +330,66 @@ public class JumpRj : Jump
 		return SqliteJumpRj.Insert(dbconOpened, tableName, 
 				uniqueID.ToString(),
 				personID, sessionID, 
-				type, TvMax, TcMax, fall, weight,
+				type, TvMax, TcMax, fall, weightPercent,
 				description, TvAvg, TcAvg, tvString, tcString,
 				jumps, time, limited, 
 				angleString, simulated, datetime);
 	}
 
+	// based on treeviewJump printAVG
+	public double PowerAverage (double personMassInKg)
+	{
+		double powerSum = 0;
+		for (int i = 0; i < tcList.Count; i ++)
+		{
+			double tc = tcList[i];
+			double tv = tvList[i];
+			double myfall = 0;
+			double weightInKg = WeightInKg (personMassInKg);
+			if (tcList[i] == -1) //startIn at first jump tc is 0, better check like this (string)
+				powerSum += GetPower (tv, personMassInKg, weightInKg);
+			else {
+				if (i == 0)
+					myfall = fall;
+				else
+					myfall = Util.GetHeightInCentimeters (tvList[i-1]);
+
+				powerSum += Jump.GetDjPower (tc, tv,
+						(personMassInKg + weightInKg), myfall);
+
+				/* debug
+				LogB.Information (string.Format (
+							"at jumpRj.PowerAverage, tc: {0}, tv: {1}, (personMassInKg + weightInKg): {2}, myfall: {3}, powerSum: {4}",
+							tc, tv, (personMassInKg + weightInKg), myfall, powerSum));
+
+				LogB.Information ("at jumpRj.PowerAverage, powerSum = ", powerSum.ToString());
+				*/
+			}
+		}
+		return UtilAll.DivideSafe (powerSum, tcList.Count);
+	}
+
+	// based on treeviewJump printAVG
+	public double StiffnessAverage (double personMassInKg, double weightInKg)
+	{
+		double stiffnessSum = 0;
+		int stiffnessCount = 0;
+
+		for (int i = 0; i < tcList.Count; i ++)
+		{
+			if(tcList[i] == -1) //startIn at first jump tc is 0, better check like this (string)
+			{
+				//do nothing
+			} else
+			{
+				stiffnessSum += Util.GetStiffness
+					(personMassInKg, weightInKg, tvList[i], tcList[i]);
+				stiffnessCount ++;
+			}
+		}
+
+		return UtilAll.DivideSafe (stiffnessSum, stiffnessCount);
+	}
 
 	public override double Stiffness(double personMassInKg, double extraMass) 
 	{
@@ -390,6 +508,52 @@ public class JumpRj : Jump
 		}
 	}
 
+	//both used on jumpsRjFatigue
+	public List<double> TvList
+	{
+		get { return tvList; }
+	}
+	public List<double> TcList
+	{
+		get { return tcList; }
+	}
+
+
+	/*
+	public List<double> TcPlusTvList
+	{
+		get {
+			List<double> l = new List<double>();
+			for (int i = 0; i < tcList.Count; i ++)
+			{
+				if (tcList[i] <= 0)
+					l.Add (tvList[i]); //discard -1 tc on first jump starting in
+				else
+					l.Add (tcList[i] + tvList[i]);
+			}
+			return l;
+		}
+	}
+	*/
+	//tc + tv, used on jumpsRjFatigue
+	public List<double> TcPlusTvAccumulatedList
+	{
+		get {
+			List<double> l = new List<double>();
+			double accumulatedSum = 0;
+			for (int i = 0; i < tcList.Count; i ++)
+			{
+				if (tcList[i] <= 0)
+					accumulatedSum += tvList[i]; //discard -1 tc on first jump starting in
+				else
+					accumulatedSum += tcList[i] + tvList[i];
+
+				l.Add (accumulatedSum);
+			}
+			return l;
+		}
+	}
+
 	public double tvLast
 	{
 		get {
