@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -56,6 +56,7 @@ public class Preferences
 	public bool loadLastModeAtStart;
 	public Constants.Modes lastMode;
 	public SessionLoadDisplay sessionLoadDisplay;
+	public int lastPersonID;
 
 	public enum UnitsEnum { METRIC, IMPERIAL };
 	public UnitsEnum units;
@@ -103,6 +104,24 @@ public class Preferences
 	public bool encoderShowStartAndDuration;
 	public enum TriggerTypes { NO_TRIGGERS, START_AT_CAPTURE, START_AT_FIRST_ON};
 	public TriggerTypes encoderCaptureCutByTriggers;
+
+	public enum EncoderRepetitionCriteria { ECC_CON, ECC, CON };
+	public EncoderRepetitionCriteria encoderRepetitionCriteriaGravitatory;
+	public EncoderRepetitionCriteria encoderRepetitionCriteriaInertial;
+	public EncoderRepetitionCriteria GetEncoderRepetitionCriteria (Constants.Modes mode)
+	{
+		if (mode == Constants.Modes.POWERINERTIAL)
+			return encoderRepetitionCriteriaInertial;
+		else
+			return encoderRepetitionCriteriaGravitatory;
+	}
+	public EncoderRepetitionCriteria GetEncoderRepetitionCriteria (bool inertial)
+	{
+		if (inertial)
+			return encoderRepetitionCriteriaInertial;
+		else
+			return encoderRepetitionCriteriaGravitatory;
+	}
 	
 	//encoder other
 	public bool encoderPropulsive;
@@ -133,6 +152,7 @@ public class Preferences
 	public int forceSensorNotElasticConMinForce;
 	public enum VariabilityMethodEnum { CHRONOJUMP_OLD, RMSSD, CVRMSSD };
 	public VariabilityMethodEnum forceSensorVariabilityMethod;
+	public int forceSensorVariabilityLag;
 	public double forceSensorAnalyzeABSliderIncrement;
 	public double forceSensorAnalyzeMaxAVGInWindow; //seconds
 	public int forceSensorGraphsLineWidth;
