@@ -44,6 +44,7 @@ public class RunEncoder
 	private string dateTime;
 	private string comments;
 	private string videoURL;
+	private int angle;
 
 	private string exerciseName;
 
@@ -58,7 +59,7 @@ public class RunEncoder
 	//constructor
 	public RunEncoder(int uniqueID, int personID, int sessionID, int exerciseID, Devices device,
 			int distance, int temperature, string filename, string url,
-			string dateTime, string comments, string videoURL, string exerciseName)
+			string dateTime, string comments, string videoURL, int angle, string exerciseName)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -72,6 +73,7 @@ public class RunEncoder
 		this.dateTime = dateTime;
 		this.comments = comments;
 		this.videoURL = videoURL;
+		this.angle = angle;
 
 		this.exerciseName = exerciseName;
 	}
@@ -91,7 +93,7 @@ public class RunEncoder
 		return
 			"(" + uniqueIDStr + ", " + personID + ", " + sessionID + ", " + exerciseID + ", \"" + device.ToString() + "\", " +
 			distance + ", " + temperature + ", \"" + filename + "\", \"" + url + "\", \"" + dateTime + "\", \"" +
-			comments + "\", \"" + videoURL + "\")";
+			comments + "\", \"" + videoURL + "\", " + angle + ")";
 	}
 
 	public void UpdateSQL(bool dbconOpened)
@@ -113,7 +115,8 @@ public class RunEncoder
 			"\", dateTime = \"" + dateTime +
 			"\", comments = \"" + comments +
 			"\", videoURL = \"" + Util.MakeURLrelative(videoURL) +
-			"\" WHERE uniqueID = " + uniqueID;
+			"\", angle = " + angle +
+			" WHERE uniqueID = " + uniqueID;
 	}
 
 	public void UpdateSQLJustComments(bool dbconOpened)
@@ -259,6 +262,11 @@ public class RunEncoder
 		get { return videoURL; }
 		set { videoURL = value; }
 	}
+	public int Angle
+	{
+		get { return angle; }
+		set { angle = value; }
+	}
 	public string ExerciseName
 	{
 		get { return exerciseName; }
@@ -274,27 +282,48 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 	private int segmentCm;
 	private List<int> segmentVariableCm; //if segmentCm == -1 then this is used
 	private int segmentVariableCmDistAccumulated;
-	private TwoListsOfDoubles segmentDistTime_2l;
+	private RunEncoderSegmentCalcs segmentCalcs;
+
+	private double massKg;
+	private int angle;
 
 	private int encoderDisplacement;
 	private int time;
+	private List<int> time_l; //to calculate smoothing
 	private int force;
 	private int encoderOrRCA;
 
 	private int timePre;
+	private int timeAtEnoughAccelOrTrigger0; //load (discard previous and shift time)
+	private int timeAtEnoughAccelMark; //capture (just draw a vertical line, to not erase previous points while capture)
+	private double distanceAtEnoughAccelMark; //load (to know where the bars start)
+	private bool distanceAtEnoughAccelMarkSet;
 
 	private double runEncoderCaptureSpeed;
 	private double runEncoderCaptureSpeedMax;
 	private double runEncoderCaptureDistance; //m
+	private List<double> runEncoderCaptureDistance_l; //to calculate smoothing
+	private List<double> runEncoderCaptureSpeed_l; //to calculate smoothing
+	//private List<double> runEncoderCaptureSpeedSmoothed_l; //smoothed
 
-	public RunEncoderCaptureGetSpeedAndDisplacement(int segmentCm, List<int> segmentVariableCm)
+	public RunEncoderCaptureGetSpeedAndDisplacement(int segmentCm, List<int> segmentVariableCm, double massKg, int angle)
 	{
 		this.segmentCm = segmentCm;
 		this.segmentVariableCm = segmentVariableCm;
+		this.massKg = massKg;
+		this.angle = angle;
 		segmentVariableCmDistAccumulated = 0;
 
-		segmentDistTime_2l = new TwoListsOfDoubles();
+		segmentCalcs = new RunEncoderSegmentCalcs (massKg, angle);
 		timePre = 0;
+		timeAtEnoughAccelOrTrigger0 = -1;
+		timeAtEnoughAccelMark = -1;
+		distanceAtEnoughAccelMark = 0;
+		distanceAtEnoughAccelMarkSet = false;
+
+		time_l = new List<int> ();
+		runEncoderCaptureDistance_l = new List<double> ();
+		runEncoderCaptureSpeed_l = new List<double> ();
 	}
 
 	public void PassCapturedRow (List<int> binaryReaded)
@@ -315,10 +344,72 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 			return false;
 
 		this.encoderDisplacement = Convert.ToInt32(cells[0]);
+
 		this.time = Convert.ToInt32(cells[1]);
+		//after enoughAccel, time has to be shifted to left.
+		if(timeAtEnoughAccelOrTrigger0 > 0)
+			time -= timeAtEnoughAccelOrTrigger0;
+		time_l.Add (time);
+
 		return true;
 	}
 
+	//to show a vertical line at capture (meaning: passed the min accel)
+	public void SetTimeAtEnoughAccelMark (List<int> binaryReaded)
+	{
+		timeAtEnoughAccelMark = binaryReaded[1];
+	}
+	//to show a vertical line at load (if a trigger marks previously the beginning of the set) (meaning: passed the min accel)
+	public void SetTimeAtEnoughAccelMark (int t)
+	{
+		timeAtEnoughAccelMark = t;
+
+		distanceAtEnoughAccelMark = runEncoderCaptureDistance;
+		distanceAtEnoughAccelMarkSet = true; //need this because distanceAtEnoughAccelMark = 0 can be a valid value
+	}
+
+	//to sync time at load, also used to sync triggers at load
+	public void SetTimeAtEnoughAccelOrTrigger0 (int time)
+	{
+		timeAtEnoughAccelOrTrigger0 = time;
+
+		distanceAtEnoughAccelMark = runEncoderCaptureDistance;
+		distanceAtEnoughAccelMarkSet = true; //need this because distanceAtEnoughAccelMark = 0 can be a valid value
+	}
+
+	// when at load signal is shifted, calcule the speed of previous sample and the sample that will be 0
+	public void CalculeSpeedAt0Shifted (string rowPre, string row)
+	{
+		string [] cells = rowPre.Split(new char[] {';'});
+		if(cells.Length != 3)
+			return;
+
+		if(! Util.IsNumber(cells[0], false) || ! Util.IsNumber(cells[1], false))
+			return;
+
+		//int encDisplacement = Convert.ToInt32(cells[0]);
+		int tPre = Convert.ToInt32(cells[1]);
+
+		cells = row.Split(new char[] {';'});
+		if(cells.Length != 3)
+			return;
+
+		if(! Util.IsNumber(cells[0], false) || ! Util.IsNumber(cells[1], false))
+			return;
+
+		int encDisplacement = Convert.ToInt32(cells[0]);
+		int t = Convert.ToInt32(cells[1]);
+
+		double runEncoderCaptureDistanceAtThisSample = Math.Abs(encDisplacement) * 0.0030321; //hardcoded: same as sprintEncoder.R
+		runEncoderCaptureSpeed = UtilAll.DivideSafe(runEncoderCaptureDistanceAtThisSample, (t - tPre)) * 1000000;
+		//LogB.Information(string.Format("speed: {0}, runEncoderCaptureDistanceAtThisSample: {1}, tPre: {2}, t: {3}",
+		//			runEncoderCaptureSpeed, runEncoderCaptureDistanceAtThisSample, tPre, t));
+		runEncoderCaptureSpeed_l.Add (runEncoderCaptureSpeed);
+
+		if(runEncoderCaptureSpeed > runEncoderCaptureSpeedMax)
+			runEncoderCaptureSpeedMax = runEncoderCaptureSpeed;
+	}
+
 	public bool Calcule ()
 	{
 		bool hasCalculed = false;
@@ -327,16 +418,31 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 			if(timePre > 0)
 			{
 				double runEncoderCaptureDistanceAtThisSample = Math.Abs(encoderDisplacement) * 0.0030321; //hardcoded: same as sprintEncoder.R
+				runEncoderCaptureDistance_l.Add (runEncoderCaptureDistanceAtThisSample);
+
 				runEncoderCaptureSpeed = UtilAll.DivideSafe(runEncoderCaptureDistanceAtThisSample, (time - timePre)) * 1000000;
+
+LogB.Information (string.Format ("encoderDisplacement: {0}, runEncoderCaptureDistanceAtThisSample: {1}," +
+			"time: {2}, timePre: {3}, runEncoderCaptureSpeed: {4}",
+			encoderDisplacement, runEncoderCaptureDistanceAtThisSample,
+			time, timePre, runEncoderCaptureSpeed));
+
+				runEncoderCaptureSpeed_l.Add (runEncoderCaptureSpeed);
+				//LogB.Information(string.Format("speed: {0}, runEncoderCaptureDistanceAtThisSample: {1}, timePre: {2}, time: {3}",
+				//			runEncoderCaptureSpeed, runEncoderCaptureDistanceAtThisSample, timePre, time));
+
 				if(runEncoderCaptureSpeed > runEncoderCaptureSpeedMax)
 					runEncoderCaptureSpeedMax = runEncoderCaptureSpeed;
 
 				runEncoderCaptureDistance += runEncoderCaptureDistanceAtThisSample;
 
-				if(segmentCm > 0)
-					updateSegmentDistTimeFixed ();
-				else if(segmentVariableCm.Count > 0)
-					updateSegmentDistTimeVariable ();
+				if(distanceAtEnoughAccelMarkSet)
+				{
+					if(segmentCm > 0)
+						updateSegmentDistTimeFixed ();
+					else if(segmentVariableCm.Count > 0)
+						updateSegmentDistTimeVariable ();
+				}
 
 				hasCalculed = true;
 			}
@@ -344,23 +450,115 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 		}
 		return hasCalculed;
 	}
-	private void updateSegmentDistTimeFixed () //m
+
+	private double getFirstSegmentTimeStart ()
 	{
-		if(runEncoderCaptureDistance >= (segmentCm/100.0) * (segmentDistTime_2l.Count() +1))
-			segmentDistTime_2l.Add((segmentCm/100.0) * (segmentDistTime_2l.Count() +1), time);
+		double timeStart = 0;
+		if(segmentCalcs.Count == 0)
+		{
+			if (timeAtEnoughAccelOrTrigger0 >= 0 && timeAtEnoughAccelMark > timeAtEnoughAccelOrTrigger0)
+			{
+				if (timeAtEnoughAccelMark < 0)
+					timeStart = timeAtEnoughAccelOrTrigger0;
+				else
+					timeStart = timeAtEnoughAccelMark - timeAtEnoughAccelOrTrigger0;
+			} else {
+				if (timeAtEnoughAccelMark < 0)
+					timeStart = 0;
+				else
+					timeStart = timeAtEnoughAccelMark;
+			}
+		} else
+			timeStart = segmentCalcs.TimeEnd_l[segmentCalcs.Count -1];
+
+		return timeStart;
+	}
+
+	private void updateSegmentDistTimeFixed () //at capture or load (no smooth)
+	{
+		updateSegmentDistTimeFixed (runEncoderCaptureDistance, time, runEncoderCaptureSpeed);
+	}
+	private void updateSegmentDistTimeFixed (double distanceNow, double timeNow, double speedNow) //m
+	{
+		double timeStart = getFirstSegmentTimeStart ();
+
+		if(distanceNow - distanceAtEnoughAccelMark
+				>= (segmentCm/100.0) * (segmentCalcs.Count +1))
+			segmentCalcs.Add((segmentCm/100.0) * (segmentCalcs.Count +1), timeStart, timeNow, speedNow);
 		//note this is not very precise because time can be a bit later than the selected dist
 	}
-	private void updateSegmentDistTimeVariable () //cm
+
+	private void updateSegmentDistTimeVariable () //at capture or load (no smooth)
+	{
+		updateSegmentDistTimeVariable (runEncoderCaptureDistance, time, runEncoderCaptureSpeed);
+	}
+	private void updateSegmentDistTimeVariable (double distanceNow, double timeNow, double speedNow)
 	{
 		//care of overflow
-		if(segmentDistTime_2l.Count() >= segmentVariableCm.Count)
+		if(segmentCalcs.Count >= segmentVariableCm.Count)
 			return;
 
-		double distToBeat = (segmentVariableCm[segmentDistTime_2l.Count()] + segmentVariableCmDistAccumulated) / 100.0; //cm -> m
-		if(runEncoderCaptureDistance >= distToBeat)
+		double timeStart = getFirstSegmentTimeStart ();
+
+		double distToBeat = (segmentVariableCm[segmentCalcs.Count] + segmentVariableCmDistAccumulated) / 100.0; //cm -> m
+		if(distanceNow >= distToBeat)
 		{
-			segmentVariableCmDistAccumulated += segmentVariableCm[segmentDistTime_2l.Count()];
-			segmentDistTime_2l.Add(distToBeat, time);
+			segmentVariableCmDistAccumulated += segmentVariableCm[segmentCalcs.Count];
+			segmentCalcs.Add (distToBeat, timeStart, timeNow, speedNow);
+		}
+	}
+
+	public void SegmentsRedoWithSmoothing (int smoothSamples)
+	{
+		LogB.Information ( string.Format ("SegmentsRedoWithSmoothing smoothSamples: {0}", smoothSamples));
+		// 1) convert time_l and runEncoderCaptureSpeed_l to List<PointF>
+		List<PointF> pf_l = new List<PointF> ();
+		for (int i = 0; i < time_l.Count; i++)
+			if (i < runEncoderCaptureSpeed_l.Count)
+				pf_l.Add (new PointF (time_l[i], runEncoderCaptureSpeed_l[i]));
+
+		MovingAverage mAverageSmoothLine = null;
+		List<double> runEncoderCaptureSpeedSmoothed_l = new List<double> ();
+		if (smoothSamples >= 3)
+		{
+			// 2) calculate the moving average and get the smoothed speed
+			mAverageSmoothLine = new MovingAverage (pf_l, smoothSamples);
+			mAverageSmoothLine.Calculate ();
+			runEncoderCaptureSpeedSmoothed_l = mAverageSmoothLine.MovingAverage_l_Y;
+		}
+
+		// 3) initialize objects
+		segmentVariableCmDistAccumulated = 0;
+		segmentCalcs = new RunEncoderSegmentCalcs (massKg, angle);
+		double distanceNow = 0;
+		double timeNow = 0;
+		double speedNow = 0;
+
+		List<double> speed_l = new List<double> ();
+		if (smoothSamples < 3)
+			speed_l = runEncoderCaptureSpeed_l;
+		else
+			speed_l = runEncoderCaptureSpeedSmoothed_l;
+
+		// 4) redo the segments
+		for (int i = 0; i < time_l.Count; i++)
+		{
+			if (i >= runEncoderCaptureDistance_l.Count ||
+					i >= time_l.Count ||
+					i >= speed_l.Count)
+				break;
+
+			distanceNow += runEncoderCaptureDistance_l[i];
+			timeNow = time_l[i];
+			speedNow = speed_l[i];
+
+			if(distanceNow >= distanceAtEnoughAccelMark)
+			{
+				if(segmentCm > 0)
+					updateSegmentDistTimeFixed (distanceNow, timeNow, speedNow);
+				else if(segmentVariableCm.Count > 0)
+					updateSegmentDistTimeVariable (distanceNow, timeNow, speedNow);
+			}
 		}
 	}
 
@@ -387,8 +585,137 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 	public double RunEncoderCaptureDistance {
 		get { return runEncoderCaptureDistance; }
 	}
-	public TwoListsOfDoubles SegmentDistTime_2l {
-		get { return segmentDistTime_2l; }
+	public RunEncoderSegmentCalcs SegmentCalcs {
+		get { return segmentCalcs; }
+	}
+
+	public int TimeAtEnoughAccelOrTrigger0 {
+		get { return timeAtEnoughAccelOrTrigger0; }
+	}
+	public int TimeAtEnoughAccelMark {
+		get { return timeAtEnoughAccelMark; }
+	}
+	public double DistanceAtEnoughAccelMark {
+		get { return distanceAtEnoughAccelMark; }
+	}
+}
+
+/*
+   first we had TwoListsOfDoubles SegmentDistTime_2l
+   but as we want to implement (accel, F, P) avg on each track, we use this new class
+   */
+public class RunEncoderSegmentCalcs
+{
+	private const double g = 9.81;
+
+	//passed variables
+	private double massKg;
+	private int angle;
+
+	//calculated list of vars
+	private List<double> dist_l;
+	private List<double> timeStart_l;
+	private List<double> timeEnd_l;
+	private List<double> speedCont_l;
+	private List<double> accel_l;
+	private List<double> force_l;
+	private List<double> power_l;
+	/*
+	accel = (V2 - V1)/(T2 - T1)
+	F = m * (a + g*sin(alpha))
+	P = 0.5 * m * ((V2^2 - V1^2) + m*g*(h2 - h1)) / (T2 - T1)
+	h = pos * sin(alpha)
+	*/
+
+	public RunEncoderSegmentCalcs ()
+	{
+	}
+
+	public RunEncoderSegmentCalcs (double massKg, int angle)
+	{
+		this.massKg = massKg;
+		this.angle = angle;
+
+		dist_l = new List<double> ();
+		timeStart_l = new List<double> ();
+		timeEnd_l = new List<double> ();
+		speedCont_l = new List<double> ();
+		accel_l = new List<double> ();
+		force_l = new List<double> ();
+		power_l = new List<double> ();
+	}
+
+	//speedCont is continuous (at this instant) (no avg: dist/time of the segment)
+	public void Add (double dist, double timeStart, double timeEnd, double speedCont)
+	{
+		//store this variable before adding the dist
+		bool isFirstOne = (dist_l.Count == 0);
+
+		dist_l.Add (dist);
+		timeStart_l.Add (timeStart);
+		timeEnd_l.Add (timeEnd);
+		speedCont_l.Add(speedCont);
+		double timeElapsed = timeEnd - timeStart;
+
+		if(isFirstOne)
+		{
+			double accel = UtilAll.DivideSafe(speedCont, timeElapsed/1000000.0);
+			accel_l.Add (accel);
+			force_l.Add ( massKg * (accel + g * Math.Sin(angle)) );
+			power_l.Add (UtilAll.DivideSafe(( 0.5 * massKg * Math.Pow(speedCont, 2) + massKg * g * (dist * Math.Sin(angle)) ) , timeElapsed/1000000.0));
+		}
+		else
+		{
+			/*
+			debug accel:
+			LogB.Information(string.Format("speed now: {0}, speed pre: {1}, time now: {2}, time pre: {3}, result: {4}",
+						speedCont, speedCont_l[Count -2], time/1000000.0, time_l[Count -2]/1000000.0,
+						UtilAll.DivideSafe( (speedCont - speedCont_l[Count -2]), (time/1000000.0 - time_l[Count -2]/1000000.0) ) ));
+						*/
+
+			double accel = UtilAll.DivideSafe(
+					(speedCont - speedCont_l[Count -2]), (timeEnd/1000000.0 - timeStart/1000000.0) );
+			accel_l.Add (accel);
+			force_l.Add ( massKg * (accel + g * Math.Sin(angle)) );
+			power_l.Add ( UtilAll.DivideSafe (
+						0.5 * massKg * (Math.Pow(speedCont, 2) - Math.Pow(speedCont_l[Count -2], 2)) + //Kinetic Energy +
+						massKg * g * (dist * Math.Sin(angle) - dist_l[Count -2] * Math.Sin(angle)), //Potential Energy
+						(timeElapsed) / 1000000.0 //Time
+						) );
+		}
+	}
+
+	public int Count
+	{
+		get {
+			if(dist_l == null)
+				return 0;
+			else
+				return dist_l.Count;
+		}
+	}
+
+	public List<double> Dist_l {
+		get { return dist_l; }
+	}
+	public List<double> TimeStart_l {
+		get { return timeStart_l; }
+	}
+	public List<double> TimeEnd_l {
+		get { return timeEnd_l; }
+	}
+	//to debug
+	public List<double> SpeedCont_l {
+		get { return speedCont_l; }
+	}
+	public List<double> Accel_l {
+		get { return accel_l; }
+	}
+	public List<double> Force_l {
+		get { return force_l; }
+	}
+	public List<double> Power_l {
+		get { return power_l; }
 	}
 }
 
@@ -401,6 +728,7 @@ public class RunEncoderExercise
 	public static int SegmentCmDefault = 500;
 	private List<int> segmentVariableCm; //if segmentCm == -1 then this is used
 	private bool isSprint;
+	private int angleDefault;
 
 	public RunEncoderExercise()
 	{
@@ -411,7 +739,8 @@ public class RunEncoderExercise
 		this.name = name;
 	}
 
-	public RunEncoderExercise(int uniqueID, string name, string description, int segmentCm, List<int> segmentVariableCm, bool isSprint)
+	public RunEncoderExercise(int uniqueID, string name, string description,
+			int segmentCm, List<int> segmentVariableCm, bool isSprint, int angleDefault)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -419,13 +748,15 @@ public class RunEncoderExercise
 		this.segmentCm = segmentCm;
 		this.segmentVariableCm = segmentVariableCm;
 		this.isSprint = isSprint;
+		this.angleDefault = angleDefault;
 	}
 
 	public override string ToString()
 	{
-		return string.Format("{0}:{1}:{2}:{3}:{4}:{5}",
+		return string.Format("{0}:{1}:{2}:{3}:{4}:{5}:{6}",
 				uniqueID, name, description, segmentCm,
-				Util.ListIntToSQLString (segmentVariableCm, ";"), isSprint);
+				Util.ListIntToSQLString (segmentVariableCm, ";"),
+				isSprint, angleDefault);
 	}
 
 	public void InsertSQL (bool dbconOpened)
@@ -441,7 +772,8 @@ public class RunEncoderExercise
 
 		return
 			"(" + uniqueIDStr + ", \"" + name + "\", \"" + description + "\", " +
-			segmentCm + ", \"" + SegmentVariableCmToSQL + "\", " + Util.BoolToInt(isSprint) + ")";
+			segmentCm + ", \"" + SegmentVariableCmToSQL + "\", " +
+			Util.BoolToInt(isSprint) + ", " + angleDefault + ")";
 	}
 
 	public int UniqueID
@@ -481,39 +813,22 @@ public class RunEncoderExercise
 	{
 		get { return isSprint; }
 	}
+	public int AngleDefault
+	{
+		get { return angleDefault; }
+	}
 }
 
 //results coming from analyze (load) using R. To be published on exportable table
-public class RunEncoderCSV
+public class RunEncoderCSV : RexportedCSV
 {
-	public double Mass;
-	public double Height;
-	public int Temperature;
-	public double Vw;
-	public double Ka;
-	public double K_fitted;
-	public double Vmax_fitted;
-	public double Amax_fitted;
-	public double Fmax_fitted;
-	public double Fmax_rel_fitted;
-	public double Sfv_fitted;
-	public double Sfv_rel_fitted;
-	public double Sfv_lm;
-	public double Sfv_rel_lm;
-	public double Pmax_fitted;
-	public double Pmax_rel_fitted;
-	public double Tpmax_fitted;
-	public double F0;
-	public double F0_rel;
-	public double V0;
-	public double Pmax_lm;
-	public double Pmax_rel_lm;
-
 	public RunEncoderCSV ()
 	{
 	}
 
-	public RunEncoderCSV (double mass, double height, int temperature, double vw, double ka, double k_fitted, double vmax_fitted, double amax_fitted, double fmax_fitted, double fmax_rel_fitted, double sfv_fitted, double sfv_rel_fitted, double sfv_lm, double sfv_rel_lm, double pmax_fitted, double pmax_rel_fitted, double tpmax_fitted, double f0, double f0_rel, double v0, double pmax_lm, double pmax_rel_lm)
+	public RunEncoderCSV (double mass, double height, int temperature, double vw, double ka, double k_fitted, double vmax_fitted, double amax_fitted, double fmax_fitted, double fmax_rel_fitted, double sfv_fitted, double sfv_rel_fitted, double sfv_lm, double sfv_rel_lm, double pmax_fitted, double pmax_rel_fitted, double tpmax_fitted, double f0, double f0_rel, double v0, double pmax_lm, double pmax_rel_lm,
+			double vmax_raw, double amax_raw, double fmax_raw, double pmax_raw,
+			List<double> time_l)
 	{
 		this.Mass = mass;
 		this.Height = height;
@@ -537,53 +852,11 @@ public class RunEncoderCSV
 		this.V0 = v0;
 		this.Pmax_lm = pmax_lm;
 		this.Pmax_rel_lm = pmax_rel_lm;
-	}
-
-	public string [] ToTreeView()
-	{
-		return new string [] {
-			Util.TrimDecimals(Mass, 1),
-				Util.TrimDecimals(Height, 1),
-				Temperature.ToString(),
-				Util.TrimDecimals(Vw, 3),
-				Util.TrimDecimals(Ka, 3),
-				Util.TrimDecimals(K_fitted, 3),
-				Util.TrimDecimals(Vmax_fitted, 3),
-				Util.TrimDecimals(Amax_fitted, 3),
-				Util.TrimDecimals(Fmax_fitted, 3),
-				Util.TrimDecimals(Fmax_rel_fitted, 3),
-				Util.TrimDecimals(Sfv_fitted, 3),
-				Util.TrimDecimals(Sfv_rel_fitted, 3),
-				Util.TrimDecimals(Sfv_lm, 3),
-				Util.TrimDecimals(Sfv_rel_lm, 3),
-				Util.TrimDecimals(Pmax_fitted, 3),
-				Util.TrimDecimals(Pmax_rel_fitted, 3),
-				Util.TrimDecimals(Tpmax_fitted, 3),
-				Util.TrimDecimals(F0, 3),
-				Util.TrimDecimals(F0_rel, 3),
-				Util.TrimDecimals(V0, 3),
-				Util.TrimDecimals(Pmax_lm, 3),
-				Util.TrimDecimals(Pmax_rel_lm, 3)
-		};
-	}
-
-	public string ToCSV(string decimalSeparator)
-	{
-		//latin:	2,3 ; 2,5
-		//non-latin:	2.3 , 2.5
-
-		string sep = ":::";
-		string str = Util.StringArrayToString(ToTreeView(), sep);
-
-		if(decimalSeparator == "COMMA")
-			str = Util.ConvertToComma(str);
-		else
-			str = Util.ConvertToPoint(str);
-
-		if(decimalSeparator == "COMMA")
-			return Util.ChangeChars(str, ":::", ";");
-		else
-			return Util.ChangeChars(str, ":::", ",");
+		this.Vmax_raw = vmax_raw;
+		this.Amax_raw = amax_raw;
+		this.Fmax_raw = fmax_raw;
+		this.Pmax_raw = pmax_raw;
+		this.time_l = time_l;
 	}
 }
 
@@ -649,6 +922,7 @@ public class RunEncoderGraphExport
 			device.ToString() + ";" +
 			Util.ConvertToPoint(tempC) + ";" +
 			testLength.ToString() + ";" +
+			Util.BoolToRBool(exercise.IsSprint) + ";" +
 			segmentM + ";" + //fixed segments (m)
 			segmentVariableCm + ";" + //variable segments (cm)
 			title + ";" +
@@ -665,7 +939,7 @@ public class RunEncoderGraphExport
 
 	public static string PrintCSVHeaderOnExport()
 	{
-		return "fullURL;mass;personHeight;device;tempC;testLength;" +
+		return "fullURL;mass;personHeight;device;tempC;testLength;isSprint;" +
 			"splitLength;" + //segmentCm on C#, splitLength on R
 			"splitVariableCm;" +
 			"title;datetime;triggersOn;triggersOff;comments";
@@ -812,6 +1086,7 @@ public class RunEncoderGraph
 			"#personHeight\n" + 		Util.ConvertToPoint(personHeight / 100.0) + "\n" + 	//unused on multiple  //send it in meters
 			"#tempC\n" + 			tempC + "\n" +	//unused on multiple
 			"#testLength\n" + 		testLength.ToString() + "\n" +	//unused on multiple
+			"#isSprint\n" + 		Util.BoolToRBool(rex.IsSprint) + "\n" +
 			"#os\n" + 			UtilEncoder.OperatingSystemForRGraphs() + "\n" +
 			"#graphWidth\n" + 		graphWidth.ToString() + "\n" +
 			"#graphHeight\n" + 		graphHeight.ToString() + "\n" +
