@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2017-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -247,6 +247,172 @@ public class SprintRGraph
 	}
 }
 
+public abstract class RexportedCSV
+{
+	public double Mass;
+	public double Height;
+	public int Temperature;
+	public double Vw;
+	public double Ka;
+	public double K_fitted;
+	public double Vmax_fitted;
+	public double Amax_fitted;
+	public double Fmax_fitted;
+	public double Fmax_rel_fitted;
+	public double Sfv_fitted;
+	public double Sfv_rel_fitted;
+	public double Sfv_lm;
+	public double Sfv_rel_lm;
+	public double Pmax_fitted;
+	public double Pmax_rel_fitted;
+	public double Tpmax_fitted;
+	public double F0;
+	public double F0_rel;
+	public double V0;
+	public double Pmax_lm;
+	public double Pmax_rel_lm;
+	public double Vmax_raw;
+	public double Amax_raw;
+	public double Fmax_raw;
+	public double Pmax_raw;
+	public List<double> time_l;
+
+	public virtual string [] ToTreeView()
+	{
+		string [] strArray = new string [] {
+			Util.TrimDecimals(Mass, 1),
+				Util.TrimDecimals(Height, 1),
+				Temperature.ToString(),
+				Util.TrimDecimals(Vw, 3),
+				Util.TrimDecimals(Ka, 3),
+				Util.TrimDecimals(K_fitted, 3),
+				Util.TrimDecimals(Vmax_fitted, 3),
+				Util.TrimDecimals(Amax_fitted, 3),
+				Util.TrimDecimals(Fmax_fitted, 3),
+				Util.TrimDecimals(Fmax_rel_fitted, 3),
+				Util.TrimDecimals(Sfv_fitted, 3),
+				Util.TrimDecimals(Sfv_rel_fitted, 3),
+				Util.TrimDecimals(Sfv_lm, 3),
+				Util.TrimDecimals(Sfv_rel_lm, 3),
+				Util.TrimDecimals(Pmax_fitted, 3),
+				Util.TrimDecimals(Pmax_rel_fitted, 3),
+				Util.TrimDecimals(Tpmax_fitted, 3),
+				Util.TrimDecimals(F0, 3),
+				Util.TrimDecimals(F0_rel, 3),
+				Util.TrimDecimals(V0, 3),
+				Util.TrimDecimals(Pmax_lm, 3),
+				Util.TrimDecimals(Pmax_rel_lm, 3),
+				Util.TrimDecimals(Vmax_raw, 3),
+				Util.TrimDecimals(Amax_raw, 3),
+				Util.TrimDecimals(Fmax_raw, 3),
+				Util.TrimDecimals(Pmax_raw, 3)
+		};
+
+		//convert time_l to strings to add them to strArray
+		List<string> timeStr_l = new List<string> ();
+		foreach (double time in time_l)
+			timeStr_l.Add (Util.TrimDecimals (time, 3));
+		strArray = Util.AddToArrayString (strArray, timeStr_l);
+
+		return strArray;
+	}
+
+	public string ToCSV(string decimalSeparator)
+	{
+		//latin:	2,3 ; 2,5
+		//non-latin:	2.3 , 2.5
+
+		string sep = ":::";
+		string str = Util.StringArrayToString(ToTreeView(), sep);
+
+		if(decimalSeparator == "COMMA")
+			str = Util.ConvertToComma(str);
+		else
+			str = Util.ConvertToPoint(str);
+
+		if(decimalSeparator == "COMMA")
+			return Util.ChangeChars(str, ":::", ";");
+		else
+			return Util.ChangeChars(str, ":::", ",");
+	}
+}
+
+public class SprintCSV : RexportedCSV
+{
+	public SprintCSV ()
+	{
+	}
+
+	public SprintCSV (double mass, double height, int temperature, double vw, double ka, double k_fitted, double vmax_fitted, double amax_fitted, double fmax_fitted, double fmax_rel_fitted, double sfv_fitted, double sfv_rel_fitted, double sfv_lm, double sfv_rel_lm, double pmax_fitted, double pmax_rel_fitted, double tpmax_fitted, double f0, double f0_rel, double v0, double pmax_lm, double pmax_rel_lm,
+			double vmax_raw, double amax_raw, double fmax_raw, double pmax_raw,
+			List<double> time_l)
+	{
+		this.Mass = mass;
+		this.Height = height;
+		this.Temperature = temperature;
+		this.Vw = vw;
+		this.Ka = ka;
+		this.K_fitted = k_fitted;
+		this.Vmax_fitted = vmax_fitted;
+		this.Amax_fitted = amax_fitted;
+		this.Fmax_fitted = fmax_fitted;
+		this.Fmax_rel_fitted = fmax_rel_fitted;
+		this.Sfv_fitted = sfv_fitted;
+		this.Sfv_rel_fitted = sfv_rel_fitted;
+		this.Sfv_lm = sfv_lm;
+		this.Sfv_rel_lm = sfv_rel_lm;
+		this.Pmax_fitted = pmax_fitted;
+		this.Pmax_rel_fitted = pmax_rel_fitted;
+		this.Tpmax_fitted = tpmax_fitted;
+		this.F0 = f0;
+		this.F0_rel = f0_rel;
+		this.V0 = v0;
+		this.Pmax_lm = pmax_lm;
+		this.Pmax_rel_lm = pmax_rel_lm;
+		this.Vmax_raw = vmax_raw;
+		this.Amax_raw = amax_raw;
+		this.Fmax_raw = fmax_raw;
+		this.Pmax_raw = pmax_raw;
+		this.time_l = time_l;
+	}
+
+	public override string [] ToTreeView()
+	{
+		string [] strArray = new string [] {
+			Util.TrimDecimals(Mass, 1),
+				Util.TrimDecimals(Height, 1),
+				Temperature.ToString(),
+				Util.TrimDecimals(Vw, 3),
+				Util.TrimDecimals(Ka, 3),
+				Util.TrimDecimals(K_fitted, 3),
+				Util.TrimDecimals(Vmax_fitted, 3),
+				Util.TrimDecimals(Amax_fitted, 3),
+				Util.TrimDecimals(Fmax_fitted, 3),
+				Util.TrimDecimals(Fmax_rel_fitted, 3),
+				Util.TrimDecimals(Sfv_fitted, 3),
+				Util.TrimDecimals(Sfv_rel_fitted, 3),
+				Util.TrimDecimals(Sfv_lm, 3),
+				Util.TrimDecimals(Sfv_rel_lm, 3),
+				Util.TrimDecimals(Pmax_fitted, 3),
+				Util.TrimDecimals(Pmax_rel_fitted, 3),
+				Util.TrimDecimals(Tpmax_fitted, 3),
+				Util.TrimDecimals(F0, 3),
+				Util.TrimDecimals(F0_rel, 3),
+				Util.TrimDecimals(V0, 3),
+				Util.TrimDecimals(Pmax_lm, 3),
+				Util.TrimDecimals(Pmax_rel_lm, 3)
+		};
+
+		//convert time_l to strings to add them to strArray
+		List<string> timeStr_l = new List<string> ();
+		foreach (double time in time_l)
+			timeStr_l.Add (Util.TrimDecimals (time, 3));
+		strArray = Util.AddToArrayString (strArray, timeStr_l);
+
+		return strArray;
+	}
+}
+
 //this class creates the rows of each set for the csv input multi that is read by R
 public class SprintRGraphExport
 {
