@@ -61,7 +61,8 @@ class SqliteEncoder : Sqlite
 		       	"future1 TEXT, " +	//Since 1.4.4 (DB 1.06) this stores last meanPower detected on a curve 
 						//(as string with '.' because future1 was created as TEXT)
 			"future2 TEXT, " + 	//same as future1
-			"future3 TEXT )"; 	//same as future1
+			"future3 TEXT, " + 	//same as future1
+			"repCriteria TEXT )"; 	//criteria of meanPower, meanSpeed, meanForce: ecc_con, ecc, con
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -80,7 +81,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderTable +  
 			" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, " + 
 			"signalOrCurve, filename, url, time, minHeight, description, status, " +
-			"videoURL, encoderConfiguration, future1, future2, future3)" +
+			"videoURL, encoderConfiguration, future1, future2, future3, repCriteria)" +
 			" VALUES (" + es.uniqueID + ", " +
 			es.personID + ", " + es.sessionID + ", " +
 			es.exerciseID + ", \"" + es.eccon + "\", \"" +
@@ -91,7 +92,8 @@ class SqliteEncoder : Sqlite
 			"\", \"" + es.status + "\", \"" + 
 			Util.MakeURLrelative(es.videoURL) + "\", \"" +
 			es.encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) + "\", \"" +
-			Util.ConvertToPoint(es.future1) + "\", \"" + Util.ConvertToPoint(es.future2) + "\", \"" + Util.ConvertToPoint(es.future3) + "\")";
+			Util.ConvertToPoint(es.future1) + "\", \"" + Util.ConvertToPoint(es.future2) + "\", \"" + Util.ConvertToPoint(es.future3) + "\", \"" +
+			es.repCriteria.ToString() + "\")";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -144,6 +146,7 @@ class SqliteEncoder : Sqlite
 				"\", future1 = \"" + Util.ConvertToPoint(es.future1) +
 				"\", future2 = \"" + Util.ConvertToPoint(es.future2) +
 				"\", future3 = \"" + Util.ConvertToPoint(es.future3) +
+				"\", repCriteria = \"" + es.repCriteria.ToString() +
 				"\" WHERE uniqueID == " + es.uniqueID ;
 
 		LogB.SQL(mycmd.CommandText.ToString());
@@ -213,16 +216,21 @@ class SqliteEncoder : Sqlite
 	   eg if you save only the best (maybe the 4th), will have uniqueID 1, and then if you save it all,
 	   then they will be saved as 2, 3, (4 not saved becuase it is already one), 4, 5, ... So 4th in order will be 1
 	   orderRepsByPosInSet fixes this problem. this is used eg. in analyze session to sort them correctly
+	   but note it Select will only work ok for curves
 	 */
 	public static ArrayList Select (
 			bool dbconOpened, int uniqueID, int personID, int sessionID, Constants.EncoderGI encoderGI, 
 			int exerciseID, string signalOrCurve, EncoderSQL.Eccons ecconSelect, string lateralityEnglish,
 			bool onlyActive, bool orderIDascendent,
-			bool orderRepsByPosInSet)
+			bool orderRepsByPosInSet) // Attention! note this only selects curves
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 
+		string encT = Constants.EncoderTable;
+		string encSCT = Constants.EncoderSignalCurveTable;
+		string encExT = Constants.EncoderExerciseTable;
+
 		string andString = "";
 		string personIDStr = "";
 		if(personID != -1) {
@@ -250,7 +258,7 @@ class SqliteEncoder : Sqlite
 
 		string selectStr = "";
 		if(uniqueID != -1)
-			selectStr = Constants.EncoderTable + ".uniqueID = " + uniqueID;
+			selectStr = encT + ".uniqueID = " + uniqueID;
 		else {
 			if(signalOrCurve == "all")
 				selectStr = personIDStr + sessionIDStr + exerciseIDStr + lateralityEnglishStr;
@@ -258,12 +266,12 @@ class SqliteEncoder : Sqlite
 				selectStr = personIDStr + sessionIDStr + exerciseIDStr + lateralityEnglishStr + andString + " signalOrCurve = \"" + signalOrCurve + "\"";
 		
 			if(ecconSelect != EncoderSQL.Eccons.ALL)
-				selectStr += andString + Constants.EncoderTable + ".eccon = \"" + EncoderSQL.Eccons.ecS.ToString() + "\"";
+				selectStr += andString + encT + ".eccon = \"" + EncoderSQL.Eccons.ecS.ToString() + "\"";
 		}
 
-		string fromString = " FROM " + Constants.EncoderTable  + ", " + Constants.EncoderExerciseTable;
+		string fromString = " FROM " + encT  + ", " + encExT;
 		if(orderRepsByPosInSet)
-			fromString += ", " + Constants.EncoderSignalCurveTable;
+			fromString += ", " + encSCT;
 
 		//ensure andString is defined if selectStr is != "" (bug on 2.1.2 release)
 		if(selectStr != "")
@@ -272,32 +280,32 @@ class SqliteEncoder : Sqlite
 		string onlyActiveString = "";
 		if(onlyActive)
 		{
-			onlyActiveString = andString + Constants.EncoderTable + ".status = \"active\" ";
+			onlyActiveString = andString + encT + ".status = \"active\" ";
 			andString = " AND ";
 		}
 
 		string orderRepsByPosInSetAndStr = "";
 		if(orderRepsByPosInSet)
 		{
-			orderRepsByPosInSetAndStr = andString + Constants.EncoderTable + ".uniqueID = " +
-				Constants.EncoderSignalCurveTable + ".curveID ";
+			orderRepsByPosInSetAndStr = andString + encT + ".uniqueID = " +
+				encSCT + ".curveID ";
 			//andString = " AND ";
 		}
 
 		string orderRepsByPosInSetOrderStr = "";
 		if(orderRepsByPosInSet)
-			orderRepsByPosInSetOrderStr = Constants.EncoderSignalCurveTable + ".mscentral, ";
+			orderRepsByPosInSetOrderStr = encSCT + ".mscentral, ";
 
 		string orderIDstr = "";
 		if(! orderIDascendent)
 			orderIDstr = " DESC";
 
 		dbcmd.CommandText = "SELECT " + 
-			Constants.EncoderTable + ".*, " + Constants.EncoderExerciseTable + ".name " +
+			encT + ".*, " + encExT + ".name " +
 			fromString +
 			" WHERE " + selectStr +
-			andString + Constants.EncoderTable + ".exerciseID = " + 
-				Constants.EncoderExerciseTable + ".uniqueID " +
+			andString + encT + ".exerciseID = " + 
+				encExT + ".uniqueID " +
 				onlyActiveString + orderRepsByPosInSetAndStr +
 			" ORDER BY substr(filename,-23,19), " + //'filename,-23,19' has the date of capture signal
 			orderRepsByPosInSetOrderStr +
@@ -354,7 +362,9 @@ class SqliteEncoder : Sqlite
 					Util.ChangeDecimalSeparator(reader[16].ToString()),	//future1 (meanPower on curves)
 					Util.ChangeDecimalSeparator(reader[17].ToString()),	//future2 (meanSpeed on curves)
 					Util.ChangeDecimalSeparator(reader[18].ToString()),	//future3 (meanForce on curves)
-					reader[19].ToString()			//EncoderExercise.name
+					(Preferences.EncoderRepetitionCriteria) Enum.Parse(
+						typeof (Preferences.EncoderRepetitionCriteria), reader[19].ToString()),
+					reader[20].ToString()			//EncoderExercise.name
 					);
 			array.Add (eSQL);
 		}
@@ -367,16 +377,22 @@ class SqliteEncoder : Sqlite
 	}
 	
 
+	//used on EncoderSelectRepetitionsIndividualAllSessions
 	//exerciseID can be -1 to get all exercises
-	public static ArrayList SelectCompareIntersession (bool dbconOpened, Constants.EncoderGI encoderGI, int exerciseID, int personID)
+	public static ArrayList SelectCompareIntersession (bool dbconOpened, Constants.EncoderGI encoderGI,
+			int exerciseID, string lateralityCode, int personID)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
-		
+
 		string exerciseIDStr = "";
 		if(exerciseID != -1)
 			exerciseIDStr = "encoder.exerciseID = " + exerciseID + " AND ";
 
+		string lateralityCodeStr = "";
+		if(lateralityCode != "")
+			lateralityCodeStr = "laterality = \"" + lateralityCode + "\" AND ";
+
 		//returns a row for each session where there are active or inactive
 		dbcmd.CommandText = 
 			"SELECT encoder.sessionID, session.name, session.date, encoder.extraWeight, " +
@@ -385,7 +401,7 @@ class SqliteEncoder : Sqlite
 			" encoder.encoderConfiguration " +
 			" FROM encoder, session, person77 " +
 			" WHERE " +
-			exerciseIDStr + 	
+			exerciseIDStr + lateralityCodeStr +
 			" encoder.personID = " + personID + " AND signalOrCurve = \"curve\" AND " +
 			" encoder.personID = person77.uniqueID AND encoder.sessionID = session.uniqueID " +
 			" GROUP BY encoder.sessionID, encoder.extraWeight ORDER BY encoder.sessionID, encoder.extraWeight, encoder.status";
@@ -576,7 +592,8 @@ class SqliteEncoder : Sqlite
 			Sqlite.Open();
 
 		dbcmd.CommandText =
-			"SELECT person77.uniqueID, person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, encoder.extraWeight, encoder.future1 " + //TODO: future2, future3
+			"SELECT person77.uniqueID, person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, " + 
+			"encoder.extraWeight, encoder.eccon, encoder.future1, encoder.future2, encoder.future3, encoder.repCriteria " +
 			"FROM person77, encoderExercise, encoder " +
 			"WHERE sessionID = " + sessionID.ToString() +
 		        " AND signalOrCurve = \"curve\" " +
@@ -604,6 +621,17 @@ class SqliteEncoder : Sqlite
 			else if(encoderGI == Constants.EncoderGI.INERTIAL && ! econf.has_inertia)
 				continue;
 
+			string repCriteria = "";
+			if(reader[6].ToString() != "c")
+			{
+				if(reader[10].ToString() == Preferences.EncoderRepetitionCriteria.ECC_CON.ToString())
+					repCriteria = Catalog.GetString("Eccentric-concentric");
+				else if(reader[10].ToString() == Preferences.EncoderRepetitionCriteria.ECC.ToString())
+					repCriteria = Catalog.GetString("Eccentric");
+				else if(reader[10].ToString() == Preferences.EncoderRepetitionCriteria.CON.ToString())
+					repCriteria = Catalog.GetString("Concentric");
+			}
+
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
 			{
 				string [] s = {
@@ -613,8 +641,11 @@ class SqliteEncoder : Sqlite
 					econf.ToStringPretty(), //encoder configuration
 					reader[4].ToString(), 	//encoder exercise name
 					Util.ChangeDecimalSeparator(reader[5].ToString()),	//extra mass
-					reader[6].ToString()	//power
-						//TODO: speed, force
+					EncoderSQL.EcconLong(reader[6].ToString()),
+					reader[7].ToString(),	//power
+					reader[8].ToString(),	//speed
+					reader[9].ToString(),	//force
+					repCriteria
 				};
 				array.Add (s);
 			} else {
@@ -624,8 +655,11 @@ class SqliteEncoder : Sqlite
 					reader[2].ToString(), 	//person sex
 					econf.ToStringPretty(), //encoder configuration
 					reader[4].ToString(), 	//encoder exercise name
-					reader[6].ToString()	//power
-						//TODO: speed, force
+					EncoderSQL.EcconLong(reader[6].ToString()),
+					reader[7].ToString(),	//power
+					reader[8].ToString(),	//speed
+					reader[9].ToString(),	//force
+					repCriteria
 				};
 				array.Add (s);
 			}
