@@ -136,8 +136,8 @@ class SqliteForceSensor : Sqlite
 			Util.FileDelete(fs.FullVideoURL);
 	}
 
-	//SELECT forceSensor.*, forceSensorExercise.Name FROM forceSensor, forceSensorExercise WHERE forceSensor.exerciseID = forceSensorExercise.UniqueID ORDER BY forceSensor.uniqueID;
-	public static List<ForceSensor> Select (bool dbconOpened, int uniqueID, int personID, int sessionID)
+	//elastic (-1: both; 0: not elastic; 1: elastic)
+	public static List<ForceSensor> Select (bool dbconOpened, int uniqueID, int personID, int sessionID, int elastic)
 	{
 		openIfNeeded(dbconOpened);
 
@@ -156,7 +156,14 @@ class SqliteForceSensor : Sqlite
 		if(sessionID != -1)
 			sessionIDStr = " AND " + table + ".sessionID = " + sessionID;
 
-		dbcmd.CommandText = selectStr + whereStr + uniqueIDStr + personIDStr + sessionIDStr + " Order BY " + table + ".uniqueID";
+		string elasticStr = "";
+		if (elastic == 0)
+			elasticStr = " AND " + Constants.ForceSensorExerciseTable + ".elastic != 1"; //0 or -1 (both)
+		else if (elastic == 1)
+			elasticStr = " AND " + Constants.ForceSensorExerciseTable + ".elastic != 0"; //1 or -1 (both)
+
+		dbcmd.CommandText = selectStr + whereStr + uniqueIDStr + personIDStr + sessionIDStr + elasticStr +
+			" Order BY " + table + ".uniqueID";
 
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -238,15 +245,21 @@ class SqliteForceSensor : Sqlite
 		return array;
 	}
 
-	public static ArrayList SelectSessionOverviewSets (bool dbconOpened, int sessionID)
+	public static ArrayList SelectSessionOverviewSets (bool dbconOpened, int sessionID, Constants.Modes chronojumpMode)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 
+		string elasticStr = "";
+		if (chronojumpMode == Constants.Modes.FORCESENSORISOMETRIC)
+			elasticStr = " AND " + Constants.ForceSensorExerciseTable + ".elastic != 1"; //0 or -1 (both)
+		else if (chronojumpMode == Constants.Modes.FORCESENSORELASTIC)
+			elasticStr = " AND " + Constants.ForceSensorExerciseTable + ".elastic != 0"; //1 or -1 (both)
+
 		dbcmd.CommandText =
 			"SELECT person77.uniqueID, person77.name, person77.sex, forceSensorExercise.name, COUNT(*)" +
 			" FROM person77, personSession77, forceSensorExercise, forceSensor" +
-			" WHERE person77.uniqueID == forceSensor.personID AND personSession77.personID == forceSensor.personID AND personSession77.sessionID == forceSensor.sessionID AND forceSensorExercise.uniqueID==forceSensor.exerciseID AND forceSensor.sessionID == " + sessionID +
+			" WHERE person77.uniqueID == forceSensor.personID AND personSession77.personID == forceSensor.personID AND personSession77.sessionID == forceSensor.sessionID AND forceSensorExercise.uniqueID==forceSensor.exerciseID AND forceSensor.sessionID == " + sessionID + elasticStr +
 			" GROUP BY forceSensor.personID, exerciseID" +
 			" ORDER BY person77.name";
 
@@ -391,7 +404,7 @@ class SqliteForceSensor : Sqlite
 				{
 					if(unknownExerciseID == -1)
 					{
-						ForceSensorExercise fse = new ForceSensorExercise (-1, Catalog.GetString("Unknown"), 0, "", 0, "", false, false, false);
+						ForceSensorExercise fse = new ForceSensorExercise (-1, Catalog.GetString("Unknown"), 0, "", 0, "", false, false, ForceSensorExercise.Types.ISOMETRIC);
 						//note we are on 1_68 so we need this import method
 						unknownExerciseID = SqliteForceSensorExerciseImport.InsertAtDB_1_68(true, fse);
 					}
@@ -405,7 +418,7 @@ class SqliteForceSensor : Sqlite
 
 				if(fslt.Exercise != "" && exerciseID == -1)
 				{
-					ForceSensorExercise fse = new ForceSensorExercise (-1, fslt.Exercise, 0, "", 0, "", false, false, false);
+					ForceSensorExercise fse = new ForceSensorExercise (-1, fslt.Exercise, 0, "", 0, "", false, false, ForceSensorExercise.Types.ISOMETRIC);
 					//note we are on 1_68 so we need this import method
 					unknownExerciseID = SqliteForceSensorExerciseImport.InsertAtDB_1_68(true, fse);
 				}
@@ -486,8 +499,8 @@ class SqliteForceSensorExercise : Sqlite
 			"description TEXT, " +
 			"tareBeforeCapture INT, " +
 			"forceResultant INT NOT NULL, " +
-			"elastic INT NOT NULL, " +
-			"eccReps INT DEFAULT 0, " + 	//since ~2.22 (not really a change on DB) is repetitionsShow
+			"elastic INT NOT NULL, " + 	//since 2.2.2 on edit can be also -1 (meaning both, used when force is divided into isometric/elastic)
+			"eccReps INT DEFAULT 0, " + 	//since ~2.2.2 (not really a change on DB) is repetitionsShow
 			"eccMin FLOAT DEFAULT -1, " + 	//can be displacement or N
 			"conMin FLOAT DEFAULT -1)"; 	//can be displacement or N
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -523,23 +536,23 @@ class SqliteForceSensorExercise : Sqlite
 	protected internal static void insertDefault ()
 	{
 		Insert (true, new ForceSensorExercise(-1, "Leg extension", 0, "", 0,
-					"", false, false, false,
+					"", false, false, ForceSensorExercise.Types.ISOMETRIC,
 					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
 					100, 100));
 		Insert (true, new ForceSensorExercise(-1, "ABD/ADD", 0, "", 0,
-					"Abduction/Adduction", false, false, false,
+					"Abduction/Adduction", false, false, ForceSensorExercise.Types.ISOMETRIC,
 					ForceSensorExercise.RepetitionsShowTypes.BOTHSEPARATED,
 					100, 100));
 		Insert (true, new ForceSensorExercise(-1, "Mid thigh pull", 100, "", 90,
-					"", false, true, false,
+					"", false, true, ForceSensorExercise.Types.ISOMETRIC,
 					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
 					200, 200));
 		Insert (true, new ForceSensorExercise(-1, "Hamstring", 0, "", 0,
-					"", true, true, false,
+					"", true, true, ForceSensorExercise.Types.ISOMETRIC,
 					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
 					50, 50));
 		Insert (true, new ForceSensorExercise(-1, "Pull rubber band", 0, "", 0,
-					"", false, true, true,
+					"", false, true, ForceSensorExercise.Types.ELASTIC,
 					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
 					-1, -1));
 	}
@@ -555,9 +568,9 @@ class SqliteForceSensorExercise : Sqlite
 			", resistance = \"" + ex.Resistance + 					//unused
 			"\", angleDefault = " + ex.AngleDefault +
 			", description = \"" + ex.Description +
-			"\", tareBeforeCapture = " + Util.BoolToInt(ex.TareBeforeCapture).ToString() +
+			"\", tareBeforeCapture = " + Util.BoolToInt(ex.TareBeforeCaptureOnExerciseEdit).ToString() +
 			", forceResultant = " + Util.BoolToInt(ex.ForceResultant).ToString() +
-			", elastic = " + Util.BoolToInt(ex.Elastic).ToString() +
+			", elastic = " + ex.TypeToInt ().ToString() +
 			", eccReps = " + ex.RepetitionsShowToCode().ToString() +
 			", eccMin = " + Util.ConvertToPoint(ex.EccMin) +
 			", conMin = " + Util.ConvertToPoint(ex.ConMin) +
@@ -583,19 +596,44 @@ class SqliteForceSensorExercise : Sqlite
 	}
 
 
-	public static ArrayList Select (bool dbconOpened, int uniqueID, bool onlyNames)
+	//elastic (-1: both; 0: not elastic; 1: elastic)
+	public static ArrayList Select (bool dbconOpened, int uniqueID, int elastic, bool onlyNames)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 
+		string whereOrAndStr = " WHERE ";
+
 		string uniqueIDStr = "";
 		if(uniqueID != -1)
-			uniqueIDStr = " WHERE " + table + ".uniqueID = " + uniqueID;
+		{
+			uniqueIDStr = whereOrAndStr + table + ".uniqueID = " + uniqueID;
+			whereOrAndStr = " AND ";
+		}
+
+		string elasticStr = "";
+		if(elastic != -1)
+		{
+			/*
+			//note for elastic need: elastic = 1 && forceResultant = 1 (like ForceSensor.ComputeAsElastic does)
+			if (elastic == 1)
+				elasticStr = whereOrAndStr + table + ".elastic = 1 AND " + table + ".forceResultant = 1";
+			else //elastic == 0
+				elasticStr = whereOrAndStr + " (" + table + ".elastic = 0 OR " + table + ".forceResultant = 0)";
+				*/
+			//since the separation between isometric and elastic, show on elastic all the elastic exercises (not only the resultant = 1)
+			if (elastic == 1)
+				elasticStr = whereOrAndStr + table + ".elastic != 0"; //elastic && both (-1)
+			else //elastic == 0
+				elasticStr = whereOrAndStr + table + ".elastic != 1"; //isometric && both (-1)
+
+			whereOrAndStr = " AND ";
+		}
 
 		if(onlyNames)
-			dbcmd.CommandText = "SELECT name FROM " + table + uniqueIDStr;
+			dbcmd.CommandText = "SELECT name FROM " + table + uniqueIDStr + elasticStr;
 		else
-			dbcmd.CommandText = "SELECT * FROM " + table + uniqueIDStr;
+			dbcmd.CommandText = "SELECT * FROM " + table + uniqueIDStr + elasticStr;
 
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -624,7 +662,7 @@ class SqliteForceSensorExercise : Sqlite
 							reader[5].ToString(),			//description
 							Util.IntToBool(Convert.ToInt32(reader[6].ToString())),	//tareBeforeCapture
 							Util.IntToBool(Convert.ToInt32(reader[7].ToString())),	//forceResultant
-							Util.IntToBool(Convert.ToInt32(reader[8].ToString()))	//elastic
+							ForceSensorExercise.IntToType (Convert.ToInt32(reader[8].ToString()))	//elastic (on this DB conversation cannot be both: "-1")
 							);
 				else //if(reader.FieldCount == 12) DB: 1.87
 					ex = new ForceSensorExercise (
@@ -636,7 +674,7 @@ class SqliteForceSensorExercise : Sqlite
 							reader[5].ToString(),			//description
 							Util.IntToBool(Convert.ToInt32(reader[6].ToString())),	//tareBeforeCapture
 							Util.IntToBool(Convert.ToInt32(reader[7].ToString())),	//forceResultant
-							Util.IntToBool(Convert.ToInt32(reader[8].ToString())),	//elastic
+							ForceSensorExercise.IntToType (Convert.ToInt32(reader[8].ToString())),	//elastic (on this DB conversation cannot be both: "-1")
 							ForceSensorExercise.RepetitionsShowFromCode(Convert.ToInt32(reader[9].ToString())),	//eccReps
 							Convert.ToDouble(Util.ChangeDecimalSeparator(reader[10].ToString())), 	//eccMin
 							Convert.ToDouble(Util.ChangeDecimalSeparator(reader[11].ToString())) 	//conMin
@@ -651,6 +689,19 @@ class SqliteForceSensorExercise : Sqlite
 
 		return array;
 	}
+
+	/*
+	   ForceSensor exercises raw are now both (isometric & elastic) because there was a bug creating raw exercises
+	   (elastic was not asked and was assigned true) and we don't know where to put them
+	   */
+	protected internal static void UpdateTo2_40 ()
+	{
+		dbcmd.CommandText = "UPDATE " + table + " SET elastic = -1 WHERE forceResultant = 0";
+		//-1 as is the same than a select inespecific
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+	}
 }
 
 class SqliteForceSensorExerciseImport : SqliteForceSensorExercise
@@ -700,7 +751,7 @@ class SqliteForceSensorExerciseImport : SqliteForceSensorExercise
 	//database is opened
 	protected internal static void import_partially_from_1_73_to_1_74_unify_resistance_and_description()
 	{
-		ArrayList exercises = Select(true, -1, false);
+		ArrayList exercises = Select(true, -1, -1, false);
 		foreach (ForceSensorExercise ex in exercises)
 		{
 			LogB.Information(ex.ToString());
@@ -729,9 +780,9 @@ class SqliteForceSensorExerciseImport : SqliteForceSensorExercise
 			", resistance = \"" + ex.Resistance + 					//unused
 			"\", angleDefault = " + ex.AngleDefault +
 			", description = \"" + ex.Description +
-			"\", tareBeforeCapture = " + Util.BoolToInt(ex.TareBeforeCapture).ToString() +
+			"\", tareBeforeCapture = " + Util.BoolToInt(ex.TareBeforeCaptureOnExerciseEdit).ToString() +
 			", forceResultant = " + Util.BoolToInt(ex.ForceResultant).ToString() +
-			", elastic = " + Util.BoolToInt(ex.Elastic).ToString() +
+			", elastic = " + ex.TypeToInt ().ToString() + //on this DB conversation cannot be both "-1"
 			" WHERE uniqueID = " + ex.UniqueID;
 
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -883,7 +934,7 @@ class SqliteForceSensorElasticBand : Sqlite
 			"FROM session, forceSensor, forceSensorExercise " +
 			"WHERE forceSensor.sessionID = session.uniqueID " +
 			"AND forceSensor.exerciseID = forceSensorExercise.uniqueID " +
-			"AND forceSensorExercise.elastic = 1 " +
+			"AND forceSensorExercise.elastic != 0 " + //elastic && both
 			"AND forceSensorExercise.forceResultant = 1 " +
 			"ORDER BY session.name";
 
@@ -1119,16 +1170,29 @@ class SqliteForceSensorRFD : Sqlite
 
 		List<ForceSensorRFD> l = new List<ForceSensorRFD>();
 		while(reader.Read()) {
-			ForceSensorRFD rfd = new ForceSensorRFD(
-					reader[0].ToString(), 				//code
-					Util.IntToBool(Convert.ToInt32(reader[1])), 	//active
-					(ForceSensorRFD.Functions) Enum.Parse(
-						typeof(ForceSensorRFD.Functions), reader[2].ToString()), 	//function
-					(ForceSensorRFD.Types) Enum.Parse(
-						typeof(ForceSensorRFD.Types), reader[3].ToString()), 	//type
-					Convert.ToInt32(reader[4]), 			//num1
-					Convert.ToInt32(reader[5]) 			//num2
-					);
+			//try/catch here because BEST_AVG_RFD_IN_X_MS is new and a user can have a db of another more updated
+			ForceSensorRFD rfd;
+			try {
+				rfd = new ForceSensorRFD(
+						reader[0].ToString(), 				//code
+						Util.IntToBool(Convert.ToInt32(reader[1])), 	//active
+						(ForceSensorRFD.Functions) Enum.Parse(
+							typeof(ForceSensorRFD.Functions), reader[2].ToString()), 	//function
+						(ForceSensorRFD.Types) Enum.Parse(
+							typeof(ForceSensorRFD.Types), reader[3].ToString()), 	//type
+						Convert.ToInt32(reader[4]), 			//num1
+						Convert.ToInt32(reader[5]) 			//num2
+						);
+			} catch  {
+				LogB.Information (string.Format (
+							"Catched on SqliteForceSensorRFD.SelectAll creating a ForceSensorRFD of function: {0} and type: {1}",
+							reader[2].ToString(), reader[3].ToString() ));
+
+				//create a default rfd for that code and make it inactive
+				rfd = new ForceSensorRFD (reader[0].ToString(), false,
+					ForceSensorRFD.Functions.FITTED, ForceSensorRFD.Types.INSTANTANEOUS, 0, -1);
+			}
+
 			l.Add(rfd);
 		}
 
