@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -181,12 +181,12 @@ class SqlitePerson : Sqlite
 		return myArray;
 	}
 		
-	public static ArrayList SelectAllPersonsRecuperable(string sortedBy, int except, int inSession, string searchFilterName) 
+	public static ArrayList SelectAllPersonsRecuperable(string sortedBy, int exceptSession, int inSession, string searchFilterName)
 	{
 		//sortedBy = name or uniqueID (= creation date)
 	
 
-		//1st select all the person.uniqueID of people who are in CurrentSession (or none if except == -1)
+		//1st select all the person.uniqueID of people who are in CurrentSession (or none if exceptSession == -1)
 		//2n select all names in database (or in one session if inSession != -1)
 		//3d filter all names (save all found in 2 that is not in 1)
 		//
@@ -200,7 +200,7 @@ class SqlitePerson : Sqlite
 		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".uniqueID " +
 			" FROM " + tp + "," + tps +
-			" WHERE " + tps + ".sessionID == " + except + 
+			" WHERE " + tps + ".sessionID == " + exceptSession +
 			" AND " + tp + ".uniqueID == " + tps + ".personID "; 
 		LogB.SQL(dbcmd.CommandText.ToString());
 		
@@ -286,7 +286,10 @@ finishForeach:
 		return arrayReturn;
 	}
 
-	public static ArrayList SelectAllPersonEvents(int personID) 
+	/*
+	   unused, now used SqliteSession.SelectAllSessionsTestsCount
+
+	public static ArrayList SelectAllPersonEvents (int personID)
 	{
 		SqliteDataReader reader;
 		ArrayList arraySessions = new ArrayList(2);
@@ -299,7 +302,8 @@ finishForeach:
 		ArrayList arrayMCs = new ArrayList(2);
 		ArrayList arrayEncS = new ArrayList(2);
 		ArrayList arrayEncC = new ArrayList(2);
-		ArrayList arrayForce = new ArrayList(2);
+		ArrayList arrayForceIsometric = new ArrayList(2);
+		ArrayList arrayForceElastic = new ArrayList(2);
 		ArrayList arrayRunEncoder = new ArrayList(2);
 		
 		string tps = Constants.PersonSessionTable;
@@ -426,14 +430,29 @@ finishForeach:
 		}
 		reader.Close();
 
-		//forceSensor
-		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable + " WHERE personID = " + personID +
+		//forceSensor (isometric)
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable +
+			" WHERE personID = " + personID +
+			" AND " + Constants.ForceSensorTable + ".stiffness < 0" + //isometric has stiffness -1.0
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 
 		reader = dbcmd.ExecuteReader();
 		while(reader.Read()) {
-			arrayForce.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
+			arrayForceIsometric.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
+		}
+		reader.Close();
+
+		//forceSensor (elastic)
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable +
+			" WHERE personID = " + personID +
+			" AND " + Constants.ForceSensorTable + ".stiffness > 0" + //elastic has stiffness > 0
+			" GROUP BY sessionID ORDER BY sessionID";
+		LogB.SQL(dbcmd.CommandText.ToString());
+
+		reader = dbcmd.ExecuteReader();
+		while(reader.Read()) {
+			arrayForceElastic.Add ( reader[0].ToString() + ":" + reader[1].ToString() );
 		}
 		reader.Close();
 
@@ -463,7 +482,8 @@ finishForeach:
 		string tempMCs;
 		string tempEncS;
 		string tempEncC;
-		string tempForce;
+		string tempForceIsometric;
+		string tempForceElastic;
 		string tempRunEncoder;
 		bool found; 	//using found because a person can be loaded in a session 
 				//but whithout having done any event yet
@@ -480,7 +500,8 @@ finishForeach:
 			tempMCs = "";
 			tempEncS = "";
 			tempEncC = "";
-			tempForce = "";
+			tempForceIsometric = "";
+			tempForceElastic = "";
 			tempRunEncoder = "";
 			found = false;
 			
@@ -565,10 +586,19 @@ finishForeach:
 				}
 			}
 
-			foreach (string f in arrayForce) {
+			foreach (string f in arrayForceIsometric) {
 				string [] myStr = f.Split(new char[] {':'});
 				if(myStrSession[0] == myStr[0]) {
-					tempForce = myStr[1];
+					tempForceIsometric = myStr[1];
+					found = true;
+					break;
+				}
+			}
+
+			foreach (string f in arrayForceElastic) {
+				string [] myStr = f.Split(new char[] {':'});
+				if(myStrSession[0] == myStr[0]) {
+					tempForceElastic = myStr[1];
 					found = true;
 					break;
 				}
@@ -592,13 +622,15 @@ finishForeach:
 						tempRunsInterval + ":" + tempRTs + ":" + 	//runsInterval, Reaction times
 						tempPulses + ":" + tempMCs + ":" +		//pulses, MultiChronopic
 						tempEncS + ":" + tempEncC + ":" + 		//encoder signal, encoder curve
-						tempForce + ":" + tempRunEncoder 		//forceSensor, runEncoder
+						tempForceIsometric + ":" + tempForceElastic + ":" + //forceSensor
+						tempRunEncoder 		//runEncoder
 						);
 			}
 		}
 
 		return arrayAll;
 	}
+*/
 	
 	public static bool ExistsAndItsNotMe(int uniqueID, string personName)
 	{
@@ -671,4 +703,23 @@ finishForeach:
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
 	}
+
+	public static void DeletePersonAndImages (bool dbconOpened, int uniqueID)
+	{
+		// 1) delete from DB
+		openIfNeeded (dbconOpened);
+
+		dbcmd.CommandText = "DELETE FROM " + Constants.PersonTable + " WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL (dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery ();
+
+		closeIfNeeded (dbconOpened);
+
+		// 2) delete photos if any
+		if (File.Exists (Util.UserPhotoURL (false, uniqueID)))
+			File.Delete (Util.UserPhotoURL (false, uniqueID));
+		if (File.Exists (Util.UserPhotoURL (true, uniqueID)))
+			File.Delete (Util.UserPhotoURL (true, uniqueID));
+	}
 }
