@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -141,9 +141,10 @@ class SqlitePersonSession : Sqlite
 		return myReturn;
 	}
 	
-	public static void Update(PersonSession ps)
+	public static void Update (bool dbconOpened, PersonSession ps)
 	{
-		Sqlite.Open();
+		openIfNeeded (dbconOpened);
+
 		dbcmd.CommandText = "UPDATE " + Constants.PersonSessionTable + 
 			" SET personID = " + ps.PersonID + 
 			", sessionID = " + ps.SessionID + 
@@ -158,7 +159,8 @@ class SqlitePersonSession : Sqlite
 			" WHERE uniqueID == " + ps.UniqueID;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
-		Sqlite.Close();
+
+		closeIfNeeded (dbconOpened);
 	}
 
 	//double
@@ -374,14 +376,36 @@ class SqlitePersonSession : Sqlite
 	}
 	
 	//use this in the future:
-	public static List<PersonSession> SelectPersonSessionList(int sessionID)
+	public static List<PersonSession> SelectPersonSessionList (int personID, int sessionID)
 	{
 		string tps = Constants.PersonSessionTable;
 
+		string whereStr = "";
+		string andStr = "";
+
+		string personIDStr = "";
+		if (personID != -1)
+		{
+			personIDStr = tps + ".personID = " + personID;
+			whereStr = " WHERE ";
+		}
+
+		string sessionIDStr = "";
+		if (sessionID != -1)
+		{
+			sessionIDStr = tps + ".sessionID = " + sessionID;
+			if (whereStr == "")
+				whereStr = " WHERE ";
+			else
+				andStr = " AND ";
+		}
+
 		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tps + ".*" +
 			" FROM " + tps +
-			" WHERE " + tps + ".sessionID == " + sessionID;
+			whereStr + personIDStr +
+			andStr + sessionIDStr;
+
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		SqliteDataReader reader;
@@ -410,7 +434,6 @@ class SqlitePersonSession : Sqlite
 		return list;
 	}
 
-
 	public static void DeletePersonFromSessionAndTests(string sessionID, string personID)
 	{
 		Sqlite.Open();
@@ -426,20 +449,12 @@ class SqlitePersonSession : Sqlite
 		//2.- Now, it's not in this personSession77 in other sessions, delete if from DB
 
 		//if person is not in other sessions, delete it from DB
-		if(! PersonExistsInPS(true, Convert.ToInt32(personID))) {
-			//this will open and close DB connection
-			Delete(true, Constants.PersonTable, Convert.ToInt32(personID));
-
-			//delete photos if any
-			if(File.Exists(Util.UserPhotoURL(false, Convert.ToInt32(personID))))
-				File.Delete(Util.UserPhotoURL(false, Convert.ToInt32(personID)));
-			if(File.Exists(Util.UserPhotoURL(true, Convert.ToInt32(personID))))
-				File.Delete(Util.UserPhotoURL(true, Convert.ToInt32(personID)));
-		}
+		if (! PersonExistsInAnyPS (true, Convert.ToInt32 (personID)))
+			SqlitePerson.DeletePersonAndImages (true, Convert.ToInt32 (personID));
 
 		//3.- Delete tests without files
 				
-		//delete normal jumps
+		//delete simple jumps
 		dbcmd.CommandText = "Delete FROM jump WHERE sessionID == " + sessionID +
 			" AND personID == " + personID;
 			
@@ -450,7 +465,7 @@ class SqlitePersonSession : Sqlite
 			" AND personID == " + personID;
 		dbcmd.ExecuteNonQuery();
 		
-		//delete normal runs
+		//delete simple runs
 		dbcmd.CommandText = "Delete FROM run WHERE sessionID == " + sessionID +
 			" AND personID == " + personID;
 		
@@ -515,7 +530,7 @@ class SqlitePersonSession : Sqlite
 		}
 
 		// 5) delete forceSensor and related triggers
-		List<ForceSensor> fs_l = SqliteForceSensor.Select (true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID));
+		List<ForceSensor> fs_l = SqliteForceSensor.Select (true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID), -1);
 		foreach(ForceSensor fs in fs_l)
 		{
 			SqliteForceSensor.DeleteSQLAndFiles (true, fs); //deletes also the .csv
@@ -539,7 +554,20 @@ class SqlitePersonSession : Sqlite
 		Sqlite.Close();
 	}
 
-	public static bool PersonExistsInPS(bool dbconOpened, int personID)
+	public static void DeletePersonSessionOnMerge (bool dbconOpened, int uniqueID)
+	{
+		// 1) delete from DB
+		openIfNeeded (dbconOpened);
+
+		dbcmd.CommandText = "DELETE FROM " + Constants.PersonSessionTable + " WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL (dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery ();
+
+		closeIfNeeded (dbconOpened);
+	}
+
+	public static bool PersonExistsInAnyPS (bool dbconOpened, int personID)
 	{
 		if( ! dbconOpened)
 			Sqlite.Open();
