@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -72,8 +72,8 @@ class SqlitePreferences : Sqlite
 	public const string EncoderContractionInertial = "encoderContractionInertial";
 	public const string EncoderLateralityGravitatory = "encoderLateralityGravitatory";
 	public const string EncoderLateralityInertial = "encoderLateralityInertial";
-	public const string EncoderMassGravitatory = "encoderMassGravitatory";
-	public const string EncoderWeightsInertial = "encoderWeightsInertial";
+	public const string EncoderMassGravitatory = "encoderMassGravitatory"; //unused on 2.2.2. Just use encoderConfiguration table
+	public const string EncoderWeightsInertial = "encoderWeightsInertial"; //unused on 2.2.2. Just use encoderConfiguration table
 
 	public const string EncoderAutoSaveCurveBestNValue = "encoderAutoSaveCurveBestNValue";
 	public const string EncoderWorkKcal = "encoderWorkKcal";
@@ -96,6 +96,8 @@ class SqlitePreferences : Sqlite
 	public const string EncoderCaptureFeedbackEccon = "encoderCaptureFeedbackEccon";
 	public const string EncoderCaptureInertialEccOverloadMode = "encoderCaptureInertialEccOverloadMode";
 	public const string EncoderCaptureShowLoss = "encoderCaptureShowLoss";
+	public const string EncoderRepetitionCriteriaGravitatoryStr = "encoderRepetitionCriteriaGravitatory";
+	public const string EncoderRepetitionCriteriaInertialStr = "encoderRepetitionCriteriaInertial";
 
 	//forceSensor
 	public const string ForceSensorCaptureWidthSeconds = "forceSensorCaptureWidthSeconds";
@@ -106,6 +108,7 @@ class SqlitePreferences : Sqlite
 	public const string ForceSensorNotElasticConMinForce = "forceSensorNotElasticConMinForce";
 	public const string ForceSensorGraphsLineWidth = "forceSensorGraphsLineWidth";
 	public const string ForceSensorVariabilityMethod = "forceSensorVariabilityMethod";
+	public const string ForceSensorVariabilityLag = "forceSensorVariabilityLag";
 
 	public const string ForceSensorTareDateTimeStr = "forceSensorTareDateTime";
 	public const string ForceSensorTareStr = "forceSensorTare";
@@ -144,6 +147,7 @@ class SqlitePreferences : Sqlite
 	public const string LoadLastModeAtStart = "loadLastModeAtStart";
 	public const string LastMode = "lastMode";
 	public const string SessionLoadDisplay = "sessionLoadDisplay";
+	public const string LastPersonID = "lastPersonID";
 
 	//export
 	public const string ExportGraphWidth = "exportGraphWidth";
@@ -290,6 +294,8 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
 				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
+				Insert (EncoderRepetitionCriteriaGravitatoryStr, Preferences.EncoderRepetitionCriteria.CON.ToString(), dbcmdTr);
+				Insert (EncoderRepetitionCriteriaInertialStr, Preferences.EncoderRepetitionCriteria.CON.ToString(), dbcmdTr);
 
 				ArrayList encoderExercises =
 					SqliteEncoder.SelectEncoderExercises(true, -1, true, Constants.EncoderGI.ALL);
@@ -332,6 +338,7 @@ class SqlitePreferences : Sqlite
 				Insert (ForceSensorNotElasticConMinForce, "100", dbcmdTr);
 				Insert (ForceSensorGraphsLineWidth, "2", dbcmdTr);
 				Insert (ForceSensorVariabilityMethod, Preferences.VariabilityMethodEnum.CVRMSSD.ToString(), dbcmdTr);
+				Insert (ForceSensorVariabilityLag, "1", dbcmdTr);
 				Insert (ForceSensorCaptureFeedbackActive, Preferences.ForceSensorCaptureFeedbackActiveEnum.NO.ToString(), dbcmdTr);
 				Insert (ForceSensorCaptureFeedbackAt, "100", dbcmdTr);
 				Insert (ForceSensorCaptureFeedbackRange, "40", dbcmdTr);
@@ -396,6 +403,7 @@ class SqlitePreferences : Sqlite
 				Insert (LoadLastModeAtStart, "True", dbcmdTr);
 				Insert (LastMode, Constants.Modes.UNDEFINED.ToString(), dbcmdTr);
 				Insert (SessionLoadDisplay, "0", dbcmdTr);
+				Insert (LastPersonID, "-1", dbcmdTr);
 
 				//export
 				Insert (ExportGraphWidth, "900", dbcmdTr);
@@ -657,6 +665,13 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoderCaptureCutByTriggers")
 				preferences.encoderCaptureCutByTriggers = (Preferences.TriggerTypes)
 					Enum.Parse(typeof(Preferences.TriggerTypes), reader[1].ToString());
+			else if(reader[0].ToString() == EncoderRepetitionCriteriaGravitatoryStr)
+				preferences.encoderRepetitionCriteriaGravitatory = (Preferences.EncoderRepetitionCriteria)
+					Enum.Parse(typeof(Preferences.EncoderRepetitionCriteria), reader[1].ToString());
+			else if(reader[0].ToString() == EncoderRepetitionCriteriaInertialStr)
+				preferences.encoderRepetitionCriteriaInertial = (Preferences.EncoderRepetitionCriteria)
+					Enum.Parse(typeof(Preferences.EncoderRepetitionCriteria), reader[1].ToString());
+
 			//encoder other
 			else if(reader[0].ToString() == "encoderPropulsive")
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
@@ -778,6 +793,8 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == ForceSensorVariabilityMethod)
 				preferences.forceSensorVariabilityMethod = (Preferences.VariabilityMethodEnum)
 					Enum.Parse(typeof(Preferences.VariabilityMethodEnum), reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorVariabilityLag)
+				preferences.forceSensorVariabilityLag = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == ForceSensorCaptureFeedbackActive)
 			{
 				//preferences.forceSensorCaptureFeedbackActive = reader[1].ToString() == "True";
@@ -892,10 +909,23 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == LoadLastModeAtStart)
 				preferences.loadLastModeAtStart = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == LastMode)
-				preferences.lastMode = (Constants.Modes)
-					Enum.Parse(typeof(Constants.Modes), reader[1].ToString());
+			{
+				//fix previous to Chronojump 2.2.2 when mode was FORCESENSOR
+				if (reader[1].ToString () == "FORCESENSOR")
+					preferences.lastMode = Constants.Modes.FORCESENSORISOMETRIC;
+				else
+					preferences.lastMode = (Constants.Modes)
+						Enum.Parse(typeof(Constants.Modes), reader[1].ToString());
+			}
 			else if(reader[0].ToString() == SessionLoadDisplay)
 				preferences.sessionLoadDisplay = new SessionLoadDisplay(Convert.ToInt32(reader[1].ToString()));
+			else if(reader[0].ToString() == LastPersonID)
+			{
+				if(Util.IsNumber(reader[1].ToString(), false))
+					preferences.lastPersonID = Convert.ToInt32(reader[1].ToString());
+				else
+					preferences.lastPersonID = -1;
+			}
 
 			//export
 			else if(reader[0].ToString() == ExportGraphWidth)
