@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -29,7 +29,7 @@ using System.Collections.Generic;
 
 public class SqliteSessionSwitcher
 {
-	/** SqliteSessionSwitcher implements two methods that SqliteSesion class had (SelectAllSessions and Select).
+	/** SqliteSessionSwitcher implements two methods that SqliteSesion class had (SelectAllSessionsTesstCount and Select).
  	* These methods are used by SessionLoadWindow and depending on the parameters passed to the
 	* SqliteSessionSwitcher constructor:
 	* -it might use the static methods of SqliteSession (so it will access the main chronojump.db file)
@@ -57,34 +57,38 @@ public class SqliteSessionSwitcher
 		this.databasePath = databasePath;
 	}
 
-	public string[] SelectAllSessions(string filterName)
+	public List<SessionTestsCount> SelectAllSessionsTestsCount (string filterName)
 	{
 		if (type == DatabaseType.DEFAULT)
 		{
-			return SqliteSession.SelectAllSessions (filterName);
+			return SqliteSession.SelectAllSessionsTestsCount (filterName);
 		}
 		else
 		{
 			SqliteGeneral sqliteGeneral = new SqliteGeneral(databasePath);
-			if (! sqliteGeneral.IsOpened) {
-				List<string> emptyResult = new List<string> ();
-				return emptyResult.ToArray ();
-			}
+			if (! sqliteGeneral.IsOpened)
+				return new List<SessionTestsCount> ();
+
 			SqliteConnection dbcon = sqliteGeneral.connection;
 
-			string[] allSessions = SqliteSession.SelectAllSessions (filterName, dbcon);
+			List<SessionTestsCount> allSessions_l = SqliteSession.SelectAllSessionsTestsCount (filterName, dbcon);
+			/*
+			   does not help to be able to export/compress the used chronojump.db
+			sqliteGeneral.CloseConnection ();
+			sqliteGeneral = null;
+			*/
 
 			// on IMPORT, filtered sessions will contain all sessions but not the "SIMULATED"
-			List<string> filteredSessions = new List<string> ();
-			foreach(string session in allSessions)
+			List<SessionTestsCount> stc_l = new List<SessionTestsCount> ();
+			foreach(SessionTestsCount stc in allSessions_l)
 			{
-				if (type == DatabaseType.IMPORT && session.Split (':') [1] == "SIMULATED")
+				if (type == DatabaseType.IMPORT && stc.sessionParams.Name == "SIMULATED")
 					continue;
 
-				filteredSessions.Add (session);
+				stc_l.Add (stc);
 			}
 
-			return filteredSessions.ToArray();
+			return stc_l;
 		}
 	}
 
@@ -132,7 +136,7 @@ public class SqliteSessionSwitcher
 	}
 
 	//for export session
-	//TODO; at the moment use the above string[] SelectAllSessions(string filterName)
+	//TODO; at the moment use the above string[] SelectAllSessionsTestsCount (string filterName)
 	/*
 	public List<Session> SelectAll()
 	{
@@ -378,27 +382,40 @@ class SqliteSession : Sqlite
 	}
 
 	// It's used by chronojump-importer and receives a specific database
-	public static string[] SelectAllSessions(string filterName, SqliteConnection dbcon) 
+	public static List<SessionTestsCount> SelectAllSessionsTestsCount (string filterName, SqliteConnection dbcon)
 	{
-		string [] mySessions = selectAllSessionsDo(filterName, dbcon);
-		return mySessions;
+		return selectAllSessionsTestsCountDo (filterName, -1, dbcon); //-1 for allTests, contrary to person show all events use
 	}
 
 	// This is the usual chronojump's call (default database)
-	public static string[] SelectAllSessions(string filterName) 
+	public static List<SessionTestsCount> SelectAllSessionsTestsCount (string filterName)
 	{
 		Sqlite.Open();
 
-		// SelectAllSessions is used here and by the Chronojump importer to allow to pass an arbitrary
-		// dbcon.
-		string [] mySessions = selectAllSessionsDo(filterName, dbcon);
+		// SelectAllSessionsTestCount is used here and by the Chronojump importer to allow to pass an arbitrary dbcon.
+		List<SessionTestsCount> stc_l = selectAllSessionsTestsCountDo (filterName, -1, dbcon);
 
 		//close database connection
 		Sqlite.Close();
 
-		return mySessions;
+		return stc_l;
 	}
-	private static string[] selectAllSessionsDo(string filterName, SqliteConnection dbcon)
+
+	//called from person show all events
+	public static List<SessionTestsCount> SelectAllSessionsTestsCount (int personID)
+	{
+		Sqlite.Open();
+
+		// SelectAllSessionsTestCount is used here and by the Chronojump importer to allow to pass an arbitrary dbcon.
+		List<SessionTestsCount> stc_l = selectAllSessionsTestsCountDo ("", personID, dbcon);
+
+		//close database connection
+		Sqlite.Close();
+
+		return stc_l;
+	}
+
+	private static List<SessionTestsCount> selectAllSessionsTestsCountDo (string filterName, int personID, SqliteConnection dbcon)
 	{
 		// This method should NOT use Sqlite.open() / Sqlite.close(): it should only use dbcon
 		// to connect to the database. This method is used by the importer after opening an arbitrary
@@ -410,22 +427,32 @@ class SqliteSession : Sqlite
 		if(filterName != "")
 			filterNameString = " AND LOWER(session.name) LIKE LOWER (\"%" + filterName  + "%\") ";
 
-		dbcmd.CommandText = 
-			"SELECT session.*, sport.name, speciallity.name" +
+		if (personID < 0)
+			dbcmd.CommandText =
+				"SELECT session.*, sport.name, speciallity.name" +
 				" FROM session, sport, speciallity " +
 				" WHERE session.personsSportID == sport.uniqueID " + 
 				" AND session.personsSpeciallityID == speciallity.UniqueID " +
 				filterNameString + 
 				" ORDER BY session.uniqueID";
+		else {
+			string tps = Constants.PersonSessionTable;
+			dbcmd.CommandText =
+				"SELECT session.*, sport.name, speciallity.name" +
+				" FROM session, sport, speciallity, " + tps +
+				" WHERE session.personsSportID == sport.uniqueID " +
+				" AND session.personsSpeciallityID == speciallity.UniqueID " +
+				" AND " + tps + ".personID = " + personID + " AND " + tps + ".sessionID = session.UniqueID" +
+				filterNameString +
+				" ORDER BY session.uniqueID";
+		}
+
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
-		ArrayList myArray = new ArrayList(2);
-
-		int count = new int();
-		count = 0;
+		List<SessionParams> sessionParams_l = new List<SessionParams> ();
 
 		while(reader.Read()) {
 			string sportName = Catalog.GetString(reader[9].ToString());
@@ -433,11 +460,17 @@ class SqliteSession : Sqlite
 			if(reader[10].ToString() != "")
 				speciallityName = Catalog.GetString(reader[10].ToString());
 			string levelName = Catalog.GetString(Util.FindLevelName(Convert.ToInt32(reader[6])));
-			myArray.Add (reader[0].ToString() + ":" + reader[1].ToString() + ":" +
-			             reader[2].ToString() + ":" + UtilDate.FromSql(reader[3].ToString()).ToShortDateString() + ":" +
-			             sportName + ":" + speciallityName + ":" +
-			             levelName + ":" + reader[7].ToString() ); //desc
-			count ++;
+
+			sessionParams_l.Add (new SessionParams (
+						Convert.ToInt32 (reader[0].ToString()),
+						reader[1].ToString(),
+						reader[2].ToString(),
+						UtilDate.FromSql(reader[3].ToString()).ToShortDateString(),
+						sportName,
+						speciallityName,
+						levelName,
+						reader[7].ToString() //desc
+						));
 		}
 
 		reader.Close();
@@ -452,8 +485,17 @@ class SqliteSession : Sqlite
 		 * this solution it's more "lighter" for people who have  abig DB
 		 * */
 
+		string wherePersonStr = "";
+		string andPersonStr = "";
+		if (personID >= 0)
+		{
+			wherePersonStr = string.Format (" WHERE personID = {0} ", personID);
+			andPersonStr = string.Format (" AND personID = {0} ", personID);
+		}
+
 		//select persons of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PersonSessionTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -469,6 +511,7 @@ class SqliteSession : Sqlite
 
 		//select jumps of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.JumpTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -484,6 +527,7 @@ class SqliteSession : Sqlite
 
 		//select jumpsRj of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.JumpRjTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -499,6 +543,7 @@ class SqliteSession : Sqlite
 
 		//select runs of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -514,6 +559,7 @@ class SqliteSession : Sqlite
 
 		//select runsInterval of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunIntervalTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -529,6 +575,7 @@ class SqliteSession : Sqlite
 
 		//select reaction time of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ReactionTimeTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -544,6 +591,7 @@ class SqliteSession : Sqlite
 
 		//select pulses of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.PulseTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -559,6 +607,7 @@ class SqliteSession : Sqlite
 
 		//select multichronopic of each session
 		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.MultiChronopicTable + 
+			wherePersonStr +
 			" GROUP BY sessionID ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -574,7 +623,9 @@ class SqliteSession : Sqlite
 
 
 		//select encoder stuff of each session
-		dbcmd.CommandText = "SELECT sessionID, encoderConfiguration, signalOrCurve FROM " + Constants.EncoderTable + " ORDER BY sessionID";
+		dbcmd.CommandText = "SELECT sessionID, encoderConfiguration, signalOrCurve FROM " + Constants.EncoderTable +
+			wherePersonStr +
+			" ORDER BY sessionID";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -630,24 +681,48 @@ class SqliteSession : Sqlite
 
 		reader_enc.Close();
 
-		//select force sensor of each session
-		ArrayList myArray_fs = new ArrayList(2);
+		//select force sensor isometric of each session
+		ArrayList myArray_fs_isometric = new ArrayList(2);
 
 		//if we are importing from a session who was not the forceSensor table (db version < 1.68)
 		if(tableExists(true, Constants.ForceSensorTable))
 		{
 			dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable +
+				" WHERE " + Constants.ForceSensorTable + ".stiffness < 0" + //isometric has stiffness -1.0
+				andPersonStr +
 				" GROUP BY sessionID ORDER BY sessionID";
 			LogB.SQL(dbcmd.CommandText.ToString());
 			dbcmd.ExecuteNonQuery();
 
-			SqliteDataReader reader_fs;
-			reader_fs = dbcmd.ExecuteReader();
+			SqliteDataReader reader_fs_isometric;
+			reader_fs_isometric = dbcmd.ExecuteReader();
 
-			while(reader_fs.Read()) {
-				myArray_fs.Add (reader_fs[0].ToString() + ":" + reader_fs[1].ToString() + ":" );
+			while(reader_fs_isometric.Read()) {
+				myArray_fs_isometric.Add (reader_fs_isometric[0].ToString() + ":" + reader_fs_isometric[1].ToString() + ":" );
 			}
-			reader_fs.Close();
+			reader_fs_isometric.Close();
+		}
+
+		//select force sensor elastic of each session
+		ArrayList myArray_fs_elastic = new ArrayList(2);
+
+		//if we are importing from a session who was not the forceSensor table (db version < 1.68)
+		if(tableExists(true, Constants.ForceSensorTable))
+		{
+			dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable +
+				" WHERE " + Constants.ForceSensorTable + ".stiffness > 0" + //elastic has stiffness > 0
+				andPersonStr +
+				" GROUP BY sessionID ORDER BY sessionID";
+			LogB.SQL(dbcmd.CommandText.ToString());
+			dbcmd.ExecuteNonQuery();
+
+			SqliteDataReader reader_fs_elastic;
+			reader_fs_elastic = dbcmd.ExecuteReader();
+
+			while(reader_fs_elastic.Read()) {
+				myArray_fs_elastic.Add (reader_fs_elastic[0].ToString() + ":" + reader_fs_elastic[1].ToString() + ":" );
+			}
+			reader_fs_elastic.Close();
 		}
 
 		//select run encoder of each session
@@ -657,6 +732,7 @@ class SqliteSession : Sqlite
 		if(tableExists(true, Constants.RunEncoderTable))
 		{
 			dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunEncoderTable +
+				wherePersonStr +
 				" GROUP BY sessionID ORDER BY sessionID";
 			LogB.SQL(dbcmd.CommandText.ToString());
 			dbcmd.ExecuteNonQuery();
@@ -670,170 +746,51 @@ class SqliteSession : Sqlite
 			reader_re.Close();
 		}
 
-		//mix ten arrayLists
-		string [] mySessions = new string[count];
-		count =0;
-		bool found;
-		string result_enc_s;	//sets
-		string result_enc_r;	//repetitions
-		foreach (string line in myArray) {
-			string lineNotReadOnly = line;
+		//mix all arrayLists
+		List<SessionTestsCount> stc_l = new List<SessionTestsCount> ();
+		foreach (SessionParams sessionParam in sessionParams_l)
+		{
+			SessionTestsCount stc = new SessionTestsCount ();
 
 			//if some sessions are deleted, do not use count=0 to mix arrays, use sessionID of line
-			string [] mixingSessionFull = line.Split(new char[] {':'});
-			string mixingSessionID = mixingSessionFull[0];
+			//string [] mixingSessionFull = line.Split(new char[] {':'});
+			//string mixingSessionID = mixingSessionFull[0];
 
-			//add persons for each session	
-			found = false;
-			foreach (string line_persons in myArray_persons) {
-				string [] myStringFull = line_persons.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
+			stc.sessionParams = sessionParam;
+			int sID = stc.sessionParams.ID;
 
-			//add jumps for each session
-			found = false;
-			foreach (string line_jumps in myArray_jumps) {
-				string [] myStringFull = line_jumps.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
+			stc.Persons = getTestsInTable (myArray_persons, sID);
+			stc.JumpsSimple = getTestsInTable (myArray_jumps, sID);
+			stc.JumpsReactive = getTestsInTable (myArray_jumpsRj, sID);
+			stc.RunsSimple = getTestsInTable (myArray_runs, sID);
+			stc.RunsInterval = getTestsInTable (myArray_runs_interval, sID);
+			stc.RunsEncoder = getTestsInTable (myArray_re, sID);
+			stc.Isometric = getTestsInTable (myArray_fs_isometric, sID);
+			stc.Elastic = getTestsInTable (myArray_fs_elastic, sID);
+			stc.WeightsSets = getTestsInTable (myArray_enc_g_s, sID);
+			stc.WeightsReps = getTestsInTable (myArray_enc_g_r, sID);
+			stc.InertialSets = getTestsInTable (myArray_enc_i_s, sID);
+			stc.InertialReps = getTestsInTable (myArray_enc_i_r, sID);
+			stc.ReactionTimeOld = getTestsInTable (myArray_rt, sID);
+			stc.Pulses = getTestsInTable (myArray_pulses, sID);
+			stc.MultiChronopic = getTestsInTable (myArray_mcs, sID);
 
-			//add jumpsRj for each session
-			found = false;
-			foreach (string line_jumpsRj in myArray_jumpsRj) {
-				string [] myStringFull = line_jumpsRj.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add runs for each session
-			found = false;
-			foreach (string line_runs in myArray_runs) {
-				string [] myStringFull = line_runs.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add runsInterval for each session
-			found = false;
-			foreach (string line_runs_interval in myArray_runs_interval) {
-				string [] myStringFull = line_runs_interval.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add reaction time for each session
-			found = false;
-			foreach (string line_rt in myArray_rt) {
-				string [] myStringFull = line_rt.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add pulses for each session
-			found = false;
-			foreach (string line_pulses in myArray_pulses) {
-				string [] myStringFull = line_pulses.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add multiChronopic for each session
-			found = false;
-			foreach (string line_mcs in myArray_mcs) {
-				string [] myStringFull = line_mcs.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add encoder gravitatory for each session (sets ; repetitions)
-			result_enc_s = "0";
-			result_enc_r = "0";
-			foreach (string line_enc_g_s in myArray_enc_g_s) {
-				string [] myStringFull = line_enc_g_s.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID)
-					result_enc_s = myStringFull[1];
-			}
-			foreach (string line_enc_g_r in myArray_enc_g_r) {
-				string [] myStringFull = line_enc_g_r.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID)
-					result_enc_r = myStringFull[1];
-			}
-			lineNotReadOnly  = lineNotReadOnly + ":" + result_enc_s + " ; " + result_enc_r;
-
-			//add encoder inertial for each session (sets ; repetitions)
-			result_enc_s = "0";
-			result_enc_r = "0";
-			foreach (string line_enc_i_s in myArray_enc_i_s) {
-				string [] myStringFull = line_enc_i_s.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID)
-					result_enc_s = myStringFull[1];
-			}
-			foreach (string line_enc_i_r in myArray_enc_i_r) {
-				string [] myStringFull = line_enc_i_r.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID)
-					result_enc_r = myStringFull[1];
-			}
-			lineNotReadOnly  = lineNotReadOnly + ":" + result_enc_s + " ; " + result_enc_r;
-
-			//add force sensor for each session
-			found = false;
-			foreach (string line_fs in myArray_fs) {
-				string [] myStringFull = line_fs.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			//add run encoder for each session
-			found = false;
-			foreach (string line_re in myArray_re) {
-				string [] myStringFull = line_re.Split(new char[] {':'});
-				if(myStringFull[0] == mixingSessionID) {
-					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
-					found = true;
-				}
-			}
-			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
-
-			mySessions [count++] = lineNotReadOnly;
+			//mySessions [count++] = lineNotReadOnly;
+			stc_l.Add (stc);
 		}
 
-		if (mySessions.Length > 0) {
-			LogB.SQL (mySessions [0]);
-		} else {
-			LogB.Debug ("SelectAllSessions with filter: " + filterName + " is empty");
+		return stc_l;
+	}
+	private static int getTestsInTable (ArrayList array, int sessionID)
+	{
+		foreach (string str in array)
+		{
+			string [] stringFull = str.Split (new char[] {':'});
+			if (Convert.ToInt32 (stringFull[0]) == sessionID)
+				return Convert.ToInt32 (stringFull [1]);
 		}
-		return mySessions;
+		return 0;
 	}
-
 
 
 	//called from gui/event.cs for doing the graph
@@ -975,7 +932,7 @@ class SqliteSession : Sqlite
 		
 		// 3) delete tests without files
 
-		//delete normal jumps
+		//delete simple jumps
 		dbcmd.CommandText = "Delete FROM " + Constants.JumpTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
@@ -983,7 +940,7 @@ class SqliteSession : Sqlite
 		dbcmd.CommandText = "Delete FROM " + Constants.JumpRjTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
-		//delete normal runs
+		//delete simple runs
 		dbcmd.CommandText = "Delete FROM " + Constants.RunTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
