@@ -49,7 +49,7 @@ public class GraphDjQ : StatDjQ
 			this.operation = "AVG";
 		}
 
-		CurrentGraphData.WindowTitle = Catalog.GetString("ChronoJump graph");
+		CurrentGraphData.WindowTitle = Catalog.GetString("Chronojump graph");
 		//title is shown on the graph except it's a report, then title will be on the html
 		if(myStatTypeStruct.ToReport) {
 			CurrentGraphData.GraphTitle = "";
