@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -139,23 +139,27 @@ public class TreeViewEvent
 		return columnsString.Length +1;
 	}
 	
-	protected virtual void addStatisticInfo(TreeIter iterDeep, System.Object myObject) {
-		store.AppendValues(iterDeep, printTotal(myObject, getColsNum()));
-		store.AppendValues(iterDeep, printAVG(myObject, getColsNum()));
-		store.AppendValues(iterDeep, printSD(myObject, getColsNum()));
+	protected virtual void addStatisticInfo (TreeIter iterDeep, System.Object myObject)
+	{
+		store.AppendValues (iterDeep, printTotal (myObject));
+		store.AppendValues (iterDeep, printAVG (myObject));
+		store.AppendValues (iterDeep, printSD (myObject));
 	}
 	
-	protected virtual string [] printTotal(System.Object myObject, int cols) {
+	protected virtual string [] printTotal (System.Object myObject)
+	{
 		string [] nothing = new string[0];
 		return nothing;
 	}
 	
-	protected virtual string [] printAVG(System.Object myObject, int cols) {
+	protected virtual string [] printAVG (System.Object myObject)
+	{
 		string [] nothing = new string[0];
 		return nothing;
 	}
 
-	protected virtual string [] printSD(System.Object myObject, int cols) {
+	protected virtual string [] printSD (System.Object myObject)
+	{
 		string [] nothing = new string[0];
 		return nothing;
 	}
@@ -207,15 +211,58 @@ public class TreeViewEvent
 		}
 	}
 
-	public void Update (Event myEvent) {
+	public void Update (Event myEvent)
+	{
+		LogB.Information ("Called TreeViewEvent.Update ()");
 		TreeIter iter = new TreeIter();
 		TreeModel myModel = treeview.Model;
-		if (treeview.Selection.GetSelected (out myModel, out iter)) {
+		if (treeview.Selection.GetSelected (out myModel, out iter))
+		{
 			//this doesn't work on windows gtk-sharp 2.10 (works on 2.12)
 			//store.SetValues (iter, getLineToStore(myEvent));
 			string [] myRow = getLineToStore(myEvent);
-			for(int i=0; i < myRow.Length; i++)
+			for (int i = 0; i < myRow.Length; i++)
 				store.SetValue (iter, i, myRow[i]);
+
+			if (treeviewHasTwoLevels)
+			{
+				TreeIter iterDeep = new TreeIter ();
+				treeview.Model.IterChildren (out iterDeep, iter);
+
+				string firstCol = treeview.Model.GetValue (iterDeep, 0).ToString ();
+				if (firstCol.StartsWith (Catalog.GetString ("Total")))
+				{
+					//do nothing as update right now only updates distance that makes change speed AVG
+					treeview.Model.IterNext (ref iterDeep);
+					firstCol = treeview.Model.GetValue (iterDeep, 0).ToString ();
+				}
+
+				if (firstCol.StartsWith (Catalog.GetString ("AVG")))
+				{
+					myRow = printAVG (myEvent);
+					for (int i = 0; i < myRow.Length; i++)
+						store.SetValue (iterDeep, i, myRow[i]);
+
+					treeview.Model.IterNext (ref iterDeep);
+					firstCol = treeview.Model.GetValue (iterDeep, 0).ToString ();
+				}
+
+				if (firstCol.StartsWith (Catalog.GetString ("SD")))
+				{
+					//do nothing as update right now only updates distance that makes change speed AVG
+					treeview.Model.IterNext (ref iterDeep);
+					firstCol = treeview.Model.GetValue (iterDeep, 0).ToString ();
+				}
+
+				for (int j = 0; j < getNumOfSubEvents (myEvent); j++)
+				{
+					myRow = getSubLineToStore (myEvent, j);
+					for (int i = 0; i < myRow.Length; i++)
+						store.SetValue (iterDeep, i, myRow[i]);
+
+					treeview.Model.IterNext (ref iterDeep);
+				}
+			}
 		}
 	}
 
@@ -235,6 +282,23 @@ public class TreeViewEvent
 		}
 	}
 
+	//if only shown persons, zoom to tests
+	public void ZoomToTestsIfNeeded ()
+	{
+		if(expandState == ExpandStates.MINIMIZED)
+		{
+			if(treeviewHasTwoLevels)
+			{
+				expandState = ExpandStates.OPTIMAL;
+				ExpandOptimal();
+			} else
+			{
+				expandState = ExpandStates.MAXIMIZED;
+				treeview.ExpandAll();
+			}
+		}
+	}
+
 	public void Add (string personName, System.Object newEvent)
 	{
 		
@@ -367,7 +431,8 @@ public class TreeViewEvent
 		Unselect(); //if not found: unselect all
 	}
 
-	public void SelectEvent(int uniqueID) {
+	public void SelectEvent (int uniqueID, bool scrollToEvent)
+	{
 		TreeIter iter = new TreeIter();
 		treeview.Model.GetIterFirst ( out iter ) ;
 		
@@ -388,6 +453,13 @@ public class TreeViewEvent
 					if(iterEventID == uniqueID) {
 						LogB.Information("We select:" + iterEventID);
 						treeview.Selection.SelectIter (iter);
+
+						if(scrollToEvent) {
+							TreePath path = store.GetPath (iter);
+							LogB.Debug(path.ToString());
+							treeview.ScrollToCell (path, null, true, 0, 0);
+						}
+
 						found = true;
 					}
 					iterValid = iter;
