@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -170,11 +170,11 @@ public class TreeViewJumps : TreeViewEvent
 		myJump.Simulated = Convert.ToInt32(myStringOfData[11].ToString());
 		myJump.Datetime = myStringOfData[12].ToString();
 
-		myJump.Weight = Convert.ToDouble(myStringOfData[8].ToString());
+		myJump.WeightPercent = Convert.ToDouble(myStringOfData[8].ToString());
 
 		//to calculate potency
 		personWeight = Convert.ToDouble(myStringOfData[13]);
-		weightInKg = Util.WeightFromPercentToKg(myJump.Weight, personWeight);
+		weightInKg = Util.WeightFromPercentToKg (myJump.WeightPercent, personWeight);
 
 		return myJump;
 	}
@@ -200,13 +200,13 @@ public class TreeViewJumps : TreeViewEvent
 		//Also this is needed on Add (where personWeight is passed using PersonWeight, but not weightInKg)
 		//LogB.Information("getLineToStore personWeight: " + personWeight.ToString());
 		weightInKg = Util.WeightFromPercentToKg(
-				Convert.ToDouble(newJump.Weight.ToString()),
+				Convert.ToDouble (newJump.WeightPercent.ToString ()),
 				personWeight);
 		
 		if(preferences.weightStatsPercent)
-			myData[count++] = Util.TrimDecimals(newJump.Weight.ToString(), pDN);
+			myData[count++] = Util.TrimDecimals (newJump.WeightPercent.ToString(), pDN);
 		else
-			myData[count++] = Util.TrimDecimals(weightInKg.ToString(), pDN);
+			myData[count++] = Util.TrimDecimals (weightInKg.ToString (), pDN);
 
 		myData[count++] = Util.TrimDecimals(newJump.Fall.ToString(), pDN);
 		myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(newJump.Tv.ToString()), pDN);
@@ -219,19 +219,19 @@ public class TreeViewJumps : TreeViewEvent
 			if(newJump.Tv > 0) {	
 				if(newJump.Tc > 0) 	//if it's Dj (has tf, and tc)
 					myData[count++] = Util.TrimDecimals(
-							Util.GetDjPower(newJump.Tc, newJump.Tv, (personWeight + weightInKg), newJump.Fall).ToString(), 1);
-				else {			//it's a normal jump without tc
+							Jump.GetDjPower (newJump.Tc, newJump.Tv, (personWeight + weightInKg), newJump.Fall).ToString(), 1);
+				else {			//it's a simple jump without tc
 					myData[count++] = Util.TrimDecimals(
-							Util.GetPower(newJump.Tv, personWeight, weightInKg).ToString(), 1);
+							Jump.GetPower (newJump.Tv, personWeight, weightInKg).ToString(), 1);
 				}
 			} else
 				myData[count++] = "0";
 		}
 
 		if (preferences.showStiffness)
-			myData[count++] = newJump.Stiffness(personWeight, weightInKg).ToString();
+			myData[count++] = Util.TrimDecimals (newJump.Stiffness(personWeight, weightInKg), pDN);
 		if (preferences.showInitialSpeed) 
-			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(newJump.Tv.ToString(), preferences.metersSecondsPreferred), pDN);
+			myData[count++] = Util.TrimDecimals(newJump.GetInitialSpeedJumpSimple (preferences.metersSecondsPreferred), pDN);
 		if (preferences.showJumpRSI)
 			myData[count++] = Util.TrimDecimals(newJump.RSI, pDN);
 		if (preferences.showAngle) 
@@ -241,7 +241,7 @@ public class TreeViewJumps : TreeViewEvent
 		if (preferences.showDjIndex)
 			myData[count++] = Util.TrimDecimals(Util.GetDjIndex(newJump.Tv, newJump.Tc).ToString(), pDN);
 		
-		myData[count++] = newJump.Datetime;
+		myData[count++] = UtilDate.GetDatetimePrint(UtilDate.FromFile(newJump.Datetime));
 		myData[count++] = newJump.Description;
 
 		myData[count++] = newJump.UniqueID.ToString();
@@ -303,10 +303,10 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myJumpRj.Simulated = Convert.ToInt32(myStringOfData[18].ToString());
 		myJumpRj.Datetime = myStringOfData[19].ToString();
 		
-		myJumpRj.Weight = Convert.ToDouble(myStringOfData[8].ToString());
+		myJumpRj.WeightPercent = Convert.ToDouble (myStringOfData[8].ToString());
 
 		personWeight = Convert.ToDouble(myStringOfData[20]);
-		weightInKg = Util.WeightFromPercentToKg(myJumpRj.Weight, personWeight);
+		weightInKg = Util.WeightFromPercentToKg (myJumpRj.WeightPercent, personWeight);
 
 		return myJumpRj;
 	}
@@ -332,7 +332,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = "";
 		
 		weightInKg = Util.WeightFromPercentToKg(
-				Convert.ToDouble(newJumpRj.Weight.ToString()),
+				Convert.ToDouble (newJumpRj.WeightPercent.ToString()),
 				personWeight);
 		myData[count++] = Util.TrimDecimals(weightInKg.ToString(), pDN);
 
@@ -351,7 +351,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 		if (preferences.showDjIndex)
 			myData[count++] = "";
 		
-		myData[count++] = newJumpRj.Datetime;
+		myData[count++] = UtilDate.GetDatetimePrint(UtilDate.FromFile(newJumpRj.Datetime));
 		myData[count++] = newJumpRj.Description;
 		myData[count++] = newJumpRj.UniqueID.ToString();
 		return myData;
@@ -390,7 +390,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 		
 		//This is needed on Add (where personWeight is passed using PersonWeight, but not weightInKg)
 		weightInKg = Util.WeightFromPercentToKg(
-				Convert.ToDouble(newJumpRj.Weight.ToString()),
+				Convert.ToDouble (newJumpRj.WeightPercent.ToString()),
 				personWeight);
 		
 		if (preferences.showPower) {
@@ -402,11 +402,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 			
 			if(Convert.ToDouble(thisTc) > 0)
 				myData[count++] = Util.TrimDecimals(
-						Util.GetDjPower(thisTcD, thisTvD,
+						Jump.GetDjPower (thisTcD, thisTvD,
 							(personWeight + weightInKg), myFall).ToString(), 1);
 			else
 				myData[count++] = Util.TrimDecimals(
-						Util.GetPower(thisTvD, personWeight, weightInKg).ToString(), 1);
+						Jump.GetPower (thisTvD, personWeight, weightInKg).ToString(), 1);
 		}
 		if (preferences.showStiffness) {
 			//use directly Util.GetStiffness because we want to get from this specific subjump, not all the reactive jump.
@@ -419,7 +419,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 				myData[count++] = ""; 
 		}
 		if (preferences.showInitialSpeed) 
-			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(
+			myData[count++] = Util.TrimDecimals(Jump.GetInitialSpeed(
 						thisTv, preferences.metersSecondsPreferred), pDN);
 		if (preferences.showJumpRSI)
 			myData[count++] = Util.TrimDecimals(
@@ -443,7 +443,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 		return myData;
 	}
 
-	protected override string [] printTotal(System.Object myObject, int cols) {
+	protected override string [] printTotal (System.Object myObject)
+	{
 		JumpRj newJumpRj = (JumpRj)myObject;
 
 		string [] myData = new String [getColsNum()];
@@ -473,7 +474,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 		return myData;
 	}
 	
-	protected override string [] printAVG(System.Object myObject, int cols)
+	protected override string [] printAVG (System.Object myObject)
 	{
 		JumpRj newJumpRj = (JumpRj)myObject;
 
@@ -516,8 +517,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 			 * in order to calculate the total, AVG, SD using that data
 			 */
 
-			weightInKg = Util.WeightFromPercentToKg(
-					Convert.ToDouble(newJumpRj.Weight.ToString()),
+			weightInKg = Util.WeightFromPercentToKg (
+					Convert.ToDouble (newJumpRj.WeightPercent.ToString ()),
 					personWeight);
 
 			string [] tc_array = newJumpRj.TcString.Split(new char[] {'='});
@@ -533,17 +534,26 @@ public class TreeViewJumpsRj : TreeViewJumps
 				double tv = Convert.ToDouble(tv_array[i]);
 				double fall = 0;
 				if(tc_array[i] == "-1") //startIn at first jump tc is 0, better check like this (string)
-					powerSum += Util.GetPower(tv, personWeight, weightInKg);
+					powerSum += Jump.GetPower (tv, personWeight, weightInKg);
 				else {
 					if(i == 0)
 						fall = newJumpRj.Fall;
 					else
 						fall = Util.GetHeightInCentimeters(Convert.ToDouble(tv_array[i-1]));
-					powerSum += Util.GetDjPower(tc, tv,
+
+					powerSum += Jump.GetDjPower (tc, tv,
 							(personWeight + weightInKg), fall);
+
+					/* debug
+					LogB.Information (string.Format (
+								"at treeviewJump, tc: {0}, tv: {1}, (personWeight + weightInKg): {2}, fall: {3}, powerSum: {4}",
+							tc, tv, (personWeight + weightInKg), fall, powerSum));
+							*/
+
 					stiffnessSum += Util.GetStiffness(personWeight, weightInKg, tv, tc);
 					stiffnessCount ++;
 				}
+				//LogB.Information ("at treeviewJump, powerSum = ", powerSum.ToString());
 				powerCount ++;
 			}
 			if (preferences.showPower)
@@ -553,7 +563,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 		}
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(
-					Util.GetInitialSpeed(
+					Jump.GetInitialSpeed(
 						tvAVGDouble.ToString(), preferences.metersSecondsPreferred)
 					, pDN);
 		if (preferences.showJumpRSI)
@@ -573,7 +583,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 		return myData;
 	}
 	
-	protected override string [] printSD(System.Object myObject, int cols) {
+	protected override string [] printSD (System.Object myObject)
+	{
 		JumpRj newJumpRj = (JumpRj)myObject;
 		
 		string tcString = newJumpRj.TcString;
