@@ -95,6 +95,7 @@ public class Trigger
 
 	public int Us {
 		get { return us; }
+		set { us = value; }
 	}
 	public double Ms {
 		get {
@@ -113,6 +114,10 @@ public class Trigger
 		get { return inOut; }
 	}
 
+	public Modes Mode {
+		get { return mode; }
+	}
+
 	public int ModeID {
 		set { modeID = value; }
 	}
