@@ -82,13 +82,9 @@ public class Util
 	//all numbers are saved in database with '.' as decimal separator (method for numbers)
 	public static string ConvertToPoint (double myDouble)
 	{
-		StringBuilder myStringBuilder = new StringBuilder(myDouble.ToString());
-		myStringBuilder.Replace(",", ".");
-		return myStringBuilder.ToString();
+		return ConvertToPoint (myDouble.ToString ());
 	}
-	
 	//all numbers are saved in database with '.' as decimal separator
-	//method for the tvString, tcString, and runIntervalTimesString
 	public static string ConvertToPoint (string myString)
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
@@ -141,6 +137,18 @@ public class Util
 		return l;
 	}
 
+	public static string ListDoubleToString (List<double> d_l, int decs, string sep)
+	{
+		string str = "";
+		string sepStr = "";
+		foreach (double d in d_l)
+		{
+			str += sepStr + TrimDecimals (d, decs);
+			sepStr = sep;
+		}
+		return str;
+	}
+
 	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
 	//if client is on english machine, need to convert this to "0.54"
 	public static string ConvertToPointIfNeeded (string myString)
@@ -449,13 +457,14 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
-	public static string RemoveNewLine(string myString, bool changeBySpace) 
+	public static string RemoveNewLine(string myString, bool changeBySpace)
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
 		if(changeBySpace)
 			myStringBuilder.Replace("\n", " ");
 		else
 			myStringBuilder.Replace("\n", "");
+
 		return myStringBuilder.ToString();
 	}
 
@@ -478,11 +487,20 @@ public class Util
 		return s;
 	}
 
-	//use this!!!	
-	public static string RemoveChar(string s, char c) 
+	//use on of this two methods
+	//this is the default, used by almost all methods: change to an space
+	public static string RemoveChar(string s, char c)
+	{
+		return RemoveChar(s, c, true);
+	}
+	public static string RemoveChar(string s, char c, bool changeBySpace)
 	{
 		StringBuilder myStringBuilder = new StringBuilder(s);
-		myStringBuilder.Replace(c,' ');
+		if(changeBySpace)
+			myStringBuilder.Replace(c,' ');
+		else
+			myStringBuilder.Replace(c.ToString(), "");
+
 		return myStringBuilder.ToString();
 	}
 
@@ -508,6 +526,15 @@ public class Util
 		return s;
 	}
 
+	public static string RemoveFromChar (string str, char c)
+	{
+		int pos = str.IndexOf(c);
+		if (pos > 0)
+			return str.Substring(0, pos);
+
+		return str;
+	}
+
 	public static string ChangeEqualForColon(string myString) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
@@ -530,6 +557,17 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
+	public static string RemoveCenterCharsOnLongString (string str, int maxLength)
+	{
+		if (str.Length > maxLength)
+		{
+			int charsAtSide = Convert.ToInt32 (Math.Floor (maxLength / 2.0));
+			return (
+					str.Substring (0, charsAtSide) + "…" +
+					str.Substring (str.Length -charsAtSide, charsAtSide) );
+		}
+		return str;
+	}
 
 	//old code sends and returns strings
 	public static string GetHeightInCentimeters (string time) {
@@ -540,6 +578,11 @@ public class Util
 		// s = 100 * 4.9 * (tv/2)^2
 		return 100 * 4.9 * Math.Pow( tv / 2.0 , 2 );
 	}
+	//shorter
+	public static double GetHeightInCm (double tv) {
+		return GetHeightInCentimeters (tv);
+	}
+
 	public static double GetHeightInMeters (double tv) {
 		// s = 4.9 * (tv/2)^2
 		return 4.9 * Math.Pow( tv / 2.0 , 2 );
@@ -728,17 +771,17 @@ public class Util
 	}
 
 
-	//public static string GetSpeed (string distance, string time) {
-	public static string GetSpeed (string distance, string time, bool metersSecondsPreferred) {
-		double distanceAsDouble = Convert.ToDouble(distance);
-		double timeAsDouble = Convert.ToDouble(time);
-
+	public static string GetSpeed (string distance, string time, bool metersSecondsPreferred)
+	{
+		return GetSpeed (Convert.ToDouble (distance), Convert.ToDouble (time), metersSecondsPreferred).ToString ();
+	}
+	public static double GetSpeed (double distance, double time, bool metersSecondsPreferred)
+	{
 		if(metersSecondsPreferred)
-			return (distanceAsDouble / timeAsDouble).ToString();
+			return UtilAll.DivideSafe (distance, time);
 		else
-			return (3.6 * distanceAsDouble / timeAsDouble).ToString();
+			return UtilAll.DivideSafe (3.6 * distance, time);
 	}
-					
 	
 	public static int FetchID (string text)
 	{
@@ -789,67 +832,11 @@ public class Util
 		return stiffness;
 	}
 
-	//old code sends and returns strings
-	public static string GetInitialSpeed (string time, bool metersSecondsPreferred)
-	{
-		return GetInitialSpeed (Convert.ToDouble(time), metersSecondsPreferred).ToString();
-	}
-	//new code (2019 ...) sends and returns doubles
-	public static double GetInitialSpeed (double time, bool metersSecondsPreferred)
-	{
-		double height = GetHeightInCentimeters(time);
-		height = height / 100; //in meters
-		
-		// Vo = sqrt(2gh)
-		double initialSpeed = System.Math.Sqrt ( 2 * 9.81 * height ); 
-
-		if(! metersSecondsPreferred)
-			initialSpeed *= 3.6;
-
-		return initialSpeed;
-	}
-
 	public static double GetAverageImpulsionSpeed(double jumpHeightM)
 	{
 		return Math.Sqrt( (9.81 * jumpHeightM) / 2);
 	}
 	
-	public static double GetDjPower (double tc, double tf, double mass, double fallHeight) 
-	{
-		/*
-		 * old method
-		//relative potency in Watts/Kg
-		//Bosco. Pendent to find if published
-
-		//P = 24.6 * (TotalTime + FlightTime) / ContactTime
-
-		double tt = tc + tf; //totalTime
-
-		return 24.6 * ( tt + tf ) / (Double)tc;
-		*/
-
-		//new method (proposal by Xavier Padullés)
-		//Calcule the potential energies before (mass * g * fallHeight) and after the jump (mass * g * tv^2 * 1.226)
-		//and divide by the time during force is applied
-		double g = 9.81;
-		fallHeight = fallHeight / 100.0; //cm -> m
-		
-		return mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tc;
-	}
-				
-	//only Lewis now
-	public static double GetPower (double tf, double bodyWeight, double extraWeightKg) 
-	{
-		//Log.WriteLine("tf: " + tf + ", bodyWeight: " + bodyWeight + ", extra: " + extraWeightKg);
-		double pw = System.Math.Sqrt ( 4.9 ) * 9.8 * (bodyWeight + extraWeightKg) *
-			System.Math.Sqrt(
-				       Convert.ToDouble(GetHeightInCentimeters(tf.ToString()))/100);
-		//Log.WriteLine("pw: " + pw);
-		return pw;
-
-	}
-
-
 	public static double GetQIndex (double tv, double tc) 
 	{
 		if(tv == 0 || tc == 0)
@@ -953,32 +940,42 @@ public class Util
 	}
 	
 	/********** start of LocalApplicationData path ************/
-	
+
 	//parent of database, multimedia and encoder
-	//if withFinalSeparator, then return a '\' or '/' at the end
-	public static string GetParentDir(bool withFinalSeparator) {
-		string path = Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump");
-
-		if(withFinalSeparator)
-			path += Path.DirectorySeparatorChar;
-
-		return path;
+	//Since 2.2.2 on Compujump admin LocaApplicationData can change
+	//this will check if any config path is present
+	public static string GetLocalDataDir (bool withFinalSeparator)
+	{
+		if (Config.LastDBFullPathStatic == "")
+			return UtilAll.GetDefaultLocalDataDir (withFinalSeparator); //this can be checked by Mini
+		else {
+			if (withFinalSeparator)
+				 return Config.LastDBFullPathStatic + Path.DirectorySeparatorChar;
+			else
+				 return Config.LastDBFullPathStatic;
+		}
 	}
-	
+
+	public static string GetConfigFileName() {
+		return Path.Combine (GetLocalDataDir (false) +  Path.DirectorySeparatorChar + Constants.FileNameConfig);
+	}
+	public static string GetECapSimSignalFileName() {
+		return Path.Combine (GetLocalDataDir (false) +  Path.DirectorySeparatorChar + "eCapSimSignal.txt");
+	}
+
+
 	//url and videoURL stored path is relative to be able to move data between computers
 	//then SELECT: makes it abolute (addURLpath)
 	//INSERT and UPDATE: makes it relative (removeURLpath)
 	public static string MakeURLabsolute(string url) {
-		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		string parentDir = Util.GetLocalDataDir(true); //add final '/' or '\'
 		if( ! url.StartsWith(parentDir) )
 			url = parentDir + url;
 
 		return url;
 	}
 	public static string MakeURLrelative(string url) {
-		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		string parentDir = Util.GetLocalDataDir(true); //add final '/' or '\'
 		if( url.StartsWith(parentDir) )
 			url = url.Replace(parentDir, "");
 
@@ -987,6 +984,7 @@ public class Util
 
 	/********** end of LocalApplicationData path ************/
 	
+
 	/********** start of database paths ************/
 
 	public static string GetReallyOldDatabaseDir() {
@@ -1005,9 +1003,8 @@ public class Util
 	public static string GetDatabaseDir() {
 		//fixing:
 		//http://lists.ximian.com/pipermail/mono-list/2008-November/040480.html
-		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "database");
+		return Path.Combine (
+				GetLocalDataDir (false) + Path.DirectorySeparatorChar + "database");
 	}
 	
 	//if database dir has illegal characters, use this temp dir and remember to copy db at end, or to restore if chrashed
@@ -1034,8 +1031,7 @@ public class Util
 
 	public static string GetMultimediaDir() {
 		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "multimedia");
+				GetLocalDataDir (false) + Path.DirectorySeparatorChar + "multimedia");
 	}
 	
 	public static string GetPhotosDir(bool small) {
@@ -1044,15 +1040,15 @@ public class Util
 			smallDir = Path.DirectorySeparatorChar + Constants.SmallPhotoDir; 
 
 		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "multimedia" +
+				GetLocalDataDir (false) +
+				Path.DirectorySeparatorChar + "multimedia" +
 				Path.DirectorySeparatorChar + "photos") + smallDir;
 	}
 	
 	public static string GetVideosDir() {
 		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "multimedia" +
+				GetLocalDataDir (false) +
+				Path.DirectorySeparatorChar + "multimedia" +
 				Path.DirectorySeparatorChar + "videos");
 	}
 	
@@ -1076,8 +1072,8 @@ public class Util
 	public static string GetForceSensorDir()
 	{
 		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "forceSensor");
+				GetLocalDataDir (false) +
+				Path.DirectorySeparatorChar + "forceSensor");
 	}
 	public static void CreateForceSensorDirIfNeeded ()
 	{
@@ -1114,8 +1110,8 @@ public class Util
 	public static string GetRunEncoderDir()
 	{
 		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "raceAnalyzer");
+				GetLocalDataDir (false) +
+				Path.DirectorySeparatorChar + "raceAnalyzer");
 	}
 	public static void CreateRunEncoderDirIfNeeded ()
 	{
@@ -1306,7 +1302,7 @@ public class Util
 	/********** end of multimedia paths ************/
 	
 	public static string GetThemeDir() {
-		return Path.Combine(GetDataDir(), "theme");
+		return Path.Combine(GetChronojumpDir (), "theme");
 	}
 	public static string GetThemeFile() {
 		return Path.Combine(GetThemeDir(), "gtk-2.0" + Path.DirectorySeparatorChar + "gtkrc");
@@ -1369,17 +1365,19 @@ public class Util
 		return baseDirectory;
 	}
 
-	public static string GetDataDir(){
+	public static string GetChronojumpDir ()
+	{
 		return System.IO.Path.Combine(GetPrefixDir(),
 			"share" + Path.DirectorySeparatorChar + "chronojump");
 	}
 
-	public static string GetImagesDir(){
-		return System.IO.Path.Combine(GetDataDir(),"images");
+	public static string GetImagesDir ()
+	{
+		return System.IO.Path.Combine (GetChronojumpDir (),"images");
 	}
 
 	public static string GetCssDir(){
-		return GetDataDir();
+		return GetChronojumpDir( );
 	}
 
 	//currently sounds are inside images folder	
@@ -1443,7 +1441,7 @@ public class Util
 	//TODO: maybe this will need a thread
 	public static int GetFullDataSize (bool includingOldBackupsDir)
 	{
-		long fullDataSize = DirSizeWithSubdirs (new DirectoryInfo(GetParentDir(false)));
+		long fullDataSize = DirSizeWithSubdirs (new DirectoryInfo( GetLocalDataDir(false)));
 		int sizeInKB = (int) UtilAll.DivideSafe(fullDataSize, 1024);
 
 		if(! includingOldBackupsDir)
@@ -1491,6 +1489,22 @@ public class Util
 		return false;
 	}
 	
+	public static bool DirectoryDelete (string fileName)
+	{
+		LogB.Information("Checking if this directory exists: " + fileName);
+		try {
+			if(Directory.Exists (fileName)) {
+				LogB.Information ("Deleting " + fileName + " ...");
+				Directory.Delete (fileName, true); //recursive
+				LogB.Information ("Deleted");
+				return true;
+			}
+		} catch {
+			LogB.Error ("Problem deleting");
+		}
+		return false;
+	}
+
 	public static bool FileMove(string path, string filenameOrigin, string filenameDestination)
 	{
 		LogB.Information(string.Format("Going to move: {0} to {1}",
@@ -1511,6 +1525,10 @@ public class Util
 		return false;
 	}
 	
+	public static bool DirectoryExists(string dirName){
+		return Directory.Exists(dirName);
+	}
+
 	public static bool FileExists(string fileName){
 		return File.Exists(fileName);
 	}
@@ -1820,7 +1838,7 @@ public class Util
 	static int soundListPos;
 
 	public static string getSoundsFileName() {
-		return Path.Combine(UtilAll.GetApplicationDataDir() +  Path.DirectorySeparatorChar + "sounds.txt");
+		return Path.Combine(Util.GetLocalDataDir (false) +  Path.DirectorySeparatorChar + "sounds.txt");
 	}
 
 	public static void CreateSoundList()
@@ -1915,33 +1933,47 @@ public class Util
 
 		
 	//do this for showing the Limited with selected decimals and without loosing the end letter: 'J' or 'T'
-	//called by treeview_jump, treeview_run and gui/jump_edit and gui/run_edit?
-	public static string GetLimitedRounded(string limitedString, int pDN)
+	//called by treeview_jump, treeview_run and gui/jump_edit and gui/run_edit
+	public static string GetLimitedRounded (string limitedString, int pDN)
 	{
 		LogB.Information("GetLimitedRounded limitedString pdN");
 		LogB.Information(limitedString);
 		LogB.Information(pDN.ToString());
 
 		string myLimitedWithoutLetter = limitedString.Substring(0, limitedString.Length -1);
+
 		string myLimitedLetter = limitedString.Substring(limitedString.Length -1, 1);
 
-		return TrimDecimals(myLimitedWithoutLetter, pDN) + myLimitedLetter;
+		//without the letter, use jumps, tracks or seconds
+		string myLimiter = " " + Constants.jumpsTranslatedStr (); //("J")
+		if (myLimitedLetter == "R")
+			myLimiter = " " + Constants.tracksTranslatedStr ();
+		if (myLimitedLetter == "T")
+			myLimiter = " s";
+
+		return TrimDecimals(myLimitedWithoutLetter, pDN) + myLimiter;
 	}
 
-	public static string [] AddArrayString(string [] initialString, string [] addString) {
-		string [] returnString = new string[initialString.Length + addString.Length];
-		int i;
-		int j;
+	public static string [] AddToArrayString (string [] initialString, List<string> add_l)
+	{
+		string [] returnString = new string[initialString.Length + add_l.Count];
+		int i, j;
 		for (i=0 ; i < initialString.Length; i ++)
 			returnString[i] = initialString[i];
-		for (j=0 ; j < addString.Length; j ++)
-			returnString[i+j] = addString[j];
+		for (j=0 ; j < add_l.Count; j ++)
+			returnString[i+j] = add_l[j];
 
 		return returnString;
 	}
 
+	public static string [] AddArrayString (string [] initialString, string [] addString)
+	{
+		return UtilAll.AddArrayString (initialString, addString);
+	}
+
 	//bool firstOrLast: true means first
-	public static string [] AddArrayString(string [] initialString, string addString, bool firstOrLast) {
+	public static string [] AddArrayString (string [] initialString, string addString, bool firstOrLast)
+	{
 		string [] returnString = new string[initialString.Length + 1];
 
 		int i;
@@ -2154,7 +2186,15 @@ public class Util
 		}
 		return uniqueString;
 	}
+
+	public static List<string> StringArrayToListString (string [] arrayString)
+	{
+		List<string> str_l = new List<string> ();
+		foreach (string myStr in arrayString)
+			str_l.Add (myStr);
 	
+		return str_l;
+	}
 	
 	//to create an string [] of one member
 	public static string [] StringToStringArray (string str) {
@@ -2548,8 +2588,27 @@ public class Util
 			LogB.Error("Couldn't Insert text at the beginning of File");
 		}
 	}
+
+	//used on export where we just want to copy the dirs without updating gui objects
+	//https://stackoverflow.com/a/3822913
+	public static void CopyFilesRecursively(string sourcePath, string targetPath)
+	{
+		//Now Create all of the directories
+		foreach (string dirPath in Directory.GetDirectories(sourcePath, "*", SearchOption.AllDirectories))
+		{
+			Directory.CreateDirectory(dirPath.Replace(sourcePath, targetPath));
+		}
+
+		//Copy all the files & Replaces any files with the same name
+		foreach (string newPath in Directory.GetFiles(sourcePath, "*.*",SearchOption.AllDirectories))
+		{
+			File.Copy(newPath, newPath.Replace(sourcePath, targetPath), true);
+		}
+	}
+
 }
 
+//used on backup
 public class UtilCopy
 {
 	public int BackupMainDirsCount;
