@@ -100,20 +100,49 @@ public class UtilAll
 		}
 	}
 	
-	
+
+	/*
 	public static string GetApplicationDataDir() {
 		return Path.Combine(
 				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
 				"Chronojump");
 	}
-	
-	public static string GetConfigFileName() {
-		return Path.Combine(GetApplicationDataDir() +  Path.DirectorySeparatorChar + Constants.FileNameConfig);
-	}
-	public static string GetECapSimSignalFileName() {
-		return Path.Combine(GetApplicationDataDir() +  Path.DirectorySeparatorChar + "eCapSimSignal.txt");
+	*/
+	//if withFinalSeparator, then return a '\' or '/' at the end
+	public static string GetDefaultLocalDataDir (bool withFinalSeparator)
+	{
+		string path = Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump");
+
+		if(withFinalSeparator)
+			path += Path.DirectorySeparatorChar;
+
+		return path;
 	}
+
+	// ----------- logs -----------------------
 	
+	public static string GetLogsDir() {
+		return Path.Combine(
+				GetDefaultLocalDataDir (false) + Path.DirectorySeparatorChar + "logs");
+	}
+	public static string GetLogFileCurrent() {
+		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLog);
+	}
+	public static string GetLogFileOld() {
+		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLogOld);
+	}
+
+	public static string GetLogsCrashedDir() {
+		return Path.Combine(
+				GetDefaultLocalDataDir (false) + Path.DirectorySeparatorChar + "logs" +
+				Path.DirectorySeparatorChar + "crashed");
+	}
+	public static string GetLogCrashedFileTimeStamp() {
+		return Path.Combine(GetLogsCrashedDir() +  Path.DirectorySeparatorChar +
+				"crashed_log_" + UtilDate.ToFile(DateTime.Now) + ".txt");
+	}
 	
 	
 	public static string DetectPortsLinux(bool formatting) {
@@ -156,31 +185,6 @@ public class UtilAll
 		return str;
 	}
 
-	// ----------- logs -----------------------
-	
-	public static string GetLogsDir() {
-		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "logs");
-	}
-	public static string GetLogFileCurrent() {
-		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLog);
-	}
-	public static string GetLogFileOld() {
-		return Path.Combine(GetLogsDir() +  Path.DirectorySeparatorChar + Constants.FileNameLogOld);
-	}
-
-	public static string GetLogsCrashedDir() {
-		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "logs" +
-				Path.DirectorySeparatorChar + "crashed");
-	}
-	public static string GetLogCrashedFileTimeStamp() {
-		return Path.Combine(GetLogsCrashedDir() +  Path.DirectorySeparatorChar +
-				"crashed_log_" + UtilDate.ToFile(DateTime.Now) + ".txt");
-	}
-
 
 	public static string GetTempDir() {
 		string path = Path.GetTempPath();
@@ -227,5 +231,19 @@ public class UtilAll
 		return Convert.ToInt32(DivideSafe(val1, val2));
 	}
 
+	//here to be able to be called from chronojumpMini
+	public static string [] AddArrayString(string [] initialString, string [] addString)
+	{
+		string [] returnString = new string[initialString.Length + addString.Length];
+		int i;
+		int j;
+		for (i=0 ; i < initialString.Length; i ++)
+			returnString[i] = initialString[i];
+		for (j=0 ; j < addString.Length; j ++)
+			returnString[i+j] = addString[j];
+
+		return returnString;
+	}
+
 
 }
