@@ -16,7 +16,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *  Copyright (C) 2016, 2019   Xavier Padullés <x.padulles@gmail.com>
- *  Copyright (C) 2016-2017, 2019-2020   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2016-2017, 2019-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -523,6 +523,20 @@ public class MovingAverage
 
 		//tested with LibreOffice Calc, works as expected
 	}
+
+	//the smoothed list
+	public List<PointF> MovingAverage_l {
+		get { return movingAverage_l; }
+	}
+	public List<double> MovingAverage_l_Y {
+		get {
+			List<double> d_l = new List<double> ();
+			foreach (PointF p in movingAverage_l)
+				d_l.Add (p.Y);
+
+			return d_l;
+		}
+	}
 }
 
 public static class MathCJ
@@ -609,6 +623,40 @@ public static class MathUtil
 
 		return max;
 	}
+	public static double GetMin (List<double> d_l)
+	{
+		double min = 1000000;
+		foreach (double d in d_l)
+			if ( d < min )
+				min = d;
+
+		return min;
+	}
+
+	public static double GetProportion (double d, double min, double max)
+	{
+		d -= min;
+		max -= min;
+		return UtilAll.DivideSafe(d, max);
+	}
+
+	/*
+	   on raceAnalyzer we want a proportion of a value between a list of values, and we want 0 is included.
+	   Maybe in that list the min is above 0, so shouldInclude0 fixes it
+	   */
+	public static double GetProportion (double d, List<double> d_l, bool shouldInclude0)
+	{
+		double max = GetMax (d_l);
+		double min = GetMin (d_l);
+
+		if (shouldInclude0 && min > 0)
+			min = 0;
+
+		// move d and max to min
+		d -= min;
+		max -= min;
+		return UtilAll.DivideSafe(d, max);
+	}
 
 }
 
